=== modified file 'AUTHORS'
--- AUTHORS	2011-11-29 10:06:50 +0000
+++ AUTHORS	2010-05-25 17:09:02 +0000
@@ -18,5 +18,3 @@
 
 Numerous other people have contributed useful patches.  See the Bazaar history 
 of this branch for a full list of authors.
-
-Curtis Hovey converted bzr-gtk to pygi and Gtk3.

=== modified file 'NEWS'
--- NEWS	2012-07-09 15:23:26 +0000
+++ NEWS	2011-06-17 12:54:05 +0000
@@ -1,25 +1,4 @@
-0.104.0	UNRELEASED
-
- BUG FIXES
-
-  * Fix compatibility with newer versions of gir-gtk which don't allow
-    None in STRING columns of ListStores. (Jelmer Vernooij)
-
-  * Properly handle popup menus when there is no selected revision in
-    "bzr viz". (Jelmer Vernooij, #281717)
-
-  * Ignore bzr-handle-patch.desktop in sofware center.
-    (Jelmer Vernooij, #854245)
-
-  * Fix searching in tree views. (Jelmer Vernooij, #928301)
-
- CHANGES
-
-  * bzr-notify has been removed, as it was causing regressions
-    on several machines and not particularly useful.
-    (Jelmer Vernooij, #714767, #949798, #998994, #342135, #342136, #394536)
-
-0.103.0	2011-12-11
+0.101.0	UNRELEASED
 
  FEATURES
 
@@ -35,22 +14,11 @@
     interactive search for revision numbers continues to work.
     (Sergei Golubchik)
 
-  * Switch to gtk3. The old gtk2 branch is still available as lp:bzr-gtk/gtk2. (Curtis Hovey)
-
-  * Remove keyring support - this is broken for GTK3, and replaced by a DBus service
-    that is not specific to GNOME. Instead, bzr or bzr-dbus will provide support
-    for this service. (Jelmer Vernooij)
-
  BUG FIXES
 
   * Ensure config directory exists before writing configuration.
     (Jelmer Vernooij, #231150)
 
-  * Mark as supporting bzr 2.5.0. (Jelmer Vernooij)
-
-  * Add X-GNOME-Autostart-Delay=30 to bzr-notify.desktop.
-    (Mikkel Kamstrup Erlandsen, #861201)
-
 0.100.0	2011-03-02
 
  BUG FIXES

=== modified file '__init__.py'
--- __init__.py	2012-03-16 17:28:20 +0000
+++ __init__.py	2011-07-31 16:50:29 +0000
@@ -33,8 +33,6 @@
 visualise         Graphically visualise this branch.
 """
 
-from __future__ import absolute_import
-
 import os
 import sys
 
@@ -53,9 +51,14 @@
 
 import bzrlib
 import bzrlib.api
+from bzrlib import (
+    branch,
+    config,
+    errors,
+    )
 from bzrlib.commands import plugin_cmds
 
-from bzrlib.plugins.gtk.info import (
+from info import (
     bzr_plugin_version as version_info,
     bzr_compatible_versions,
     )
@@ -74,7 +77,7 @@
 
 
 def set_ui_factory():
-    from bzrlib.plugins.gtk.ui import GtkUIFactory
+    from ui import GtkUIFactory
     import bzrlib.ui
     bzrlib.ui.ui_factory = GtkUIFactory()
 
@@ -127,32 +130,24 @@
                               "bzrlib.plugins.gtk.commands")
 
 def save_commit_messages(*args):
-    from bzrlib.plugins.gtk import commitmsgs
-    commitmsgs.save_commit_messages(*args)
-
-try:
-    from bzrlib.hooks import install_lazy_named_hook
-except ImportError:
-    from bzrlib.branch import Branch
-    Branch.hooks.install_named_hook('post_uncommit',
-                                    save_commit_messages,
-                                    "Saving commit messages for gcommit")
-else:
-    install_lazy_named_hook("bzrlib.branch", "Branch.hooks",
-        'post_uncommit', save_commit_messages, "Saving commit messages for gcommit")
-
-try:
-    from bzrlib.registry import register_lazy
-except ImportError:
-    from bzrlib import config
-    option_registry = getattr(config, "option_registry", None)
-    if option_registry is not None:
-        config.option_registry.register_lazy('nautilus_integration',
-                'bzrlib.plugins.gtk.config', 'opt_nautilus_integration')
-else:
-    register_lazy("bzrlib.config", "option_registry",
-        'nautilus_integration', 'bzrlib.plugins.gtk.config',
-        'opt_nautilus_integration')
+    from bzrlib.plugins.gtk import commit
+    commit.save_commit_messages(*args)
+
+branch.Branch.hooks.install_named_hook('post_uncommit',
+                                       save_commit_messages,
+                                       "Saving commit messages for gcommit")
+
+credential_store_registry = getattr(config, "credential_store_registry", None)
+if credential_store_registry is not None:
+    try:
+        credential_store_registry.register_lazy(
+            "gnome-keyring", "bzrlib.plugins.gtk.keyring", "GnomeKeyringCredentialStore",
+            help="The GNOME Keyring.", fallback=True)
+    except TypeError:
+    # Fallback credentials stores were introduced in Bazaar 1.15
+        credential_store_registry.register_lazy(
+            "gnome-keyring", "bzrlib.plugins.gtk.keyring", "GnomeKeyringCredentialStore",
+            help="The GNOME Keyring.")
 
 
 def load_tests(basic_tests, module, loader):

=== modified file 'annotate/colormap.py'
--- annotate/colormap.py	2011-09-05 03:44:26 +0000
+++ annotate/colormap.py	2011-03-14 20:12:19 +0000
@@ -14,12 +14,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__metaclass__ = type
-
 import sys
 
-
-class AnnotateColorMap:
+class AnnotateColorMap(object):
 
     really_old_color = "#0046FF"
 
@@ -65,10 +62,9 @@
 
         return color
 
-
 class AnnotateColorSaturation(AnnotateColorMap):
     def __init__(self, span=340.):
-        super(AnnotateColorSaturation, self).__init__(span)
+        AnnotateColorMap.__init__(self, span)
         self.current_angle = 0
 
     def hue(self, angle):

=== modified file 'annotate/config.py'
--- annotate/config.py	2012-02-09 02:55:06 +0000
+++ annotate/config.py	2011-08-12 22:58:29 +0000
@@ -38,7 +38,7 @@
     """
 
     def __init__(self, window):
-        super(GAnnotateConfig, self).__init__(gannotate_config_filename())
+        configobj.ConfigObj.__init__(self, gannotate_config_filename())
         self.window = window
         self.pane = window.pane
 
@@ -62,8 +62,7 @@
         self.pane.set_position(self['window'].as_int('pane_position'))
         self.window.set_default_size(self['window'].as_int('width'),
                                      self['window'].as_int('height'))
-        self.window.move(
-            self['window'].as_int('x'), self['window'].as_int('y'))
+        self.window.move(self['window'].as_int('x'), self['window'].as_int('y'))
 
         if self['window'].as_bool('maximized'):
             self.window.maximize()
@@ -72,6 +71,7 @@
         self.window.connect("destroy", self._write)
         self.window.connect("configure-event", self._save_window_props)
         self.window.connect("window-state-event", self._save_window_props)
+        self.pane.connect("notify", self._save_pane_props)
 
     def _save_window_props(self, w, e, *args):
         if e.window.get_state() & Gdk.WindowState.MAXIMIZED:
@@ -83,11 +83,14 @@
         self["window"]["maximized"] = maximized
         return False
 
-    def _save_pane_props(self):
-        self["window"]["pane_position"] = self.pane.get_position()
+    def _save_pane_props(self, w, gparam):
+        if gparam.name == "position":
+            self["window"]["pane_position"] = w.get_position()
+
+        return False
 
     def _write(self, *args):
-        self._save_pane_props()
         config.ensure_config_dir_exists()
         self.write()
         return False
+

=== modified file 'annotate/gannotate.py'
--- annotate/gannotate.py	2012-03-11 18:24:06 +0000
+++ annotate/gannotate.py	2011-08-27 15:31:00 +0000
@@ -27,7 +27,6 @@
 from bzrlib.revision import NULL_REVISION, CURRENT_REVISION
 
 from bzrlib.plugins.gtk.annotate.colormap import AnnotateColorSaturation
-from bzrlib.plugins.gtk.i18n import _i18n
 from bzrlib.plugins.gtk.revisionview import RevisionView
 from bzrlib.plugins.gtk.window import Window
 
@@ -50,7 +49,7 @@
         self.plain = plain
         self._branch = branch
 
-        super(GAnnotateWindow, self).__init__(parent=parent)
+        Window.__init__(self, parent)
 
         self.set_icon(
             self.render_icon_pixbuf(Gtk.STOCK_FIND, Gtk.IconSize.BUTTON))
@@ -134,6 +133,7 @@
         self.annoview.set_cursor(tree_path, None, False)
         self.annoview.scroll_to_cell(tree_path, use_align=True)
 
+
     def _annotate(self, tree, file_id):
         current_revision = FakeRevision(CURRENT_REVISION)
         current_revision.committer = self.branch.get_config().username()
@@ -221,7 +221,7 @@
         hbox.show()
         vbox.pack_start(hbox, False, True, 0)
 
-        self.pane = pane = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        self.pane = pane = Gtk.VPaned()
         pane.add1(swbox)
         pane.add2(self.revisionview)
         pane.show()
@@ -457,11 +457,10 @@
             self.__cache[revision_id] = revision
         return self.__cache[revision_id]
 
-
 class SearchBox(Gtk.HBox):
     """A button box for searching in text or lines of annotations"""
     def __init__(self):
-        super(SearchBox, self).__init__(homogeneous=False, spacing=6)
+        Gtk.HBox.__init__(self, homogeneous=False, spacing=6)
 
         # Close button
         button = Gtk.Button()
@@ -484,7 +483,7 @@
         self.pack_start(entry, False, False, 0)
 
         # Next/previous buttons
-        button = Gtk.Button(_i18n('_Next'), use_underline=True)
+        button = Gtk.Button('_Next')
         image = Gtk.Image()
         image.set_from_stock('gtk-go-forward', Gtk.IconSize.BUTTON)
         button.set_image(image)
@@ -492,7 +491,7 @@
                        'forward')
         self.pack_start(button, False, False, 0)
 
-        button = Gtk.Button(_i18n('_Previous'), use_underline=True)
+        button = Gtk.Button('_Previous')
         image = Gtk.Image()
         image.set_from_stock('gtk-go-back', Gtk.IconSize.BUTTON)
         button.set_image(image)

=== modified file 'annotate/spanselector.py'
--- annotate/spanselector.py	2011-09-05 03:44:26 +0000
+++ annotate/spanselector.py	2011-08-27 18:03:04 +0000
@@ -39,8 +39,7 @@
     last_selected = None
 
     def __init__(self, homogeneous=False, spacing=6):
-        super(SpanSelector, self).__init__(
-            homogeneous=homogeneous, spacing=spacing)
+        GObject.GObject.__init__(self, homogeneous, spacing)
 
         self.model = self._create_model()
         self.combo = self._create_combobox(self.model)

=== modified file 'avatarproviders.py'
--- avatarproviders.py	2011-10-30 08:07:30 +0000
+++ avatarproviders.py	2011-04-06 14:50:40 +0000
@@ -46,68 +46,45 @@
 
     def __init__(self, provider_method):
         """Constructor
-
+        
         :param provider_method: Provider method that returns fields
                  to send with the request.
         """
         threading.Thread.__init__(self)
         self.__stop = threading.Event()
         self.__queue = Queue.Queue()
+
         self.__provider_method = provider_method
-        self.__callback_method = None
-        self.__error_method = None
+        self.__end_thread = False
 
     def stop(self):
         """ Stop this worker """
+        self.__end_thread = True
         self.__stop.set()
-        while self.__queue.qsize() > 0:
-            self.__queue.get_nowait()
-            self.__queue.task_done()
-        self.__queue.join()
-
-    @property
-    def is_running(self):
-        return not self.__stop.is_set()
 
     def set_callback_method(self, method):
-        """Fire the given callback method when treatment is finished."""
+        """ Fire the given callback method when treatment is finished """
         self.__callback_method = method
 
-    def set_error_method(self, method):
-        """Fire the given callback when retrieving a avatar fails."""
-        self.__error_method = method
-
     def queue(self, id_field):
         """Put in Queue the id_field to treat in the thread.
 
         This id_field is for example with Gravatar the email address.
         """
-        if self.is_running:
-            self.__queue.put(id_field)
-            if not self.is_alive():
-                self.start()
+        self.__queue.put(id_field)
 
     def run(self):
         """Worker core code. """
-        while self.is_running:
-            try:
-                id_field = self.__queue.get_nowait()
-                # Call provider method to get fields to pass in the request
-                url = self.__provider_method(id_field)
-                # Execute the request
-                try:
-                    response = urllib2.urlopen(url)
-                except urllib2.URLError, e:
-                    if self.__error_method is not None:
-                        self.__error_method(e)
-                else:
-                    # Fire the callback method
-                    if not self.__callback_method is None:
-                        self.__callback_method(response, id_field)
-                self.__queue.task_done()
-            except Queue.Empty:
-                # There is no more work to do.
-                pass
+        while not self.__end_thread:
+            id_field = self.__queue.get()
+            # Call provider method to get fields to pass in the request
+            url = self.__provider_method(id_field)
+            # Execute the request
+            response = urllib2.urlopen(url)
+            # Fire the callback method
+            if not self.__callback_method is None:
+                self.__callback_method(response, id_field)
+            self.__queue.task_done()
 
 
 class AvatarProviderGravatar(AvatarProvider):
@@ -120,6 +97,6 @@
         """Return a gravatar URL for an email address.."""
         return self.get_base_url() + \
                 urllib.urlencode({
-                    'gravatar_id': hashlib.md5(email.lower()).hexdigest(),
-                    'size': str(self.size)
+                    'gravatar_id':hashlib.md5(email.lower()).hexdigest(),
+                    'size':str(self.size)
                 })

=== modified file 'avatarsbox.py'
--- avatarsbox.py	2011-09-05 03:44:26 +0000
+++ avatarsbox.py	2011-08-27 18:35:08 +0000
@@ -31,7 +31,7 @@
 
     def __init__(self, apparent_username):
         """ Constructor """
-        super(Avatar, self).__init__()
+        Gtk.HBox.__init__(self)
 
         self.apparent_username = apparent_username
         self.username, self.email = parse_username(apparent_username)
@@ -65,9 +65,7 @@
     def show_image(self):
         """Replace the current content of the Avatar with the Gtk.Image """
         if self.email and self.image:
-            children = self.get_children()
-            if children != []:
-                self.remove(children[0])
+            self.remove(self.get_children()[0])
             self.pack_start(self.image, True, True, 0)
             self.image.set_tooltip_text(self.apparent_username)
             self.image.show()
@@ -77,8 +75,7 @@
     """HBox showing an avatar."""
 
     def __init__(self, homogeneous=False, spacing=0):
-        super(AvatarBox, self).__init__(
-            homogeneous=homogeneous, spacing=spacing)
+        Gtk.HBox.__init__(self, homogeneous=homogeneous, spacing=spacing)
         self.__avatars = {}
         self.avatar = None
         self.__displaying = None
@@ -150,7 +147,7 @@
         self.__displaying = avatar
 
     def _show_no_email(self):
-        """Show a Gtk.Label with text 'No email'."""
+        """Show a Gtk.Label with test 'No email'."""
         no_email = Gtk.Label(label=_i18n("No email"))
         self.pack_start(no_email, True, True, 0)
         no_email.show()
@@ -160,7 +157,8 @@
     """GTK container for author and committer avatars."""
 
     def __init__(self):
-        super(AvatarsBox, self).__init__(homogeneous=False, spacing=10)
+        Gtk.HBox.__init__(self, homogeneous=False, spacing=10)
+
         self.__committer_box = None
         self.__authors_box = None
         self._init_gui()
@@ -181,19 +179,13 @@
         # This callback method should be fired by all workers when a request
         # is done.
         self.__worker.set_callback_method(self._update_avatar_from_response)
-        self.connect('destroy', self.on_destroy)
-
-    def on_destroy(self, widget):
-        self.__worker.stop()
-        if self.__worker.is_alive():
-            self.__worker.join()
+        self.__worker.start()
 
     def add(self, username, role):
         """Add the given username in the role box and add in the worker queue.
         """
         avatar = Avatar(username)
-        is_shown = self._role_box_for("committer").showing(avatar)
-        if (role == "author" and not is_shown) or role == "committer":
+        if (role == "author" and not self._role_box_for("committer").showing(avatar)) or role == "committer":
             if self._role_box_for(role).append_avatars_with(avatar):
                 self.__worker.queue(avatar.email)
 
@@ -237,8 +229,7 @@
             loader.close()
 
             for role in ["committer", "author"]:
-                self._role_box_for(role).and_avatar_email(
-                    email).update_avatar_image_from_pixbuf_loader(loader)
+                self._role_box_for(role).and_avatar_email(email).update_avatar_image_from_pixbuf_loader(loader)
 
     def _role_box_for(self, role):
         """ Return the Gtk.HBox for the given role """

=== modified file 'branch.py'
--- branch.py	2011-09-05 03:44:26 +0000
+++ branch.py	2011-08-01 14:46:23 +0000
@@ -16,6 +16,7 @@
 
 import os
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from bzrlib import (
@@ -35,9 +36,10 @@
 
     def __init__(self, path=None, parent=None, remote_path=None):
         """ Initialize the Branch dialog. """
-        super(BranchDialog, self).__init__(
-            title="Branch - Olive", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Branch - Olive",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
 
         # Get arguments
         self.path = path
@@ -83,20 +85,20 @@
         self._label_revision.set_alignment(0, 0.5)
         self._table.set_row_spacings(3)
         self._table.set_col_spacings(3)
-        self.get_content_area().set_spacing(3)
+        self.vbox.set_spacing(3)
         if remote_path is not None:
             self._remote_branch.set_url(remote_path)
         if self.path is not None:
             self._filechooser.set_filename(self.path)
 
         # Pack some widgets
-        self._hbox_revision.pack_start(self._entry_revision, True, True, 0)
-        self._hbox_revision.pack_start(self._button_revision, False, False, 0)
-        self.get_content_area().add(self._table)
-        self.action_area.pack_end(self._button_branch, False, False, 0)
+        self._hbox_revision.pack_start(self._entry_revision, True, True)
+        self._hbox_revision.pack_start(self._button_revision, False, False)
+        self.vbox.add(self._table)
+        self.action_area.pack_end(self._button_branch)
 
         # Show the dialog
-        self.get_content_area().show_all()
+        self.vbox.show_all()
 
     def _get_last_revno(self):
         """ Get the revno of the last revision (if any). """

=== modified file 'branchbox.py'
--- branchbox.py	2011-09-05 03:44:26 +0000
+++ branchbox.py	2011-08-13 01:28:20 +0000
@@ -22,14 +22,12 @@
 
 from bzrlib.plugins.gtk.history import UrlHistory
 
-
 class BranchSelectionBox(Gtk.HBox):
 
     def __init__(self, path=None):
-        super(BranchSelectionBox, self).__init__()
+        Gtk.HBox.__init__(self)
         self._combo = Gtk.ComboBox.new_with_entry()
-        self._combo.get_child().connect(
-            'focus-out-event', self._on_combo_changed)
+        self._combo.get_child().connect('focus-out-event', self._on_combo_changed)
 
         # Build branch history
         self._history = UrlHistory(GlobalConfig(), 'branch_history')
@@ -62,7 +60,6 @@
     def _on_combo_changed(self, widget, event):
         self.emit('branch-changed', widget)
 
-
 GObject.signal_new('branch-changed', BranchSelectionBox,
                    GObject.SignalFlags.RUN_LAST,
                    None, (GObject.TYPE_OBJECT,))

=== modified file 'branchview/graphcell.py'
--- branchview/graphcell.py	2011-09-07 16:01:14 +0000
+++ branchview/graphcell.py	2011-08-27 20:13:10 +0000
@@ -10,7 +10,7 @@
 just be for the background.
 """
 
-__copyright__ = "Copyright © 2005-2011 Canonical Ltd."
+__copyright__ = "Copyright © 2005 Canonical Ltd."
 __author__    = "Scott James Remnant <scott@ubuntu.com>"
 
 
@@ -19,25 +19,10 @@
 from gi.repository import Gtk
 from gi.repository import GObject
 from gi.repository import Pango
-from gi.repository import PangoCairo
-
-
-# Cairo constants are not exported yet. These are taken from documentation.
-CAIRO_LINE_CAP_BUTT = 0
-CAIRO_LINE_CAP_ROUND = 1
-CAIRO_LINE_CAP_SQUARE = 2
-
-
-CAIRO_FILL_RULE_WINDING = 0
-CAIRO_FILL_RULE_EVEN_ODD = 1
-
-
-# Macro from  Pango header.
-def PANGO_PIXELS(d):
-    return (d + 512) / 1000
-
-
-class CellRendererGraph(Gtk.CellRendererPixbuf):
+from gi.repository import cairo
+
+
+class CellRendererGraph(Gtk.CellRenderer):
     """Cell renderer for directed graph.
 
     Properties:
@@ -92,8 +77,14 @@
             pango_ctx = widget.get_pango_context()
             font_desc = widget.get_style().font_desc
             metrics = pango_ctx.get_metrics(font_desc, None)
+
+            def PANGO_PIXELS(d):
+                # Macro from  Pango header.
+                return (d + 512) / 1000
+
             ascent = PANGO_PIXELS(metrics.get_ascent())
             descent = PANGO_PIXELS(metrics.get_descent())
+
             self._box_size = ascent + descent + 6
             return self._box_size
 
@@ -126,15 +117,7 @@
 
         ctx.set_source_rgb(red, green, blue)
 
-    def do_activate(event, widget, path, bg_area, cell_area, flags):
-        """Renderers cannot be activated; always return True."""
-        return True
-
-    def do_editing_started(event, widget, path, fb_area, cell_area, flags):
-        """Renderers cannot be edited; always return None."""
-        return None
-
-    def do_get_size(self, widget, cell_area):
+    def on_get_size(self, widget, cell_area):
         """Return the size we need for this cell.
 
         Each cell is drawn individually and is only as wide as it needs
@@ -149,7 +132,7 @@
         # FIXME I have no idea how to use cell_area properly
         return (0, 0, width, height)
 
-    def do_render(self, ctx, widget, bg_area, cell_area, flags):
+    def on_render(self, window, widget, bg_area, cell_area, exp_area, flags):
         """Render an individual cell.
 
         Draws the cell contents using cairo, taking care to clip what we
@@ -163,6 +146,7 @@
         instead of a pure diagonal ... this reduces confusion by an
         incredible amount.
         """
+        ctx = window.cairo_create()
         ctx.rectangle(bg_area.x, bg_area.y, bg_area.width, bg_area.height)
         ctx.clip()
 
@@ -188,7 +172,7 @@
                 cell_area.y + cell_area.height / 2,
                 box_size / 4, 0, 2 * math.pi)
 
-        if flags & Gtk.CellRendererState.SELECTED:
+        if flags & Gtk.CELL_RENDERER_SELECTED:
             ctx.set_source_rgb(1.0, 1.0, 1.0)
             ctx.set_line_width(box_size / 4)
             ctx.stroke_preserve()
@@ -202,10 +186,9 @@
 
         self.render_tags(ctx, widget.create_pango_context(), cell_area, box_size)
 
-    def render_line(self, ctx, cell_area, box_size,
-                    mid, height, start, end, colour, flags):
+    def render_line(self, ctx, cell_area, box_size, mid, height, start, end, colour, flags):
         if start is None:
-            ctx.set_line_cap(CAIRO_LINE_CAP_ROUND)
+            ctx.set_line_cap(cairo.LINE_CAP_ROUND)
             x = cell_area.x + box_size * end + box_size / 2
             ctx.move_to(x, mid + height / 3)
             ctx.line_to(x, mid + height / 3)
@@ -213,7 +196,7 @@
             ctx.line_to(x, mid + height / 6)
 
         elif end is None:
-            ctx.set_line_cap(CAIRO_LINE_CAP_ROUND)
+            ctx.set_line_cap(cairo.LINE_CAP_ROUND)
             x = cell_area.x + box_size * start + box_size / 2
             ctx.move_to(x, mid - height / 3)
             ctx.line_to(x, mid - height / 3)
@@ -221,7 +204,7 @@
             ctx.line_to(x, mid - height / 6)
 
         else:
-            ctx.set_line_cap(CAIRO_LINE_CAP_BUTT)
+            ctx.set_line_cap(cairo.LINE_CAP_BUTT)
             startx = cell_area.x + box_size * start + box_size / 2
             endx = cell_area.x + box_size * end + box_size / 2
 
@@ -238,7 +221,7 @@
                              endx, mid + height / 5 ,
                              endx, mid + height / 2 + 1)
 
-        if flags & Gtk.CellRendererState.SELECTED:
+        if flags & Gtk.CELL_RENDERER_SELECTED:
             ctx.set_source_rgb(1.0, 1.0, 1.0)
             ctx.set_line_width(box_size / 5)
             ctx.stroke_preserve()
@@ -264,7 +247,7 @@
         width = 0
 
         for tag_idx, tag in enumerate(self.tags):
-            tag_layout.set_text(" " + tag + " ", -1)
+            tag_layout.set_text(" " + tag + " ")
             text_width, text_height = tag_layout.get_pixel_size()
 
             x0 = cell_area.x + \
@@ -293,11 +276,12 @@
             self.set_colour(ctx, TAG_COLOUR_ID, 0.0, 0.5)
             ctx.stroke_preserve()
 
-            ctx.set_fill_rule (CAIRO_FILL_RULE_EVEN_ODD)
+            ctx.set_fill_rule (cairo.FILL_RULE_EVEN_ODD)
             self.set_colour(ctx, TAG_COLOUR_ID, 0.5, 1.0)
             ctx.fill()
 
             # Draw the tag text
             self.set_colour(ctx, 0, 0.0, 0.0)
             ctx.move_to(x0, y0)
-            PangoCairo.show_layout(ctx, tag_layout)
+            ctx.show_layout(tag_layout)
+

=== modified file 'branchview/treemodel.py'
--- branchview/treemodel.py	2011-09-04 20:04:03 +0000
+++ branchview/treemodel.py	2011-08-27 18:03:04 +0000
@@ -1,8 +1,10 @@
 # -*- coding: UTF-8 -*-
-"""BranchTreeModel."""
+"""Tree model.
+
+"""
 
 __copyright__ = "Copyright  2005 Canonical Ltd."
-__author__ = "Gary van der Merwe <garyvdm@gmail.com>"
+__author__    = "Gary van der Merwe <garyvdm@gmail.com>"
 
 
 from gi.repository import Gtk
@@ -17,7 +19,6 @@
     localtime,
     )
 
-
 REVID = 0
 NODE = 1
 LINES = 2
@@ -33,34 +34,19 @@
 TAGS = 12
 AUTHORS = 13
 
-
-class BranchTreeModel(Gtk.ListStore):
-    """A model of branch's merge history."""
-
-    def __init__(self, branch, line_graph_data):
-        super(BranchTreeModel, self).__init__(
-            GObject.TYPE_STRING,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_STRING,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_PYOBJECT,
-            GObject.TYPE_STRING)
+class TreeModel(Gtk.TreeStore):
+
+    def __init__ (self, branch, line_graph_data):
+        Gtk.TreeStore.__init__(self)
         self.revisions = {}
         self.branch = branch
         self.repository = branch.repository
+        self.line_graph_data = line_graph_data
+
         if self.branch.supports_tags():
             self.tags = self.branch.tags.get_reverse_tag_dict()
         else:
             self.tags = {}
-        self.set_line_graph_data(line_graph_data)
 
     def add_tag(self, tag, revid):
         self.branch.tags.set_tag(tag, revid)
@@ -69,39 +55,94 @@
         except KeyError:
             self.tags[revid] = [tag]
 
-    def _line_graph_item_to_model_row(self, rowref, data):
-        revid, node, lines, parents, children, revno_sequence = data
-        if rowref > 0:
-            last_lines = self.line_graph_data[rowref - 1][2]
+    def on_get_flags(self):
+        return Gtk.TREE_MODEL_LIST_ONLY
+
+    def on_get_n_columns(self):
+        return 14
+
+    def on_get_column_type(self, index):
+        if index == REVID: return GObject.TYPE_STRING
+        if index == NODE: return GObject.TYPE_PYOBJECT
+        if index == LINES: return GObject.TYPE_PYOBJECT
+        if index == LAST_LINES: return GObject.TYPE_PYOBJECT
+        if index == REVNO: return GObject.TYPE_STRING
+        if index == SUMMARY: return GObject.TYPE_STRING
+        if index == MESSAGE: return GObject.TYPE_STRING
+        if index == COMMITTER: return GObject.TYPE_STRING
+        if index == TIMESTAMP: return GObject.TYPE_STRING
+        if index == REVISION: return GObject.TYPE_PYOBJECT
+        if index == PARENTS: return GObject.TYPE_PYOBJECT
+        if index == CHILDREN: return GObject.TYPE_PYOBJECT
+        if index == TAGS: return GObject.TYPE_PYOBJECT
+        if index == AUTHORS: return GObject.TYPE_STRING
+
+    def on_get_iter(self, path):
+        # XXX sinzui 2011-08-12: maybe path.get_indices()[0]?
+        return path[0]
+
+    def on_get_path(self, rowref):
+        return rowref
+
+    def on_get_value(self, rowref, column):
+        if len(self.line_graph_data) > 0:
+            (revid, node, lines, parents,
+             children, revno_sequence) = self.line_graph_data[rowref]
         else:
-            last_lines = []
-        revno = ".".join(["%d" % (revno) for revno in revno_sequence])
-        tags = self.tags.get(revid, [])
+            (revid, node, lines, parents,
+             children, revno_sequence) = (None, (0, 0), (), (),
+                                          (), ())
+        if column == REVID: return revid
+        if column == NODE: return node
+        if column == LINES: return lines
+        if column == PARENTS: return parents
+        if column == CHILDREN: return children
+        if column == LAST_LINES:
+            if rowref>0:
+                return self.line_graph_data[rowref-1][2]
+            return []
+        if column == REVNO: return ".".join(["%d" % (revno)
+                                      for revno in revno_sequence])
+
+        if column == TAGS: return self.tags.get(revid, [])
+
         if not revid or revid == NULL_REVISION:
-            revision = None
-        elif revid not in self.revisions:
+            return None
+        if revid not in self.revisions:
             revision = self.repository.get_revisions([revid])[0]
             self.revisions[revid] = revision
         else:
             revision = self.revisions[revid]
-        if revision is None:
-            summary = message = committer = timestamp = authors = None
-        else:
-            summary = escape(revision.get_summary())
-            message = escape(revision.message)
-            committer = parse_username(revision.committer)[0]
-            timestamp = strftime(
-                "%Y-%m-%d %H:%M", localtime(revision.timestamp))
-            authors = ", ".join([
-                parse_username(author)[0]
-                for author in revision.get_apparent_authors()])
-        return (revid, node, lines, last_lines, revno, summary, message,
-                committer, timestamp, revision, parents, children, tags,
-                authors)
-
-    def set_line_graph_data(self, line_graph_data):
-        self.clear()
-        self.line_graph_data = line_graph_data
-        for rowref, data in enumerate(self.line_graph_data):
-            row = self._line_graph_item_to_model_row(rowref, data)
-            self.append(row)
+
+        if column == REVISION: return revision
+        if column == SUMMARY: return escape(revision.get_summary())
+        if column == MESSAGE: return escape(revision.message)
+        if column == COMMITTER: return parse_username(revision.committer)[0]
+        if column == TIMESTAMP:
+            return strftime("%Y-%m-%d %H:%M", localtime(revision.timestamp))
+        if column == AUTHORS:
+            return ", ".join([
+                parse_username(author)[0] for author in revision.get_apparent_authors()])
+
+    def on_iter_next(self, rowref):
+        if rowref < len(self.line_graph_data) - 1:
+            return rowref+1
+        return None
+
+    def on_iter_children(self, parent):
+        if parent is None: return 0
+        return None
+
+    def on_iter_has_child(self, rowref):
+        return False
+
+    def on_iter_n_children(self, rowref):
+        if rowref is None: return len(self.line_graph_data)
+        return 0
+
+    def on_iter_nth_child(self, parent, n):
+        if parent is None: return n
+        return None
+
+    def on_iter_parent(self, child):
+        return None

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2012-03-23 15:02:38 +0000
+++ branchview/treeview.py	2011-08-27 20:13:10 +0000
@@ -105,7 +105,7 @@
         :param broken_line_length: After how much lines to break 
                                    branches.
         """
-        super(TreeView, self).__init__(homogeneous=False, spacing=0)
+        Gtk.VBox.__init__(self, homogeneous=False, spacing=0)
 
         self.progress_widget = ProgressPanel()
         self.pack_start(self.progress_widget, False, True, 0)
@@ -131,7 +131,7 @@
         self.maxnum = maxnum
         self.compact = compact
 
-        self.model = treemodel.BranchTreeModel(self.branch, [])
+        self.model = treemodel.TreeModel(self.branch, [])
         GObject.idle_add(self.populate)
 
         self.connect("destroy", self._on_destroy)
@@ -260,7 +260,7 @@
     def back(self):
         """Signal handler for the Back button."""
         parents = self.get_parents()
-        if not parents:
+        if not len(parents):
             return
 
         for parent_id in parents:
@@ -275,7 +275,7 @@
     def forward(self):
         """Signal handler for the Forward button."""
         children = self.get_children()
-        if not children:
+        if not len(children):
             return
 
         for child_id in children:
@@ -312,16 +312,15 @@
             show_graph = self.graph_column.get_visible()
 
             self.branch.lock_read()
-            (linegraphdata, index, columns_len) = linegraph(
-                self.branch.repository.get_graph(),
-                self.start,
-                self.maxnum, 
-                broken_line_length,
-                show_graph,
-                self.mainline_only,
-                self.progress_bar)
+            (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
+                                                            self.start,
+                                                            self.maxnum, 
+                                                            broken_line_length,
+                                                            show_graph,
+                                                            self.mainline_only,
+                                                            self.progress_bar)
 
-            self.model.set_line_graph_data(linegraphdata)
+            self.model.line_graph_data = linegraphdata
             self.graph_cell.columns_len = columns_len
             width = self.graph_cell.get_preferred_width(self.treeview)[1]
             if width > 500:
@@ -354,7 +353,7 @@
         # from the key (that is the key is found in a REVNO at the offset 0)
         # or if a MESSAGE *contains* the key anywhere (that is, the key is
         # found case insensitively in a MESSAGE at any offset)
-        def search_equal_func(model, column, key, iter, ignored):
+        def search_equal_func(model, column, key, iter):
             return (model.get_value(iter, treemodel.REVNO).find(key) != 0
                 and model.get_value(iter, treemodel.MESSAGE).lower().find(key.lower()) == -1)
 
@@ -362,7 +361,6 @@
         self.treeview.set_enable_search(True)
 
         self.treeview.set_tooltip_column(treemodel.MESSAGE)
-        self.treeview.set_headers_visible(True)
 
         self._prev_cursor_path = None
         self.treeview.connect("cursor-changed",
@@ -395,14 +393,10 @@
         self.graph_column.set_resizable(True)
         self.graph_column.set_sizing(Gtk.TreeViewColumnSizing.FIXED)
         self.graph_column.pack_start(self.graph_cell, True)
-        self.graph_column.add_attribute(
-            self.graph_cell, "node", treemodel.NODE)
-        self.graph_column.add_attribute(
-            self.graph_cell, "tags", treemodel.TAGS)
-        self.graph_column.add_attribute(
-            self.graph_cell, "in-lines", treemodel.LAST_LINES)
-        self.graph_column.add_attribute(
-            self.graph_cell, "out-lines", treemodel.LINES)
+        self.graph_column.add_attribute(self.graph_cell, "node", treemodel.NODE)
+        self.graph_column.add_attribute(self.graph_cell, "tags", treemodel.TAGS)
+        self.graph_column.add_attribute(self.graph_cell, "in-lines", treemodel.LAST_LINES)
+        self.graph_column.add_attribute(self.graph_cell, "out-lines", treemodel.LINES)
         self.treeview.append_column(self.graph_column)
 
         cell = Gtk.CellRendererText()
@@ -454,13 +448,11 @@
     def _on_revision_selected(self, widget, event):
         from bzrlib.plugins.gtk.revisionmenu import RevisionMenu
         if event.button == 3:
-            revs = []
-            rev = self.get_revision()
-            if rev is not None:
-                revs.append(rev.revision_id)
-            menu = RevisionMenu(self.branch.repository, revs, self.branch)
+            menu = RevisionMenu(self.branch.repository, 
+                [self.get_revision().revision_id],
+                self.branch)
             menu.connect('tag-added', lambda w, t, r: self.add_tag(t, r))
-            menu.popup(None, None, None, None, event.button, event.get_time())
+            menu.popup(None, None, None, event.button, event.get_time())
 
     def _on_revision_activated(self, widget, path, col):
         self.emit('revision-activated', path, col)

=== modified file 'bzr-handle-patch'
--- bzr-handle-patch	2012-03-23 12:56:39 +0000
+++ bzr-handle-patch	2011-07-31 16:50:29 +0000
@@ -2,42 +2,39 @@
 
 from bzrlib import errors, merge_directive
 from bzrlib.plugin import load_plugins
+from bzrlib.plugins.gtk.commands import open_display
+
 load_plugins()
-from bzrlib.plugins.gtk.commands import open_display
 
 import sys
 
 if len(sys.argv) < 2:
-    print "Usage: handle-patch <path>"
-    sys.exit(1)
+	print "Usage: handle-patch <path>"
+	sys.exit(1)
 
 
 path = sys.argv[1]
 
 try:
-    from bzrlib.plugins.gtk.diff import (DiffController,
-                                         MergeDirectiveController)
-    if path == '-':
-        lines = sys.stdin.readlines()
-    else:
-        lines = open(path, 'rb').readlines()
-    lines = [l.replace('\r\n', '\n') for l in lines]
-    try:
-        directive = merge_directive.MergeDirective.from_lines(lines)
-    except errors.NotAMergeDirective:
-        controller = DiffController(path, lines, allow_dirty=True)
-    else:
-        controller = MergeDirectiveController(path, directive)
-    window = controller.window
-    window.show()
-    Gtk = open_display()
-    window.connect("destroy", Gtk.main_quit)
+	from bzrlib.plugins.gtk.diff import (DiffController,
+										 MergeDirectiveController)
+	if path == '-':
+		lines = sys.stdin.readlines()
+	else:
+		lines = open(path, 'rb').readlines()
+	lines = [l.replace('\r\n', '\n') for l in lines]
+	try:
+		directive = merge_directive.MergeDirective.from_lines(lines)
+	except errors.NotAMergeDirective:
+		controller = DiffController(path, lines, allow_dirty=True)
+	else:
+		controller = MergeDirectiveController(path, directive)
+	window = controller.window
+	window.show()
+	Gtk = open_display()
+	window.connect("destroy", gtk.main_quit)
 except Exception, e:
-    from bzrlib.plugins.gtk.dialog import error_dialog
-    error_dialog('Error', str(e))
-    raise
-
-if len(sys.argv) == 3 and sys.argv[2] == 'test':
-    sys.exit(0)
-
-Gtk.main()
+	from bzrlib.plugins.gtk.dialog import error_dialog
+	error_dialog('Error', str(e))
+	raise
+gtk.main()

=== modified file 'bzr-handle-patch.desktop'
--- bzr-handle-patch.desktop	2012-03-23 13:45:02 +0000
+++ bzr-handle-patch.desktop	2011-03-06 08:24:07 +0000
@@ -8,4 +8,3 @@
 Type=Application
 Categories=Application;Development;RevisionControl;
 MimeType=text/x-diff;text/x-patch;application/x-bazaar-merge-directive;
-X-AppInstall-Ignore=true

=== added file 'bzr-notify'
--- bzr-notify	1970-01-01 00:00:00 +0000
+++ bzr-notify	2011-07-31 16:50:29 +0000
@@ -0,0 +1,92 @@
+#!/usr/bin/env python
+
+"""Run the bzr tray icon.
+
+This is a background program which will pop up a notification on the users
+screen when a commit occurs.
+"""
+
+from bzrlib.plugin import load_plugins
+load_plugins()
+
+from bzrlib.plugins.gtk.commands import open_display
+
+from bzrlib.plugins.gtk.notify import NotifyPopupMenu
+Gtk = open_display()
+
+import cgi
+import dbus
+import dbus.service
+import gobject
+import pynotify
+from bzrlib.bzrdir import BzrDir
+from bzrlib.osutils import format_date
+from bzrlib.transport import get_transport
+
+menu = NotifyPopupMenu()
+try:
+    import appindicator
+except ImportError:
+    icon = gtk.status_icon_new_from_icon_name("bzr-panel")
+    icon.connect('popup-menu', menu.display)
+    icon.set_visible(False)
+    hide_icon = lambda: icon.set_visible(False)
+    show_icon = lambda: icon.set_visible(True)
+else:
+    indicator = appindicator.Indicator ("bzr-gtk-notify",
+        "bzr-panel", appindicator.CATEGORY_OTHER)
+    indicator.set_status (appindicator.STATUS_PASSIVE)
+    indicator.set_attention_icon("bzr-panel")
+    indicator.set_menu(menu)
+    hide_icon = lambda: indicator.set_status (appindicator.STATUS_PASSIVE)
+    show_icon = lambda: indicator.set_status (appindicator.STATUS_ATTENTION)
+
+if getattr(dbus, 'version', (0,0,0)) >= (0,41,0):
+    import dbus.glib
+BROADCAST_INTERFACE = "org.bazaarvcs.plugins.dbus.Broadcast"
+bus = dbus.SessionBus()
+
+def catch_branch(revision_id, urls):
+    # TODO: show all the urls, or perhaps choose the 'best'.
+    url = urls[0]
+    try:
+        if isinstance(revision_id, unicode):
+            revision_id = revision_id.encode('utf8')
+        transport = get_transport(url)
+        a_dir = BzrDir.open_from_transport(transport)
+        branch = a_dir.open_branch()
+        revno = branch.revision_id_to_revno(revision_id)
+        revision = branch.repository.get_revision(revision_id)
+        summary = 'New revision %d in %s' % (revno, url)
+        body = 'Committer: %s\n' % revision.committer
+        body += 'Date: %s\n' % format_date(revision.timestamp,
+            revision.timezone)
+        body += '\n'
+        body += revision.message
+        body = cgi.escape(body)
+        nw = pynotify.Notification(summary, body)
+        def start_viz(notification=None, action=None, data=None):
+            """Start the viz program."""
+            from bzrlib.plugins.gtk.commands import start_viz_window
+            pp = start_viz_window(branch, revision_id)
+            pp.show()
+        def start_branch(notification=None, action=None, data=None):
+            """Start a Branch dialog"""
+            from bzrlib.plugins.gtk.branch import BranchDialog
+            bd = BranchDialog(remote_path=url)
+            bd.run()
+        if "actions" in pynotify.get_server_caps():
+            nw.add_action("inspect", "Inspect", start_viz, None)
+            nw.add_action("branch", "Branch", start_branch, None)
+        show_icon()
+        gobject.timeout_add(5000, hide_icon)
+        nw.set_timeout(5000)
+        nw.show()
+    except Exception, e:
+        print e
+        raise
+bus.add_signal_receiver(catch_branch,
+                        dbus_interface=BROADCAST_INTERFACE,
+                        signal_name="Revision")
+pynotify.init("bzr-notify")
+gtk.main()

=== added file 'bzr-notify.desktop'
--- bzr-notify.desktop	1970-01-01 00:00:00 +0000
+++ bzr-notify.desktop	2011-03-06 08:24:07 +0000
@@ -0,0 +1,10 @@
+[Desktop Entry]
+Type=Application
+Version=0.1
+Name=Bazaar Notification
+GenericName=Bazaar Notification
+Comment=Notification Area Icon for Bazaar
+Icon=bzr-icon-64
+Exec=bzr-notify
+Categories=Application;Development;RevisionControl;
+Terminal=false

=== added file 'bzr-notify.desktop.in'
--- bzr-notify.desktop.in	1970-01-01 00:00:00 +0000
+++ bzr-notify.desktop.in	2010-08-21 09:32:13 +0000
@@ -0,0 +1,10 @@
+[Desktop Entry]
+Type=Application
+Version=0.1
+_Name=Bazaar Notification
+_GenericName=Bazaar Notification
+_Comment=Notification Area Icon for Bazaar
+Icon=bzr-icon-64
+Exec=bzr-notify
+Categories=Application;Development;RevisionControl;
+Terminal=false

=== modified file 'checkout.py'
--- checkout.py	2011-09-05 03:44:26 +0000
+++ checkout.py	2011-08-13 01:28:20 +0000
@@ -33,9 +33,10 @@
 
     def __init__(self, path=None, parent=None, remote_path=None):
         """ Initialize the Checkout dialog. """
-        super(CheckoutDialog, self).__init__(
-            title="Checkout - Olive", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Checkout - Olive",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
 
         # Get arguments
         self.path = path
@@ -84,20 +85,20 @@
         self._label_revision.set_alignment(0, 0.5)
         self._table.set_row_spacings(3)
         self._table.set_col_spacings(3)
-        self.get_content_area().set_spacing(3)
+        self.vbox.set_spacing(3)
         if self.path is not None:
             self._filechooser.set_filename(self.path)
         if remote_path is not None:
             self._combo.get_child().set_text(remote_path)
 
         # Pack some widgets
-        self._hbox_revision.pack_start(self._entry_revision, True, True, 0)
-        self._hbox_revision.pack_start(self._button_revision, False, False, 0)
-        self.get_content_area().add(self._table)
-        self.action_area.pack_end(self._button_checkout, False, False, 0)
+        self._hbox_revision.pack_start(self._entry_revision, True, True)
+        self._hbox_revision.pack_start(self._button_revision, False, False)
+        self.vbox.add(self._table)
+        self.action_area.pack_end(self._button_checkout)
 
         # Show the dialog
-        self.get_content_area().show_all()
+        self.vbox.show_all()
 
         # Build checkout history
         self._history = UrlHistory(GlobalConfig(), 'branch_history')

=== modified file 'commit.py'
--- commit.py	2012-03-22 17:14:22 +0000
+++ commit.py	2011-08-27 15:31:00 +0000
@@ -22,18 +22,18 @@
 from gi.repository import Pango
 
 from bzrlib import (
-    bencode,
     errors,
     osutils,
-    revision as _mod_revision,
     trace,
-    tsort,
     )
+try:
+    from bzrlib import bencode
+except ImportError:
+    from bzrlib.util import bencode
+
 from bzrlib.plugins.gtk.dialog import question_dialog
-from bzrlib.plugins.gtk.diff import DiffView
 from bzrlib.plugins.gtk.errors import show_bzr_error
 from bzrlib.plugins.gtk.i18n import _i18n
-from bzrlib.plugins.gtk.commitmsgs import SavedCommitMessagesManager
 
 try:
     import dbus
@@ -43,32 +43,6 @@
     have_dbus = False
 
 
-def _get_sorted_revisions(tip_revision, revision_ids, parent_map):
-    """Get an iterator which will return the revisions in merge sorted order.
-
-    This will build up a list of all nodes, such that only nodes in the list
-    are referenced. It then uses MergeSorter to return them in 'merge-sorted'
-    order.
-
-    :param revision_ids: A set of revision_ids
-    :param parent_map: The parent information for each node. Revisions which
-        are considered ghosts should not be present in the map.
-    :return: iterator from MergeSorter.iter_topo_order()
-    """
-    # MergeSorter requires that all nodes be present in the graph, so get rid
-    # of any references pointing outside of this graph.
-    parent_graph = {}
-    for revision_id in revision_ids:
-        if revision_id not in parent_map: # ghost
-            parent_graph[revision_id] = []
-        else:
-            # Only include parents which are in this sub-graph
-            parent_graph[revision_id] = [p for p in parent_map[revision_id]
-                                            if p in revision_ids]
-    sorter = tsort.MergeSorter(parent_graph, tip_revision)
-    return sorter.iter_topo_order()
-
-
 def pending_revisions(wt):
     """Return a list of pending merges or None if there are none of them.
 
@@ -79,7 +53,7 @@
     """
     parents = wt.get_parent_ids()
     if len(parents) < 2:
-        return
+        return None
 
     # The basic pending merge algorithm uses the same algorithm as
     # bzrlib.status.show_pending_merges
@@ -87,71 +61,55 @@
     branch = wt.branch
     last_revision = parents[0]
 
-    graph = branch.repository.get_graph()
-    other_revisions = [last_revision]
+    if last_revision is not None:
+        try:
+            ignore = set(branch.repository.get_ancestry(last_revision,
+                                                        topo_sorted=False))
+        except errors.NoSuchRevision:
+            # the last revision is a ghost : assume everything is new
+            # except for it
+            ignore = set([None, last_revision])
+    else:
+        ignore = set([None])
 
     pm = []
     for merge in pending:
-        try:
-            merge_rev = branch.repository.get_revision(merge)
-        except errors.NoSuchRevision:
-            # If we are missing a revision, just print out the revision id
-            trace.mutter("ghost: %r", merge)
-            other_revisions.append(merge)
-            continue
-
-        # Find all of the revisions in the merge source, which are not in the
-        # last committed revision.
-        merge_extra = graph.find_unique_ancestors(merge, other_revisions)
-        other_revisions.append(merge)
-        merge_extra.discard(_mod_revision.NULL_REVISION)
-
-        # Get a handle to all of the revisions we will need
-        try:
-            revisions = dict((rev.revision_id, rev) for rev in
-                             branch.repository.get_revisions(merge_extra))
-        except errors.NoSuchRevision:
-            # One of the sub nodes is a ghost, check each one
-            revisions = {}
-            for revision_id in merge_extra:
-                try:
-                    rev = branch.repository.get_revisions([revision_id])[0]
-                except errors.NoSuchRevision:
-                    revisions[revision_id] = None
-                else:
-                    revisions[revision_id] = rev
-
-         # Display the revisions brought in by this merge.
-        rev_id_iterator = _get_sorted_revisions(merge, merge_extra,
-                            branch.repository.get_parent_map(merge_extra))
-        # Skip the first node
-        num, first, depth, eom = rev_id_iterator.next()
-        if first != merge:
-            raise AssertionError('Somehow we misunderstood how'
-                ' iter_topo_order works %s != %s' % (first, merge))
-        children = []
-        for num, sub_merge, depth, eom in rev_id_iterator:
-            rev = revisions[sub_merge]
-            if rev is None:
-                trace.warning("ghost: %r", sub_merge)
-                continue
-            children.append(rev)
-        yield (merge_rev, children)
+        ignore.add(merge)
+        try:
+            rev = branch.repository.get_revision(merge)
+            children = []
+            pm.append((rev, children))
+
+            # This does need to be topo sorted, so we search backwards
+            inner_merges = branch.repository.get_ancestry(merge)
+            assert inner_merges[0] is None
+            inner_merges.pop(0)
+            for mmerge in reversed(inner_merges):
+                if mmerge in ignore:
+                    continue
+                rev = branch.repository.get_revision(mmerge)
+                children.append(rev)
+
+                ignore.add(mmerge)
+        except errors.NoSuchRevision:
+            print "DEBUG: NoSuchRevision:", merge
+
+    return pm
 
 
 _newline_variants_re = re.compile(r'\r\n?')
 def _sanitize_and_decode_message(utf8_message):
     """Turn a utf-8 message into a sanitized Unicode message."""
     fixed_newline = _newline_variants_re.sub('\n', utf8_message)
-    return osutils.safe_unicode(fixed_newline)
+    return fixed_newline.decode('utf-8')
 
 
 class CommitDialog(Gtk.Dialog):
     """Implementation of Commit."""
 
     def __init__(self, wt, selected=None, parent=None):
-        super(CommitDialog, self).__init__(
-            title="Commit to %s" % wt.basedir, parent=parent, flags=0)
+        Gtk.Dialog.__init__(self, title="Commit to %s" % wt.basedir,
+                            parent=parent, flags=0,)
         self.connect('delete-event', self._on_delete_window)
         self._question_dialog = question_dialog
 
@@ -164,7 +122,6 @@
         self._enable_per_file_commits = True
         self._commit_all_changes = True
         self.committed_revision_id = None # Nothing has been committed yet
-        self._last_selected_file = None
         self._saved_commit_messages_manager = SavedCommitMessagesManager(
             self._wt, self._wt.branch)
 
@@ -176,11 +133,7 @@
         """Setup the member variables for state."""
         self._basis_tree = self._wt.basis_tree()
         self._delta = None
-        self._wt.lock_read()
-        try:
-            self._pending = list(pending_revisions(self._wt))
-        finally:
-            self._wt.unlock()
+        self._pending = pending_revisions(self._wt)
 
         self._is_checkout = (self._wt.branch.get_bound_location() is not None)
 
@@ -238,7 +191,7 @@
 
         all_enabled = (self._selected is None)
         # The first entry is always the 'whole tree'
-        all_iter = store.append(["", "", all_enabled, 'All Files', '', ''])
+        all_iter = store.append([None, None, all_enabled, 'All Files', '', ''])
         initial_cursor = store.get_path(all_iter)
         # should we pass specific_files?
         self._wt.lock_read()
@@ -289,12 +242,7 @@
             self._check_local.hide()
             return
         if have_dbus:
-            try:
-                bus = dbus.SystemBus()
-            except dbus.DBusException:
-                trace.mutter("DBus system bus not available")
-                self._check_local.show()
-                return
+            bus = dbus.SystemBus()
             try:
                 proxy_obj = bus.get_object('org.freedesktop.NetworkManager',
                                            '/org/freedesktop/NetworkManager')
@@ -302,7 +250,7 @@
                 trace.mutter("networkmanager not available.")
                 self._check_local.show()
                 return
-
+            
             dbus_iface = dbus.Interface(proxy_obj,
                                         'org.freedesktop.NetworkManager')
             try:
@@ -334,7 +282,7 @@
         """Build up the dialog widgets."""
         # The primary pane which splits it into left and right (adjustable)
         # sections.
-        self._hpane = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
+        self._hpane = Gtk.HPaned()
 
         self._construct_left_pane()
         self._construct_right_pane()
@@ -500,7 +448,7 @@
                                      self._on_treeview_files_cursor_changed)
 
     def _toggle_commit(self, cell, path, model):
-        if model[path][0] == "": # No file_id means 'All Files'
+        if model[path][0] is None: # No file_id means 'All Files'
             new_val = not model[path][2]
             for node in model:
                 node[2] = new_val
@@ -560,6 +508,8 @@
                                              Gtk.CellRendererText(), text=3))
 
     def _construct_diff_view(self):
+        from bzrlib.plugins.gtk.diff import DiffView
+
         # TODO: jam 2007-10-30 The diff label is currently disabled. If we
         #       decide that we really don't ever want to display it, we should
         #       actually remove it, and other references to it, along with the
@@ -574,12 +524,6 @@
         self._add_to_right_table(self._diff_view, 4, True)
         self._diff_view.show()
 
-    @staticmethod
-    def get_line_height(widget):
-        pango_layout = widget.create_pango_layout("X");
-        ink_rectangle, logical_rectangle = pango_layout.get_pixel_extents()
-        return logical_rectangle.height
-
     def _construct_file_message(self):
         scroller = Gtk.ScrolledWindow()
         scroller.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
@@ -592,8 +536,6 @@
         self._file_message_text_view.modify_font(Pango.FontDescription("Monospace"))
         self._file_message_text_view.set_wrap_mode(Gtk.WrapMode.WORD)
         self._file_message_text_view.set_accepts_tab(False)
-        line_height = self.get_line_height(self._file_message_text_view)
-        self._file_message_text_view.set_size_request(-1, line_height * 2)
         self._file_message_text_view.show()
 
         self._file_message_expander = Gtk.Expander(
@@ -629,18 +571,15 @@
 
     def _on_treeview_files_cursor_changed(self, treeview):
         treeselection = treeview.get_selection()
-        if treeselection is None:
-            # The treeview was probably destroyed as the dialog closes.
-            return
         (model, selection) = treeselection.get_selected()
 
         if selection is not None:
             path, display_path = model.get(selection, 1, 3)
             self._diff_label.set_text(_i18n('Diff for ') + display_path)
-            if path == "":
+            if path is None:
                 self._diff_view.show_diff(None)
             else:
-                self._diff_view.show_diff([osutils.safe_unicode(path)])
+                self._diff_view.show_diff([path.decode('UTF-8')])
             self._update_per_file_info(selection)
 
     def _on_accel_next(self, accel_group, window, keyval, modifier):
@@ -658,7 +597,7 @@
             # selected. Either way, select All Files, and jump to the global
             # commit message.
             self._treeview_files.set_cursor(
-                Gtk.TreePath(path=0), "", False)
+                Gtk.TreePath(path=0), None, False)
             self._global_message_text_view.grab_focus()
         else:
             # Set the cursor to this entry, and jump to the per-file commit
@@ -683,7 +622,7 @@
         self._save_current_file_message()
         text_buffer = self._file_message_text_view.get_buffer()
         file_id, display_path, message = self._files_store.get(selection, 0, 3, 5)
-        if file_id == "": # Whole tree
+        if file_id is None: # Whole tree
             self._file_message_expander.set_label(_i18n('File commit message'))
             self._file_message_expander.set_expanded(False)
             self._file_message_expander.set_sensitive(False)
@@ -706,13 +645,13 @@
         files = []
         records = iter(self._files_store)
         rec = records.next() # Skip the All Files record
-        assert rec[0] == "", "Are we skipping the wrong record?"
+        assert rec[0] is None, "Are we skipping the wrong record?"
 
         file_info = []
         for record in records:
             if self._commit_all_changes or record[2]:# [2] checkbox
-                file_id = osutils.safe_utf8(record[0]) # [0] file_id
-                path = osutils.safe_utf8(record[1])    # [1] real path
+                file_id = record[0] # [0] file_id
+                path = record[1]    # [1] real path
                 # [5] commit message
                 file_message = _sanitize_and_decode_message(record[5])
                 files.append(path.decode('UTF-8'))
@@ -854,3 +793,101 @@
         rev_dict['revision_id'] = rev.revision_id
         return rev_dict
 
+
+class SavedCommitMessagesManager:
+    """Save glogal and per-file commit messages.
+
+    Saves global commit message and utf-8 file_id->message dictionary
+    of per-file commit messages on disk. Re-reads them later for re-using.
+    """
+
+    def __init__(self, tree=None, branch=None):
+        """If branch is None, builds empty messages, otherwise reads them
+        from branch's disk storage. 'tree' argument is for the future."""
+        if branch is None:
+            self.global_message = u''
+            self.file_messages = {}
+        else:
+            config = branch.get_config()
+            self.global_message = config.get_user_option(
+                'gtk_global_commit_message')
+            if self.global_message is None:
+                self.global_message = u''
+            file_messages = config.get_user_option('gtk_file_commit_messages')
+            if file_messages: # unicode and B-encoded:
+                self.file_messages = bencode.bdecode(
+                    file_messages.encode('UTF-8'))
+            else:
+                self.file_messages = {}
+
+    def get(self):
+        return self.global_message, self.file_messages
+
+    def is_not_empty(self):
+        return bool(self.global_message or self.file_messages)
+
+    def insert(self, global_message, file_info):
+        """Formats per-file commit messages (list of dictionaries, one per file)
+        into one utf-8 file_id->message dictionary and merges this with
+        previously existing dictionary. Merges global commit message too."""
+        file_messages = {}
+        for fi in file_info:
+            file_message = fi['message']
+            if file_message:
+                file_messages[fi['file_id']] = file_message # utf-8 strings
+        for k,v in file_messages.iteritems():
+            try:
+                self.file_messages[k] = v + '\n******\n' + self.file_messages[k]
+            except KeyError:
+                self.file_messages[k] = v
+        if self.global_message:
+            self.global_message = global_message + '\n******\n' \
+                + self.global_message
+        else:
+            self.global_message = global_message
+
+    def save(self, tree, branch):
+        # We store in branch's config, which can be a problem if two gcommit
+        # are done in two checkouts of one single branch (comments overwrite
+        # each other). Ideally should be in working tree. But uncommit does
+        # not always have a working tree, though it always has a branch.
+        # 'tree' argument is for the future
+        config = branch.get_config()
+        # should it be named "gtk_" or some more neutral name ("gui_" ?) to
+        # be compatible with qbzr in the future?
+        config.set_user_option('gtk_global_commit_message', self.global_message)
+        # bencode() does not know unicode objects but set_user_option()
+        # requires one:
+        config.set_user_option(
+            'gtk_file_commit_messages',
+            bencode.bencode(self.file_messages).decode('UTF-8'))
+
+
+def save_commit_messages(local, master, old_revno, old_revid,
+                         new_revno, new_revid):
+    b = local
+    if b is None:
+        b = master
+    mgr = SavedCommitMessagesManager(None, b)
+    revid_iterator = b.repository.iter_reverse_revision_history(old_revid)
+    cur_revno = old_revno
+    new_revision_id = old_revid
+    graph = b.repository.get_graph()
+    for rev_id in revid_iterator:
+        if cur_revno == new_revno:
+            break
+        cur_revno -= 1
+        rev = b.repository.get_revision(rev_id)
+        file_info = rev.properties.get('file-info', None)
+        if file_info is None:
+            file_info = {}
+        else:
+            file_info = bencode.bdecode(file_info.encode('UTF-8'))
+        global_message = osutils.safe_unicode(rev.message)
+        # Concatenate comment of the uncommitted revision
+        mgr.insert(global_message, file_info)
+
+        parents = graph.get_parent_map([rev_id]).get(rev_id, None)
+        if not parents:
+            continue
+    mgr.save(None, b)

=== removed file 'commitmsgs.py'
--- commitmsgs.py	2011-12-20 16:47:38 +0000
+++ commitmsgs.py	1970-01-01 00:00:00 +0000
@@ -1,122 +0,0 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-from bzrlib import (
-    bencode,
-    osutils,
-    )
-
-class SavedCommitMessagesManager(object):
-    """Save global and per-file commit messages.
-
-    Saves global commit message and utf-8 file_id->message dictionary
-    of per-file commit messages on disk. Re-reads them later for re-using.
-    """
-
-    def __init__(self, tree=None, branch=None):
-        """If branch is None, builds empty messages, otherwise reads them
-        from branch's disk storage. 'tree' argument is for the future."""
-        if branch is None:
-            self.global_message = u''
-            self.file_messages = {}
-        else:
-            config = branch.get_config()
-            self.global_message = config.get_user_option(
-                'gtk_global_commit_message')
-            if self.global_message is None:
-                self.global_message = u''
-            file_messages = config.get_user_option('gtk_file_commit_messages')
-            if file_messages: # unicode and B-encoded:
-                self.file_messages = bencode.bdecode(
-                    file_messages.encode('UTF-8'))
-            else:
-                self.file_messages = {}
-
-    def get(self):
-        return self.global_message, self.file_messages
-
-    def is_not_empty(self):
-        return bool(self.global_message or self.file_messages)
-
-    def insert(self, global_message, file_info):
-        """Formats per-file commit messages (list of dictionaries, one per file)
-        into one utf-8 file_id->message dictionary and merges this with
-        previously existing dictionary. Merges global commit message too."""
-        file_messages = {}
-        for fi in file_info:
-            file_message = fi['message']
-            if file_message:
-                file_id = fi['file_id']
-                assert type(file_id) is str
-                file_messages[file_id] = file_message # utf-8 strings
-        for k,v in file_messages.iteritems():
-            assert type(k) is str
-            try:
-                self.file_messages[k] = v + '\n******\n' + self.file_messages[k]
-            except KeyError:
-                self.file_messages[k] = v
-        if self.global_message:
-            self.global_message = global_message + '\n******\n' \
-                + self.global_message
-        else:
-            self.global_message = global_message
-
-    def save(self, tree, branch):
-        # We store in branch's config, which can be a problem if two gcommit
-        # are done in two checkouts of one single branch (comments overwrite
-        # each other). Ideally should be in working tree. But uncommit does
-        # not always have a working tree, though it always has a branch.
-        # 'tree' argument is for the future
-        config = branch.get_config()
-        # should it be named "gtk_" or some more neutral name ("gui_" ?) to
-        # be compatible with qbzr in the future?
-        config.set_user_option('gtk_global_commit_message', self.global_message)
-        # bencode() does not know unicode objects but set_user_option()
-        # requires one:
-        config.set_user_option(
-            'gtk_file_commit_messages',
-            bencode.bencode(self.file_messages).decode('UTF-8'))
-
-
-def save_commit_messages(local, master, old_revno, old_revid,
-                         new_revno, new_revid):
-    b = local
-    if b is None:
-        b = master
-    mgr = SavedCommitMessagesManager(None, b)
-    graph = b.repository.get_graph()
-    revid_iterator = graph.iter_lefthand_ancestry(old_revid)
-    cur_revno = old_revno
-    new_revision_id = old_revid
-    graph = b.repository.get_graph()
-    for rev_id in revid_iterator:
-        if cur_revno == new_revno:
-            break
-        cur_revno -= 1
-        rev = b.repository.get_revision(rev_id)
-        file_info = rev.properties.get('file-info', None)
-        if file_info is None:
-            file_info = {}
-        else:
-            file_info = bencode.bdecode(file_info.encode('UTF-8'))
-        global_message = osutils.safe_unicode(rev.message)
-        # Concatenate comment of the uncommitted revision
-        mgr.insert(global_message, file_info)
-
-        parents = graph.get_parent_map([rev_id]).get(rev_id, None)
-        if not parents:
-            continue
-    mgr.save(None, b)

=== removed file 'config.py'
--- config.py	2011-12-06 16:57:32 +0000
+++ config.py	1970-01-01 00:00:00 +0000
@@ -1,36 +0,0 @@
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Configuration options."""
-
-from bzrlib import (
-    config,
-    version_info as bzrlib_version,
-    )
-
-if bzrlib_version < (2, 5):
-    def Option(*args, **kwargs):
-        if 'help' in kwargs:
-            del kwargs['help']
-        return config.Option(*args, **kwargs)
-else:
-    Option = config.Option
-
-opt_nautilus_integration = Option('nautilus_integration', default=True,
-               from_unicode=config.bool_from_store,
-               help='''\
-Whether to enable nautilus integration.
-
-Defines whether Nautilus integration should be enabled.
-''')

=== modified file 'conflicts.py'
--- conflicts.py	2011-09-05 03:44:26 +0000
+++ conflicts.py	2011-08-12 20:23:32 +0000
@@ -32,9 +32,10 @@
 
     def __init__(self, wt, parent=None):
         """ Initialize the Conflicts dialog. """
-        super(ConflictsDialog, self).__init__(
-            title="Conflicts - Olive", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CANCEL))
+        Gtk.Dialog.__init__(self, title="Conflicts - Olive",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CANCEL))
 
         # Get arguments
         self.wt = wt

=== modified file 'diff.py'
--- diff.py	2012-02-05 05:14:11 +0000
+++ diff.py	2011-08-12 22:58:29 +0000
@@ -5,21 +5,32 @@
 """
 
 __copyright__ = "Copyright 2005 Canonical Ltd."
-__author__ = "Scott James Remnant <scott@ubuntu.com>"
+__author__    = "Scott James Remnant <scott@ubuntu.com>"
 
 
 from cStringIO import StringIO
 
+from gi.repository import Gtk
+from gi.repository import Pango
+import os
+import re
 import sys
 import inspect
+try:
+    from xml.etree.ElementTree import Element, SubElement, tostring
+except ImportError:
+    from elementtree.ElementTree import Element, SubElement, tostring
 
-from gi.repository import Gtk
-from gi.repository import Pango
 try:
     from gi.repository import GtkSource
     have_gtksourceview = True
 except ImportError:
     have_gtksourceview = False
+try:
+    from gi.repository import GConf
+    have_gconf = True
+except ImportError:
+    have_gconf = False
 
 from bzrlib import (
     errors,
@@ -27,9 +38,10 @@
     osutils,
     urlutils,
     workingtree,
-    )
+)
 from bzrlib.diff import show_diff_trees
 from bzrlib.patches import parse_patches
+from bzrlib.trace import warning
 from bzrlib.plugins.gtk.dialog import (
     error_dialog,
     info_dialog,
@@ -55,10 +67,8 @@
 class DiffFileView(Gtk.ScrolledWindow):
     """Window for displaying diffs from a diff file"""
 
-    SHOW_WIDGETS = True
-
     def __init__(self):
-        super(DiffFileView, self).__init__()
+        Gtk.ScrolledWindow.__init__(self)
         self.construct()
         self._diffs = {}
 
@@ -70,18 +80,132 @@
             self.buffer = GtkSource.Buffer()
             lang_manager = GtkSource.LanguageManager.get_default()
             language = lang_manager.guess_language(None, "text/x-patch")
+            if have_gconf:
+                self.apply_gedit_colors(self.buffer)
+            self.apply_colordiff_colors(self.buffer)
             self.buffer.set_language(language)
             self.buffer.set_highlight_syntax(True)
+
             self.sourceview = GtkSource.View(buffer=self.buffer)
         else:
             self.buffer = Gtk.TextBuffer()
             self.sourceview = Gtk.TextView(self.buffer)
 
         self.sourceview.set_editable(False)
-        self.sourceview.override_font(Pango.FontDescription("Monospace"))
+        self.sourceview.modify_font(Pango.FontDescription("Monospace"))
         self.add(self.sourceview)
-        if self.SHOW_WIDGETS:
-            self.sourceview.show()
+        self.sourceview.show()
+
+    @staticmethod
+    def apply_gedit_colors(buf):
+        """Set style to that specified in gedit configuration.
+
+        This method needs the gconf module.
+
+        :param buf: a GtkSource.Buffer object.
+        """
+        GEDIT_SCHEME_PATH = '/apps/gedit-2/preferences/editor/colors/scheme'
+        GEDIT_USER_STYLES_PATH = os.path.expanduser('~/.gnome2/gedit/styles')
+
+        client = GConf.Client.get_default()
+        style_scheme_name = client.get_string(GEDIT_SCHEME_PATH)
+        if style_scheme_name is not None:
+            style_scheme_mgr = GtkSource.StyleSchemeManager()
+            style_scheme_mgr.append_search_path(GEDIT_USER_STYLES_PATH)
+            
+            style_scheme = style_scheme_mgr.get_scheme(style_scheme_name)
+            
+            if style_scheme is not None:
+                buf.set_style_scheme(style_scheme)
+
+    @classmethod
+    def apply_colordiff_colors(klass, buf):
+        """Set style colors for lang using the colordiff configuration file.
+
+        Both ~/.colordiffrc and ~/.colordiffrc.bzr-gtk are read.
+
+        :param buf: a "Diff" GtkSource.Buffer object.
+        """
+        scheme_manager = GtkSource.StyleSchemeManager()
+        style_scheme = scheme_manager.get_scheme('colordiff')
+        
+        # if style scheme not found, we'll generate it from colordiffrc
+        # TODO: reload if colordiffrc has changed.
+        if style_scheme is None:
+            colors = {}
+
+            for f in ('~/.colordiffrc', '~/.colordiffrc.bzr-gtk'):
+                f = os.path.expanduser(f)
+                if os.path.exists(f):
+                    try:
+                        f = file(f)
+                    except IOError, e:
+                        warning('could not open file %s: %s' % (f, str(e)))
+                    else:
+                        colors.update(klass.parse_colordiffrc(f))
+                        f.close()
+
+            if not colors:
+                # ~/.colordiffrc does not exist
+                return
+            
+            mapping = {
+                # map GtkSourceView2 scheme styles to colordiff names
+                # since GSV is richer, accept new names for extra bits,
+                # defaulting to old names if they're not present
+                'diff:added-line': ['newtext'],
+                'diff:removed-line': ['oldtext'],
+                'diff:location': ['location', 'diffstuff'],
+                'diff:file': ['file', 'diffstuff'],
+                'diff:special-case': ['specialcase', 'diffstuff'],
+            }
+            
+            converted_colors = {}
+            for name, values in mapping.items():
+                color = None
+                for value in values:
+                    color = colors.get(value, None)
+                    if color is not None:
+                        break
+                if color is None:
+                    continue
+                converted_colors[name] = color
+            
+            # some xml magic to produce needed style scheme description
+            e_style_scheme = Element('style-scheme')
+            e_style_scheme.set('id', 'colordiff')
+            e_style_scheme.set('_name', 'ColorDiff')
+            e_style_scheme.set('version', '1.0')
+            for name, color in converted_colors.items():
+                style = SubElement(e_style_scheme, 'style')
+                style.set('name', name)
+                style.set('foreground', '#%s' % color)
+            
+            scheme_xml = tostring(e_style_scheme, 'UTF-8')
+            if not os.path.exists(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles')):
+                os.makedirs(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles'))
+            file(os.path.expanduser('~/.local/share/gtksourceview-2.0/styles/colordiff.xml'), 'w').write(scheme_xml)
+            
+            scheme_manager.force_rescan()
+            style_scheme = scheme_manager.get_scheme('colordiff')
+        
+        buf.set_style_scheme(style_scheme)
+
+    @staticmethod
+    def parse_colordiffrc(fileobj):
+        """Parse fileobj as a colordiff configuration file.
+
+        :return: A dict with the key -> value pairs.
+        """
+        colors = {}
+        for line in fileobj:
+            if re.match(r'^\s*#', line):
+                continue
+            if '=' not in line:
+                continue
+            key, val = line.split('=', 1)
+            colors[key.strip()] = val.strip()
+        return colors
 
     def set_trees(self, rev_tree, parent_tree):
         self.rev_tree = rev_tree
@@ -92,15 +216,13 @@
 #        self.parent_tree.lock_read()
 #        self.rev_tree.lock_read()
 #        try:
-#            self.delta = iter_changes_to_status(
-#               self.parent_tree, self.rev_tree)
+#            self.delta = iter_changes_to_status(self.parent_tree, self.rev_tree)
 #            self.path_to_status = {}
 #            self.path_to_diff = {}
 #            source_inv = self.parent_tree.inventory
 #            target_inv = self.rev_tree.inventory
 #            for (file_id, real_path, change_type, display_path) in self.delta:
-#                self.path_to_status[real_path] = u'=== %s %s' % (
-#                    change_type, display_path)
+#                self.path_to_status[real_path] = u'=== %s %s' % (change_type, display_path)
 #                if change_type in ('modified', 'renamed and modified'):
 #                    source_ie = source_inv[file_id]
 #                    target_ie = target_inv[file_id]
@@ -108,7 +230,7 @@
 #                    source_ie.diff(internal_diff, *old path, *old_tree,
 #                                   *new_path, target_ie, self.rev_tree,
 #                                   sio)
-#                    self.path_to_diff[real_path] =
+#                    self.path_to_diff[real_path] = 
 #
 #        finally:
 #            self.rev_tree.unlock()
@@ -128,7 +250,7 @@
     """This is the soft and chewy filling for a DiffWindow."""
 
     def __init__(self):
-        super(DiffView, self).__init__()
+        DiffFileView.__init__(self)
         self.rev_tree = None
         self.parent_tree = None
 
@@ -162,9 +284,6 @@
     """Diff widget
 
     """
-
-    SHOW_WIDGETS = True
-
     def __init__(self):
         super(DiffWidget, self).__init__()
 
@@ -173,17 +292,15 @@
         scrollwin.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
         scrollwin.set_shadow_type(Gtk.ShadowType.IN)
         self.pack1(scrollwin)
-        if self.SHOW_WIDGETS:
-            scrollwin.show()
-
+        scrollwin.show()
+        
         self.model = Gtk.TreeStore(str, str)
         self.treeview = Gtk.TreeView(model=self.model)
         self.treeview.set_headers_visible(False)
         self.treeview.set_search_column(1)
         self.treeview.connect("cursor-changed", self._treeview_cursor_cb)
         scrollwin.add(self.treeview)
-        if self.SHOW_WIDGETS:
-            self.treeview.show()
+        self.treeview.show()
 
         cell = Gtk.CellRendererText()
         cell.set_property("width-chars", 20)
@@ -204,8 +321,7 @@
         if getattr(self, 'diff_view', None) is None:
             self.diff_view = DiffFileView()
             self.pack2(self.diff_view)
-        if self.SHOW_WIDGETS:
-            self.diff_view.show()
+        self.diff_view.show()
         for oldname, newname, patch in sections:
             self.diff_view._diffs[newname] = str(patch)
             if newname is None:
@@ -222,8 +338,7 @@
         if getattr(self, 'diff_view', None) is None:
             self.diff_view = DiffView()
             self.pack2(self.diff_view)
-        if self.SHOW_WIDGETS:
-            self.diff_view.show()
+        self.diff_view.show()
         self.diff_view.set_trees(rev_tree, parent_tree)
         self.rev_tree = rev_tree
         self.parent_tree = parent_tree
@@ -231,28 +346,28 @@
         self.model.clear()
         delta = self.rev_tree.changes_from(self.parent_tree)
 
-        self.model.append(None, ["Complete Diff", ""])
+        self.model.append(None, [ "Complete Diff", "" ])
 
         if len(delta.added):
-            titer = self.model.append(None, ["Added", None])
+            titer = self.model.append(None, [ "Added", None ])
             for path, id, kind in delta.added:
-                self.model.append(titer, [path, path])
+                self.model.append(titer, [ path, path ])
 
         if len(delta.removed):
-            titer = self.model.append(None, ["Removed", None])
+            titer = self.model.append(None, [ "Removed", None ])
             for path, id, kind in delta.removed:
-                self.model.append(titer, [path, path])
+                self.model.append(titer, [ path, path ])
 
         if len(delta.renamed):
-            titer = self.model.append(None, ["Renamed", None])
+            titer = self.model.append(None, [ "Renamed", None ])
             for oldpath, newpath, id, kind, text_modified, meta_modified \
                     in delta.renamed:
-                self.model.append(titer, [oldpath, newpath])
+                self.model.append(titer, [ oldpath, newpath ])
 
         if len(delta.modified):
-            titer = self.model.append(None, ["Modified", None])
+            titer = self.model.append(None, [ "Modified", None ])
             for path, id, kind, text_modified, meta_modified in delta.modified:
-                self.model.append(titer, [path, path])
+                self.model.append(titer, [ path, path ])
 
         self.treeview.expand_all()
         self.diff_view.show_diff(None)
@@ -273,16 +388,14 @@
     def _treeview_cursor_cb(self, *args):
         """Callback for when the treeview cursor changes."""
         (path, col) = self.treeview.get_cursor()
-        if path is None:
-            return
-        specific_files = [self.model[path][1]]
-        if specific_files == [None]:
-            return
-        elif specific_files == [""]:
+        specific_files = [ self.model[path][1] ]
+        if specific_files == [ None ]:
+            return
+        elif specific_files == [ "" ]:
             specific_files = None
-
+        
         self.diff_view.show_diff(specific_files)
-
+    
     def _on_wraplines_toggled(self, widget=None, wrap=False):
         """Callback for when the wrap lines checkbutton is toggled"""
         if wrap or widget.get_active():
@@ -290,7 +403,6 @@
         else:
             self.diff_view.sourceview.set_wrap_mode(Gtk.WrapMode.NONE)
 
-
 class DiffWindow(Window):
     """Diff window.
 
@@ -298,12 +410,10 @@
     differences between two revisions on a branch.
     """
 
-    SHOW_WIDGETS = True
-
     def __init__(self, parent=None, operations=None):
-        super(DiffWindow, self).__init__(parent=parent)
+        Window.__init__(self, parent)
         self.set_border_width(0)
-        self.set_title("bzr diff")
+        self.set_title("bzrk diff")
 
         # Use two thirds of the screen by default
         screen = self.get_screen()
@@ -317,34 +427,35 @@
         """Construct the window contents."""
         self.vbox = Gtk.VBox()
         self.add(self.vbox)
-        if self.SHOW_WIDGETS:
-            self.vbox.show()
+        self.vbox.show()
         self.diff = DiffWidget()
         self.vbox.pack_end(self.diff, True, True, 0)
-        if self.SHOW_WIDGETS:
-            self.diff.show_all()
+        self.diff.show_all()
         # Build after DiffWidget to connect signals
         menubar = self._get_menu_bar()
         self.vbox.pack_start(menubar, False, False, 0)
         hbox = self._get_button_bar(operations)
         if hbox is not None:
             self.vbox.pack_start(hbox, False, True, 0)
-
+        
+    
     def _get_menu_bar(self):
         menubar = Gtk.MenuBar()
         # View menu
-        mb_view = Gtk.MenuItem.new_with_mnemonic(_i18n("_View"))
+        mb_view = Gtk.MenuItem(label=_i18n("_View"))
         mb_view_menu = Gtk.Menu()
-        mb_view_wrapsource = Gtk.CheckMenuItem.new_with_mnemonic(
-            _i18n("Wrap _Long Lines"))
+        mb_view_wrapsource = Gtk.CheckMenuItem(
+            label=_i18n("Wrap _Long Lines"))
         mb_view_wrapsource.connect('activate', self.diff._on_wraplines_toggled)
+        mb_view_wrapsource.show()
         mb_view_menu.append(mb_view_wrapsource)
+        mb_view.show()
         mb_view.set_submenu(mb_view_menu)
+        mb_view.show()
         menubar.append(mb_view)
-        if self.SHOW_WIDGETS:
-            menubar.show_all()
+        menubar.show()
         return menubar
-
+    
     def _get_button_bar(self, operations):
         """Return a button bar to use.
 
@@ -356,13 +467,11 @@
         hbox.set_layout(Gtk.ButtonBoxStyle.START)
         for title, method in operations:
             merge_button = Gtk.Button(title)
-            if self.SHOW_WIDGETS:
-                merge_button.show()
+            merge_button.show()
             merge_button.set_relief(Gtk.ReliefStyle.NONE)
             merge_button.connect("clicked", method)
-            hbox.pack_start(merge_button, False, True, 0)
-        if self.SHOW_WIDGETS:
-            hbox.show()
+            hbox.pack_start(merge_button, expand=False, fill=True)
+        hbox.show()
         return hbox
 
     def _get_merge_target(self):
@@ -469,8 +578,8 @@
 class MergeDirectiveController(DiffController):
 
     def __init__(self, path, directive, window=None):
-        super(MergeDirectiveController, self).__init__(
-            path, directive.patch.splitlines(True), window)
+        DiffController.__init__(self, path, directive.patch.splitlines(True),
+                                window)
         self.directive = directive
         self.merge_target = None
 

=== modified file 'info.py'
--- info.py	2011-12-11 17:14:12 +0000
+++ info.py	2011-03-02 15:24:46 +0000
@@ -20,12 +20,12 @@
 # versions ending in 'exp' mean experimental mappings
 # versions ending in 'dev' mean development version
 # versions ending in 'final' mean release (well tested, etc)
-bzr_plugin_version = (0, 104, 0, 'dev', 0)
+bzr_plugin_version = (0, 101, 0, 'dev', 0)
 
 #FIXME: fill this in automatically somehow
 bzr_commands = []
 
-bzr_compatible_versions = [(2, 1, 0), (2, 2, 0), (2, 3, 0), (2, 4, 0), (2, 5, 0)]
+bzr_compatible_versions = [(2, 1, 0), (2, 2, 0), (2, 3, 0), (2, 4, 0)]
 
 bzr_minimum_version = bzr_compatible_versions[0]
 

=== modified file 'initialize.py'
--- initialize.py	2011-09-05 03:44:26 +0000
+++ initialize.py	2011-08-27 13:02:59 +0000
@@ -35,9 +35,10 @@
 
     def __init__(self, path, parent=None):
         """ Initialize the Initialize dialog. """
-        super(InitDialog, self).__init__(
-            title="Initialize - Olive", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Initialize - Olive",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
         
         # Get arguments
         self.path = path
@@ -60,18 +61,17 @@
         self._entry_custom.set_sensitive(False)
         
         # Construct the dialog
-        self.action_area.pack_end(self._button_init, False, False, 0)
-        
-        self._hbox_custom.pack_start(self._radio_custom, False, False, 0)
-        self._hbox_custom.pack_start(self._entry_custom, True, True, 0)
-        
-        content_area = self.get_content_area()
-        content_area.pack_start(self._label_question, True, True, 0)
-        content_area.pack_start(self._radio_current, True, True, 0)
-        content_area.pack_start(self._hbox_custom, True, True, 0)
+        self.action_area.pack_end(self._button_init)
+        
+        self._hbox_custom.pack_start(self._radio_custom, False, False)
+        self._hbox_custom.pack_start(self._entry_custom, True, True)
+        
+        self.vbox.pack_start(self._label_question, True, True, 0)
+        self.vbox.pack_start(self._radio_current, True, True, 0)
+        self.vbox.pack_start(self._hbox_custom, True, True, 0)
         
         # Display the dialog
-        content_area.show_all()
+        self.vbox.show_all()
     
     def _on_custom_toggled(self, widget):
         """ Occurs if the Custom radiobutton is toggled. """

=== added file 'keyring.py'
--- keyring.py	1970-01-01 00:00:00 +0000
+++ keyring.py	2011-08-01 14:46:23 +0000
@@ -0,0 +1,83 @@
+# Copyright (C) 2009 Jelmer Vernooij <jelmer@samba.org>
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from gi.repository import GObject
+try:
+    import gnomekeyring
+except ImportError:
+    gnomekeyring = None
+
+from bzrlib.config import (
+    CredentialStore,
+    )
+
+
+class GnomeKeyringCredentialStore(CredentialStore):
+
+    def __init__(self):
+        CredentialStore.__init__(self)
+        if GObject.get_application_name() is None:
+            # External applications that load bzrlib may already have set the
+            # application name so we don't contradict them (when we can
+            # determine it that is).
+            GObject.set_application_name("bzr")
+
+    def decode_password(self, credentials):
+        if gnomekeyring is None:
+            return None
+        attrs = {}
+        if "scheme" in credentials:
+            attrs["protocol"] = credentials["scheme"].encode("utf-8")
+        if "host" in credentials:
+            attrs["server"] = credentials["host"].encode("utf-8")
+        if "user" in credentials:
+            attrs["user"] = credentials["user"].encode("utf-8")
+        if credentials.get("port") is not None:
+            attrs["port"] = credentials["port"]
+        try:
+            items = gnomekeyring.find_items_sync(
+                gnomekeyring.ITEM_NETWORK_PASSWORD, attrs)
+            return items[0].secret
+        except (gnomekeyring.NoMatchError, gnomekeyring.DeniedError):
+            return None
+
+    def get_credentials(self, scheme, host, port=None, user=None, path=None, 
+                        realm=None):
+        if gnomekeyring is None:
+            return None
+        attrs = {
+            "protocol": scheme.encode("utf-8"),
+            "server": host.encode("utf-8"),
+            }
+        # TODO: realm ?
+        if port is not None:
+            attrs["port"] = port
+        if user is not None:
+            attrs["user"] = user.encode("utf-8")
+        credentials = { "scheme": scheme, "host": host, "port": port, 
+            "realm": realm, "user": user}
+        try:
+            items = gnomekeyring.find_items_sync(
+                gnomekeyring.ITEM_NETWORK_PASSWORD, attrs)
+            credentials["user"] = items[0].attributes["user"]
+            credentials["password"] = items[0].secret
+            return credentials
+        except (gnomekeyring.NoMatchError, gnomekeyring.DeniedError, gnomekeyring.NoKeyringDaemonError,
+                gnomekeyring.IOError), e:
+            from bzrlib import trace
+            trace.mutter('Unable to obtain credentials for %r from GNOME keyring: %r',
+                         attrs, e)
+            return None

=== modified file 'lock.py'
--- lock.py	2011-09-05 03:44:26 +0000
+++ lock.py	2011-08-01 14:46:23 +0000
@@ -1,3 +1,4 @@
+from gi.repository import GObject
 from gi.repository import Gtk
 
 
@@ -46,18 +47,16 @@
 class LockDialog(Gtk.Dialog):
 
     def __init__(self, branch):
-        super(LockDialog, self).__init__()
+        GObject.GObject.__init__(self)
 
         self.branch = branch
 
         self.set_title('Lock Not Held')
 
-        self.get_content_area().add(
-            Gtk.Label(label=(
-                'This operation cannot be completed as '
-                'another application has locked the branch.')))
+        self.vbox.add(Gtk.Label(label='This operation cannot be completed as ' \
+                                'another application has locked the branch.'))
 
         self.add_button('Break Lock', RESPONSE_BREAK)
         self.add_button(Gtk.STOCK_CANCEL, RESPONSE_CANCEL)
 
-        self.get_content_area().show_all()
+        self.vbox.show_all()

=== modified file 'loom.py'
--- loom.py	2011-09-08 03:11:06 +0000
+++ loom.py	2011-07-31 16:50:29 +0000
@@ -30,9 +30,10 @@
     """Simple Loom browse dialog."""
 
     def __init__(self, branch, tree=None, parent=None):
-        super(LoomDialog, self).__init__(
-            title="Threads", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CLOSE,Gtk.ResponseType.OK))
+        GObject.GObject.__init__(self, title="Threads",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CLOSE,Gtk.ResponseType.OK))
         self.branch = branch
         if tree is not None:
             self.tree = loom_tree.LoomTreeDecorator(tree)
@@ -77,10 +78,10 @@
 
         self._diff = DiffWidget()
         self._diff.show()
-        hbox.pack_end(self._diff, False, False, 0)
+        hbox.pack_end(self._diff)
 
         hbox.show_all()
-        self.get_content_area().pack_start(hbox, True, True, 0)
+        self.vbox.pack_start(hbox, True, True, 0)
 
         # FIXME: Buttons: combine-thread, revert-loom, record
         self.set_default_size(500, 350)

=== modified file 'merge.py'
--- merge.py	2012-03-11 18:24:06 +0000
+++ merge.py	2011-08-27 13:02:38 +0000
@@ -16,6 +16,7 @@
 
 import os
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from bzrlib.branch import Branch
@@ -36,9 +37,10 @@
     
     def __init__(self, wt, wtpath, default_branch_path=None, parent=None):
         """ Initialize the Merge dialog. """
-        super(MergeDialog, self).__init__(
-            title="Merge changes", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        Gtk.Dialog.__init__(self, title="Merge changes",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
         self.set_icon_from_file(icon_path("bzr-icon-64.png"))
         # Get arguments
         self.wt = wt
@@ -54,7 +56,7 @@
         for entry in [_i18n("Folder"),_i18n("Custom Location")]:
             self._combo_source.append_text(entry)
         self._combo_source.connect("changed", self._on_combo_changed)
-        self._button_merge = Gtk.Button(_i18n("_Merge"), use_underline=True)
+        self._button_merge = Gtk.Button(_i18n("_Merge"))
         self._button_merge_icon = Gtk.Image()
         self._button_merge_icon.set_from_stock(Gtk.STOCK_APPLY, Gtk.IconSize.BUTTON)
         self._button_merge.set_image(self._button_merge_icon)
@@ -65,7 +67,7 @@
         self._hbox.add(self._label_merge_from)
         self._hbox.add(self._combo_source)
         self._hbox.set_spacing(5)
-        self.action_area.pack_end(self._button_merge, False, False, 0)
+        self.action_area.pack_end(self._button_merge)
         
         if self.default_branch_path and os.path.isdir(
                             self.default_branch_path.partition('file://')[2]):

=== modified file 'mergedirective.py'
--- mergedirective.py	2011-11-30 21:45:54 +0000
+++ mergedirective.py	2011-08-13 01:28:20 +0000
@@ -61,7 +61,7 @@
         self.submit_branch = BranchSelectionBox(self.branch.get_submit_branch())
         table.attach(self.submit_branch, 1, 2, 1, 2, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
-        # TODO: Display number of revisions to be sent whenever 
+        # TODO: Display number of revisions to be send whenever 
         # submit branch changes
 
         label = Gtk.Label()

=== modified file 'missing.py'
--- missing.py	2012-02-09 03:43:01 +0000
+++ missing.py	2011-08-13 03:06:56 +0000
@@ -47,7 +47,7 @@
 
     def _create(self):
         self.set_default_size(600, 600)
-        paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        paned = Gtk.VPaned()
 
         frame = Gtk.Frame(label="You have the following extra revisions:")
 

=== modified file 'nautilus-bzr.py'
--- nautilus-bzr.py	2012-03-05 14:02:16 +0000
+++ nautilus-bzr.py	2011-07-31 15:52:43 +0000
@@ -2,108 +2,172 @@
 #
 # Copyright (C) 2006 Jeff Bailey
 # Copyright (C) 2006 Wouter van Heyst
-# Copyright (C) 2006-2011 Jelmer Vernooij <jelmer@samba.org>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 3 of the License, or
-# (at your option) any later version.
-
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-# Installation:
-# setup.py can install nautilus-bzr to the right system folder, if pkg-config
-# is present.
-#
-# You can also install nautilus-bzr manually by copying it (or linking it from)
-# ~/.local/share/nautilus-python/extensions/nautilus-bzr.py
-
-from gi.repository import Gtk, GObject, Nautilus
-from bzrlib.controldir import ControlDir
+# Copyright (C) 2006-2008 Jelmer Vernooij <jelmer@samba.org>
+#
+# Published under the GNU GPL
+
+from gi.repository import Gtk
+import nautilus
+from bzrlib.branch import Branch
+from bzrlib.bzrdir import BzrDir
 from bzrlib.errors import (
     NotBranchError,
     NoWorkingTree,
+    UnsupportedProtocol,
     )
-from bzrlib.ignores import tree_ignores_add_patterns
-from bzrlib.tree import InterTree
+from bzrlib.workingtree import WorkingTree
+from bzrlib.config import GlobalConfig
 
 from bzrlib.plugin import load_plugins
 load_plugins()
 
-from bzrlib.plugins.gtk.i18n import _i18n
-
-
-class BazaarExtension(Nautilus.MenuProvider, Nautilus.ColumnProvider,
-        Nautilus.InfoProvider, Nautilus.PropertyPageProvider,
-        Nautilus.LocationWidgetProvider, GObject.GObject):
-    """Nautilus extension providing Bazaar integration."""
+from bzrlib.plugins.gtk.commands import (
+    cmd_gannotate,
+    start_viz_window,
+    )
+
+print "Bazaar nautilus module initialized"
+
+
+class BzrExtension(nautilus.MenuProvider, nautilus.ColumnProvider, nautilus.InfoProvider):
 
     def __init__(self):
         pass
 
-    @classmethod
-    def _open_bzrdir(cls, vfs_file):
-        uri = vfs_file.get_uri()
-        controldir, path = ControlDir.open_containing(uri)
-        return controldir, path
-
-    @classmethod
-    def _open_tree(cls, vfs_file):
-        controldir, path = cls._open_bzrdir(vfs_file)
-        return controldir.open_workingtree(), path
-
-    def add_cb(self, menu, tree, path):
+    def add_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
         tree.add(path)
 
-    def ignore_cb(self, menu, tree, path):
-        # We can only cope with local files
-        tree_ignores_add_patterns(tree, [path])
-        #FIXME: Add path to ignore file
-
-    def unignore_cb(self, menu, tree, path):
-        pass
-        # We can only cope with local files
-        #FIXME
-
-    def diff_cb(self, menu, tree, path=None):
+        return
+
+    def ignore_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
+        #FIXME
+
+        return
+
+    def unignore_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
+        #FIXME
+
+        return
+
+    def diff_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
         from bzrlib.plugins.gtk.diff import DiffWindow
         window = DiffWindow()
         window.set_diff(tree.branch._get_nick(local=True), tree, 
                         tree.branch.basis_tree())
         window.show()
 
+        return
+
     def newtree_cb(self, menu, vfs_file):
-        controldir, path = self._open_bzrdir(vfs_file)
-        controldir.create_workingtree()
-
-    def remove_cb(self, menu, tree, path):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+
+        # We only want to continue here if we get a NotBranchError
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            BzrDir.create_standalone_workingtree(file)
+
+    def remove_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
         tree.remove(path)
 
-    def annotate_cb(self, menu, tree, path, file_id):
-        from bzrlib.plugins.gtk.annotate.gannotate import GAnnotateWindow
-        win = GAnnotateWindow()
-        win.show()
-        win.annotate(tree, tree.branch, file_id)
-        Gtk.main()
+    def annotate_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+
+        vis = cmd_gannotate()
+        vis.run(file)
 
     def clone_cb(self, menu, vfs_file=None):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
         from bzrlib.plugins.gtk.branch import BranchDialog
-        controldir, path = self._open_bzrdir(vfs_file)
-
+        
         dialog = BranchDialog(vfs_file.get_name())
         response = dialog.run()
         if response != Gtk.ResponseType.NONE:
             dialog.hide()
             dialog.destroy()
-
-    def commit_cb(self, menu, tree, path=None):
+ 
+    def commit_cb(self, menu, vfs_file=None):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        tree = None
+        branch = None
+        try:
+            tree, path = WorkingTree.open_containing(file)
+            branch = tree.branch
+        except NotBranchError, e:
+            path = e.path
+            #return
+        except NoWorkingTree, e:
+            path = e.base
+            try:
+                (branch, path) = Branch.open_containing(path)
+            except NotBranchError, e:
+                path = e.path
+
         from bzrlib.plugins.gtk.commit import CommitDialog
         dialog = CommitDialog(tree, path)
         response = dialog.run()
@@ -111,436 +175,294 @@
             dialog.hide()
             dialog.destroy()
 
-    def log_cb(self, menu, controldir, path=None):
-        from bzrlib.plugins.gtk.viz import BranchWindow
-        branch = controldir.open_branch()
-        pp = BranchWindow(branch, [branch.last_revision()], None)
+    def log_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+
+        # We only want to continue here if we get a NotBranchError
+        try:
+            branch, path = Branch.open_containing(file)
+        except NotBranchError:
+            return
+
+        pp = start_viz_window(branch, [branch.last_revision()])
         pp.show()
         Gtk.main()
 
-    def pull_cb(self, menu, controldir, path=None):
+    def pull_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+
+        # We only want to continue here if we get a NotBranchError
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
         from bzrlib.plugins.gtk.pull import PullDialog
-        dialog = PullDialog(controldir.open_workingtree(), path)
-        dialog.display()
-        Gtk.main()
-
-    def push_cb(self, menu, controldir, path=None):
-        from bzrlib.plugins.gtk.push import PushDialog
-        dialog = PushDialog(branch=controldir.open_workingtree().branch)
-        dialog.display()
-        Gtk.main()
-
-    def merge_cb(self, menu, tree, path=None):
+        dialog = PullDialog(tree, path)
+        dialog.display()
+        Gtk.main()
+
+    def merge_cb(self, menu, vfs_file):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+
+        # We only want to continue here if we get a NotBranchError
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
         from bzrlib.plugins.gtk.merge import MergeDialog
         dialog = MergeDialog(tree, path)
         dialog.run()
         dialog.destroy()
 
-    def create_tree_cb(self, menu, controldir):
-        controldir.create_workingtree()
-
     def get_background_items(self, window, vfs_file):
+        items = []
+        file = vfs_file.get_uri()
+
         try:
-            controldir, path = self._open_bzrdir(vfs_file)
-        except NotBranchError:
+            tree, path = WorkingTree.open_containing(file)
+            disabled_flag = self.check_branch_enabled(tree.branch)
+        except UnsupportedProtocol:
             return
-        try:
-            branch = controldir.open_branch()
         except NotBranchError:
-            items = []
-            item = Nautilus.MenuItem(name='BzrNautilus::newtree',
-                                 label='Make directory versioned',
-                                 tip='Create new Bazaar tree in this folder',
-                                 icon='')
+            disabled_flag = self.check_branch_enabled()
+            item = nautilus.MenuItem('BzrNautilus::newtree',
+                                 'Make directory versioned',
+                                 'Create new Bazaar tree in this folder')
             item.connect('activate', self.newtree_cb, vfs_file)
             items.append(item)
 
-            item = Nautilus.MenuItem(name='BzrNautilus::clone',
-                                 label='Checkout Bazaar branch ...',
-                                 tip='Checkout Existing Bazaar Branch',
-                                 icon='')
+            item = nautilus.MenuItem('BzrNautilus::clone',
+                                 'Checkout Bazaar branch ...',
+                                 'Checkout Existing Bazaar Branch')
             item.connect('activate', self.clone_cb, vfs_file)
             items.append(item)
+
             return items
-
-        items = []
-
-        nautilus_integration = self.check_branch_enabled(branch)
-        if not nautilus_integration:
-            item = Nautilus.MenuItem(name='BzrNautilus::enable',
-                                     label='Enable Bazaar Plugin for this Branch',
-                                     tip='Enable Bazaar plugin for nautilus',
-                                     icon='')
-            item.connect('activate', self.toggle_integration, True, branch)
-            return [item]
-        else:
-            item = Nautilus.MenuItem(name='BzrNautilus::disable',
-                                     label='Disable Bazaar Plugin this Branch',
-                                     tip='Disable Bazaar plugin for nautilus',
-                                     icon='')
-            item.connect('activate', self.toggle_integration, False, branch)
-            items.append(item)
-
-        item = Nautilus.MenuItem(name='BzrNautilus::log',
-                             label='History ...',
-                             tip='Show Bazaar history',
-                             icon='')
-        item.connect('activate', self.log_cb, controldir)
-        items.append(item)
-
-        item = Nautilus.MenuItem(name='BzrNautilus::pull',
-                             label='Pull ...',
-                             tip='Pull from another branch',
-                             icon='')
-        item.connect('activate', self.pull_cb, controldir)
-        items.append(item)
-
-        try:
-            tree = controldir.open_workingtree()
         except NoWorkingTree:
-            item = Nautilus.MenuItem(name='BzrNautilus::create_tree',
-                                 label='Create working tree...',
-                                 tip='Create a working tree for this branch',
-                                 icon='')
-            item.connect('activate', self.create_tree_cb, controldir)
-            items.append(item)
+            return
+        
+        if disabled_flag == 'False':
+            item = nautilus.MenuItem('BzrNautilus::enable',
+                                     'Enable Bazaar Plugin for this Branch',
+                                     'Enable Bazaar plugin for nautilus')
+            item.connect('activate', self.toggle_integration, 'True', vfs_file)
+            return item,
         else:
-            item = Nautilus.MenuItem(name='BzrNautilus::merge',
-                                 label='Merge ...',
-                                 tip='Merge from another branch',
-                                 icon='')
-            item.connect('activate', self.merge_cb, tree, path)
-            items.append(item)
-
-            item = Nautilus.MenuItem(name='BzrNautilus::commit',
-                                 label='Commit ...',
-                                 tip='Commit Changes',
-                                 icon='')
-            item.connect('activate', self.commit_cb, tree, path)
-            items.append(item)
+            item = nautilus.MenuItem('BzrNautilus::disable',
+                                      'Disable Bazaar Plugin this Branch',
+                                      'Disable Bazaar plugin for nautilus')
+            item.connect('activate', self.toggle_integration, 'False', vfs_file)
+            items.append(item)
+
+        item = nautilus.MenuItem('BzrNautilus::log',
+                             'History ...',
+                             'Show Bazaar history')
+        item.connect('activate', self.log_cb, vfs_file)
+        items.append(item)
+
+        item = nautilus.MenuItem('BzrNautilus::pull',
+                             'Pull ...',
+                             'Pull from another branch')
+        item.connect('activate', self.pull_cb, vfs_file)
+        items.append(item)
+
+        item = nautilus.MenuItem('BzrNautilus::merge',
+                             'Merge ...',
+                             'Merge from another branch')
+        item.connect('activate', self.merge_cb, vfs_file)
+        items.append(item)
+
+        item = nautilus.MenuItem('BzrNautilus::commit',
+                             'Commit ...',
+                             'Commit Changes')
+        item.connect('activate', self.commit_cb, vfs_file)
+        items.append(item)
 
         return items
 
-    def _get_file_menuitems(self, tree, intertree, path):
-        file_id = tree.path2id(path)
-        if file_id is None:
-            item = Nautilus.MenuItem(name='BzrNautilus::add',
-                                 label='Add',
-                                 tip='Add as versioned file',
-                                 icon='')
-            item.connect('activate', self.add_cb, tree, path)
-            yield item
-
-            item = Nautilus.MenuItem(name='BzrNautilus::ignore',
-                                 label='Ignore',
-                                 tip='Ignore file for versioning',
-                                 icon='')
-            item.connect('activate', self.ignore_cb, tree, path)
-            yield item
-        elif tree.is_ignored(path):
-            item = Nautilus.MenuItem(name='BzrNautilus::unignore',
-                                 label='Unignore',
-                                 tip='Unignore file for versioning',
-                                 icon='')
-            item.connect('activate', self.unignore_cb, tree, path)
-            yield item
-        else:
-            kind = tree.kind(file_id)
-            item = Nautilus.MenuItem(name='BzrNautilus::log',
-                             label='History ...',
-                             tip='List changes',
-                             icon='')
-            item.connect('activate', self.log_cb, tree.bzrdir, path)
-            yield item
-
-            if not intertree.file_content_matches(file_id, file_id):
-                item = Nautilus.MenuItem(name='BzrNautilus::diff',
-                                 label='View Changes ...',
-                                 tip='Show differences',
-                                 icon='')
-                item.connect('activate', self.diff_cb, tree, path)
-                yield item
-
-                item = Nautilus.MenuItem(name='BzrNautilus::commit',
-                             label='Commit ...',
-                             tip='Commit Changes',
-                             icon='')
-                item.connect('activate', self.commit_cb, tree, path)
-                yield item
-
-            item = Nautilus.MenuItem(name='BzrNautilus::remove',
-                                 label='Remove',
-                                 tip='Remove this file from versioning',
-                                 icon='')
-            item.connect('activate', self.remove_cb, tree, path)
-            yield item
-
-            if kind == 'file':
-                item = Nautilus.MenuItem(name='BzrNautilus::annotate',
-                             label='Annotate ...',
-                             tip='Annotate File Data',
-                             icon='')
-                item.connect('activate', self.annotate_cb, tree, path, file_id)
-                yield item
-
     def get_file_items(self, window, files):
         items = []
-        trees = {}
-
-        try:
-            for vfs_file in files:
-                controldir, path = self._open_bzrdir(vfs_file)
-
-                try:
-                    tree = trees[controldir.user_url]
-                except KeyError:
-                    try:
-                        tree = controldir.open_workingtree()
-                    except NoWorkingTree:
-                        continue
-                    trees[controldir.user_url] = tree
-                    tree.lock_read()
-
-                nautilus_integration = self.check_branch_enabled(tree.branch)
-                if not nautilus_integration:
+        
+        wtfiles = {}
+        for vfs_file in files:
+            # We can only cope with local files
+            if vfs_file.get_uri_scheme() != 'file':
+                continue
+
+            file = vfs_file.get_uri()
+            try:
+                tree, path = WorkingTree.open_containing(file)
+                disabled_flag = self.check_branch_enabled(tree.branch)
+            except NotBranchError:
+                disabled_flag = self.check_branch_enabled()
+                if not vfs_file.is_directory():
                     continue
 
-                intertree = InterTree.get(tree.basis_tree(), tree)
-                items.extend(list(self._get_file_menuitems(tree, intertree, path)))
-        finally:
-            for tree in trees.itervalues():
+                if disabled_flag == 'False':
+                    return
+
+                item = nautilus.MenuItem('BzrNautilus::newtree',
+                                     'Make directory versioned',
+                                     'Create new Bazaar tree in %s' % vfs_file.get_name())
+                item.connect('activate', self.newtree_cb, vfs_file)
+                return item,
+            except NoWorkingTree:
+                continue
+            # Refresh the list of filestatuses in the working tree
+            if path not in wtfiles.keys():
+                tree.lock_read()
+                for rpath, file_class, kind, id, entry in tree.list_files():
+                    wtfiles[rpath] = file_class
                 tree.unlock()
+                wtfiles[u''] = 'V'
+
+            if wtfiles[path] == '?':
+                item = nautilus.MenuItem('BzrNautilus::add',
+                                     'Add',
+                                     'Add as versioned file')
+                item.connect('activate', self.add_cb, vfs_file)
+                items.append(item)
+
+                item = nautilus.MenuItem('BzrNautilus::ignore',
+                                     'Ignore',
+                                     'Ignore file for versioning')
+                item.connect('activate', self.ignore_cb, vfs_file)
+                items.append(item)
+            elif wtfiles[path] == 'I':
+                item = nautilus.MenuItem('BzrNautilus::unignore',
+                                     'Unignore',
+                                     'Unignore file for versioning')
+                item.connect('activate', self.unignore_cb, vfs_file)
+                items.append(item)
+            elif wtfiles[path] == 'V':
+                item = nautilus.MenuItem('BzrNautilus::log',
+                                 'History ...',
+                                 'List changes')
+                item.connect('activate', self.log_cb, vfs_file)
+                items.append(item)
+
+                item = nautilus.MenuItem('BzrNautilus::diff',
+                                 'View Changes ...',
+                                 'Show differences')
+                item.connect('activate', self.diff_cb, vfs_file)
+                items.append(item)
+
+                item = nautilus.MenuItem('BzrNautilus::remove',
+                                     'Remove',
+                                     'Remove this file from versioning')
+                item.connect('activate', self.remove_cb, vfs_file)
+                items.append(item)
+
+                item = nautilus.MenuItem('BzrNautilus::annotate',
+                             'Annotate ...',
+                             'Annotate File Data')
+                item.connect('activate', self.annotate_cb, vfs_file)
+                items.append(item)
+
+                item = nautilus.MenuItem('BzrNautilus::commit',
+                             'Commit ...',
+                             'Commit Changes')
+                item.connect('activate', self.commit_cb, vfs_file)
+                items.append(item)
 
         return items
 
     def get_columns(self):
-        return [
-            Nautilus.Column(name="BzrNautilus::bzr_status",
-                            attribute="bzr_status",
-                            label="Status",
-                            description="Version control status"),
-            Nautilus.Column(name="BzrNautilus::bzr_revision",
-                            attribute="bzr_revision",
-                            label="Revision",
-                            description="Last change revision"),
-            ]
-
-    def _file_summary(self, tree, basis_tree, intertree, path):
-        file_revision = ""
+        return nautilus.Column("BzrNautilus::bzr_status",
+                               "bzr_status",
+                               "Bzr Status",
+                               "Version control status"),
+
+    def update_file_info(self, file):
+
+        if file.get_uri_scheme() != 'file':
+            return
+        
+        try:
+            tree, path = WorkingTree.open_containing(file.get_uri())
+        except NotBranchError:
+            return
+        except NoWorkingTree:
+            return   
+
+        disabled_flag = self.check_branch_enabled(tree.branch)
+        if disabled_flag == 'False':
+            return
+
         emblem = None
+        status = None
 
-        file_id = tree.path2id(path)
-        if file_id is None:
+        id = tree.path2id(path)
+        if id == None:
             if tree.is_ignored(path):
                 status = 'ignored'
                 emblem = 'bzr-ignored'
             else:
                 status = 'unversioned'
-            file_revision = "N/A"
-        elif tree.has_filename(path): # Still present
-            if not intertree.file_content_matches(file_id, file_id):
-                if not basis_tree.has_id(file_id):
+                        
+        elif tree.has_filename(path):
+            emblem = 'bzr-controlled'
+            status = 'unchanged'
+
+            delta = tree.changes_from(tree.branch.basis_tree())
+            if delta.touches_file_id(id):
+                emblem = 'bzr-modified'
+                status = 'modified'
+            for f, _, _ in delta.added:
+                if f == path:
                     emblem = 'bzr-added'
                     status = 'added'
-                    file_revision = "new file"
-                elif basis_tree.path2id(file_id) != path:
-                    status = 'bzr-renamed'
-                    status = 'renamed from %s' % basis_tree.path2id(file_id)
-                else:
-                    emblem = 'bzr-modified'
-                    status = 'modified'
-            else:
-                emblem = 'bzr-controlled'
-                status = 'unchanged'
-        elif basis_tree.has_filename(path):
+
+            for of, f, _, _, _, _ in delta.renamed:
+                if f == path:
+                    status = 'renamed from %s' % f
+
+        elif tree.branch.basis_tree().has_filename(path):
             emblem = 'bzr-removed'
             status = 'removed'
         else:
             # FIXME: Check for ignored files
             status = 'unversioned'
-        return (status, emblem, file_revision)
-
-    def update_file_info(self, vfs_file):
-        try:
-            controldir, path = self._open_bzrdir(vfs_file)
-        except NotBranchError:
-            return
-
-        try:
-            tree = controldir.open_workingtree()
-        except NoWorkingTree:
-            return
-
-        tree.lock_read()
-        try:
-            nautilus_integration = self.check_branch_enabled(tree.branch)
-            if not nautilus_integration:
-                return
-
-            basis_tree = tree.basis_tree()
-            intertree = InterTree.get(basis_tree, tree)
-
-            basis_tree.lock_read()
-            try:
-                (status, emblem, file_revision) = self._file_summary(tree, basis_tree, intertree, path)
-            finally:
-                basis_tree.unlock()
-            if emblem is not None:
-                vfs_file.add_emblem(emblem)
-            vfs_file.add_string_attribute('bzr_status', status)
-            vfs_file.add_string_attribute('bzr_revision', file_revision)
-        finally:
-            tree.unlock()
-
-    def check_branch_enabled(self, branch):
+        
+        if emblem is not None:
+            file.add_emblem(emblem)
+        file.add_string_attribute('bzr_status', status)
+
+    def check_branch_enabled(self, branch=None):
         # Supports global disable, but there is currently no UI to do this
-        config = branch.get_config_stack()
-        return config.get("nautilus_integration")
-
-    def toggle_integration(self, menu, action, branch):
-        config = branch.get_config_stack()
-        config.set("nautilus_integration", action)
-
-    def get_property_pages(self, files):
-        pages = []
-        for vfs_file in files:
-            try:
-                controldir, path = self._open_bzrdir(vfs_file)
-            except NotBranchError:
-                continue
-
-            try:
-                tree = controldir.open_workingtree()
-            except NoWorkingTree:
-                continue
-
-            tree.lock_read()
-            try:
-                file_id = tree.path2id(path)
-                pages.append(PropertyPageFile(tree, file_id, path))
-                pages.append(PropertyPageBranch(tree.branch))
-            finally:
-                tree.unlock()
-        return pages
-
-    def get_widget(self, uri, window):
-        controldir, path = ControlDir.open_containing(uri)
+        config = GlobalConfig()
+        disabled_flag = config.get_user_option('nautilus_integration')
+        if disabled_flag != 'False':
+            if branch is not None:
+                config = branch.get_config()
+                disabled_flag = config.get_user_option('nautilus_integration')
+        return disabled_flag
+
+    def toggle_integration(self, menu, action, vfs_file=None):
         try:
-            tree = controldir.open_workingtree()
+            tree, path = WorkingTree.open_containing(vfs_file.get_uri())
+        except NotBranchError:
+            return
         except NoWorkingTree:
             return
-        ret = Gtk.HBox(False, 4)
-        text = 'This is a Bazaar working tree. '
-        get_shelf_manager = getattr(tree, 'get_shelf_manager', None)
-        if get_shelf_manager is not None:
-            manager = get_shelf_manager()
-            shelves = manager.active_shelves()
-            if len(shelves) == 0:
-                pass
-            elif len(shelves) == 1:
-                text += '1 shelf exists. '
-            else:
-                text += '%d shelf exists. ' % len(shelves)
-        label = Gtk.Label(text)
-        label.show()
-        ret.pack_start(label, True, True, 0)
-        ret.show_all()
-        return ret
-
-
-class PropertyPageFile(Nautilus.PropertyPage):
-
-    def __init__(self, tree, file_id, path):
-        self.tree = tree
-        self.file_id = file_id
-        self.path = path
-        label = Gtk.Label('File Version')
-        label.show()
-
-        table = self._create_table()
-
-        super(PropertyPageFile, self).__init__(label=label,
-            name="BzrNautilus::file_page", page=table)
-
-    def _create_table(self):
-        table = Gtk.Table(homogeneous=False, columns=2, rows=3)
-
-        table.attach(Gtk.Label(_i18n('File id:')), 0, 1, 0, 1)
-        table.attach(Gtk.Label(self.file_id), 1, 2, 0, 1)
-
-        table.attach(Gtk.Label(_i18n('SHA1Sum:')), 0, 1, 1, 2)
-        table.attach(Gtk.Label(self.tree.get_file_sha1(self.file_id, self.path)), 1, 1, 1, 2)
-
-        basis_tree = self.tree.revision_tree(self.tree.last_revision())
-        last_revision = basis_tree.get_file_revision(self.file_id)
-
-        table.attach(Gtk.Label(_i18n('Last Change Revision:')), 0, 1, 2, 3)
-        revno = ".".join([str(x) for x in
-            self.tree.branch.revision_id_to_dotted_revno(last_revision)])
-        table.attach(Gtk.Label(revno), 1, 1, 2, 3)
-
-        table.attach(Gtk.Label(_i18n('Last Change Author:')), 0, 1, 3, 4)
-        rev = self.tree.branch.repository.get_revision(last_revision)
-        table.attach(Gtk.Label("\n".join(rev.get_apparent_authors())), 1, 1, 3, 4)
-
-        table.show_all()
-        return table
-
-
-class PropertyPageBranch(Nautilus.PropertyPage):
-
-    def __init__(self, branch):
-        self.branch = branch
-        label = Gtk.Label('Branch')
-        label.show()
-
-        table = self._create_table()
-
-        super(PropertyPageBranch, self).__init__(label=label,
-            name="BzrNautilus::branch_page", page=table)
-
-    def _create_location_entry(self, get_location, set_location):
-        location = get_location()
-        ret = Gtk.Entry()
-        if location is not None:
-            ret.set_text(location)
-        return ret
-
-    def _create_table(self):
-        table = Gtk.Table(homogeneous=False, columns=2, rows=6)
-
-        self._push_location_entry = self._create_location_entry(
-            self.branch.get_push_location, self.branch.set_push_location)
-        self._parent_location_entry = self._create_location_entry(
-            self.branch.get_parent, self.branch.set_parent)
-        self._bound_location_entry = self._create_location_entry(
-            self.branch.get_bound_location, self.branch.set_bound_location)
-        self._public_location_entry = self._create_location_entry(
-            self.branch.get_public_branch, self.branch.set_public_branch)
-        self._submit_location_entry = self._create_location_entry(
-            self.branch.get_submit_branch, self.branch.set_submit_branch)
-
-        table.attach(Gtk.Label(_i18n('Push location:')), 0, 1, 0, 1)
-        table.attach(self._push_location_entry, 1, 2, 0, 1)
-
-        table.attach(Gtk.Label(_i18n('Parent location:')), 0, 1, 1, 2)
-        table.attach(self._parent_location_entry, 1, 1, 1, 2)
-
-        table.attach(Gtk.Label(_i18n('Bound location:')), 0, 1, 2, 3)
-        table.attach(self._bound_location_entry, 1, 1, 2, 3)
-
-        table.attach(Gtk.Label(_i18n('Public location:')), 0, 1, 3, 4)
-        table.attach(self._public_location_entry, 1, 1, 3, 4)
-
-        table.attach(Gtk.Label(_i18n('Submit location:')), 0, 1, 4, 5)
-        table.attach(self._submit_location_entry, 1, 1, 4, 5)
-
-        self._append_revisions_only = Gtk.CheckButton(_i18n('Append revisions only'))
-        value = self.branch.get_append_revisions_only()
-        if value is None:
-            value = False
-        self._append_revisions_only.set_active(value)
-        table.attach(self._append_revisions_only, 0, 2, 5, 6)
-
-        table.show_all()
-        return table
+        branch = tree.branch
+        if branch is None:
+            config = GlobalConfig()
+        else:
+            config = branch.get_config()
+        config.set_user_option('nautilus_integration', action)
+

=== added file 'notify.py'
--- notify.py	1970-01-01 00:00:00 +0000
+++ notify.py	2011-07-31 16:50:29 +0000
@@ -0,0 +1,101 @@
+# Copyright (C) 2007 by Robert Collins
+#                       Jelmer Vernooij
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+"""Notification area icon and notification for Bazaar."""
+
+from gi.repository import Gtk
+import bzrlib
+
+
+def has_dbus():
+    return (getattr(bzrlib.plugins, "dbus", None) is not None)
+
+
+def has_avahi():
+    return (getattr(bzrlib.plugins, "avahi", None) is not None)
+
+
+class NotifyPopupMenu(Gtk.Menu):
+
+    def __init__(self):
+        super(NotifyPopupMenu, self).__init__()
+        self.create_items()
+
+    def create_items(self):
+        from bzrlib import errors
+        item = Gtk.CheckMenuItem('_Gateway to LAN')
+        item.connect('toggled', self.toggle_lan_gateway)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        try:
+            from bzrlib.plugins.dbus.activity import LanGateway
+            self.langateway = LanGateway()
+        except ImportError:
+            item.set_sensitive(False)
+        except errors.BzrError:
+            # FIXME: Should only catch errors that indicate a lan-notify 
+            # process is already running.
+            item.set_sensitive(False)
+
+        item = Gtk.CheckMenuItem('Announce _branches on LAN')
+        item.connect('toggled', self.toggle_announce_branches)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        try:
+            from bzrlib.plugins.avahi.share import ZeroConfServer
+            from bzrlib import urlutils
+            self.zeroconfserver = ZeroConfServer(urlutils.normalize_url('.'))
+        except ImportError:
+            item.set_sensitive(False)
+
+        item = Gtk.ImageMenuItem(Gtk.STOCK_PREFERENCES, None)
+        item.connect('activate', self.show_preferences)
+        self.append(item)
+        item = Gtk.ImageMenuItem(Gtk.STOCK_ABOUT, None)
+        item.connect('activate', self.show_about)
+        self.append(item)
+        self.append(Gtk.SeparatorMenuItem())
+        item = Gtk.ImageMenuItem(Gtk.STOCK_QUIT, None)
+        item.connect('activate', Gtk.main_quit)
+        self.append(item)
+        self.show_all()
+
+    def display(self, icon, event_button, event_time):
+        self.popup(None, None, Gtk.status_icon_position_menu, 
+               event_button, event_time, icon)
+
+    def toggle_lan_gateway(self, item):
+        if item.get_active():
+            self.langateway.start()
+        else:
+            self.langateway.stop()
+
+    def toggle_announce_branches(self, item):
+        if item.get_active():
+            self.zeroconfserver.start()
+        else:
+            self.zeroconfserver.close()
+
+    def show_about(self, item):
+        from bzrlib.plugins.gtk.about import AboutDialog
+        dialog = AboutDialog()
+        dialog.run()
+
+    def show_preferences(self, item):
+        from bzrlib.plugins.gtk.preferences import PreferencesWindow
+        prefs = PreferencesWindow()
+        prefs.run()
+

=== modified file 'po/bzr-gtk.pot'
--- po/bzr-gtk.pot	2011-12-01 10:46:10 +0000
+++ po/bzr-gtk.pot	2011-03-06 08:24:07 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: PACKAGE VERSION\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,132 +208,132 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -345,178 +345,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -524,119 +524,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -644,11 +604,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -656,32 +616,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -693,44 +653,44 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""

=== modified file 'po/ca.po'
--- po/ca.po	2011-12-02 05:55:20 +0000
+++ po/ca.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-07 18:37+0000\n"
 "Last-Translator: David Planella <david.planella@ubuntu.com>\n"
 "Language-Team: Ubuntu Catalan Translators <ubuntu-l10n-ca@lists.ubuntu.com>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr "Icona a l'àrea de notificació per al Bazaar"
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "Crea una _branca"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Ubicació de la branca:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destinació:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Sobrenom de la branca:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisió"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Seleccioneu una carpeta"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Manca la ubicació de la branca"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Heu d'especificar la ubicació de la branca."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "S'ha creat la branca satisfactòriament"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "S'ha creat una branca de %d revisions."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "_Obté"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr "Sobrenom de la branca:"
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Obtenció _lleugera"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "El directori no té cap arbre de treball"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "S'ha interromput l'operació"
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Hi ha modificacions locals a la branca"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Heu de publicar o desfer els canvis abans de poder fer la fusió."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "afegit"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "suprimit"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "canviat de nom"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "nom canviat i modificat"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificat"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "_Només publica localment"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Pu_blica"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr "Fitxers"
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Publica"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Camí"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tipus"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Publicador"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Resum"
 
@@ -208,135 +208,135 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Voleu publicar-ho amb un missatge buit?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Podeu descriure el vostre intent de publicació en el missatge"
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Voleu publicar-ho tot i haver-hi fitxers desconeguts?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Hi ha fitxers desconeguts en l'arbre de treball. Voleu publicar de totes "
 "maneres?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Voleu publicar sense canvis?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Eina externa:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflictes"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No hi ha cap conflicte en l'arbre de treball."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflicte de camí"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflicte de contingut"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflicte de text"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "identificador duplicat"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicat"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "bucle del pare"
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "pare sense versionar"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "manca el pare"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "supressió del pare"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipus de conflicte desconegut"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "No s'ha seleccionat cap fitxer"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Seleccioneu un fitxer de la llista."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Ha fallat l'execució de l'eina externa"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "No es pot resoldre el conflicta"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -351,74 +351,74 @@
 msgid "_View"
 msgstr "_Visualització"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "S'ha fusionat correctament"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "S'han aplicat tots els canvis correctament."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "S'han trobat conflictes."
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Heu de resoldre els conflictes manualment abans de poder publicar."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "El directori no és una branca"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "No podeu dur a terme aquesta acció en una branca."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "El directori no és una obtenció"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Només podeu fer publicacions locals en obtencions."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "No hi ha cap canvi per a publicar"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Intenteu una publicació forçada si és que voleu publicar de totes maneres."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Hi ha conflictes en l'arbre"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Heu de resoldre els conflictes abans de publicar."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "La publicació estricta ha fallat"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -426,29 +426,29 @@
 "Hi ha fitxers desconeguts a l'arbre de treball.\n"
 "Hauríeu d'afegir-los o suprimir-los."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "La branca lligada no està actualitzada"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Fitxer no versionat"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "El fitxer seleccionat no és versionat"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "S'han divergit les branques"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -457,35 +457,35 @@
 "Utilitzeu la opció de sobreescriptura si voleu\n"
 "empènyer de totes maneres."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Sense sortida diff"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "El fitxer seleccionat no ha estat modificat."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "No existeix tal revisió"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La revisió que heu especificat no existeix."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "La destinació ja existeix"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "El directori objectiu ja existeix. Seleccioneu-ne un altre."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "El directori ja és una branca"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -494,11 +494,11 @@
 "El directori actual (%s) ja és una branca.\n"
 "Podeu començar a utilitzar-lo o bé inicialitzar un altre directori."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branca sense un arbre de treball"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -507,32 +507,32 @@
 "El directori actual (%s)\n"
 "és una branca sense cap arbre de treball."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Error desconegut del bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Se us ha denegat el permís"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "se us ha denegat el permís"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Error desconegut"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicialitza"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Quin directori voleu inicialitzar?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "El directori actual"
 
@@ -540,101 +540,61 @@
 msgid "Create a new directory with the name:"
 msgstr "Crea un directori nou amb el nom següent:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "No s'ha especificat cap nom de directori"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Heu d'especificar un nom per al directori"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr "Directori"
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr "Ubicació personalitzada"
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Fusiona"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "No s'ha especificat cap branca"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 "Heu d'especificar el nom de la branca a partir de la qual es fusionarà"
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Error en l'ordre del Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Ubicació:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "E_mpeny"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -642,20 +602,20 @@
 "No podeu empènyer branques que hagin divergit.\n"
 "Voleu sobreescriure-la?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "S'ha empès satisfactòriament"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "S'han empès %d revisions."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "El directori pare no existeix"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -665,11 +625,11 @@
 "no existeix. El voleu crear?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selecciona"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr "Cerca:"
 
@@ -677,32 +637,32 @@
 msgid "Document"
 msgstr "Document"
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Afegit"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Suprimit"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Nom canviat"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificat"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Desconegut"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Sense canvis."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetes"
 
@@ -714,46 +674,615 @@
 msgid "Revision ID"
 msgstr "Identificador de la revisió"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Les etiquetes no estan implementades en aquest format de branca. Hauríeu "
 "d'actualitzar-lo."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No hi ha cap revisió etiquetada a la branca."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Suprimeix l'etiqueta"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Voleu suprimir l'etiqueta?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Esteu segur de voler suprimir l'etiqueta: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Afegeix una etiqueta"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nom de l'etiqueta:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Identificador de la revisió:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No s'ha especificat cap nom per a l'etiqueta"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Heu d'especificar un nom per a l'etiqueta."
+
+#~ msgid "_Rename..."
+#~ msgstr "Canvia el _nom..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mou..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crea un _directori..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Suprimeix fitxers..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - IU del Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Afegeix fitxers..."
+
+#~ msgid "_File"
+#~ msgstr "_Fitxer"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refresca"
+
+#~ msgid "_Get..."
+#~ msgstr "_Aconsegueix..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostra els fit_xers ocults"
+
+#~ msgid "C_heckout..."
+#~ msgstr "O_bté..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "E_stira"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Es_tat..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Publica..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "E_mpeny..."
+
+#~ msgid "_Log..."
+#~ msgstr "Re_gistre..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferències..."
+
+#~ msgid "_Statistics"
+#~ msgstr "E_stadístiques"
+
+#~ msgid "_Help"
+#~ msgstr "A_juda"
+
+#~ msgid "Diff"
+#~ msgstr "Diferencia"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quins fitxers voleu afegir?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - addició de fitxers"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tots els fitxers amb l'estat «added» (afegits)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Suprimeix"
+
+#~ msgid "Selected only"
+#~ msgstr "Només els seleccionats"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - supressió de fitxers"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quins fitxers voleu suprimir?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Tots els desconeguts de manera recursiva"
+
+#~ msgid "_Add"
+#~ msgstr "_Afegeix"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - creació d'un directori"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Directori _versionat"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crea un directori"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - moviment"
+
+#~ msgid "Move to"
+#~ msgstr "Mou a"
+
+#~ msgid "Rename to"
+#~ msgstr "Canvia el nom a"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - canvi de nom"
+
+#~ msgid "_Move"
+#~ msgstr "_Mou"
+
+#~ msgid "Select a directory"
+#~ msgstr "Seleccioneu un directori"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publica a la branca: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branca pare: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Arrel de l'obtenció: "
+
+#~ msgid "(none)"
+#~ msgstr "(cap)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Obtenció del repositori: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Arrel de la branca: "
+
+#~ msgid "Control format: "
+#~ msgstr "Format del control: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format de l'arbre de treball: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fitxers amb el nom canviat: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fitxers desconeguts: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fitxers ignorats: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fitxers no modificats: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fitxers modificats: "
+
+#~ msgid "Added files: "
+#~ msgstr "Fitxers afegits: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fitxers suprimits: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revisions que manquen en l'arbre de treball: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revisions que manquen a la branca: "
+
+#~ msgid "Title:"
+#~ msgstr "Títol:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Data de la darrera revisió "
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Seleccioneu un fitxer de la llista\n"
+#~ "o bé escolliu l'altra opció."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Mida del dipòsit: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisions al dipòsit: "
+
+#~ msgid "Pull successful"
+#~ msgstr "L'estirada s'ha completat satisfactòriament"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "S'han estirat %d revisions."
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Manquen revisions"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "No es poden determinar les revisions que manquen si la ubicació pare és "
+#~ "desconeguda."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branca local actualitzada"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "Manquen %d revisions."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "No manquen revisions."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Afegeix el fitxer seleccionat"
+
+#~ msgid "unchanged"
+#~ msgstr "sense canvis"
+
+#~ msgid "Bookmark"
+#~ msgstr "Adreça d'interès"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Adreces d'interès"
+
+#~ msgid "Status"
+#~ msgstr "Estat"
+
+#~ msgid "Filename"
+#~ msgstr "Nom del fitxer"
+
+#~ msgid "unknown"
+#~ msgstr "desconegut"
+
+#~ msgid "Add"
+#~ msgstr "Afegeix"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "El fitxer de descripció de la IU no s'ha trobat"
+
+#~ msgid "Remove"
+#~ msgstr "Suprimeix"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "El directori actual s'ha afegit a les adreces d'interès.\n"
+#~ "Hi podeu accedir des de quadre de l'esquerra."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "S'ha afegit l'adreça d'interès amb èxit"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "El directori actual ja s'ha afegit a les adreces \n"
+#~ "d'interès. Vegeu el quadre de l'esquerra."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "La ubicació ja és una adreça d'interès"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostra les diferències de tots els fitxers"
+
+#~ msgid "All..."
+#~ msgstr "Tots..."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Hauríeu d'especificar un nom per al directori nou"
+
+#~ msgid "No directory name given"
+#~ msgstr "No s'ha especificat cap nom de directori"
+
+#~ msgid "Not the same branch"
+#~ msgstr "No és la mateixa branca"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destinació no és a la mateixa branca."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Hauríeu d'especificar un nom nou per al fitxer."
+
+#~ msgid "Filename not given"
+#~ msgstr "No s'ha especificat el nom del fitxer"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Obtenció de la branca: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branca del dipòsit: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Dipòsit compartit: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Arrel de l'obtenció lleugera: "
+
+#~ msgid "_Rename"
+#~ msgstr "Canvia el _nom"
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisions en la branca: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdirectoris versionats: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Data de la primera revisió: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Edat de la branca en dies: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Nombre de publicadors: "
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "No s'ha trobat el fitxer del Glade."
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Hauríeu de seleccionar un fitxer de la llista per a continuar."
+
+#~ msgid "Directory already exists"
+#~ msgstr "El directori ja existeix"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Hauríeu d'especificar un altre nom per a continuar."
+
+#~ msgid "Repository format: "
+#~ msgstr "Format del dipòsit: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estat del blocatge del dipòsit: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estat del blocatge de la branca: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format de la branca: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estat del blocatge de l'arbre de treball: "
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Es desconeix la ubicació pare"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Suprimeix el fitxer seleccionat"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No s'ha trobat cap fitxer afegit en l'arbre de treball."
+
+#~ msgid "No matching files"
+#~ msgstr "No hi ha fitxers coincidents"
+
+#~ msgid "Selected..."
+#~ msgstr "Seleccionat..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostra les diferències del fitxer seleccionat"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Afegeix la ubicació actual a les adreces d'interès"
+
+#~ msgid "Edit"
+#~ msgstr "Edita"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Edita l'adreça d'interès seleccionada"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Suprimeix l'adreça d'interès seleccionada"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Publica els canvis"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostra les diferències del fitxer"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Hauríeu d'especificar un títol per a continuar."
+
+#~ msgid "No title given"
+#~ msgstr "No s'ha especificat cap títol"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Fitxers a publicar"
+
+#~ msgid "Commit message:"
+#~ msgstr "Missatge de publicació"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "No hi ha cap canvi en l'arbre de treball."
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "No hi ha cap ubicació predeterminada per a empènyer.\n"
+#~ "Voleu establir %r com a tal?"
+
+#~ msgid "Set default push location"
+#~ msgstr "Establiu la ubicació predeterminada per a empènyer"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "S'estan carregant les revisions. Espereu un moment..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "S'han detectat conflictes"
+
+#~ msgid "Last modified"
+#~ msgstr "Darrera modificació"
+
+#~ msgid "Revert successful"
+#~ msgstr "S'ha desfet correctament"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "S'han tornat tots els fitxers a la darrera revisió."
+
+#~ msgid "ignored"
+#~ msgstr "ignorat"
+
+#~ msgid "Size"
+#~ msgstr "Mida"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Comproveu l'arbre de treball abans de continuar."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "No podeu estirar sense una ubicació pare."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostra les diferències entre dues revisions del fitxer"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Visualitza el contingut del fitxer en un visualitzador integrat"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostra les diferències"
+
+#~ msgid "Revert"
+#~ msgstr "Torna a l'estat anterior"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anota el fitxer seleccionat"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Desfés els canvis"
+
+#~ msgid "Annotate"
+#~ msgstr "Anota"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Obre una carpeta de les adreces d'interès en el Nautilus"
+
+#~ msgid "Open Folder"
+#~ msgstr "Obre una carpeta"
+
+#~ msgid "View contents"
+#~ msgstr "Visualitza el contingut"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mode d'h_istorial"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Branques relacionades:</b>"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revisions que manquen"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flictes..."
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ubicació:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - informació"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estat del blocatge:</b>"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informació..."
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusions pendents"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Torna a aquesta revisió"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicialitza..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anota..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusiona..."
+
+#~ msgid "Ta_gs..."
+#~ msgstr "E_tiquetes..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Desfés tots els canvis"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Torna el fitxer seleccionar a la revisió seleccionada"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Voleu suprimir el directori i tots els seus subdirectoris?"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Torna a anomenar el fitxer seleccionat"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Suprimeix"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Suprimeix el fitxer o directori del disc"
+
+#~ msgid "Rename"
+#~ msgstr "Torna a anomenar"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Obre el fitxer seleccionat"
+
+#~ msgid "Open"
+#~ msgstr "Obre"
+
+#~ msgid "Time"
+#~ msgstr "Hora"
+
+#~ msgid "Revno"
+#~ msgstr "NúmRev"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historial de branca:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>En l'arbre de treball:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisions que manquen:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Dipòsit de revisions:</b>"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusió - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusiona des de:"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  David Planella https://launchpad.net/~dpm"

=== modified file 'po/cs.po'
--- po/cs.po	2011-12-02 05:55:20 +0000
+++ po/cs.po	2011-03-10 04:41:02 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 23:00+0000\n"
-"Last-Translator: Konki <pavel.konkol@seznam.cz>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-09 10:28+0000\n"
+"Last-Translator: Daniel Milde <info@milde.cz>\n"
 "Language-Team: Czech <cs@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-10 04:40+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Větev"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Umístění větve:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Cíl:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Označení větve:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revize:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Zvolte adresář"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Chybí umístění větve"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Musíte zadat umístění větve."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Větvení bylo úspěšné"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revize byla rozvětvena."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N / A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Adresář nemá pracovní strom"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operace byla přerušena."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
-msgstr "Větev obsahuje lokální změny"
+msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
-msgstr "Prosím potvrďte nebo navraťte změny před slučováním."
+msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "přidáno"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "odstraněno"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "přejmenováno"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "přejmenováno a změněno"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "změněno"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
-msgstr "Potvr_dit"
+msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
-msgstr "Potvrdit"
+msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Cesta"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Typ"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Datum"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
-msgstr "Vývojář"
+msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Souhrn"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
-msgstr "Odevzdat s prázdnou zprávou?"
+msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Vnější nástroj:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Konflikty"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "V pracovním stromě nejsou žádné konflikty."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "konflikt cesty"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "konflikt obsahu"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "konflikt textu"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplikát"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "neznámý typ konfliktu"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Nebyl zvolen žádný soubor"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Vyberte prosím soubor ze seznamu."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr "Volání vnějšího nástroje selhalo"
+msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Konflikt nelze vyřešit"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr "_Náhled"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Sloučení úspěšné"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Všechny změny byly úspěsně uplatněny."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
-msgstr "Objeveny konflikty"
+msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Adresář není větví"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Konflikty ve stromu"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
-msgstr "Připojená větev je zastaralá"
+msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
-msgstr "%s"
+msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
-msgstr "Soubor neverzován"
+msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
-msgstr "Žádný výstup nástroje diff"
+msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Vybraný soubor se nezměnil."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
-msgstr "Neexistující revize"
+msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Revize, kterou jste zadali, neexistuje."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Cíl již existuje"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "Cílový adresář již existuje. Vyberte prosím jiný cíl."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Větev bez pracovního stromu"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Neznámá chyba bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Přístup odepřen"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "Přístup byl odepřen."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Neznámá chyba"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicializovat"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Současný adresář"
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr "Vytvořit nový adresář se jménem:"
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr "Název adresáře nezadán"
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
-msgstr "Měl byste zadat jméno nového adresáře."
+msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Sloučit"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Umístění:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Vybrat"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,81 +617,196 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Přidáno"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Odstraněno"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Přejmenováno"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Upraveno"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Neznámý"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Žádné změny."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
-msgstr "Popisky"
+msgstr ""
 
 #: ../tags.py:110
 msgid "Tag Name"
-msgstr "Název popisku"
+msgstr ""
 
 #: ../tags.py:115
 msgid "Revision ID"
 msgstr "ID revize"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
-msgstr "Žádné popsané revize ve větvi."
+msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
-msgstr "Odst_ranit popisek"
+msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
-msgstr "<b><big>Odstranit popisek?</big></b>"
+msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
-msgstr "Jste si jistý, že chcete odstranit popisek: <b>%s</b>?"
+msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
-msgstr "Přid_at popisek"
+msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
-msgstr "Název popisku:"
+msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
-msgstr "ID revize:"
+msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
-msgstr "Nebyl zadán název popisku"
+msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
-msgstr "Musíte zadat požadovaný název popisku."
+msgstr ""
+
+#~ msgid "_Make directory"
+#~ msgstr "_Vytvořit adresář"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Přesunout"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Přejmenovat"
+
+#~ msgid "_Move"
+#~ msgstr "_Přesunout"
+
+#~ msgid "Select a directory"
+#~ msgstr "Zvolte adresář"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Přejmenovat..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Vytvořit _adresář..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Vyjmout soubor(y)..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Přidat soubor(y)..."
+
+#~ msgid "_File"
+#~ msgstr "_Soubor"
+
+#~ msgid "_Move..."
+#~ msgstr "_Přesunout..."
+
+#~ msgid "_Refresh"
+#~ msgstr "_Obnovit"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Zobrazit _skryté soubory"
+
+#~ msgid "_Log..."
+#~ msgstr "_Záznam..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Rozdíly..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistika"
+
+#~ msgid "_Help"
+#~ msgstr "_Nápověda"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Přidat soubor(y)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Vyjmout"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Vyjmout soubor(y)"
+
+#~ msgid "_Add"
+#~ msgstr "_Přidat"
+
+#~ msgid "_Rename"
+#~ msgstr "_Přejmenovat"
+
+#~ msgid "Rename to"
+#~ msgstr "Přejmenovat na"
+
+#~ msgid "Modified files: "
+#~ msgstr "Pozměněné soubory: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Nepozměněné soubory: "
+
+#~ msgid "Added files: "
+#~ msgstr "Přidané soubory: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Přejmenované soubory: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Neznámé soubory: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Vyjmuté soubory: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revize ve větvi: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Stáří větve ve dnech: "
+
+#~ msgid "Title:"
+#~ msgstr "Titul:"
+
+#~ msgid "Bookmark"
+#~ msgstr "Záložka"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Záložky"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Daniel Milde https://launchpad.net/~daniel-milde\n"
+#~ "  DarkenCZ https://launchpad.net/~darkencz\n"
+#~ "  Fred https://launchpad.net/~fredrooks\n"
+#~ "  Jan Tojnar https://launchpad.net/~jtojnar\n"
+#~ "  Jan Vlnas https://launchpad.net/~jnv\n"
+#~ "  Konki https://launchpad.net/~pavel-konkol"

=== modified file 'po/da.po'
--- po/da.po	2012-03-02 04:30:32 +0000
+++ po/da.po	2011-03-08 04:41:48 +0000
@@ -8,14 +8,15 @@
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
 "POT-Creation-Date: 2011-03-06 02:19+0100\n"
-"PO-Revision-Date: 2012-03-01 17:12+0000\n"
-"Last-Translator: nanker <Unknown>\n"
+"PO-Revision-Date: 2009-12-06 12:55+0000\n"
+"Last-Translator: Launchpad Translations Administrators "
+"<rosetta@launchpad.net>\n"
 "Language-Team: Danish <da@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2012-03-02 04:30+0000\n"
-"X-Generator: Launchpad (build 14886)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -31,7 +32,7 @@
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
@@ -42,299 +43,299 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr "Revision:"
+msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
-msgstr "Vælg venligst en mappe"
+msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr "Operation afbrudt."
+msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
-msgstr "fjernet"
+msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
-msgstr "omdøbt"
+msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
-msgstr "omdøbt og ændret"
+msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
-msgstr "ændret"
+msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
-msgstr "Sti"
+msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
-msgstr "Dato"
+msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
-msgstr "Oversigt"
+msgstr ""
 
 #. TODO: jam 2007-10-30 The diff label is currently disabled. If we
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
-msgstr "Konflikter"
+msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr "ukendt type af konflikt"
+msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr "Vælg venligst en fil fra listen."
+msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
-msgstr "Kan ikke løse konflikt"
+msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +347,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,79 +526,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -605,11 +606,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -617,32 +618,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -654,44 +655,49 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  nanker https://launchpad.net/~nanker"

=== modified file 'po/de.po'
--- po/de.po	2012-01-01 05:55:28 +0000
+++ po/de.po	2011-03-08 04:41:48 +0000
@@ -7,200 +7,200 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-12-31 16:09+0000\n"
-"Last-Translator: Daniel Winzen <d@winzen4.de>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:41+0000\n"
+"Last-Translator: welterde <dev@welterde.de>\n"
 "Language-Team: German <de@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2012-01-01 05:55+0000\n"
-"X-Generator: Launchpad (build 14560)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
-msgstr "Bazaar-Einstellungen"
+msgstr ""
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
-msgstr "Bazaar-Einstellungen konfigurieren"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
-msgstr "Bazaarpaket anwenden"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
-msgstr "Bazaar-Benachrichtigungen"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:2
 msgid "Notification Area Icon for Bazaar"
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Zweig"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Zweig Position:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Zielort:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Zweig Spitzname:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revision:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
-msgstr "Bitte wählen Sie ein Verzeichnis"
+msgstr "Bitte wählen Sie ein Verzeichniss"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Fehlender Zweigpfad"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Sie müssen einen Zweigpfad angeben."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Abzweigung erfolgreich"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d Revision(en) abgezweigt."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "Nicht Verfügbar"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "_Checkout"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "_Lightweight checkout"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Verzeichnis hat keine aktive Verzeichnisstruktur"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Aktion abgebrochen."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Es gibt lokale Änderungen im dem Zweig"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Bitte führen sie commit oder revert aus bevor sie mergen."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "hinzugefügt"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "entfernt"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "umbenannt"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "umbenannt und verändert"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "verändert"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "Nur l_okal abschicken"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Absch_icken"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
-msgstr "Dateien"
+msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Festlegen"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Pfad"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Typ"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Datum"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Festleger"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Zusammenfassung"
 
@@ -208,135 +208,135 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Hinzufügen mit Leerer Kommentar?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Du kannst Grund für deine Übermittlung in der Nachricht beschreiben."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Abschicken mit Unbekannten?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Unbekannte Dateien bestehen im aktiven Verzeichnisstruktur. Definitiv "
 "festlegen?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Festlegen ohne Änderungen im Arbeitsbaum?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Externes Hilfsprogramm"
+msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Konflikte"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Kein konflikte im aktiven Verzeichnisstruktur"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
-msgstr "Pfadkonflikt"
+msgstr "Pfad konflikt"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "Inhaltskonflikt"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr "Textkonflikt"
+msgstr "Text konflikt"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "Doppelte ID"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "Duplikat"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr "Eltern-Schleife"
+msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "unversionierter parent"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "fehlender parent"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "lösche parent"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "Unbekannte type des Konflikts"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Keine Datei wurde ausgewählt"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Wählen Sie bitte eine Datei von der Liste."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Keine Verbindung mit externem Dienstprogramm möglich"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Konflikt kann nicht aufgelöst werden"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -351,75 +351,75 @@
 msgid "_View"
 msgstr "Anzeigen"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Merge erfolgreich"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Alle Änderungen erfolgreich angewendet."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Konflikte gefunden"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Bitte löse die Konflikte vor der Übermittlung manuell auf."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Verzeichnis ist kein Zweig"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "Sie können diese Aktion nur in einem Zweig ausführen."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Verzeichnis ist kein Austrag"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Sie können eine lokale Festlegung nur an Austrägen ausführen."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Keine Änderungen festzulegen"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Versuchen Sie eine Zwangsfestlegung, falls Sie trotzdem festlegen wollen."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Konflikte in der Verzeichnisstruktur"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 "Sie müssen erst die Konflikte beseitigen, bevor Sie festlegen können."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Striktes festlegen misslingt"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -427,29 +427,29 @@
 "Es befinden sich unbekannte Dateien in dem aktiven Verzeichnisstruktur.\n"
 "Fügen Sie bitte diese hinzu oder löschen Sie sie."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Gebundener Zweig ist veraltet"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Datei nicht versioniert"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Die ausgewählte Datei ist nicht versioniert."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Zweige sind geschieden"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -457,37 +457,37 @@
 "Getrennte Zweige koennen nicht hochgeladen werden. Benutzen\n"
 "Sie die Überschreibungsoption um trotzdem hochzuladen."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Kein Unterschied gefunden"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Die gewählte Datei hat sich nicht geändert"
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "keine solche Revision"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Die angegebene Revision existiert nicth."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Ziel existiert bereits"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 "Zielverzeichnis existiert schon. Bitte wählen Sie einen anderen "
 "Zielverzeichnis."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Verzeichnis ist schon ein Zweig"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -496,11 +496,11 @@
 "Das aktuelle Verzeichnis (%s) ist schon ein Zweig.\n"
 "Sie können es benutzen, oder ein anderes Verzeichnis initialisieren."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Zweig ohne aktives Verzeichnisstruktur"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -509,32 +509,32 @@
 "Das aktuelle Verzeichnis (%s)\n"
 "ist ein Zweig ohne funktionsfähige Verzeichnisstruktur."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Unbekannte bzr Fehler"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Zugriff verboten"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "Zugriff verboten"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Unbekannte Fehler"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initializieren"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Welches Verzeichnis möchten Sie initialisieren?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Aktuelles Verzeichnis"
 
@@ -542,100 +542,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Erzeugen Sie ein neues Verzeichnis mit dem Namen:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Verzeichnis Name ist nicht spezifiziert"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Sie solten ein neues Verzeichnis Name spezifizieren"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Merge"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Zweig nicht angegeben"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Bitte geben Sie einen Zweig an von dem gemerged werden soll."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Bazaar Befehl Fehler"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Ort:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Drücken"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -643,20 +603,20 @@
 "Du kannst nicht pushen, wenn die Branches sich unterscheiden.\n"
 "Überschreiben?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Hochladen erfolgreich"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d Revision(en) hochgeladen."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Nicht-existierendes Überverzeichnis."
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -666,44 +626,44 @@
 "existiert nicht. Erzeugen?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "Aus_wahl"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
-msgstr "Suche nach:"
+msgstr ""
 
 #: ../search.py:56
 msgid "Document"
-msgstr "Dokument"
+msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Hinzugefügt"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Entfernt"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Umbenannt"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Geändert"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Unbekannt"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Keine Änderungen."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tags"
 
@@ -715,45 +675,625 @@
 msgid "Revision ID"
 msgstr "Revision ID"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Tags werden in diesem Branch-Format nicht unterstützt. Bitte upgraden."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Keine markierten Überarbeitungen im Branch."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Entferne tag"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Entferne Tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Sind sie sicher das Sie das Tag <b>%s</b> entfernen möchten?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "T_ag hinzufügen"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Tag Name:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Revision ID:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Kein Tag Name angegeben"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Sie müssen den gewünschten Tag Namen angeben."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Umbenennen..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Verschieben..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Verzeichniss erstellen..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Datei(en) entfernen..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Datei(en) hinzufügen..."
+
+#~ msgid "_File"
+#~ msgstr "_Datei"
+
+#~ msgid "_Refresh"
+#~ msgstr "Aktualisie_ren"
+
+#~ msgid "_Get..."
+#~ msgstr "Holen..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Versteckte Dateien zeigen"
+
+#~ msgid "C_heckout..."
+#~ msgstr "Auschecken..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Herunter_laden"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "Festlegen..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Hochloaden..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Logbuch..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Unterschiede"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistik"
+
+#~ msgid "_Help"
+#~ msgstr "_Hilfe"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Welche Datei(en) möchten Sie hinzufügen?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Datei(en) hinzufügen"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Alle Dateien mit Status 'hinzugefügt'"
+
+#~ msgid "_Remove"
+#~ msgstr "_Entfernen"
+
+#~ msgid "Selected only"
+#~ msgstr "Nur ausgewältes"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Datei(en) entfernen"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Welche Datei(en) wollen Sie entfernen?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Alle unbekannten rekursiv"
+
+#~ msgid "_Add"
+#~ msgstr "_Hinzufügen"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Verzeichnis erstellen"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versioniertes Verzeichnis"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Versetzen"
+
+#~ msgid "Move to"
+#~ msgstr "Versetzen nach"
+
+#~ msgid "_Make directory"
+#~ msgstr "Verzeichnis erstellen"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Umbennen"
+
+#~ msgid "_Move"
+#~ msgstr "_Verschieben"
+
+#~ msgid "Select a directory"
+#~ msgstr "Wählen Sie ein Verzeichnis aus"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Austragsstammpfad: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Quellenaustrag: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Zweigstammpfad: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Zweigaustrag: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Quellenzweig: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Beteiligte Quelle: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Leichtaustragsstammpfad: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Umbenennen"
+
+#~ msgid "Rename to"
+#~ msgstr "Umbenennen zu"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Zu Zweig veröffentlichen: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Zweigvorläufer: "
+
+#~ msgid "(none)"
+#~ msgstr "(nichts)"
+
+#~ msgid "Control format: "
+#~ msgstr "Kontroll Format "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Aktive Verzeichnisstrukturformat: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Quellenformat: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Branch Format "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Quellen Festlegungsstatus: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Zweig Festlegungsstatus: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Arbeitsverzeichnisstruktur SperrFetatus: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Umbennante Dateien: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Unbekannte Dateien: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignorierte Dateien: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versionierte Unterverzeichnisse: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Unveränderte Dateien: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Geänderte Dateien: "
+
+#~ msgid "Added files: "
+#~ msgstr "Hinzugefügte Dateien: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Entfernte Dateien: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Fehlende Revisionen in Zweig: "
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Bitte wählen Sie eine Datei aus der Liste,\n"
+#~ "oder wählen Sie eine andere Option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Quellengrösse: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisionen in der Quelle: "
+
+#~ msgid "No title given"
+#~ msgstr "Kein Titel angegeben."
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisionen in Zweig: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Fehlende Revisionen in der Arbeitsverzeichnisstruktur: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Anzahl Festleger: "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Bitte geben Sie einen Titel an, um fortzufahren."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Vorläuferpfad ist unbekannt"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Es fehlen Revisionen"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Kann fehlende Revisionen nicht ermitteln falls Vorläuferpfad unbekannt ist."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Lokaler Zweig ist aktuell"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d fehlende Revision(en)"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Es fehlen keine Revisionen."
+
+#~ msgid "unchanged"
+#~ msgstr "unverändert"
+
+#~ msgid "Bookmark"
+#~ msgstr "Lesezeichen"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Lesezeichen"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade Datei konnte nicht gefunden werden."
+
+#~ msgid "unknown"
+#~ msgstr "unbekennt"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Lesezeichen erfolgreich hinzugefügt."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Unterschiede aller Dateien anzeigen"
+
+#~ msgid "All..."
+#~ msgstr "Alles..."
+
+#~ msgid "Selected..."
+#~ msgstr "Ausgewählt..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Unterschiede der ausgewählten Dateien anzeigen"
+
+#~ msgid "Edit"
+#~ msgstr "Bearbeiten"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Ausgewähltes Lesezeichen bearbeiten"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Auswähltes Lesezeichen entfernen"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Nicht dasselbe Zweig"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Das Zielort ist nicht in demselben Zweig."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Bitte geben Sie einen neuen Dateiennamen an."
+
+#~ msgid "Filename not given"
+#~ msgstr "Dateienname nicht angegeben"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr ""
+#~ "Keine hinzugefuegten Dateien konnten in der aktiven Verzeichnisstruktur "
+#~ "gefunden werden."
+
+#~ msgid "No matching files"
+#~ msgstr "Keine übereinstimmende Dateien"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Zeit der letzten Revision: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Zeit der ersten Revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Zweigalter in Tagen: "
+
+#~ msgid "Pull successful"
+#~ msgstr "Herunterladen erfolgreich"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d Revision(en) heruntergeladen."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Pfad ist schon als Lesezeichen abgespeichert"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Das aktuelle Verzeichnis wurde as Lesezeichen abgespeichert. Sie können\n"
+#~ "es im linken Panel auswählen."
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Das aktuelle Verzeichnis wurde schon als Lesezeichen abgespeichert.\n"
+#~ "Bitte berufen Sie sich auf das linke Panel."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr ""
+#~ "Bitte geben Sie den gewünschten Verzeichnisnamen für das neue Verzeichnis an."
+
+#~ msgid "No directory name given"
+#~ msgstr "Kein Verzeichnisnamen angegeben"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Verzeichnis existiert bereits"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Bitte geben Sie einen anderen Namen an, um fortzufahren."
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Aktueller Pfad als Lesezeichen abspeichern"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Bitte wählen Sie eine Datei aus der List aus um fortzufahren."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Ausgewählte Datei hinzufügen"
+
+#~ msgid "Add"
+#~ msgstr "Hinzufügen"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "UI Beschreibungsdatei konnte nicht gefunden werden."
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Dateiname"
+
+#~ msgid "Remove"
+#~ msgstr "Entfernen"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Ausgewählte Datei entfernen"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Änderungen festlegen"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Dateiendifferenzen anzeigen"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Datei(en) zu hinzufügen"
+
+#~ msgid "Commit message:"
+#~ msgstr "Nachricht abschicken"
+
+#~ msgid "Pending merges"
+#~ msgstr "Wartende Merges"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Es gibt keine Änderungen im Arbeitsbaum."
+
+#~ msgid "Set default push location"
+#~ msgstr "Standard-Push-Ziel einstellen"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Es wurde kein Standard-Push-Ziel eingestellt.\n"
+#~ "Willst du %r als Standard einstellen?"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Warten Sie bitte, Revisionen werden geladen..."
+
+#~ msgid "Time"
+#~ msgstr "Datum"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Herunterladen ist nicht möglich bis es ein Vorläuferpfad existiert."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Konflikte gefunden"
+
+#~ msgid "ignored"
+#~ msgstr "ignoriert"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr ""
+#~ "Schauen Sie bitte das aktive Verzeichnisstruktur an, bevor Sie fortfahren."
+
+#~ msgid "Last modified"
+#~ msgstr "Zuletzt verändert"
+
+#~ msgid "Size"
+#~ msgstr "Gr&ouml;&szlig;e"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Die ausgewählte Datei umbenennen"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Entfernen und löschen"
+
+#~ msgid "Rename"
+#~ msgstr "Umbenenen"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Öffne die ausgewählte Datei"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Zeige Dateiinhalt an in einem built-in viewer"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Öffne Lesezeichen in Nautilus"
+
+#~ msgid "Show differences"
+#~ msgstr "Zeige differenz ain"
+
+#~ msgid "View contents"
+#~ msgstr "Zeige Inhalt an"
+
+#~ msgid "Open Folder"
+#~ msgstr "Öffne Verzeichnis"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Bis zu dieser Überarbeitung rückgängig machen"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Die gewählte Datei bis zur gewählten Überarbeitung zurücksetzen."
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Lösche Verzeichnis und alle Unterverzeichnisse?"
+
+#~ msgid "Revert"
+#~ msgstr "Rückgängig"
+
+#~ msgid "Annotate"
+#~ msgstr "Beschreibe"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Änderung verwerfen"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialisiere..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Beschreibe..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Alle Änderungen _rückgängig machen"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Fehlende Übe_rarbeitungen"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_gs..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Kon_flikte..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Verbindende Zweige</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informationen"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Im aktiven Verzeichnisstruktur:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Fehlende Revisionen:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Sperrstatus:</b>"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Breschreibe die gewählte Datei"
+
+#~ msgid "Merge from:"
+#~ msgstr "Mergen aus:"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ort:</b>"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert erfolgreich"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr ""
+#~ "Sämtliche Dateien wurden zur letzten Revision zurückgesetzt (revert)."
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "H_istory Modus"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Zweig history:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Revisions Speicher:</b>"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr ""
+#~ "Entferne die gewählte(n) Datei(en)/Verzeichnis(se) und lösche sie von der "
+#~ "Festplatte"
+
+#~ msgid "Open"
+#~ msgstr "Öffnen..."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Zeige die Unterschiede zwischen zwei Revisionen der Datei"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Augustus Kling https://launchpad.net/~augustus-kling\n"
+#~ "  Benjamin Jochheim https://launchpad.net/~benjamin-jochheim\n"
+#~ "  C-S https://launchpad.net/~c-s\n"
+#~ "  Christian Faulhammer https://launchpad.net/~fauli\n"
+#~ "  Mike Bronner https://launchpad.net/~mike.bronner\n"
+#~ "  Philipp Wolfer https://launchpad.net/~phw\n"
+#~ "  Pierre Vorhagen https://launchpad.net/~pep.\n"
+#~ "  Roman Stingler https://launchpad.net/~coolx67\n"
+#~ "  Sebastian Wallroth https://launchpad.net/~sebastian-wallroth\n"
+#~ "  Simon Pascal Klein https://launchpad.net/~klepas\n"
+#~ "  Xandi https://launchpad.net/~launchpad-net-20-taube\n"
+#~ "  welterde https://launchpad.net/~welterde"

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2011-12-02 05:55:20 +0000
+++ po/en_GB.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
-"Last-Translator: Jelmer Vernooij <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:08+0000\n"
+"Last-Translator: Bruce Cowan <Unknown>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branch"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Branch location:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destination:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Branch nick:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revision:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Please select a folder"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Missing branch location"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "You must specify a branch location."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Branching successful"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revision(s) branched."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "_Light-weight checkout"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Directory does not have a working tree"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operation aborted."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "There are local changes in the branch"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Please commit or revert the changes before merging."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "added"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "removed"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "renamed"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "renamed and modified"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modified"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "_Only commit locally"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Commit"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Path"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Type"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Date"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Committer"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Summary"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Commit with an empty message?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "You can describe your commit intent in the message."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Commit with unknowns?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr "Unknown files exist in the working tree. Commit anyway?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Commit with no changes?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "External utility:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflicts"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No conflicts in working tree."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "path conflict"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "contents conflict"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "text conflict"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "duplicate id"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicate"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "parent loop"
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "unversioned parent"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "missing parent"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "deleting parent"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "unknown type of conflict"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "No file was selected"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Please select a file from the list."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Call to external utility failed"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Cannot resolve conflict"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -349,73 +349,73 @@
 msgid "_View"
 msgstr "_View"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Merge successful"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "All changes applied successfully."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Conflicts encountered"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Please resolve the conflicts manually before committing."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Directory is not a branch"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "You can perform this action only in a branch."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Directory is not a checkout"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "You can perform local commit only on checkouts."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "No changes to commit"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Try force commit if you want to commit anyway."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflicts in tree"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "You need to resolve the conflicts before committing."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Strict commit failed"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -423,29 +423,29 @@
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Bound branch is out of date"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "File not versioned"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "The selected file is not versioned."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Branches have been diverged"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -453,35 +453,35 @@
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "No diff output"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "The selected file hasn't changed."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "No such revision"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "The revision you specified doesn't exist."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Target already exists"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "Target directory already exists. Please select another target."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Directory is already a branch"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -490,11 +490,11 @@
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialise another directory."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branch without a working tree"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -503,32 +503,32 @@
 "The current directory (%s)\n"
 "is a branch without a working tree."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Unknown bzr error"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permission denied"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permission denied."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Unknown error"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initialise"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Which directory do you want to initialise?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Current directory"
 
@@ -536,100 +536,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Create a new directory with the name:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Directory name not specified"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "You should specify a new directory name."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Merge"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Branch not given"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Please specify a branch to merge from."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Bazaar command error"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Location:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -637,20 +597,20 @@
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Push successful"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d revision(s) pushed."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Non existing parent directory"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -660,11 +620,11 @@
 "doesn't exist. Create?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Select"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -672,32 +632,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Added"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Removed"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renamed"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modified"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Unknown"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "No changes."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tags"
 
@@ -709,44 +669,612 @@
 msgid "Revision ID"
 msgstr "Revision ID"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr "Tags are not supported by this branch format. Please upgrade."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No tagged revisions in the branch."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Remove tag"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Remove tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Are you sure you want to remove the tag: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Add tag"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Tag Name:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Revision ID:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No tag name specified"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "You have to specify the tag's desired name."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Rename..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Move..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Make _directory..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Remove file(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Add file(s)..."
+
+#~ msgid "_File"
+#~ msgstr "_File"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refresh"
+
+#~ msgid "_Get..."
+#~ msgstr "_Get..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Show _hidden files"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Differences..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistics"
+
+#~ msgid "_Help"
+#~ msgstr "_Help"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Which file(s) do you want to add?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Add file(s)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "All files with status 'added'"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remove"
+
+#~ msgid "Selected only"
+#~ msgstr "Selected only"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Remove file(s)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Which file(s) do you want to remove?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "All unknowns recursively"
+
+#~ msgid "_Add"
+#~ msgstr "_Add"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Make directory"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versioned directory"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Move"
+
+#~ msgid "Move to"
+#~ msgstr "Move to"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Make directory"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Rename"
+
+#~ msgid "_Move"
+#~ msgstr "_Move"
+
+#~ msgid "Select a directory"
+#~ msgstr "Select a directory"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Checkout root: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Repository checkout: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Branch root: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout of branch: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Repository branch: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Shared repository: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Light checkout root: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Rename"
+
+#~ msgid "Rename to"
+#~ msgstr "Rename to"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publish to branch: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Parent branch: "
+
+#~ msgid "(none)"
+#~ msgstr "(none)"
+
+#~ msgid "Working tree format: "
+#~ msgstr "Working tree format: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Repository format: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Branch format: "
+
+#~ msgid "Control format: "
+#~ msgstr "Control format: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Unchanged files: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Modified files: "
+
+#~ msgid "Added files: "
+#~ msgstr "Added files: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Repository lock status: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Branch lock status: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Missing revisions in working tree: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Working tree lock status: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Missing revisions in branch: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisions in branch: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Renamed files: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Unknown files: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignored files: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versioned subdirectories: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Removed files: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Time of first revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Age of branch in days: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Number of commiters: "
+
+#~ msgid "Title:"
+#~ msgstr "Title:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Time of last revision: "
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Size of repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisions in repository: "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Please specify a title to continue."
+
+#~ msgid "No title given"
+#~ msgstr "No title given"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull successful"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revision(s) pulled."
+
+#~ msgid "There are missing revisions"
+#~ msgstr "There are missing revisions"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Parent location is unknown"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr "Cannot determine missing revisions if no parent location is known."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Local branch up to date"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(s) missing."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "There are no missing revisions."
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bookmarks"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade file cannot be found."
+
+#~ msgid "Bookmark"
+#~ msgstr "Bookmark"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Add the selected file"
+
+#~ msgid "Add"
+#~ msgstr "Add"
+
+#~ msgid "unchanged"
+#~ msgstr "unchanged"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "UI description file cannot be found."
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Filename"
+
+#~ msgid "unknown"
+#~ msgstr "unknown"
+
+#~ msgid "Remove"
+#~ msgstr "Remove"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Remove the selected file"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Commit the changes"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Show the diff of the file"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Show the differences of all files"
+
+#~ msgid "All..."
+#~ msgstr "All..."
+
+#~ msgid "Selected..."
+#~ msgstr "Selected..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Show the differences of the selected file"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Bookmark current location"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Edit the selected bookmark"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Remove the selected bookmark"
+
+#~ msgid "Edit"
+#~ msgstr "Edit"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Bookmark successfully added"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Location already bookmarked"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Please specify a desired name for the new directory."
+
+#~ msgid "No directory name given"
+#~ msgstr "No directory name given"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Directory already exists"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Please specify another name to continue."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Not the same branch"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Please select a file from the list to proceed."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "The destination is not in the same branch."
+
+#~ msgid "No matching files"
+#~ msgstr "No matching files"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Please specify a new name for the file."
+
+#~ msgid "Filename not given"
+#~ msgstr "Filename not given"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No added files were found in the working tree."
+
+#~ msgid "File(s) to commit"
+#~ msgstr "File(s) to commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Commit message:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Pending merges"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "There are no changes in the working tree."
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert successful"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Pulling is not possible until there is a parent location."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflicts detected"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "View the contents of the file in a built-in viewer"
+
+#~ msgid "Show differences"
+#~ msgstr "Show differences"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annotate the selected file"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Revert the changes"
+
+#~ msgid "Annotate"
+#~ msgstr "Annotate"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Open the selected file"
+
+#~ msgid "View contents"
+#~ msgstr "View contents"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "H_istory Mode"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Related branches:</b>"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Missing _revisions"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_gs..."
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flicts..."
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Location:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Information"
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "Time"
+#~ msgstr "Time"
+
+#~ msgid "Set default push location"
+#~ msgstr "Set default push location"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Please wait, revisions are being loaded..."
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Open bookmark directory in Nautilus"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annotate..."
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Rename the selected file"
+
+#~ msgid "Rename"
+#~ msgstr "Rename"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Revert the selected file to the selected revision"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Delete directory with all directories below ?"
+
+#~ msgid "Open"
+#~ msgstr "Open"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Show the differences between two revisions of the file"
+
+#~ msgid "Open Folder"
+#~ msgstr "Open Directory"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Revert to this revision"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Merge from:"
+
+#~ msgid "Last modified"
+#~ msgstr "Last modified"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Remove and delete"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "All files reverted to last revision."
+
+#~ msgid "ignored"
+#~ msgstr "ignored"
+
+#~ msgid "Size"
+#~ msgstr "Size"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Please have a look at the working tree before continuing."
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Branch history:</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Missing revisions:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Revision store:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>In the working tree:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Lock status:</b>"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialise..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Revert all changes"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Remove the selected file/directory and permanently delete"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Bruce Cowan https://launchpad.net/~bruce89\n"
+#~ "  John Drinkwater https://launchpad.net/~johndrinkwater"

=== modified file 'po/eo.po'
--- po/eo.po	2011-12-02 05:55:20 +0000
+++ po/eo.po	2011-03-08 04:41:48 +0000
@@ -7,23 +7,24 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Michael Moroni <michael.moroni@mailoo.org>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-12-23 20:48+0000\n"
+"Last-Translator: Launchpad Translations Administrators "
+"<rosetta@launchpad.net>\n"
 "Language-Team: Esperanto <eo@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
-msgstr "Preferoj de Bazaro"
+msgstr ""
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
-msgstr "Agordi Bazaron"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
@@ -31,176 +32,176 @@
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaro"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
-msgstr "Atentigoj de Bazaro"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:2
 msgid "Notification Area Icon for Bazaar"
-msgstr "Atentigarea piktogramo por Bazaro"
+msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "_Branĉo"
+msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Branĉloko"
+msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Celo:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr "Revizio:"
+msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
-msgstr "Bonvolu elekti dosierujon"
+msgstr "Bonvolu elekti leterujon"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Branĉloko mankas"
+msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Vi devu specifi branĉlokon."
+msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
-msgstr "Sukcesa branĉado"
+msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr "%d revizio(j) branĉita(j)."
+msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
-msgstr "N/D"
+msgstr "N/A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "K_ontrolo"
+msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
-msgstr "Branĉnomo:"
+msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr "Ma_lpeza kontrolo"
+msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operacio haltigita."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Dato"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +209,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Konfliktoj"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +347,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +526,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +606,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +618,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +655,50 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Colin Dean https://launchpad.net/~colindean\n"
+#~ "  Larry Gilbert https://launchpad.net/~l2g"

=== modified file 'po/es.po'
--- po/es.po	2011-12-02 05:55:20 +0000
+++ po/es.po	2011-03-08 04:41:48 +0000
@@ -7,201 +7,201 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Fitoschido <fitoschido@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:27+0000\n"
+"Last-Translator: BigSus <bigsus@gmail.com>\n"
 "Language-Team: Spanish <es@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
-msgstr "Preferencias de Bazaar"
+msgstr ""
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
-msgstr "Configurar Bazaar"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
-msgstr "Aplicar paquete de Bazaar"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
-msgstr "Notificación Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:2
 msgid "Notification Area Icon for Bazaar"
-msgstr "Icono del área de notificación para Bazaar"
+msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Rama"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Ubicación de la rama:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destino:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Apodo de la rama:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisión:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
-msgstr "Seleccionar una carpeta"
+msgstr "Por favor, seleccione una carpeta"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "No se ha encontrado la ubicación de la rama"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Debe especificar la ubicación de una rama."
+msgstr "Debe especificar la ubicación de una rama"
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Rama creada con éxito"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revision(es) ramificada(s)."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "C_omprobar"
+msgstr "Comprobación"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Comprobación _ligera"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "El directorio no contiene un árbol de trabajo"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operación interrumpida."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Hay cambios locales en la rama"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 "Por favor, haga un commit o un revert de los cambios antes de fusionar."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "añadido"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "quitado"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "renombrado"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "renombrado y modificado"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificado"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "Hacer commit sólo localmente"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
-msgstr "Archivos"
+msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Commit"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Ruta"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tipo"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
-msgstr "Revisiones pendientes"
+msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Fecha"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Committer"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Resumen"
 
@@ -209,135 +209,135 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
-msgstr "Dif. para "
+msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "¿Hacer commit con un mensaje vacío?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Puede describir en el mensaje el motivo del commit."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "¿Hacer commit con desconocidos?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Existen archivos desconocidos en el árbol de trabajo. ¿Hacer commit de todos "
 "modos?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "¿Hacer commit sin cambios?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilidad externa:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflictos"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "No hay conflictos en el árbol de trabajo."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflicto en la ruta"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflicto de contenidos"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflicto de texto"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id duplicado"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicado"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "bucle padre"
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "padre sin versionar"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "no se encuentra el padre"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "borrando padre"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipo de conflicto desconocido"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "No se ha seleccionado ningún archivo"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Por favor, seleccione un archivo de la lista."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Falló la llamada a una utilidad externa"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "No se puede resolver el conflicto"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -352,74 +352,74 @@
 msgid "_View"
 msgstr "_Ver"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Fusión realizada con éxito"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Cambios aplicados con éxito."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Se encontraron conflictos"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 "Por favor, resuelva los conflictos manualmente antes de hacer commit."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "El directorio no es una rama"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "Esta acción sólo puede realizarse sobre una rama."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "El directorio no es un checkout"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Sólo puede realizar commits locales sobre checkouts."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "No hay cambios a los que hacer commit"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Intente forzar el commit si desea hacerlo de todas formas."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
-msgstr "No hay cambios que fusionar"
+msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflictos en el árbol"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Es necesario resolver los conflictos antes de hacer un commit."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Ha fallado el commit estricto"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -427,29 +427,29 @@
 "Hay archivos desconocidos en el árbol de trabajo.\n"
 "Por favor, añádalos o quítelos."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "La rama ligada está obsoleta"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Archivo no versionado"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "El archivo seleccionado no está versionado."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Las ramas se han dividido"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -457,35 +457,35 @@
 "No se puede hacer un push si las ramas se han dividido. Use\n"
 "la opción de sobreescribir si desea hacer push de todos modos."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "No hay salida de diff"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "El archivo seleccionado no ha cambiado."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "No existe esa revisión"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La revisión especificada no existe."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "El destino ya existe"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "El destino ya existe. Por favor, seleccione otro."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "El directorio ya es una rama"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -494,11 +494,11 @@
 "El directorio actual (%s) ya es una rama.\n"
 "Puede empezar a usarlo, o bien inicializar otro directorio."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Rama sin árbol de trabajo."
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -507,32 +507,32 @@
 "El directorio actual (%s)\n"
 "es una rama sin árbol de trabajo."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Error desconocido de bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permiso denegado"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permiso denegado."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Error desconocido"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicializar"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "¿Qué directorio desea inicializar?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Directorio actual"
 
@@ -540,100 +540,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Crear un nuevo directorio con el nombre:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Nombre del directorio no especificado"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Deberías especificar un nuevo nombre de directorio."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
-msgstr "Fusionar desde"
+msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
-msgstr "Carpeta"
+msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
-msgstr "Ubicación personalizada"
+msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Fusionar"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "No se ha indicado ninguna rama"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Por favor, especifique una rama desde la que fusionar."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Error en el comando Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Ubicación:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -641,20 +601,20 @@
 "No se puede hacer push si las ramas se han dividido.\n"
 "¿Sobreescribir?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Push realizado con éxito"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "Se ha realizado un push a %d revision(es)."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Directorio padre no existente"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -664,44 +624,44 @@
 "no existe. ¿Desea crearlo?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Seleccionar"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
-msgstr "Buscar:"
+msgstr ""
 
 #: ../search.py:56
 msgid "Document"
-msgstr "Documento"
+msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Añadido"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Eliminado"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renombrado"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificado"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Desconocido"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "No hay cambios."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetas"
 
@@ -713,45 +673,627 @@
 msgid "Revision ID"
 msgstr "ID de la revisión"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Este formato de rama no soporta etiquetas. Por favor, haga un upgrade."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "No hay revisiones con etiqueta en la rama."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Eliminar etiqueta"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>¿Quitar etiqueta?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "¿Seguro que quiere quitar la etiqueta <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Añadir etiqueta"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nombre de la etiqueta:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de la revisión:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "No se ha especificado un nombre de etiqueta"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Debe especificar el nombre que desea para la etiqueta."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mover..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crear _directorio..."
+
+#~ msgid "_File"
+#~ msgstr "_Archivo"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Refrescar"
+
+#~ msgid "_Get..."
+#~ msgstr "_Obtener..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "Es_tado..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Registro..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferencias..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Estadisticas"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crear directorio"
+
+#~ msgid "Repository branch: "
+#~ msgstr "Rama del repositorio: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repositorio compartido: "
+
+#~ msgid "_Move"
+#~ msgstr "_Mover"
+
+#~ msgid "Parent branch: "
+#~ msgstr "Rama padre: "
+
+#~ msgid "Control format: "
+#~ msgstr "Formato de control: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Archivos renombrados: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Archivos sin cambios: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Arcchivos modificados "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Arvhivos desconocidos: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisiones en la rama: "
+
+#~ msgid "No title given"
+#~ msgstr "Sin título"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Por favor seleccione un archivo de la lista,\n"
+#~ "o seleccione la otra opción."
+
+#~ msgid "Edit"
+#~ msgstr "Editar"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Confirmar los cambios"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostrar las diferencias del archivo"
+
+#~ msgid "Directory already exists"
+#~ msgstr "El directorio ya existe"
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusiones pendientes"
+
+#~ msgid "Last modified"
+#~ msgstr "Última modificación"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Quitar y borrar"
+
+#~ msgid "Status"
+#~ msgstr "Estado"
+
+#~ msgid "Size"
+#~ msgstr "Tamaño"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editar el marcador seleccionado"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Quitar el marcador seleccionado"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostrar las diferencias"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostrar las diferencias de todos los archivos"
+
+#~ msgid "All..."
+#~ msgstr "Todos..."
+
+#~ msgid "Selected..."
+#~ msgstr "Seleccionado..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostrar las diferencias del archivo seleccionado"
+
+#~ msgid "No matching files"
+#~ msgstr "No hay archivos coincidentes"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "El destino no está en la misma rama."
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Crear directorio"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Mover"
+
+#~ msgid "Move to"
+#~ msgstr "Mover a"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Información"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Hora de la última revisión: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusionar - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusionar desde:"
+
+#~ msgid "Time"
+#~ msgstr "Hora"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anotar el archivo seleccionado"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicializar..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Revertir todos los cambios"
+
+#~ msgid "Not the same branch"
+#~ msgstr "No están en la misma rama"
+
+#~ msgid "Working tree format: "
+#~ msgstr "Formato del árbol de trabajo: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Ramas relacionadas:</b>"
+
+#~ msgid "Branch format: "
+#~ msgstr "Formato de la rama: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisiones en el repositorio: "
+
+#~ msgid "Bookmark"
+#~ msgstr "Marcador"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Marcadores"
+
+#~ msgid "unknown"
+#~ msgstr "desconocido"
+
+#~ msgid "Open"
+#~ msgstr "Abrir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Abrir el archivo seleccionado"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flictos..."
+
+#~ msgid "_Information..."
+#~ msgstr "_Información..."
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Todos los desconocidos recursivamente"
+
+#~ msgid "_Add"
+#~ msgstr "_Añadir"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Edad de la rama en días: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Tamaño del repositorio: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historial de ramas:</b>"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Archivo(s) para el commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mensaje del commit:"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "No hay cambios en el árbol de trabajo."
+
+#~ msgid "Revno"
+#~ msgstr "Numrev"
+
+#~ msgid "Set default push location"
+#~ msgstr "Establecer la ubicación predeterminada para el push"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull realizado con éxito"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(es) no encontrada(s)."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "La ubicación del padre es desconocida"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Por favor, compruebe el árbol de trabajo antes de continuar."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Se han detectado conflictos"
+
+#~ msgid "unchanged"
+#~ msgstr "sin cambios"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert realizado con éxito"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Todos los archivos han sido revertidos a la última versión."
+
+#~ msgid "Filename"
+#~ msgstr "Nombre de archivo"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Añadir el archivo seleccionado"
+
+#~ msgid "Add"
+#~ msgstr "Add"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "No se ha podido encontrar el archivo de Glade."
+
+#~ msgid "Title:"
+#~ msgstr "Título:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Por favor, especifique un título para continuar."
+
+#~ msgid "Remove"
+#~ msgstr "Remove"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Quitar el archivo seleccionado"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Cambiar el nombre al archivo seleccionado"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Quitar el archivo o directorio seleccionado y borrarlo del disco"
+
+#~ msgid "Rename"
+#~ msgstr "Rename"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Revertir los cambios"
+
+#~ msgid "Annotate"
+#~ msgstr "Annotate"
+
+#~ msgid "Open Folder"
+#~ msgstr "Abrir carpeta"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Añadir a marcadores la ubicación actual"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Por favor, especifique el nombre deseado para el nuevo directorio."
+
+#~ msgid "No directory name given"
+#~ msgstr "No se ha indicado un nombre de directorio"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "No se encontraron archivos añadidos en el árbol de trabajo."
+
+#~ msgid "View contents"
+#~ msgstr "Ver contenidos"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostrar las diferencias entre dos revisiones del archivo"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Por favor, seleccione un archivo de la lista para continuar."
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Por favor, especifique otro nombre para continuar."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Por favor, especifique un nuevo nombre para el archivo."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Añadir archivo(s)..."
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Todos los archivos con estado «añadido»"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remove"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Quitar archivo(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI para Bazaar"
+
+#~ msgid "Selected only"
+#~ msgstr "Sólo los seleccionados"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "¿Qué archivo(s) desea quitar?"
+
+#~ msgid "_Rename..."
+#~ msgstr "Cambiar _nombre..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostrar _archivos ocultos"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anotar..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Help"
+#~ msgstr "Ay_uda"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Modo h_istorial"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "¿Qué archivo(s) desea añadir?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Añadir archivo(s)"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Quitar archivo(s)"
+
+#~ msgid "(none)"
+#~ msgstr "(ninguno)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Renombrar"
+
+#~ msgid "Rename to"
+#~ msgstr "Cambiar nombre a"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Cambiar nombre"
+
+#~ msgid "Select a directory"
+#~ msgstr "Seleccione un directorio"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publish to branch: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Raíz del checkout: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Checkout del repositorio: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Raíz de la rama: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Ubicación:</b>"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout de la rama: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdirectorios versionados: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Archivos quitados: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Formato del repositorio: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revisiones que faltan en la rama: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>En el árbol de trabajo:</b>"
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Hora de la primera revisión: "
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "No se ha establecido ninguna ubicación predeterminada para el push.\n"
+#~ "¿Desea establecer %r como predeterminada ahora?"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Faltan revisiones"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "No se pueden determinar las revisiones que faltan si no se conoce la "
+#~ "ubicación del padre."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Rama local actualizada"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Por favor, espere. Se están cargando las revisiones..."
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "Se ha realizado un pull a %d revision(es)."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "No se ha podido encontrar el archivo de descripción de la IU"
+
+#~ msgid "ignored"
+#~ msgstr "ignorado"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "No faltan revisiones."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Revertir el archivo seleccionado a la revisión indicada"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr ""
+#~ "No es posible hacer pull hasta que no haya una ubicación para el padre."
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Abrir carpeta de marcadores en Nautilus"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Ver el contenido del archivo en un visor interno"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Revertir a esta revisión"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Se ha añadido el directorio actual a los marcadores. Puede\n"
+#~ "llegar a él seleccionándolo en el panel de la izquierda."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "El marcador se ha añadido con éxito"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "El directorio actual ya está en marcadores.\n"
+#~ "Consulte el panel de la izquierda como referencia."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Esta ubicación ya está en marcadores"
+
+#~ msgid "Filename not given"
+#~ msgstr "No se ha indicado ningún nombre de archivo"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "¿Borrar el directorio con todos los directorios que contiene?"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Directorio _versionado"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revisiones que faltan"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "E_tiquetas..."
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Raíz del checkout ligero: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estado de bloqueo del repositorio: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estado de bloqueo de la rama: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estado de bloqueo del árbol de trabajo: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Archivos ignorados: "
+
+#~ msgid "Added files: "
+#~ msgstr "Archivos añadidos: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estado de bloqueo:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Almacén de revisiones:</b>"
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revisiones que faltan en el árbol de trabajo: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisiones que faltan:</b>"
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Número de commiters: "
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusionar..."
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  BigSus https://launchpad.net/~bigsus\n"
+#~ "  David Arnoldo Ortiz Lozano https://launchpad.net/~tyoc\n"
+#~ "  Joseph https://launchpad.net/~josephmail7\n"
+#~ "  Lightbuster https://launchpad.net/~herramienta-vx2\n"
+#~ "  Mario del Pozo https://launchpad.net/~mariodpros\n"
+#~ "  Omar Olarte https://launchpad.net/~oeolartep\n"
+#~ "  Paco Molinero https://launchpad.net/~franciscomol\n"
+#~ "  Ricardo Pérez López https://launchpad.net/~ricardo\n"
+#~ "  Rodrigo Garcia Gonzalez https://launchpad.net/~nibblesmx\n"
+#~ "  Virusurbano https://launchpad.net/~lfacchinelli\n"
+#~ "  kilik https://launchpad.net/~kilik\n"
+#~ "  uve https://launchpad.net/~uve\n"
+#~ "  Álvaro del Olmo Alonso https://launchpad.net/~dllum"

=== modified file 'po/fi.po'
--- po/fi.po	2011-12-02 05:55:20 +0000
+++ po/fi.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 23:01+0000\n"
-"Last-Translator: Otto Kekäläinen <otto@seravo.fi>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-06-08 13:43+0000\n"
+"Last-Translator: Otto Kekäläinen <otto@sange.fi>\n"
 "Language-Team: Finnish <fi@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Kohde:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Valitse kansio"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Toimenpide keskeytetty."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,49 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Otto Kekäläinen https://launchpad.net/~otto"

=== modified file 'po/fr.po'
--- po/fr.po	2011-12-02 05:55:20 +0000
+++ po/fr.po	2011-03-08 04:41:48 +0000
@@ -8,15 +8,15 @@
 msgstr ""
 "Project-Id-Version: Olive 0.11\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Launchpad Translations Administrators <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:06+0000\n"
+"Last-Translator: Pierre Slamich <pierre.slamich@gmail.com>\n"
 "Language-Team: GNOME French Team <gnomefr@traduc.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=utf-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -24,7 +24,7 @@
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
-msgstr "Ajuster les paramètres de Bazaar"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
@@ -32,7 +32,7 @@
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
@@ -43,165 +43,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branche"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Emplacement de la branche :"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destination :"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Pseudo de la branche :"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Révision :"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Veuillez choisir un dossier"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Emplacement de la branche manquante"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Vous devez préciser l'emplacement de la branche."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Succès de la création de la branche"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d révision(s) ont été branchées."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Checkout _léger"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Le répertoire ne contient pas de répertoire de travail"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Opération annulée."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Cette branche contient des modifications locales."
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Veuillez commiter ou annuler les modifications avant la fusion."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "ajouté"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "supprimé"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "renommé"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "renommé et modifié"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modifié"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "Ne valider que l_ocalement"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Valider"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Chemin"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Type"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Date"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Commiteur"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Résumé"
 
@@ -209,140 +209,140 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Valider avec un message vide ?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Vous pouvez donner la raison de cette validation dans ce message"
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Valider avec des inconnus ?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr "Fichiers inconnus dans l'arborescence de travail. Poursuivre ?"
+msgstr "Fichiers inconnus dans le répertoire de travail. Poursuivre  ?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
-msgstr "Valider sans aucun changement ?"
+msgstr "Validerer sans aucun changement ?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilitaire externe :"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflits"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
-msgstr "Aucun conflit dans l'arborescence de travail."
+msgstr "Aucun conflit dans l'arbre de travail."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflit sur le chemin"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflit sur le contenu"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflit sur le texte"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id en doublon"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "doublon"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
-msgstr "parent manquant"
+msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "suppression du parent"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "type de conflit inconnu"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Aucun fichier n'a été selectionné"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Veuillez sélectionner un fichier parmi la liste."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "L'appel à utilitaire externe a échoué"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Impossible de résoudre le conflit"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
 "Actuellement, seuls les conflits sur les fichiers textes peuvent être "
-"résolus par Olive. Les conflits de contenu sur la structure de "
+"résolus par Olive. Les conflits de contenu ou sur la structure de "
 "l'arborescence doivent êtres résolus en utilisant la ligne de commande."
 
 #. View menu
@@ -350,104 +350,104 @@
 msgid "_View"
 msgstr "Afficha_ge"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Succès de la fusion"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Tous les changements ont été appliqués avec succès."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Conflits rencontrés."
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Veuillez résoudre les conflits manuellement avant de valider."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Le répertoire n'est pas une branche"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
-msgstr "Cette action ne peut être effectuée que sur une branche."
+msgstr "Cette action ne peut effectuée que sur une branche."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Le répertoire n'est pas un checkout"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 "Les validations locales ne peuvent être effectués que sur des checkouts."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Aucun changement à valider"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Il est malgré tout possible de forcer la validation."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
-msgstr "Conflits dans l'arborescence"
+msgstr "Conflits dans l'arbre"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Il est nécessaire de résoudre les conflits avant de valider."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "La validation stricte a échoué."
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
-"L'arborescence de travail contient des fichiers inconnus.\n"
+"L'arbre de travail contient des fichiers inconnus.\n"
 "Veuillez les ajouter ou les supprimer."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "La branche associée n'est pas à jour"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Fichier non versionné"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Le fichier sélectionné n'est pas versionné."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Les branches ont divergées"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -456,35 +456,35 @@
 "ont divergées. Utilisez l'option d'écrasement si vous souhaitez malgré tout\n"
 "effectuer un « push »."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Pas de différences à afficher"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Le fichier sélectionné n'a pas été modifié."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "Pas de telle révision"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "La révision que vous avez renseigné n'existe pas."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "La cible existe déjà"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "Le répertoire cible existe déjà. Veuillez choisir une autre cible."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Le répertoire est déjà une branche"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -493,45 +493,45 @@
 "Le répertoire courant (%s) est déjà une branche.\n"
 "Vous avez la possibilité de l'utiliser ou d'initialiser un autre répertoire."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
-msgstr "Branche sans arborescence de travail"
+msgstr "Branche sans répertoire de travail"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 "Le répertoire courant (%s)\n"
-"est une branche sans arborescence de travail."
+"est une branche sans arbre de travail."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Erreur bzr inconnue"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permission refusée"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "permission refusée."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Erreur inconnue"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initialiser"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Quel répertoire voulez-vous intialiser ?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Répertoire actuel"
 
@@ -539,100 +539,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Créer un nouveau répertoire nommé :"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Le nom du répertoire n'est pas indiqué"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Vous devez indiquer un nouveau nom de répertoire."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Fusionner"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Branche non indiquée"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Veuillez indiquer une branche depuis laquelle fusionner."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Erreur de commande Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Emplacement :"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -640,20 +600,20 @@
 "Vous ne pouvez pas effectuer un push si les branches ont divergées.\n"
 "Voulez-vous écraser ?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Succès du push."
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d révisions exportées."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Aucun répertoire parent existant"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -663,11 +623,11 @@
 "Voulez-vous le créer ?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Sélectionner"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -675,32 +635,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Ajouté"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Supprimé"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renommé"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modifié"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Inconnu"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Aucun changement."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Étiquettes"
 
@@ -712,46 +672,620 @@
 msgid "Revision ID"
 msgstr "ID de la révision"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Les étiquettes ne sont pas prises en charge par le format de cette branche. "
 "Effectuez une mise à niveau."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Aucune révision étiquettée dans cette branche."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Supprimer l'étiquette"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Supprimer l'étiquette ?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Voulez-vous vraiment supprimer l'étiquette : <b>%s</b> ?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Ajouter une étiquette"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nom de l'étiquette :"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de révision :"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Aucun nom d'étiquette indiqué"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Vous devez renseigner le nom d'étiquette souhaité."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Renommer..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Déplacer..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Créer un _répertoire..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Supprimer des fichiers..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Interface graphique de Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Ajouter des fichiers..."
+
+#~ msgid "_File"
+#~ msgstr "_Fichier"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Rafraîchir"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Afficher les fichiers _cachés"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Historique..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Différences..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistiques"
+
+#~ msgid "_Help"
+#~ msgstr "Aid_e"
+
+#~ msgid "Diff"
+#~ msgstr "Analyse des différences"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quel(s) fichier(s) souhaitez-vous ajouter ?"
+
+#~ msgid "Selected only"
+#~ msgstr "Uniquement sélectionné(s)"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Ajouter des fichiers"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Suppression de fichiers"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quel(s) fichier(s) souhaitez-vous supprimer ?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Tous les inconnus récursivement"
+
+#~ msgid "_Add"
+#~ msgstr "_Ajouter"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tous les fichiers avec le statut « added »"
+
+#~ msgid "_Remove"
+#~ msgstr "_Supprimer"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Créer un répertoire"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Répertoire sous ré_vision"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Créer un répertoire"
+
+#~ msgid "_Get..."
+#~ msgstr "_Obtenir..."
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Move"
+
+#~ msgid "Move to"
+#~ msgstr "Déplacer vers"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Dépôt partagé : "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Racine du checkout léger : "
+
+#~ msgid "_Rename"
+#~ msgstr "_Renommer"
+
+#~ msgid "Rename to"
+#~ msgstr "Renommer en"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Renommer"
+
+#~ msgid "_Move"
+#~ msgstr "_Déplacer"
+
+#~ msgid "Select a directory"
+#~ msgstr "Sélectionnez un répertoire"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publier vers la branche : "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branche parente : "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Checkout racine : "
+
+#~ msgid "(none)"
+#~ msgstr "(aucun)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Dépôt du checkout : "
+
+#~ msgid "Branch root: "
+#~ msgstr "Branche racine : "
+
+#~ msgid "Control format: "
+#~ msgstr "Format de contrôle : "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format du répertoire de travail : "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Statut du verrou du dépôt : "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Statut du verrou de la branche : "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Révisions manquantes dans le répertoire de travail : "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format du dépôt : "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format de la branche : "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Statut du verrou du répertoire de travail : "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Révisions manquantes dans la branche : "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Révisions dans la branche : "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fichiers renommés : "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fichiers inconnus : "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Sous-répertoires avec révisions : "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fichiers supprimés : "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fichiers ignorés : "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Date de la première révision : "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Age de la branche en jours : "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Nombre de commiteurs : "
+
+#~ msgid "Title:"
+#~ msgstr "Titre :"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Veuillez sélectionner un fichier de la liste\n"
+#~ "ou choisir l'autre option."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Taille du dépôt : "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Révisions dans le dépôt : "
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Veuillez renseigner un titre pour poursuivre."
+
+#~ msgid "No title given"
+#~ msgstr "Aucun titre renseigné"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "L'emplacement parent est inconnu"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull réussi"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d révision(s) importée(s)."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Ajoute le fichier sélectionné"
+
+#~ msgid "Add"
+#~ msgstr "Ajouter"
+
+#~ msgid "unchanged"
+#~ msgstr "inchangé"
+
+#~ msgid "Bookmark"
+#~ msgstr "Marque-page"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Marque-pages"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Impossible de trouver le fichier de description UI."
+
+#~ msgid "Status"
+#~ msgstr "État"
+
+#~ msgid "Filename"
+#~ msgstr "Nom de fichier"
+
+#~ msgid "unknown"
+#~ msgstr "inconnu"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Impossible de trouver le fichier Glade."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Affiche les différences de tous les fichiers"
+
+#~ msgid "All..."
+#~ msgstr "Toutes..."
+
+#~ msgid "Selected..."
+#~ msgstr "Sélectionné..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Affiche les différences du fichier sélectionné"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Marque l'emplacement courant"
+
+#~ msgid "Edit"
+#~ msgstr "Éditer"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Édite le marque-page sélectionné"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Supprime le marque-page sélectionné"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Commit les changements"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Affiche les différences du fichier"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Le répertoire courant a été marqué. Il est dorénavant\n"
+#~ "possible de l'atteindre en le sélectionnant depuis le\n"
+#~ "panneau gauche."
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Le répertoire courant est déjà marqué.\n"
+#~ "Consultez le panneau de gauche pour référence."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Emplacement déjà marqué"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Veuillez indiquer le nom souhaité pour le nouveau répertoire."
+
+#~ msgid "No directory name given"
+#~ msgstr "Aucun nom de répertoire renseigné"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Marque-page ajouté avec succès"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Le répertoire existe déjà"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Veuillez indiquer un nom différent pour poursuivre."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Ce n'est pas la même branche"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Veuillez choisir un fichier de la liste pour opérer."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destination ne se trouve pas dans la même branche."
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Aucun fichier ajouté n'a été trouvé dans le répertoire de travail."
+
+#~ msgid "No matching files"
+#~ msgstr "Aucun fichier correspondant"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout de la branche : "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branche du dépôt : "
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Veuillez indiquer un nouveau nom pour le fichier."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nom de fichier non fourni"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fichiers inchangés : "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fichiers modifiés : "
+
+#~ msgid "Added files: "
+#~ msgstr "Fichiers ajoutés : "
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Date de la dernière révision : "
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Il y a des révisions manquantes"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Impossible de trouver les révisions manquantes si l'emplacement parent n'est "
+#~ "pas connu."
+
+#~ msgid "Local branch up to date"
+#~ msgstr "La branche locale est à jour"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d révision(s) manquante(s)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Il n'y a pas de révisions manquantes."
+
+#~ msgid "_Information..."
+#~ msgstr "_Information..."
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Information"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Emplacement :</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Relatifs aux branches :</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format :</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>État du verrou :</b>"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Révisions manquantes :</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Dans le répertoire de travail :</b>"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Historique de la branche :</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Stockage des révisions :</b>"
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr ""
+#~ "Impossible d'effectuer un « pull » tant que l'emplacement parent est absent."
+
+#~ msgid "Remove"
+#~ msgstr "Supprimer"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Supprime le fichier sélectionné"
+
+#~ msgid "Open"
+#~ msgstr "Ouvrir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Ouvrir le fichier sélectionné"
+
+#~ msgid "Open Folder"
+#~ msgstr "Ouvrir le dossier"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Ouvrir le dossier en marque-page dans Nautilus"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Aucun changement n'a été effectué dans le répertoire de travail."
+
+#~ msgid "Pending merges"
+#~ msgstr "Fusions en attente"
+
+#~ msgid "Revno"
+#~ msgstr "Renvo"
+
+#~ msgid "Set default push location"
+#~ msgstr "Définition de l'emplacement par défaut du push"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Il n'y a pas d'emplacement défini par défaut pour le push.\n"
+#~ "Voulez-vous maintenant définir « %r » par défaut ?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Veuillez patienter, les révisions sont en cours de chargement..."
+
+#~ msgid "Revert successful"
+#~ msgstr "Rétablissement réussi"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Tous les fichiers ont été rétablis à la dernière révision."
+
+#~ msgid "ignored"
+#~ msgstr "ignoré"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Vérifiez le répertoire de travail avant de poursuivre."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflits détectés"
+
+#~ msgid "Last modified"
+#~ msgstr "Dernière modification"
+
+#~ msgid "Size"
+#~ msgstr "Taille"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Renommer le fichier sélectionné"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Enlève les fichiers/répertoires sélectionnés et les efface"
+
+#~ msgid "Rename"
+#~ msgstr "Renommer"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mode H_istorique"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initialiser..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annoter..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Fusionner..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Révisions manquantes"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Annule_r les modifications"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Supprimer le répertoire et tous ses sous-répertoires ?"
+
+#~ msgid "Revert"
+#~ msgstr "Rétablir"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annoter le fichier sélectionné"
+
+#~ msgid "View contents"
+#~ msgstr "Voir le contenu"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Annuler les changements"
+
+#~ msgid "Annotate"
+#~ msgstr "Annoter"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Afficher les différences entre deux révisions du fichier"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Voir le contenu du fichier dans le visualiseur intégré"
+
+#~ msgid "Show differences"
+#~ msgstr "Montrer les différences"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusion - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Fusionner à partir de :"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Supprimer et effacer"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Rétablir le fichier sélectionné vers la révision sélectionnée"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Rétablir à cette révision"
+
+#~ msgid "Commit message:"
+#~ msgstr "Message de validation :"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flits"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Bastien Jaillot https://launchpad.net/~bastnic\n"
+#~ "  Bruno Bord https://launchpad.net/~brunobord\n"
+#~ "  DarkRedman https://launchpad.net/~darkredman\n"
+#~ "  Francois Audirac https://launchpad.net/~francois-audirac\n"
+#~ "  Hanusz leszek https://launchpad.net/~leszek-skynet\n"
+#~ "  Jean-François Fortin Tam https://launchpad.net/~kiddo\n"
+#~ "  NSV https://launchpad.net/~nsv\n"
+#~ "  Pierre Slamich https://launchpad.net/~pierre-slamich\n"
+#~ "  Shrat https://launchpad.net/~dyonisiaque\n"
+#~ "  Stéphane Raimbault https://launchpad.net/~sra\n"
+#~ "  Wilfried Kopp https://launchpad.net/~chevdor\n"
+#~ "  Yoan Blanc https://launchpad.net/~greut\n"
+#~ "  codL https://launchpad.net/~codlgaez"

=== modified file 'po/hu.po'
--- po/hu.po	2011-12-02 05:55:20 +0000
+++ po/hu.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 23:01+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 07:57+0000\n"
 "Last-Translator: Szilveszter Farkas <Szilveszter.Farkas@gmail.com>\n"
 "Language-Team: Hungarian <hu@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,53 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar grafikus felület"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Csörföly Dániel https://launchpad.net/~csorfolydaniel\n"
+#~ "  Szilveszter Farkas https://launchpad.net/~phanatic"

=== modified file 'po/id.po'
--- po/id.po	2011-12-02 05:55:20 +0000
+++ po/id.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Mahyuddin Susanto <saya@udienz.web.id>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-13 20:04+0000\n"
+"Last-Translator: Mahyuddin Susanto <mahyuddin.susanto@gmail.com>\n"
 "Language-Team: Indonesian <id@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Cabang"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Lokasi Cabang:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Tujuan:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Pilijh Folder"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Pegang"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr "_Lihat"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inisialisasi"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Lokasi"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Tekan"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,229 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "_Rename..."
+#~ msgstr "_Ubah Nama..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Pindah..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Buat _Direktori"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Buang Berkas(berkas)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Masukkan Berkas(berkas)..."
+
+#~ msgid "_File"
+#~ msgstr "_Berkas"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Penyegaran"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Perlihatkan berkas _tersembunyi"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Te_kan"
+
+#~ msgid "_Get..."
+#~ msgstr "_Dapatkan"
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Perbedaan..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistika"
+
+#~ msgid "_Help"
+#~ msgstr "_Bantuan..."
+
+#~ msgid "Diff"
+#~ msgstr "Beda"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Dimana berkas(berkas) yang akan anda tambahkan??"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Tambahkan berkas(berkas)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Semua berkas dengan status 'dimasukkan'"
+
+#~ msgid "_Remove"
+#~ msgstr "Hapus"
+
+#~ msgid "Selected only"
+#~ msgstr "Hanya yang dipilih"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Buang berkas(berkas)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "berkas mana yang akan di buang?"
+
+#~ msgid "_Add"
+#~ msgstr "_Tambahkan"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Buat Direktori"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Jenis direktory"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Buat direktory"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Pindah"
+
+#~ msgid "Move to"
+#~ msgstr "Pindahkan ke"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Penamaan Ulang"
+
+#~ msgid "Select a directory"
+#~ msgstr "Pilih direktori"
+
+#~ msgid "_Move"
+#~ msgstr "_Pindahkan"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Periksa Repository: "
+
+#~ msgid "Branch root: "
+#~ msgstr "root Cabang: "
+
+#~ msgid "Checkout root: "
+#~ msgstr "Periksa root: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Periksa Cabang: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Ganti nama"
+
+#~ msgid "Rename to"
+#~ msgstr "Ganti nama ke"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Tampilkan di cabang: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "cabang diatas: "
+
+#~ msgid "(none)"
+#~ msgstr "(tidak ada)"
+
+#~ msgid "Control format: "
+#~ msgstr "Pengendali Format: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Bekerja dengan tiga format: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format Cabang: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format Repository: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Berkas yang tidak diubah: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Berkas yang diubah: "
+
+#~ msgid "Added files: "
+#~ msgstr "Penambahan berkas: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Status pengunci Repositori: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Status pengunci Cabang: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Bekerja dengan status kunci tiga: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Penamaan ualng  berkas: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Berkas tidak diketahui; "
+
+#~ msgid "Ignored files: "
+#~ msgstr "berkas di acuhkan: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "versi anak direktori: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Buang Berkas; "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Revisi pertama: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Mahyuddin Susanto https://launchpad.net/~udienz"

=== modified file 'po/it.po'
--- po/it.po	2011-12-02 05:55:20 +0000
+++ po/it.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:59+0000\n"
-"Last-Translator: Luca Ferretti <elle.uca@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-13 20:12+0000\n"
+"Last-Translator: Luca Ferretti <elle.uca@ubuntu-it.org>\n"
 "Language-Team: Italian <it@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branch"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Posizione del branch:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destinazione:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Soprannome del branch:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisione:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Selezionare una cartella"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Posizione del branch mancante"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "È necessario specificare una posizione per il branch."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Branching riuscito"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/D"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Checkout _leggero"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "La directory non presenta un albero di working"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operazione interrotta."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Ci sono cambiamenti locali nella branca"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "aggiunto"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "rimosso"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "rinominato"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "rinominato e modificato"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificato"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "_Eseguire commit solo localmente"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Commit"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Percorso"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tipo"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Committer"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Riepilogo"
 
@@ -208,135 +208,135 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Eseguire il commit con un messaggio vuoto?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "È possibile descrivere il motivo del commit nel messaggio."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Eseguire il commit con sconosciuti?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Sono presenti dei file sconosciuti nel working tree. Eseguire il commit lo "
 "stesso?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Eseguire il commint senza cambiamenti?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilità esterna:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflitti"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Nessun conflitto nel working tree"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflitto di percorso"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflitto di contenuto"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflitto di testo"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id duplicato"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicato"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "eliminazione genitore"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipo di conflitto sconosciuto"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Non è stato selezionato alcun file"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Selezionare un file dall'elenco."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Chiamata all'utilità esterna non riuscita"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Impossibile risolvere il conflitto"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -351,73 +351,73 @@
 msgid "_View"
 msgstr "_Mostra"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "La directory non è un branch"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "È possibile eseguire questa azione sono all'interno di un branch."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "La directory non è un checkout"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "È possibile eseguire i commit locali solamente sui checkout."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Nessun cambiamento per eseguire il commit"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Provare «force commit« per eseguire il commit in ogni caso."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflitti nell'albero"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "È necessario risolvere i conflitti prima di eseguire il commit."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Commit strict non riuscito"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -425,106 +425,106 @@
 "Nell'albero di lavoro sono presenti file sconosciuti.\n"
 "Aggiungerli o eliminarli."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "File non nella versione"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Il file selezionato non è nella versione"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Nessun output diff"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -532,119 +532,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Unisci"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Sottocartella inesistente"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -654,11 +614,11 @@
 "non esiste. Crearla?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -666,32 +626,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Aggiunto"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Rimosso"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Rinominato"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificato"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Sconosciuto"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Nessuna modifica."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tag"
 
@@ -703,46 +663,474 @@
 msgid "Revision ID"
 msgstr "ID Revisione"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Le Tag non sono supportate da questo formato della branca. Per favore "
 "aggiornare."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Modifiche non taggate nella branca."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Rimuovi tag"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Rimuovere tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Sei sicuro di voler rimuovere la tag: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Aggiungi tag"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nome Tag:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID Revisione:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Nessun nome tag specificato"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Devi specificare il nome della tag desiderato."
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Non ci sono modifiche nell'albero di lavoro."
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull eseguito con successo"
+
+#~ msgid "Bookmark"
+#~ msgstr "Segnalibro"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Segnalibri"
+
+#~ msgid "ignored"
+#~ msgstr "ignorato"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Rilevati conflitti"
+
+#~ msgid "Last modified"
+#~ msgstr "Ultima modifica"
+
+#~ msgid "Status"
+#~ msgstr "Stato"
+
+#~ msgid "Filename"
+#~ msgstr "Nome file"
+
+#~ msgid "Size"
+#~ msgstr "Dimensione"
+
+#~ msgid "Title:"
+#~ msgstr "Titolo:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Specificare un titolo per continuare."
+
+#~ msgid "Modified files: "
+#~ msgstr "File modificati: "
+
+#~ msgid "Added files: "
+#~ msgstr "File aggiunti: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "File rinominati: "
+
+#~ msgid "Removed files: "
+#~ msgstr "File rimossi: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "File sconosciuti: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "File ignorati: "
+
+#~ msgid "Time"
+#~ msgstr "Orario"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Ci sono modifiche mancanti"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branca locale aggiornata"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revisione(i) mancante(i)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Non ci sono modifiche mancanti"
+
+#~ msgid "Add"
+#~ msgstr "Aggiungi"
+
+#~ msgid "unchanged"
+#~ msgstr "non modificato"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "File Glade non trovato."
+
+#~ msgid "unknown"
+#~ msgstr "sconosciuto"
+
+#~ msgid "No title given"
+#~ msgstr "Nessun titolo fornito"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Per favore selezionare un file dalla lista,\n"
+#~ "o scegliere l'altra opzione."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Aggiungi il file selezionato"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Rinomina il file selezionato"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Rimuovi ed elimina"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Rimuovi il file/cartella selezionata ed elimina dal disco"
+
+#~ msgid "Rename"
+#~ msgstr "Rinomina"
+
+#~ msgid "Revert"
+#~ msgstr "Annulla"
+
+#~ msgid "Open"
+#~ msgstr "Apri"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Apri il file selezionato"
+
+#~ msgid "Remove"
+#~ msgstr "Rimuovi"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Rimuovi il file selezionato"
+
+#~ msgid "Annotate"
+#~ msgstr "Annota"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Annota il file selezionato"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Annulla le modifiche"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Aggiungi segnalibro della posizione locale"
+
+#~ msgid "Edit"
+#~ msgstr "Modifica"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Modifica il segnalibro selezionato"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Rimuovere il segnalibro selezionato"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostra la diff del file"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Apri cartella segnalibri in Nautilus"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostra differenze"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostra le differenze di tutti i file"
+
+#~ msgid "All..."
+#~ msgstr "Tutti..."
+
+#~ msgid "View contents"
+#~ msgstr "Mostra contenuti"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostra le differenze tra due modifiche del file"
+
+#~ msgid "Open Folder"
+#~ msgstr "Apri Cartella"
+
+#~ msgid "Selected..."
+#~ msgstr "Selezionati..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostra le differenze del file selezionato"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Segnalibro aggiunto con successo"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Posizione già salvata in un segnalibro"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Per favore specificare il nome desiderato per la nuova cartella"
+
+#~ msgid "No directory name given"
+#~ msgstr "Nessun nome cartella fornito"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Riporta il file selezionato alla modifica selezionata"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Eliminare cartella e tutte le sottocartelle?"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Ritorna a questa modifica"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Cartella già esistente"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Non la stessa branca"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Tutti i file con lo status 'aggiunto'"
+
+#~ msgid "No matching files"
+#~ msgstr "File non corrispondenti"
+
+#~ msgid "Selected only"
+#~ msgstr "Selezionato solo"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Per favore selezionare un file dalla lista per continuare."
+
+#~ msgid "_Remove"
+#~ msgstr "_Rimuovi"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Per favore specificare un altro nome per continuare."
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Quali file vuoi rimuovere?"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "La destinazione non è la stessa branca"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Rinomina..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Sposta..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Annota..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Per favore specificare un nome per il file"
+
+#~ msgid "Filename not given"
+#~ msgstr "Nome file non fornito"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Crea _cartella..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Rimuovi file..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Aggiungi file..."
+
+#~ msgid "_File"
+#~ msgstr "_File"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Aggiorna"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Mostra file _nascosti"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inizializza..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Unisci..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Annulla tutte le modifiche"
+
+#~ msgid "_Differences..."
+#~ msgstr "_Differenze..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Modifiche _mancanti"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_g..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flitti"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistiche"
+
+#~ msgid "_Help"
+#~ msgstr "_Aiuto"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informazioni..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Modalità S_toria"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Quali file vuoi aggiungere?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Aggiungi file"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Rimuovi file"
+
+#~ msgid "_Add"
+#~ msgstr "_Aggiungi"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Crea cartella"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Sposta"
+
+#~ msgid "Move to"
+#~ msgstr "Sposta in"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Crea cartella"
+
+#~ msgid "Rename to"
+#~ msgstr "Rinomina in"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Rinomina"
+
+#~ msgid "_Move"
+#~ msgstr "_Sposta"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selezionare una cartella"
+
+#~ msgid "_Rename"
+#~ msgstr "_Rinomina"
+
+#~ msgid "(none)"
+#~ msgstr "(nessuno)"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Posizione:</b>"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informazioni"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Pubblica su branca: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "File invariati: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Modifiche mancanti:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Ora dell'ultima modifica: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Ora della prima modifica: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Modifiche mancanti nella branca: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Modifiche nella branca: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Unione - Olive"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Storia della branca:</b>"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Età della branca in giorni: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Numero di commiter: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Dimensione del repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Modifiche nel repository: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Unisci da:"
+
+#~ msgid "Revert successful"
+#~ msgstr "Annullato con successo"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Tutti i file riportati all'ultima modifica"
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Impossibile trovare il file di descrizione interfaccia utente"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "File per cui eseguire il commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Messaggio del commit"
+
+#~ msgid "Pending merges"
+#~ msgstr "Merge in sospeso"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Luca Ferretti https://launchpad.net/~elle.uca\n"
+#~ "  Luca Livraghi https://launchpad.net/~luca91\n"
+#~ "  Milo Casagrande https://launchpad.net/~milo\n"
+#~ "  Stefano Karapetsas https://launchpad.net/~stefano-karapetsas\n"
+#~ "  Vale https://launchpad.net/~valetzara"

=== modified file 'po/ja.po'
--- po/ja.po	2012-02-12 05:08:39 +0000
+++ po/ja.po	2011-03-08 04:41:48 +0000
@@ -7,19 +7,19 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2012-02-11 12:20+0000\n"
-"Last-Translator: Koichi Akabe <vbkaisetsu@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-04-20 14:46+0000\n"
+"Last-Translator: Fumihito YOSHIDA <hito@kugutsu.org>\n"
 "Language-Team: Japanese <ja@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2012-02-12 05:08+0000\n"
-"X-Generator: Launchpad (build 14771)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
-msgstr "Bazaar 設定"
+msgstr ""
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
@@ -31,176 +31,176 @@
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
-msgstr "Bazaar"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
-msgstr "Bazaar 通知"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:2
 msgid "Notification Area Icon for Bazaar"
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "ブランチ(_B)"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "ブランチの場所:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "リビジョン:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "フォルダを選択してください"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "ブランチの場所が欠けています"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "ブランチの場所を入力しなければなりません。"
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "ブランチを切るのが成功しました"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d 個のリビジョンをブランチしました。"
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "チェックアウト(_O)"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "軽量チェックアウト(_L)"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "ディレクトリにワーキングツリーがありません"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "操作は中止されました。"
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "マージする前に変更をコミットするかリバートしてください。"
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "追加された"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "削除された"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "名前が変更"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "名称変更/修正"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "変更"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
-msgstr "<b>コミットメッセージ</b>"
+msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "ローカルにのみコミットする (_O)"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "コミット(_I)"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
-msgstr "すべての変更をコミット"
+msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
-msgstr "選択した変更のみコミット"
+msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "コミット"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "パス"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "日付"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "コミッター"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "概要"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "空のメッセージでコミットしますか?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
-msgstr "コミット内容をメッセージで説明できます。"
+msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr "未知のファイルがワーキングツリーに存在します。とにかくコミットしますか?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "変更無しでコミットしますか?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "外部ユーティリティ:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "競合"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "ワーキングツリー内で競合は起きませんでした。"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "パスの競合"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "内容の競合"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "テキストの競合"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "重複ID"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "重複"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "ファイルが選択されていません"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "リストからファイルを選択してください"
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "外部ユーティリティの呼び出しに失敗しました"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "コンフリクトを解決することができません"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,73 +346,73 @@
 msgid "_View"
 msgstr "表示(_V)"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "マージに成功しました"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "すべての変更の適用に成功しました"
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "衝突が起きました"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "コミットする前に手動で競合を解決してください"
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "ディレクトリがブランチではありません。"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "このアクションはブランチ内でしかできません。"
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "このディレクトリはチェックアウトされたものではありません"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "チェックアウトされたものに対してのみローカルコミットを行うことができます。"
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "コミットすべき変更がありません"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "とにかくコミットをしたいなら、強制的なコミットを行ってください"
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "ツリー内に競合があります"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "コミットを行う前に競合を解決する必要があります"
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -420,29 +420,29 @@
 "ワーキングツリー内に未知のファイルがあります。\n"
 "これらを add するか delete してください。"
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "ファイルはバージョン管理下に置かれていません"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "選択されたファイルはバージョン管理下に置かれていません。"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "ブランチは分岐されました"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -450,80 +450,80 @@
 "ブランチが分岐した場合にはプッシュすることはできません。\n"
 "それでもプッシュしたい場合にはオーバライトオプションを使用してください。"
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "差分の出力はありません"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "選択されたファイルに変更はありません。"
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "そのようなリビジョンはありません。"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "指定されたリビジョンは存在しません。"
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "ターゲットはすでに存在しています"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 "ターゲットのディレクトリはすでに存在しています。\r\n"
 "他のターゲットを選択してください。"
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "そのディレクトリはすでにブランチです。"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "ワーキングツリーのないブランチ"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr "現在のディレクトリ (%s) はワーキングツリーのないブランチです。"
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "未知の bzr エラーです"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "権限がありません"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "権限がありません。"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "未知のエラー"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "初期化する(_I)"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "どのディレクトリを初期化しますか？"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "現在のディレクトリ"
 
@@ -531,100 +531,60 @@
 msgid "Create a new directory with the name:"
 msgstr "以下の名前で新しいディレクトリを作成する:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "ディレクトリ名が指定されていません"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "新しいディレクトリ名を指定してください"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "マージ(_M)"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "ブランチが与えられていません"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "マージ元のブランチを指定してください。"
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Bazaar コマンドのエラー"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "場所:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "プッシュ (_)"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -632,20 +592,20 @@
 "ブランチが分岐した場合にはプッシュすることができません。\n"
 "上書きしますか？"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "プッシュに成功しました"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d リビジョンプッシュしました。"
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -653,11 +613,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "選択する(_S)"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -665,32 +625,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "追加"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "削除"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "名称変更"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "変更"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "不明"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "変更なし"
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "タグ"
 
@@ -702,44 +662,360 @@
 msgid "Revision ID"
 msgstr "リビジョン ID"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr "このブランチフォーマットではタグはサポートされていません。アップグレードしてください。"
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "ブランチ内にタグ付けされたリビジョンはありません。"
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "タグを外す (_R)"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>タグを外しますか？</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "タグを外してもよろしいですか: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "タグ追加 (_A)"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "タグ名:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "リビジョン ID:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "タグ名が指定されていません"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "Commit message:"
+#~ msgstr "コミットメッセージ:"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "ワーキングツリー内に変更がありません。"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>ブランチの履歴:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "レポジトリのサイズ: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "レポジトリ内のリビジョン: "
+
+#~ msgid "Merge from:"
+#~ msgstr "以下よりマージ:"
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "ブランチ内のリビジョン: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "変更されなかったファイル: "
+
+#~ msgid "Modified files: "
+#~ msgstr "変更されたファイル: "
+
+#~ msgid "Added files: "
+#~ msgstr "追加されたファイル: "
+
+#~ msgid "Removed files: "
+#~ msgstr "削除されたファイル: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>ワーキングツリー内:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "最後のリビジョンの時刻: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "最初のリビジョンの時刻: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "コミッターの数: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "改名されたファイル: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "未知のファイル: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "無視されたファイル: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "バージョン管理されているサブディレクトリ: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>欠けているリビジョン:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>ロックの状態:</b>"
+
+#~ msgid "Branch lock status: "
+#~ msgstr "ブランチのロックの状態: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "ワーキングツリーに欠けているリビジョン: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "ワーキングツリーのロックの状態: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "ブランチに欠けているリビジョン: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "公表するブランチ: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "親ブランチ: "
+
+#~ msgid "Control format: "
+#~ msgstr "操作形式: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "ワーキングツリーの形式: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>場所:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>形式:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>関係のあるブランチ:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "レポジトリの形式: "
+
+#~ msgid "Branch format: "
+#~ msgstr "ブランチの形式: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "レポジトリのロックの状態: "
+
+#~ msgid "(none)"
+#~ msgstr "(なし)"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - 情報"
+
+#~ msgid "_Rename"
+#~ msgstr "名前の変更(_R)"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - ディレクトリの作成"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "バージョン管理されたディレクトリ(_V)"
+
+#~ msgid "_Make directory"
+#~ msgstr "ディレクトリの作成(_M)"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - 名前の変更"
+
+#~ msgid "_Move"
+#~ msgstr "移動(_M)"
+
+#~ msgid "Select a directory"
+#~ msgstr "ディレクトリの選択"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - 移動"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - ファイルの削除"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "履歴モード(_I)"
+
+#~ msgid "_Help"
+#~ msgstr "ヘルプ(_H)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "どのファイルを追加しますか?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - ファイルの追加"
+
+#~ msgid "_Add"
+#~ msgstr "追加(_A)"
+
+#~ msgid "_Differences..."
+#~ msgstr "差分(_D)..."
+
+#~ msgid "_Merge..."
+#~ msgstr "マージ(_M)..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "欠けているリビジョン(_R)"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "タグ(_G)..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "競合(_F)..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "ステータス(_T)..."
+
+#~ msgid "_Commit..."
+#~ msgstr "コミット(_C)..."
+
+#~ msgid "_Log..."
+#~ msgstr "ログ(_L)..."
+
+#~ msgid "_Statistics"
+#~ msgstr "統計データ(_S)"
+
+#~ msgid "_Information..."
+#~ msgstr "情報(_I)..."
+
+#~ msgid "_Refresh"
+#~ msgstr "更新(_R)"
+
+#~ msgid "_Get..."
+#~ msgstr "取得(_G)..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "隠しファイルを表示(_H)"
+
+#~ msgid "_Initialize..."
+#~ msgstr "初期化(_I)..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "注釈(_A)..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "全ての変更をリバート(_R)"
+
+#~ msgid "C_heckout..."
+#~ msgstr "チェックアウト(_H)..."
+
+#~ msgid "_Rename..."
+#~ msgstr "名前の変更(_R)..."
+
+#~ msgid "_Move..."
+#~ msgstr "移動(_M)..."
+
+#~ msgid "_Remove"
+#~ msgstr "削除(_R)"
+
+#~ msgid "Make _directory..."
+#~ msgstr "ディレクトリの作成(_D)..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "ファイルの削除..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "ファイルの追加(_A)..."
+
+#~ msgid "_File"
+#~ msgstr "ファイル(_F)"
+
+#~ msgid "Not the same branch"
+#~ msgstr "同じブランチではありません"
+
+#~ msgid "Directory already exists"
+#~ msgstr "ディレクトリは既に存在します"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "ブックマークフォルダをNautilusで開く"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "内蔵ビューアでファイルの内容を表示します"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "全てのファイルの差分を表示します"
+
+#~ msgid "All..."
+#~ msgstr "全て..."
+
+#~ msgid "View contents"
+#~ msgstr "内容を表示"
+
+#~ msgid "Open Folder"
+#~ msgstr "フォルダを開く"
+
+#~ msgid "Show differences"
+#~ msgstr "差分を表示"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "選択されているファイルの差分を表示します"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "選択されているブックマークを削除"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "このリビジョンへリバート"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "ブックマークに追加しました"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "現在のディレクトリは既にブックマークされています。\n"
+#~ "参照のために左のパネルを見てください。"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "場所は既にブックマークされています"
+
+#~ msgid "No directory name given"
+#~ msgstr "ディレクトリの名前が与えられていません"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "選択中のファイルを選択中のリビジョンへリバートします"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "ファイルの二つのリビジョン間の差分を表示します"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Fumihito YOSHIDA https://launchpad.net/~hito\n"
+#~ "  Nazo https://launchpad.net/~lovesyao\n"
+#~ "  epii https://launchpad.net/~epii"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "コミットするファイル"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "デフォルトのプッシュ先が設定されていません。\n"
+#~ "%r をデフォルトに設定しますか？"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "リビジョンが読み込まれるまでしばらくお待ちください..."
+
+#~ msgid "Time"
+#~ msgstr "時刻"
+
+#~ msgid "Revno"
+#~ msgstr "リビジョン番号"
+
+#~ msgid "Pending merges"
+#~ msgstr "マージ待ち"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "競合があります"

=== modified file 'po/ku.po'
--- po/ku.po	2011-12-02 05:55:20 +0000
+++ po/ku.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 23:01+0000\n"
-"Last-Translator: Jelmer Vernooij <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 09:34+0000\n"
+"Last-Translator: arasname <Unknown>\n"
 "Language-Team: Kurdish <ku@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Shax"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr "_Nîşandan"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,97 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "_Rename..."
+#~ msgstr "_Nav biguherîne..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Dosiye_chêke"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Pelê rake"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Pelekê Zêdeke(s).."
+
+#~ msgid "_File"
+#~ msgstr "_Pel"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Nû bike"
+
+#~ msgid "_Get..."
+#~ msgstr "_Ka"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "PlênÊ ve shartî nîshan bide"
+
+#~ msgid "Pu_ll"
+#~ msgstr "Bikshê"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Rewsh"
+
+#~ msgid "_Commit..."
+#~ msgstr "qebul"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Dehfde"
+
+#~ msgid "_Differences..."
+#~ msgstr "_Ferq"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistîk"
+
+#~ msgid "_Help"
+#~ msgstr "_Alîkarî"
+
+#~ msgid "Diff"
+#~ msgstr "Ferq"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  arasname https://launchpad.net/~arasname"

=== modified file 'po/nl.po'
--- po/nl.po	2011-12-02 05:55:20 +0000
+++ po/nl.po	2011-03-10 04:41:02 +0000
@@ -7,27 +7,27 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:59+0000\n"
-"Last-Translator: Wouter Bolsterlee (uws) <uws+launchpad@xs4all.nl>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-09 09:42+0000\n"
+"Last-Translator: Rachid <Unknown>\n"
 "Language-Team: Dutch <nl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:54+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-10 04:40+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
-msgstr "Bazaar-voorkeuren"
+msgstr "Bazaar voorkeuren"
 
 #: ../bazaar-properties.desktop.in.h:2
 msgid "Configure Bazaar settings"
-msgstr "Instellingen voor Bazaar aanpassen"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
-msgstr "Bazaar-bundel toepassen"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
@@ -35,174 +35,174 @@
 
 #: ../bzr-notify.desktop.in.h:1
 msgid "Bazaar Notification"
-msgstr "Bazaar-notificatie"
+msgstr ""
 
 #: ../bzr-notify.desktop.in.h:2
 msgid "Notification Area Icon for Bazaar"
-msgstr "Bazaar-pictogram in mededelingengebied"
+msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
-msgstr "_Branch"
+msgstr "_Tak"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Branch-locatie:"
+msgstr "Locatie aftakking"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
-msgstr "Doel:"
+msgstr "Bestemming:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr "Branch-alias:"
+msgstr "Alias aftakking"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisie:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
-msgstr "Selecteer een map"
+msgstr "Selecteer een map alstublieft"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Branch-locatie ontbreekt"
+msgstr "Locatie aftakking niet teruggevonden."
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Er dient een branch-locatie opgegeven te worden."
+msgstr "U moet een locatie voor uw aftakking opgeven."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
-msgstr "Branchen succesvol"
+msgstr "Successvol afgetakt."
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr "%d revisies gebranchet."
+msgstr "%d revisie(s) afgetakt."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
-msgstr "Niet van toepassing"
+msgstr "N/B"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "Check_out"
+msgstr "Ophalen"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
-msgstr "Branch-alias:"
+msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr "Lichtgewicht checkout"
+msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr "Map bevat geen werkkopie"
+msgstr "Folder bevat geen werkkopie!"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr "Handeling afgebroken"
+msgstr "Bewerking afgebroken."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
-msgstr "Er zijn lokale wijzigingen in deze branch"
+msgstr "Er zijn locale wijzigingen in deze branch"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
-"Wijzigiging dienen eerst gecommit danwal teruggedraaid (revert) te worden."
+"Gelieve uw wijzigingen vast te leggen of ongedaan te maken vooralleer samen "
+"te voegen."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "toegevoegd"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "verwijderd"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "hernoemd"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "hernoemd en gewijzigd"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "gewijzigd"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
-msgstr "van type veranderd"
+msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
-msgstr "<b>Commit-bericht</b>"
+msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
-msgstr "Alleen _lokaal comitten"
+msgstr "Enkel lokaal comitten"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
-msgstr "Co_mmitten"
+msgstr "Vastleggen"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
-msgstr "Bestanden"
+msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
-msgstr "Alle  wijzigingen committen"
+msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
-msgstr "Alleen geselecteerde wijzigingen committen"
+msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
-msgstr "Alle wijzigingen committen*"
+msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
-msgstr "Committen*"
+msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Committen"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Pad"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Type"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
-"<i>* Er kunnen geen specifieke bestanden geselecteerd worden bij mergen.</i>"
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
-msgstr "Revisies in behandeling"
+msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Datum"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Committer"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Samenvatting"
 
@@ -210,498 +210,460 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
-msgstr "Verschillen voor gehele mappenstructuur"
+msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
-msgstr "Commit-bericht voor bestand"
+msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
-msgstr "Globaal commit-bericht"
+msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
-msgstr "<b>Globaal commit-bericht</b>"
+msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
-msgstr "Verschillen voor "
+msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
-msgstr "Commit-bericht voor "
+msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
-msgstr "Committen geannuleerd"
+msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
-msgstr "Moeten commit-berichten bewaard blijven?"
+msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
-msgstr "Met leeg bericht committen?"
+msgstr "Vastleggen zonder boodschap?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
-msgstr ""
-"In het commit-bericht kan de bedoeling achter deze commit vastgelegd worden."
+msgstr "In dit bericht kan je de reden voor je commit beschrijven."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
-msgstr "Committen met onbekende bestanden?"
+msgstr "Vastleggen met onbekende bestanden?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
-"Er zijn onbekende bestanden in de werkkopie aanwezig. Toch committen?"
+"Er bestaan onbekende bestanden in uw werkkopie. Bent U zeker dat U dit wenst "
+"vast te leggen?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
-msgstr "Zonder wijzigingen committen?"
+msgstr "Vastleggen zonder wijzigingen?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
-msgstr "Er zijn geen wijzigingen in de werkkopie. Toch committen?"
+msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Extern hulpmiddel:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflicten"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Geen conflicten in de werkkopie."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
-msgstr "pad-conflict"
+msgstr "pad conflict"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
-msgstr "conflicterende inhoud"
+msgstr "Conflicterende inhoud"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr "conflicterende text"
+msgstr "Conflicterende text"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "dubbel id"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicaat"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr "parent loop"
+msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
-msgstr "parent niet onder versiebeheer"
+msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
-msgstr "ontbrekende parent"
+msgstr "ontbrekende ouder"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
-msgstr "parent verwijderen"
+msgstr "verwijderen van de ouder"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr "onbekend conflicttype"
+msgstr "onbekend soort conflict"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Geen bestand geselecteerd"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr "Kies een bestand uit de lijst."
+msgstr "Gelieve een bestand uit de lijst te selecteren."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr "Aanroepen van extern hulpmiddel mislukt."
+msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
-msgstr "Kan conflict niet oplossen"
+msgstr "Can conflict niet oplossen"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
 "using the command line."
 msgstr ""
-"Olive kan momenteel alleen conflicten in tekstbestanden oplossen. "
-"Inhoudelijke conflicten op de structuur van de mappen moeten met de "
-"opdrachtregel opgelost worden."
+"Enkel conflicten met textbestanden kunnen, op dit moment, met Olive opgelost "
+"worden. Inhoudelijke conflicten, op de structuur, dienen via de commandolijn "
+"opgelost te worden."
 
 #. View menu
 #: ../diff.py:445
 msgid "_View"
-msgstr "Beel_d"
+msgstr "_Beeld"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
-msgstr "_Lange regels afbreken"
+msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
-msgstr "Merge succesvol"
+msgstr "Succesvol samengevoegd"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
-msgstr "Alle wijzigingen succesvol verwerkt."
+msgstr "Alle wijzigingen succesvol toegepast."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Conflict gedetecteerd"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
-msgstr "Los de conflicten handmatig op alvorens te committen."
+msgstr ""
+"Gelieve de conflicten manueel op te lossen vooralleer uw wijzigingen vast te "
+"leggen,"
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
-msgstr "Map is geen branch"
+msgstr "Folder is geen aftakking."
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
-msgstr "Deze actie kan alleen op een branch uitgevoerd worden."
+msgstr "U kunt deze actie enkel op een aftakking uitvoeren."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
-msgstr "Map is geen checkout"
+msgstr "Folder werd niet uit versiecontrole opgehaald!"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
-msgstr "Lokaal committen kan alleen op checkouts."
+msgstr ""
+"Lokaal vastleggen is enkel mogelijk via een werkkopie verkregen door het "
+"ophalen uit versiecontrole."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
-msgstr "Niets te committen"
+msgstr "Geen wijzigingen vast te leggen."
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
-msgstr "Forceer een commit als u toch wilt committen."
+msgstr ""
+"Probeer prioritair vastleggen indien U uw wijzigingen toch wenst vast te "
+"leggen."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
-msgstr "Geen wijzigingen voor merge"
+msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
-msgstr "De merge-locatie is al geheel aanwezig in de werkkopie."
+msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
-msgstr "Conflicten in mappenstructuur"
+msgstr "Er werden conflicten in de versieboom gedetecteerd."
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
-msgstr "Deze conflicten moeten worden opgelost voordat gecommit kan worden."
+msgstr "De conflicten moeten opgelost worden voordat u kan comiten."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
-msgstr "Strikte commit is mislukt."
+msgstr "Strikt vastleggen faalde."
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
-"Er zijn onbekende bestanden in de werkkopie aanwezig, die eerst toegevoegd "
-"of verwijderd moeten worden."
+"Er bestaan ongekende bestanden in uw werkkopie!\n"
+"Gelieve deze toe te voegen of te verwijderen."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
-msgstr "Gekoppelde branch is niet meer up-to-date."
+msgstr "Gebonden aftakking is niet meer actueel."
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
-msgstr "Bestand niet onder versiebeheer"
+msgstr "Bestand niet onder versiecontrole"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Het geselecteerde bestand staat niet onder versiebeheer."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
-msgstr "Branches zijn uit elkaar gegroeid."
+msgstr "Aftakkingen werden afgeleid."
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
-"Een push kan niet uitgevoerd worden als de branches uit elkaar gegroeid "
-"zijn.\n"
-"Gebruik de optie ‘overwrite’ (overschrijven) als u de push toch wilt "
-"uitvoeren."
+"U kunt geen \"push\" uitvoeren op vertakkingen die afgeleid werden. Gebruik "
+"de optie overschrijven (overwrite) indien U de \"push\" toch wenst uit te "
+"voeren."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
-msgstr "Geen verschillen gevonden (diff)"
+msgstr "Geen verschil gevonden (diff)"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
-msgstr "Het geselecteerde bestand is niet gewijzigd."
+msgstr "Het geselecteerde bestand is ongewijzigd."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
-msgstr "Revisie bestaat niet"
+msgstr "Revisie onbestaande"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
-msgstr "De opgegeven revisie bestaat niet."
+msgstr "De opgegeven revisie bestaat niet ."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
-msgstr "Het doel bestaat al"
+msgstr "Het doel bestaat reeds"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
-msgstr "De doelmap bestaat al. Kies een andere bestemming."
+msgstr "Doel directory bestaad reeds. Kies een ander doel."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
-msgstr "De map is al een branch"
+msgstr "Folder is al een vertakking."
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
-"De huidige map ‘%s’ is al een branch. U kunt deze map gebruiken of een "
-"andere map initialiseren."
+"De huidige folder (%s) is reeds een vertakking. U kunt deze in gebruik nemen "
+"of een andere folder instellen."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
-msgstr "Branch zonder werkkopie"
+msgstr "Vertakking zonder werkkopie."
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
-msgstr "De huidige map ‘%s’ is een branch zonder werkkopie."
+msgstr "De huidige folder (%s) is een vertakking zonder werkkopie."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr "Onbekende bzr-fout"
+msgstr "Onbekende bzr fout"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Toegang geweigerd"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
-msgstr "toegang geweigerd."
+msgstr "toegang geweigerd"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Onbekende fout"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
-msgstr "_Initialiseren"
+msgstr "_Initializeren"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
-msgstr "Welke map wilt u initialiseren?"
+msgstr "Welke directory wilt u initializeren?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
-msgstr "Huidige map"
+msgstr "Huidige directory"
 
 #: ../initialize.py:51
 msgid "Create a new directory with the name:"
-msgstr "Een nieuwe map aanmaken met de volgende naam:"
+msgstr "Maak een nieuwe directory aan, genaamd:"
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr "Geen directory naam gespecificeerd"
 
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr "Geen mapnaam opgegeven"
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
-msgstr "Er dient een nieuwe mapnaam opgegeven te worden."
+msgstr "Een directory naam moet opgegeven worden."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
-msgstr "Naar loom-branch upgraden?"
+msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
-msgstr "De branch is geen loom-branch. Upgraden naar loom-formaat?"
+msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
-msgstr "Mergen van"
+msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
-msgstr "Map"
+msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
-msgstr "Aangepaste locatie"
+msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
-msgstr "_Mergen"
+msgstr "_Samenvoegen"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
-msgstr "Geen branch opgegeven"
+msgstr "Vertakking niet opgegeven"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr "Geef een merge-branch op."
+msgstr "Gelieve een vertakking op te geven om van samen te voegen."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
-msgstr "Fout in Bazaar-opdracht"
-
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
+msgstr "Fout in bazaar commando"
 
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Locatie:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
-msgstr "_Pushen"
+msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
-"Pushen is niet mogelijk als de branches uit elkaar gegroeid zijn. "
-"Overschrijven?"
+
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
 
 #: ../push.py:109
-msgid "Push successful"
-msgstr "Push succesvol"
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
-msgstr "%d revisie(s) gepusht."
+msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
-msgstr "Bovenliggende map bestaat niet"
+msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
 "doesn't exist. Create?"
 msgstr ""
-"De bovenliggende map ‘%s’\n"
-"bestaat niet. Wilt u deze aanmaken?"
+"De bovenliggende directory (%s) bestaat niet. Moet deze nu aangemaakt worden?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selecteren"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
-msgstr "Zoeken naar:"
+msgstr ""
 
 #: ../search.py:56
 msgid "Document"
-msgstr "Document"
+msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Toegevoegd"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Verwijderd"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Hernoemd"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Gewijzigd"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Onbekend"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Geen wijzigingen."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tags"
 
@@ -711,47 +673,433 @@
 
 #: ../tags.py:115
 msgid "Revision ID"
-msgstr "Revisie-ID"
+msgstr "Revisienr."
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
-"Tags worden niet door dit branch-formaat ondersteunt. Probeer te upgraden."
+"Labels worden niet ondersteund door dit aftakkingsformaat. Gelieve uw versie "
+"te actualizeren."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
-msgstr "Deze branch bevat geen revisies met een tag."
+msgstr "Er zijn geen gelabelde versies op de aftakking;"
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
-msgstr "Tag ver_wijderen"
+msgstr "Tag _verwijderen"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
-msgstr "<b><big>Tag verwijderen?</big></b>"
+msgstr "<b><big>Verwijder tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Weet u zeker dat u de tag <b>%s</b> wilt verwijderen?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
-msgstr "Tag _toevoegen"
+msgstr "T_ag toevoegen"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Tag-naam:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
-msgstr "Revisie-ID:"
+msgstr "Revisienr. :"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Geen tag-naam opgegeven"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
-msgstr "De gewenste tag-naam moet opgegeven worden."
+msgstr "U moet de gewenste labelnaam opgeven."
+
+#~ msgid "Time"
+#~ msgstr "Tijd"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Er zijn ontbrekende revisies."
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d ontbrekende revisie(s)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Er zijn geen ontbrekende revisies."
+
+#~ msgid "unchanged"
+#~ msgstr "ongewijzigd"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bladwijzers"
+
+#~ msgid "ignored"
+#~ msgstr "genegeerd"
+
+#~ msgid "unknown"
+#~ msgstr "onbekend"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflicten gedetecteerd"
+
+#~ msgid "No title given"
+#~ msgstr "Geen titel opgegeven"
+
+#~ msgid "Last modified"
+#~ msgstr "Laatst gewijzigd"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Bestandsnaam"
+
+#~ msgid "Size"
+#~ msgstr "Grootte"
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Selecteer een bestand uit de,\n"
+#~ "of kies een andere optie."
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Geef een titel op om verder te gaan"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Het geselecteerde bestand hernoemen"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Het geselecteerde bestand openen"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Het geselecteerde bestand toevoegen"
+
+#~ msgid "Add"
+#~ msgstr "Toevoegen"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Volledig verwijderen"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Het geselecteerde bestand/map volledig verwijderen"
+
+#~ msgid "Rename"
+#~ msgstr "Hernoemen"
+
+#~ msgid "Open"
+#~ msgstr "Openen"
+
+#~ msgid "Remove"
+#~ msgstr "Verwijderen"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Het geselecteerde bestand verwijderen"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Edit"
+#~ msgstr "Bewerken"
+
+#~ msgid "Open Folder"
+#~ msgstr "Map openen"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Te committen bestanden"
+
+#~ msgid "Commit message:"
+#~ msgstr "Commit bericht:"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Een moment geduld alstublieft, de wijzigingen worden geladen..."
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Het geselecteerde bestand annoteren"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Directory verwijderen, inclusief alle kind-directory's?"
+
+#~ msgid "No directory name given"
+#~ msgstr "Geen directory-naam opgegeven."
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Geef een andere naam op, om verder te gaan."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Geef een nieuwe voor het bestand op."
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Alle bestanden met de status 'toegevoegd'"
+
+#~ msgid "Selected only"
+#~ msgstr "Geselecteerde"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Welke bestanden wilt u verwijderen?"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Verversen"
+
+#~ msgid "_Rename..."
+#~ msgstr "He_rnoemen..."
+
+#~ msgid "_Move..."
+#~ msgstr "Verplaatsen..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "_Verborgen bestanden weergeven"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Directory aanmaken..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Bestanden verwijderen..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "Bestanden toevoegen..."
+
+#~ msgid "_File"
+#~ msgstr "_Bestand"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Initializeren..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Maak alle wijzigingen ongedaan"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Committen..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Conflicten..."
+
+#~ msgid "_Differences..."
+#~ msgstr "Verschillen..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistieken"
+
+#~ msgid "_Help"
+#~ msgstr "_Help"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informatie..."
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Welke bestanden wilt u toevoegen?"
+
+#~ msgid "_Add"
+#~ msgstr "_Toevoegen"
+
+#~ msgid "(none)"
+#~ msgstr "(geen)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Hernoemen"
+
+#~ msgid "Rename to"
+#~ msgstr "Hernoemen naar"
+
+#~ msgid "_Move"
+#~ msgstr "_Verplaatsen"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selecteer een directory"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Locatie:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formaat:</b>"
+
+#~ msgid "Renamed files: "
+#~ msgstr "Hernoemde bestanden: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Onbekende bestanden: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Genegeerde bestanden: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Gewijzigde bestanden: "
+
+#~ msgid "Added files: "
+#~ msgstr "Toegevoegde bestanden: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Verwijderde bestanden: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Ongewijzigde bestanden: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Aantal revisies in branch: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Branch geschiedenis:</b>"
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Leeftijd van de branch, in dagen: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Aantal committers: "
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Er werden geen wijzigingen gevonden in de werkkopie."
+
+#~ msgid "Pending merges"
+#~ msgstr "Geplande samenvoegingen"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Gelieve de werkkopie te inspecteren vooralleer verder te gaan."
+
+#~ msgid "Revert"
+#~ msgstr "Ongedaan maken"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade bestand kon niet gevonden worden."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Bestand met UI bescrhijving kon niet gevonden worden."
+
+#~ msgid "Revert the changes"
+#~ msgstr "Wijzigingen ongedaan maken"
+
+#~ msgid "Annotate"
+#~ msgstr "Annoteer"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Wijzigingen vastleggen"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Toon het verschil op dit bestand."
+
+#~ msgid "Revert successful"
+#~ msgstr "Wijzigingen succesvol ongedaan gemaakt."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Deze revisie van het geselecteerde bestand terugzetten"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Deze revisie terugzetten"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Alle bestanden werden teruggezet met hun laaste revisie."
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "ouder locatie is niet bekend"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Markeer de huideige locatie"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Open de map met markeringen in Nautilus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Toon de verschillen van alle bestanden"
+
+#~ msgid "All..."
+#~ msgstr "Alle..."
+
+#~ msgid "View contents"
+#~ msgstr "Bekijk inhoud"
+
+#~ msgid "Show differences"
+#~ msgstr "Toon verschillen"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Toon de verschillen van de gesecteerde bestanden."
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Bewerk de geselecteerde markering"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Verwijder de geselecteerde markering"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Markering succesvol toegevoegd"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Locatie is reeds gemarkeerd"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Geef de gewenste naam op voor de nieuwe map."
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Toon de verschillen tussen twee revisies van het bestand"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Niet de zelfde aftakking"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Selecteer een bestand uit de lijst, om verder te gaan."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Map bestaat al"
+
+#~ msgid "Filename not given"
+#~ msgstr "Geen bestandsnaam opgegeven"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Geen toegevoegde bestanden gevonden in de werkboom"
+
+#~ msgid "_Remove"
+#~ msgstr "_Verwijderen"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "_Geschiedenis Modus"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Samenvoegen..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Ontbrekende _revisies"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_Markeringen..."
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Ontbrekende revisies:</b>"
+
+#~ msgid "Merge from:"
+#~ msgstr "Samenvoegen vanuit:"
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Samenvoegen - Olive"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>In de werkboom:</b>"
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tijd van de eerste revisie: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Grootte van de repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisies in repository: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Lieven van der Heide https://launchpad.net/~lievenvanderheide\n"
+#~ "  Rachid https://launchpad.net/~rachidbm\n"
+#~ "  Roel Huybrechts https://launchpad.net/~rulus\n"
+#~ "  Wim Rosseel https://launchpad.net/~wim-rosseel"

=== modified file 'po/pl.po'
--- po/pl.po	2011-12-02 05:55:20 +0000
+++ po/pl.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
-"Last-Translator: Jelmer Vernooij <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-17 21:00+0000\n"
+"Last-Translator: Jaroslaw Zabiello <Unknown>\n"
 "Language-Team: Polish <pl@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Cel:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "n/d"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operacja przerwana"
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,50 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Jaroslaw Zabiello https://launchpad.net/~hipertracker\n"
+#~ "  Łukasz Jernaś https://launchpad.net/~deejay1"

=== removed file 'po/pt.po'
--- po/pt.po	2011-12-02 05:55:20 +0000
+++ po/pt.po	1970-01-01 00:00:00 +0000
@@ -1,737 +0,0 @@
-# Portuguese translation for bzr-gtk
-# Copyright (c) 2011 Rosetta Contributors and Canonical Ltd 2011
-# This file is distributed under the same license as the bzr-gtk package.
-# FIRST AUTHOR <EMAIL@ADDRESS>, 2011.
-#
-msgid ""
-msgstr ""
-"Project-Id-Version: bzr-gtk\n"
-"Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Launchpad Translations Administrators <Unknown>\n"
-"Language-Team: Portuguese <pt@li.org>\n"
-"MIME-Version: 1.0\n"
-"Content-Type: text/plain; charset=UTF-8\n"
-"Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
-
-#: ../bazaar-properties.desktop.in.h:1
-msgid "Bazaar Preferences"
-msgstr ""
-
-#: ../bazaar-properties.desktop.in.h:2
-msgid "Configure Bazaar settings"
-msgstr ""
-
-#: ../bzr-handle-patch.desktop.in.h:1
-msgid "Apply Bazaar Bundle"
-msgstr ""
-
-#: ../bzr-handle-patch.desktop.in.h:2
-msgid "Bazaar"
-msgstr ""
-
-#: ../bzr-notify.desktop.in.h:1
-msgid "Bazaar Notification"
-msgstr ""
-
-#: ../bzr-notify.desktop.in.h:2
-msgid "Notification Area Icon for Bazaar"
-msgstr ""
-
-#. Create the widgets
-#: ../branch.py:46
-msgid "_Branch"
-msgstr ""
-
-#: ../branch.py:49 ../checkout.py:49
-msgid "Branch location:"
-msgstr ""
-
-#: ../branch.py:51 ../checkout.py:50
-msgid "Destination:"
-msgstr ""
-
-#: ../branch.py:52
-msgid "Branck nick:"
-msgstr ""
-
-#: ../branch.py:53 ../checkout.py:52
-msgid "Revision:"
-msgstr ""
-
-#: ../branch.py:54 ../checkout.py:47
-msgid "Please select a folder"
-msgstr ""
-
-#: ../branch.py:134 ../checkout.py:153
-msgid "Missing branch location"
-msgstr ""
-
-#: ../branch.py:135 ../checkout.py:154
-msgid "You must specify a branch location."
-msgstr ""
-
-#: ../branch.py:174
-msgid "Branching successful"
-msgstr ""
-
-#: ../branch.py:175
-#, python-format
-msgid "%d revision(s) branched."
-msgstr ""
-
-#: ../branch.py:183 ../checkout.py:185
-msgid "N/A"
-msgstr ""
-
-#. Create the widgets
-#: ../checkout.py:44
-msgid "Check_out"
-msgstr ""
-
-#: ../checkout.py:51
-msgid "Branch nick:"
-msgstr ""
-
-#: ../checkout.py:56
-msgid "_Lightweight checkout"
-msgstr ""
-
-#: ../commands.py:305
-msgid "Directory does not have a working tree"
-msgstr ""
-
-#: ../commands.py:306
-msgid "Operation aborted."
-msgstr ""
-
-#: ../commands.py:410
-msgid "There are local changes in the branch"
-msgstr ""
-
-#: ../commands.py:411
-msgid "Please commit or revert the changes before merging."
-msgstr ""
-
-#: ../commit.py:178
-msgid "added"
-msgstr ""
-
-#: ../commit.py:179
-msgid "removed"
-msgstr ""
-
-#: ../commit.py:180
-msgid "renamed"
-msgstr ""
-
-#: ../commit.py:181
-msgid "renamed and modified"
-msgstr ""
-
-#: ../commit.py:182
-msgid "modified"
-msgstr ""
-
-#: ../commit.py:183
-msgid "kind changed"
-msgstr ""
-
-#: ../commit.py:276
-msgid "<b>Commit Message</b>"
-msgstr ""
-
-#: ../commit.py:329
-msgid "_Only commit locally"
-msgstr ""
-
-#: ../commit.py:361
-msgid "Comm_it"
-msgstr ""
-
-#: ../commit.py:388
-msgid "Files"
-msgstr ""
-
-#: ../commit.py:393
-msgid "Commit all changes"
-msgstr ""
-
-#: ../commit.py:399
-msgid "Only commit selected changes"
-msgstr ""
-
-#: ../commit.py:405
-msgid "Commit all changes*"
-msgstr ""
-
-#: ../commit.py:437
-msgid "Commit*"
-msgstr ""
-
-#: ../commit.py:439
-msgid "Commit"
-msgstr ""
-
-#: ../commit.py:443 ../conflicts.py:107
-msgid "Path"
-msgstr ""
-
-#: ../commit.py:445 ../conflicts.py:109
-msgid "Type"
-msgstr ""
-
-#: ../commit.py:478
-msgid "<i>* Cannot select specific files when merging</i>"
-msgstr ""
-
-#: ../commit.py:482
-msgid "Pending Revisions"
-msgstr ""
-
-#: ../commit.py:503
-msgid "Date"
-msgstr ""
-
-#: ../commit.py:505
-msgid "Committer"
-msgstr ""
-
-#: ../commit.py:507 ../search.py:60
-msgid "Summary"
-msgstr ""
-
-#. TODO: jam 2007-10-30 The diff label is currently disabled. If we
-#. decide that we really don't ever want to display it, we should
-#. actually remove it, and other references to it, along with the
-#. tests that it is set properly.
-#: ../commit.py:517
-msgid "Diff for whole tree"
-msgstr ""
-
-#. Whole tree
-#: ../commit.py:542 ../commit.py:626
-msgid "File commit message"
-msgstr ""
-
-#: ../commit.py:549
-msgid "Global Commit Message"
-msgstr ""
-
-#: ../commit.py:551
-msgid "<b>Global Commit Message</b>"
-msgstr ""
-
-#: ../commit.py:578
-msgid "Diff for "
-msgstr ""
-
-#: ../commit.py:632
-msgid "Commit message for "
-msgstr ""
-
-#: ../commit.py:687
-msgid "Commit cancelled"
-msgstr ""
-
-#: ../commit.py:688
-msgid "Do you want to save your commit messages ?"
-msgstr ""
-
-#: ../commit.py:706
-msgid "Commit with an empty message?"
-msgstr ""
-
-#: ../commit.py:707
-msgid "You can describe your commit intent in the message."
-msgstr ""
-
-#: ../commit.py:727
-msgid "Commit with unknowns?"
-msgstr ""
-
-#: ../commit.py:728
-msgid "Unknown files exist in the working tree. Commit anyway?"
-msgstr ""
-
-#: ../commit.py:748
-msgid "Commit with no changes?"
-msgstr ""
-
-#: ../commit.py:749
-msgid ""
-"There are no changes in the working tree. Do you want to commit anyway?"
-msgstr ""
-
-#: ../conflicts.py:45
-msgid "External utility:"
-msgstr ""
-
-#: ../conflicts.py:97
-msgid "Conflicts"
-msgstr ""
-
-#: ../conflicts.py:100
-msgid "No conflicts in working tree."
-msgstr ""
-
-#: ../conflicts.py:114
-msgid "path conflict"
-msgstr ""
-
-#: ../conflicts.py:116
-msgid "contents conflict"
-msgstr ""
-
-#: ../conflicts.py:118
-msgid "text conflict"
-msgstr ""
-
-#: ../conflicts.py:120
-msgid "duplicate id"
-msgstr ""
-
-#: ../conflicts.py:122
-msgid "duplicate"
-msgstr ""
-
-#: ../conflicts.py:124
-msgid "parent loop"
-msgstr ""
-
-#: ../conflicts.py:126
-msgid "unversioned parent"
-msgstr ""
-
-#: ../conflicts.py:128
-msgid "missing parent"
-msgstr ""
-
-#: ../conflicts.py:130
-msgid "deleting parent"
-msgstr ""
-
-#: ../conflicts.py:132
-msgid "unknown type of conflict"
-msgstr ""
-
-#: ../conflicts.py:161
-msgid "No file was selected"
-msgstr ""
-
-#: ../conflicts.py:162
-msgid "Please select a file from the list."
-msgstr ""
-
-#: ../conflicts.py:172
-msgid "Call to external utility failed"
-msgstr ""
-
-#: ../conflicts.py:174
-msgid "Cannot resolve conflict"
-msgstr ""
-
-#: ../conflicts.py:175
-msgid ""
-"Only conflicts on the text of files can be resolved with Olive at the "
-"moment. Content conflicts, on the structure of the tree, need to be resolved "
-"using the command line."
-msgstr ""
-
-#. View menu
-#: ../diff.py:445
-msgid "_View"
-msgstr ""
-
-#: ../diff.py:448
-msgid "Wrap _Long Lines"
-msgstr ""
-
-#. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
-msgid "Merge successful"
-msgstr ""
-
-#: ../diff.py:494 ../merge.py:145
-msgid "All changes applied successfully."
-msgstr ""
-
-#. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
-msgid "Conflicts encountered"
-msgstr ""
-
-#: ../diff.py:498 ../merge.py:149
-msgid "Please resolve the conflicts manually before committing."
-msgstr ""
-
-#: ../errors.py:31
-msgid "Directory is not a branch"
-msgstr ""
-
-#: ../errors.py:32
-msgid "You can perform this action only in a branch."
-msgstr ""
-
-#: ../errors.py:34
-msgid "Directory is not a checkout"
-msgstr ""
-
-#: ../errors.py:35
-msgid "You can perform local commit only on checkouts."
-msgstr ""
-
-#: ../errors.py:37
-msgid "No changes to commit"
-msgstr ""
-
-#: ../errors.py:38
-msgid "Try force commit if you want to commit anyway."
-msgstr ""
-
-#: ../errors.py:40
-msgid "No changes to merge"
-msgstr ""
-
-#: ../errors.py:41
-msgid "Merge location is already fully merged in working tree."
-msgstr ""
-
-#: ../errors.py:43
-msgid "Conflicts in tree"
-msgstr ""
-
-#: ../errors.py:44
-msgid "You need to resolve the conflicts before committing."
-msgstr ""
-
-#: ../errors.py:46
-msgid "Strict commit failed"
-msgstr ""
-
-#: ../errors.py:47
-msgid ""
-"There are unknown files in the working tree.\n"
-"Please add or delete them."
-msgstr ""
-
-#: ../errors.py:49
-msgid "Bound branch is out of date"
-msgstr ""
-
-#. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
-#, python-format
-msgid "%s"
-msgstr ""
-
-#: ../errors.py:53
-msgid "File not versioned"
-msgstr ""
-
-#: ../errors.py:54
-msgid "The selected file is not versioned."
-msgstr ""
-
-#: ../errors.py:56 ../push.py:100
-msgid "Branches have been diverged"
-msgstr ""
-
-#: ../errors.py:57
-msgid ""
-"You cannot push if branches have diverged. Use the\n"
-"overwrite option if you want to push anyway."
-msgstr ""
-
-#: ../errors.py:59
-msgid "No diff output"
-msgstr ""
-
-#: ../errors.py:60
-msgid "The selected file hasn't changed."
-msgstr ""
-
-#: ../errors.py:62
-msgid "No such revision"
-msgstr ""
-
-#: ../errors.py:63
-msgid "The revision you specified doesn't exist."
-msgstr ""
-
-#: ../errors.py:65
-msgid "Target already exists"
-msgstr ""
-
-#: ../errors.py:66
-msgid "Target directory already exists. Please select another target."
-msgstr ""
-
-#: ../errors.py:68
-msgid "Directory is already a branch"
-msgstr ""
-
-#: ../errors.py:69
-#, python-format
-msgid ""
-"The current directory (%s) is already a branch.\n"
-"You can start using it, or initialize another directory."
-msgstr ""
-
-#: ../errors.py:71
-msgid "Branch without a working tree"
-msgstr ""
-
-#: ../errors.py:72
-#, python-format
-msgid ""
-"The current directory (%s)\n"
-"is a branch without a working tree."
-msgstr ""
-
-#: ../errors.py:74
-msgid "Unknown bzr error"
-msgstr ""
-
-#: ../errors.py:76
-msgid "Permission denied"
-msgstr ""
-
-#: ../errors.py:76
-msgid "permission denied."
-msgstr ""
-
-#: ../errors.py:78
-msgid "Unknown error"
-msgstr ""
-
-#. Create the widgets
-#: ../initialize.py:46
-msgid "_Initialize"
-msgstr ""
-
-#: ../initialize.py:47
-msgid "Which directory do you want to initialize?"
-msgstr ""
-
-#: ../initialize.py:49
-msgid "Current directory"
-msgstr ""
-
-#: ../initialize.py:51
-msgid "Create a new directory with the name:"
-msgstr ""
-
-#: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
-msgid "You should specify a new directory name."
-msgstr ""
-
-#: ../loom.py:49
-msgid "Upgrade to Loom branch?"
-msgstr ""
-
-#: ../loom.py:50
-msgid "Branch is not a loom branch. Upgrade to Loom format?"
-msgstr ""
-
-#: ../merge.py:52
-msgid "Merge from"
-msgstr ""
-
-#: ../merge.py:54
-msgid "Folder"
-msgstr ""
-
-#: ../merge.py:54
-msgid "Custom Location"
-msgstr ""
-
-#: ../merge.py:57
-msgid "_Merge"
-msgstr ""
-
-#: ../merge.py:130
-msgid "Branch not given"
-msgstr ""
-
-#: ../merge.py:131
-msgid "Please specify a branch to merge from."
-msgstr ""
-
-#: ../merge.py:139
-msgid "Bazaar command error"
-msgstr ""
-
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
-#. Create the widgets
-#: ../push.py:50
-msgid "Location:"
-msgstr ""
-
-#: ../push.py:52
-msgid "_Push"
-msgstr ""
-
-#: ../push.py:101
-msgid ""
-"You cannot push if branches have diverged.\n"
-"Overwrite?"
-msgstr ""
-
-#: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
-#, python-format
-msgid "%d revision(s) pushed."
-msgstr ""
-
-#: ../push.py:141
-msgid "Non existing parent directory"
-msgstr ""
-
-#: ../push.py:142
-#, python-format
-msgid ""
-"The parent directory (%s)\n"
-"doesn't exist. Create?"
-msgstr ""
-
-#. Create the widgets
-#: ../revbrowser.py:35
-msgid "_Select"
-msgstr ""
-
-#: ../search.py:41
-msgid "Search for:"
-msgstr ""
-
-#: ../search.py:56
-msgid "Document"
-msgstr ""
-
-#: ../status.py:87
-msgid "Added"
-msgstr ""
-
-#: ../status.py:93
-msgid "Removed"
-msgstr ""
-
-#: ../status.py:99
-msgid "Renamed"
-msgstr ""
-
-#: ../status.py:106
-msgid "Modified"
-msgstr ""
-
-#: ../status.py:114
-msgid "Unknown"
-msgstr ""
-
-#: ../status.py:119
-msgid "No changes."
-msgstr ""
-
-#. Set properties
-#: ../tags.py:60
-msgid "Tags"
-msgstr ""
-
-#: ../tags.py:110
-msgid "Tag Name"
-msgstr ""
-
-#: ../tags.py:115
-msgid "Revision ID"
-msgstr ""
-
-#: ../tags.py:148
-msgid "Tags are not supported by this branch format. Please upgrade."
-msgstr ""
-
-#: ../tags.py:154
-msgid "No tagged revisions in the branch."
-msgstr ""
-
-#: ../tags.py:222
-msgid "_Remove tag"
-msgstr ""
-
-#: ../tags.py:232
-msgid "<b><big>Remove tag?</big></b>"
-msgstr ""
-
-#: ../tags.py:234
-#, python-format
-msgid "Are you sure you want to remove the tag: <b>%s</b>?"
-msgstr ""
-
-#. Create the widgets
-#: ../tags.py:278
-msgid "_Add tag"
-msgstr ""
-
-#: ../tags.py:280
-msgid "Tag Name:"
-msgstr ""
-
-#: ../tags.py:281
-msgid "Revision ID:"
-msgstr ""
-
-#: ../tags.py:312
-msgid "No tag name specified"
-msgstr ""
-
-#: ../tags.py:313
-msgid "You have to specify the tag's desired name."
-msgstr ""

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2011-12-02 05:55:20 +0000
+++ po/pt_BR.po	2011-03-10 04:41:02 +0000
@@ -7,15 +7,16 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:59+0000\n"
-"Last-Translator: Fitoschido <fitoschido@gmail.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2011-03-08 23:22+0000\n"
+"Last-Translator: Paulo Guilherme Pilotti Duarte "
+"<guilhermepilotti@gmail.com>\n"
 "Language-Team: Brazilian Portuguese <pt_BR@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-10 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -27,7 +28,7 @@
 
 #: ../bzr-handle-patch.desktop.in.h:1
 msgid "Apply Bazaar Bundle"
-msgstr "Aplica o pacote Bazaar"
+msgstr ""
 
 #: ../bzr-handle-patch.desktop.in.h:2
 msgid "Bazaar"
@@ -42,165 +43,165 @@
 msgstr "Ícone de Área de notificação para o Bazaar"
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Ramo(branch)"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Localização do ramo(branch):"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destino:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Apelido da ramo:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revisão:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Por favor selecione uma pasta"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Falta o local do ramo."
+msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Você deve especificar um local para o ramo."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Ramificação (branching) bem sucedida"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revisão(ões) ramificada(s)."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "Não disponível"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Verificaçã_o Geral"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
-msgstr "Nome do ramo:"
+msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Verificação _Leve"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "O diretório não tem uma árvore de trabalho"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "A operação foi interrompida."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Existem modificações locais no ramo"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Favor consolidar ou reverter as modificações antes de combinar"
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "Adicionado"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "removido"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "renomeado"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "renomeado e modificado"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificado"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
-msgstr "tipo modificado"
+msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
-msgstr "<b>Mensagem de Envio</b>"
+msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "S_omente consolide localmente"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Consol_idar"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr "Arquivos"
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
-msgstr "Enviar todas as mudanças"
+msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
-msgstr "Enviar apenas as mudanças selecionadas"
+msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
-msgstr "Enviar todas as mudanças*"
+msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
-msgstr "Enviar*"
+msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Enviar"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Caminho"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tipo"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
-msgstr "Revisões pendentes"
+msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Consolidador"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Sumário"
 
@@ -208,137 +209,136 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
-msgstr "Mensagem de Envio"
+msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr "<b>Mensagem de Envio</b>"
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
-msgstr "Mensagem de envio para "
+msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr "Envio cancelado"
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
-msgstr "Você deseja salvas as suas mensagens de envio ?"
+msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Consolidar com uma mensagem vazia?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 "Você pode descrever a sua intenção para a consolidação nesta mensagem."
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Consolidar com itens desconhecidos?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Há arquivos desconhecidos na árvore de trabalho. Deseja consolidar assim "
 "mesmo?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Consolidar sem modificaçãoes?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
-"Não existe mudanças na árvore de trabalho. Você deseja enviar mesmo assim?"
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilitário externo:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflitos"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Sem conflitos na árvore de trabalho."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "Conflito no caminho"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflito de conteúdos"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflito de texto"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "ID duplicada"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicar"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "tipo de conflito desconhecido"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Nenhum arquivo foi selecionado"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Por favor selecione um arquivo da lista."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Falha na chamada a utilitário externo"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Não é possível resolver o conflito"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -353,74 +353,74 @@
 msgid "_View"
 msgstr "_Visualizar"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
-msgstr "Quebra de _Linhas Longas"
+msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Fusão bem sucedida"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Todas as mudanças foram aplicadas com sucesso."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Encontrado conflitos"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Por favor resolva os conflitos manualmente antes de consolidar."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "O diretório não é um ramo."
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "Esta operação só pode ser executada em um ramo."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
-msgstr "O diretório não é um checagem de ítens."
+msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Você só pode executar consolidações locais em checkouts."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Sem mudanças para consolidar"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 "Tente impor a consolidação se você quiser consolidar de qualquer maneira."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr "Nenhuma mudança para mesclar"
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Há conflitos na árvore"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "É necessário resolver os conflitos antes de consolidar."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Falha na consolidação estrita"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -428,29 +428,29 @@
 "Existem arquivos desconhecidos na árvore de trabalho.\n"
 "Por favor adicione ou delete eles."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Ramo vinculado está desatualizado"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Arquivo sem versão definida"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "O arquivo selecionado não tem versão definida."
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Ramos foram divergidos"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -458,35 +458,35 @@
 "Você não consegue enviar se os ramos tiverem divergido. Use\n"
 "a opção sobrescrever se você quiser enviar mesmo assim."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Sem saída do diff"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "O arquivo selecionado não foi mudado."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "Revisão inexistente"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "A revisão especificada não existe."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "O destino já existe"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr "O diretório de destino já existe. Por favor selecione outro destino."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Esse diretório já é um ramo(branch)"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -495,11 +495,11 @@
 "O diretório atual (%s) já é um ramo (branch).\n"
 "Você pode começar a usá-lo ou inicializar outro diretório."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Este ramo (branch) não tem uma árvore de trabalho"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -508,32 +508,32 @@
 "O diretório atual (%s)\n"
 "é um ramo (branch) dem uma árvore de trabalho."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Erro desconhecido do bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Permissão negada"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "Permissão negada."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Erro desconhecido"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Inicializar"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Qual diretório você quer inicializar?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Diretório atual"
 
@@ -541,100 +541,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Criar um novo diretório com o nome:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "O nome do diretório não foi especificado."
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Você deve especificar um novo nome para o diretório"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr "Mesclar de"
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr "Pasta"
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
-msgstr "Localização personalizada"
+msgstr "Localização Personalizada"
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
-msgstr "_Mesclar"
+msgstr "_fusão"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Ramo não fornecido"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Por favor especifique um ramo do qual mesclar."
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Erro de comando Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Localização:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Enviar"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -642,20 +602,20 @@
 "Você não pode enviar se os ramos tiverem divergido.\n"
 "Sobrescrever?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Sucesso no envio"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d revisões enviadas."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Diretório pai inexistente"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -665,11 +625,11 @@
 "não exixte. Deseja criá-lo?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selecionar"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr "Buscar por:"
 
@@ -677,32 +637,32 @@
 msgid "Document"
 msgstr "Documento"
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Adicionado"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Removido"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Renomeado"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificado"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Desconhecido"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "sem mudanças"
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Etiquetas"
 
@@ -714,46 +674,558 @@
 msgid "Revision ID"
 msgstr "identificação da revisão"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 "Etiquetas não são suportadas por esse formato de ramo(branch). Atualize, por "
 "favor."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Não há revisões etiquetadas no ramo (branch)."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Remover tag"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Remover tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Você tem certeza de que quer remover a tag: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Adicionar tag"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nome da tag:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID de revisão:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Nome de tag não especificado"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Você tem de especificar o nome desejado da tag."
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Arquivo(s) a consolidar"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Não há mudanças na árvore de trabalho."
+
+#~ msgid "Time"
+#~ msgstr "Tempo"
+
+#~ msgid "Revno"
+#~ msgstr "nº da revisão"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Por favor aguarde, as revisões estão sendo carregadas..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Conflitos detectados"
+
+#~ msgid "unchanged"
+#~ msgstr "Sem alterações"
+
+#~ msgid "ignored"
+#~ msgstr "Ignorado"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Por favor de uma olhada na árvore de trabalho antes de continuar."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Adicionar o arquivo selecionado"
+
+#~ msgid "Add"
+#~ msgstr "Adicionar"
+
+#~ msgid "Last modified"
+#~ msgstr "Última modificação"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Arquivo Glade não pôde ser encontrado."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Descrição do arquivo UI não pôde ser encontrado."
+
+#~ msgid "Title:"
+#~ msgstr "Titulo:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Por favor especifique um título para continuar."
+
+#~ msgid "No title given"
+#~ msgstr "Título não foi dado"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Por favor selecione o arquivo da lista,\n"
+#~ "ou escolha a outra opção."
+
+#~ msgid "Remove"
+#~ msgstr "Remover"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Anotar o arquivo selecionado"
+
+#~ msgid "Annotate"
+#~ msgstr "Anotar"
+
+#~ msgid "Open Folder"
+#~ msgstr "Abrir Pasta"
+
+#~ msgid "Edit"
+#~ msgstr "Editar"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Deletar diretório com todos os diretórios abaixo?"
+
+#~ msgid "View contents"
+#~ msgstr "Visualizar conteúdo"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Mostrar as diferenças entre dois arquivos de revisão"
+
+#~ msgid "Show differences"
+#~ msgstr "Mostrar diferenças"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Todos arquivos com status \"adicionado\""
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Por favor selecione um arquivo da lista para proceder."
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Arquivos não adicionados foram encontrados na árvore de trabalho."
+
+#~ msgid "No matching files"
+#~ msgstr "Arquivos não se combinam"
+
+#~ msgid "_Remove"
+#~ msgstr "_Remover"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Por favor especifique outro nome para continuar."
+
+#~ msgid "Selected only"
+#~ msgstr "Somente selecionado"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Qual(is) arquivo(s) você deseja remover?"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Atualizar"
+
+#~ msgid "_Get..."
+#~ msgstr "_Pegar"
+
+#~ msgid "_Move..."
+#~ msgstr "_Mover..."
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Inicializar"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Anotar..."
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferenças"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Estatísticas"
+
+#~ msgid "_Help"
+#~ msgstr "_Ajuda"
+
+#~ msgid "_Information..."
+#~ msgstr "_Informação..."
+
+#~ msgid "(none)"
+#~ msgstr "(nenhum)"
+
+#~ msgid "Move to"
+#~ msgstr "Mover para"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Oliva - Informação"
+
+#~ msgid "_Rename"
+#~ msgstr "_Renomear"
+
+#~ msgid "Rename to"
+#~ msgstr "Renomear para"
+
+#~ msgid "_Move"
+#~ msgstr "_Mover"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selecionar um diretório"
+
+#~ msgid "Control format: "
+#~ msgstr "Formato do controle: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Formato da árvore de trabalho: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Formato:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "Formato do repositório: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Arquivos renomeados: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Arquivos Desconhecidos: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Arquivos ignorados: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Arquivos não modificados: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Arquivos modificados: "
+
+#~ msgid "Added files: "
+#~ msgstr "Arquivos adicionados "
+
+#~ msgid "Removed files: "
+#~ msgstr "Arquivos removidos: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>Na árvore de trabalho:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Tempo da última revisão: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tempo da primeira revisão: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Fusão - Oliva"
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revisões faltando</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "Tamanho do repositório: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisões no repositório: "
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Verificação geral do repositório: "
+
+#~ msgid "_Make directory"
+#~ msgstr "_Fazer diretório"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Oliva - Mover"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Localização:</b>"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repositório compartilhado: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Verificação geral leve do root: "
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Oliva - Fazer diretório"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flitos..."
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Oliva - Remover arquivo(s)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Qual(is) arquivo(s) você quer adicionar?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Oliva - Adicionar arquivo(s)"
+
+#~ msgid "_Add"
+#~ msgstr "_Adicionar"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Existem revisões faltando"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revisão(ões) faltando."
+
+#~ msgid "Pending merges"
+#~ msgstr "Combinações pendentes"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mensagem da consolidação:"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Não existe local padrão de envio definido.\n"
+#~ "Definir %r como padrão agora?"
+
+#~ msgid "Set default push location"
+#~ msgstr "Defina o local padrão de envio"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Ramo local está atualizado"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Localização original desconhecida"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Não é possível determinar revisões que faltam se a localização original é "
+#~ "desconhecida."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Não existem revisões faltando."
+
+#~ msgid "Pull successful"
+#~ msgstr "Recebimento bem sucedido"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revisão(ões) recebida(s)."
+
+#~ msgid "Bookmark"
+#~ msgstr "Favoritos"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Favoritos"
+
+#~ msgid "Revert successful"
+#~ msgstr "Reversão bem sucedida"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Todos os arquivos foram revertidos para a última revisão."
+
+#~ msgid "Filename"
+#~ msgstr "Nome do arquivo"
+
+#~ msgid "unknown"
+#~ msgstr "desconhecido"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Size"
+#~ msgstr "Tamanho"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Renomear o arquivo selecionado"
+
+#~ msgid "Revert"
+#~ msgstr "Reverter"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Remover e apagar"
+
+#~ msgid "Rename"
+#~ msgstr "Renomear"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Remover o arquivo ou diretório selecionado e apagar do disco"
+
+#~ msgid "Open"
+#~ msgstr "Abrir"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Reverter as modificações"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Abrir o arquivo seleccionado"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Remover o arquivo selecionado"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Consolidar as modificações"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Abrir a pasta de favoritos no Nautilus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Mostrar as diferenças de todos os arquivos"
+
+#~ msgid "Selected..."
+#~ msgstr "Selecionado..."
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Mostrar as diferenças dos arquivos selecionados"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Adicionar a atual localização aos favoritos"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editar o marcador selecionado"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Remove o marcador selecionado"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Mostrar diff do arquivo"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Reverter para esta revisão"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "O atual diretório está nos favoritos. Você pode chegar\n"
+#~ "a ele selecionando-o no painel à esquerda."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Adicionado aos favoritos com sucesso"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "O atual diretório já está nos favoritos.\n"
+#~ "Veja o painel à esquerda para referência."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "A localização já está nos favoritos"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Favor especificar o nome desejado para o novo diretório."
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Reverter o arquivo selecionado para a selecionada revisão"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Visualizar os conteúdos do arquivo no visualizador interno"
+
+#~ msgid "Directory already exists"
+#~ msgstr "O diretório já existe"
+
+#~ msgid "No directory name given"
+#~ msgstr "Não foi dado nenhum nome ao diretório."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Renomear..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Favor especificar um novo nome para o arquivo."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nome do arquivo não definido"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Não é do mesmo ramo"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Criar _diretório..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Remover arquivo(s)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Adicionar arquivo(s)..."
+
+#~ msgid "_File"
+#~ msgstr "Arquivo"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "O destino não é do mesmo ramo."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Combinar..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Reverter todas as mudanças"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Consolidar..."
+
+#~ msgid "Parent branch: "
+#~ msgstr "Ramo pai: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Sub-diretórios versionados: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Ramos relacionados:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Estado de trava:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Estado de trava do repositório: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Estado de trava do ramo: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Estado de trava da árvore de trabalho: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisões no ramo: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Quantidade de consolidadores: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Histórico do ramo:</b>"
+
+#~ msgid "Repository branch: "
+#~ msgstr "Ramo do repositório: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Formato do ramo: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Combinação vinda de:"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Verificação geral do ramo: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Alexandre Sapata Carbonell https://launchpad.net/~alexandre-sapata-"
+#~ "carbonell\n"
+#~ "  Flávio Pontes https://launchpad.net/~flaviocpontes\n"
+#~ "  Leandro Pereira de Lima e Silva https://launchpad.net/~leandro-limaesilva\n"
+#~ "  Nelson do Vale https://launchpad.net/~nelsondovale\n"
+#~ "  Paulo Guilherme Pilotti Duarte https://launchpad.net/~guilhermepilotti\n"
+#~ "  Ricardo Ichizo https://launchpad.net/~n1ghtcr4wler"

=== modified file 'po/ro.po'
--- po/ro.po	2011-12-02 05:55:20 +0000
+++ po/ro.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:12+0000\n"
 "Last-Translator: Adi Roiban <adi@roiban.ro>\n"
 "Language-Team: Romanian <ro@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Branch"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Locaţie branch:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Destinaţie:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Nume branch:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Revizie:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Vă rog să selectaţi un folder"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Lipseşte locaţia branch-ului"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Trebuie să specificaţi o locaţie pentru branch."
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Branch-ul a fost creat"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d revizii au fost copiate."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "indisp."
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Check_out"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Checkout _lightweight"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Directorul nu are working tree"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Operaţie anulată."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Există modificări locale în branch"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Vă rog să executaţi un commit sau un revert înainte de merge."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "adăugate"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "şterse"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "redenumite"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "redenumite şi modificate"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "modificate"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "Execută c_ommit doar local"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Comm_it"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Commit"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Cale"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Tip"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Data"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Autor commit"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Rezumat"
 
@@ -208,134 +208,134 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Execut commit fără mesaj?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Puteţi descrie conţinutul commit-ului în mesaj"
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Execut commit cu fişiere necunoscute?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 "Există fişiere necunoscute în working tree. Doriţi să continuaţi commit-ul?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Execut commit fără nicio schimbare?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Utilitar extern:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Conflicte"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Nu există conflicte în working tree"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "conflict cale"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "conflict conţinut"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "conflict text"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id duplicat"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "duplicat"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "bucla părinte"
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "părinte necunoscut"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "părinte lipsă"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "şterg părinte"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "conflict de tip necunoscut"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Nu a fost selectat niciun fisier"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Vă rog selectaţi un fişier din listă"
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Apelarea utilitarului extern a eşuat"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Nu pot rezolva conflict"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -350,73 +350,73 @@
 msgid "_View"
 msgstr "_Vizualizează"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Merge încheiat cu succes"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Toate modificările efectuate cu succes."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Există conflicte"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Vă rog rezolvaţi conflictele manual înainte de commit."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Directorul nu este un branch"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "Puteţi efectua această operaţie doar pe un branch."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Directorul nu este un checkout"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Puteţi efectua commit-uri locale doar în checkout-uri"
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Nicio schimbare pentru commit"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Încercaţi să forţaţi commit-ul dacă doriţi să continuaţi oricum."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Conflicte în structura de directoare"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Trebuie să rezolvaţi conflictele înainte de commit."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Commit-ul strict a eşuat"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -424,29 +424,29 @@
 "Există fişiere necunoscute în working tree.\n"
 "Vă rog să le adăugaţi sau să le ştergeţi."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Branch-ul legat este desincronizat"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Fişier necunoscut"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Fişierul selectat nu este cunoscut"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Branch-urile sunt desincronizate"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -454,36 +454,36 @@
 "Nu puteţi executa push dacă branch-urile sunt desincronizate.\n"
 "Folosiţi opţiunea de suprascriere dacă doriţi să continuaţi."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Nu există diferenţe"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Fişierul selectat nu a fost modificat."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "Revizie inexistentă"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Revizia pe care aţi specificat-o nu există."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Destinaţia există deja"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 "Directorul destinaţie există deja. Vă rog să selectaţi altă destinaţie."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Directorul este deja un branch"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -492,11 +492,11 @@
 "Directorul curent (%s) este deja un branch.\n"
 "Puteţi să-l folosiţi sau să iniţializaţi un alt director."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Branch fără ramură curentă de lucru"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -505,32 +505,32 @@
 "Directorul curent (%s)\n"
 "este un branch fără working tree"
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Eroare bzr necunoscută"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Acces interzis"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "acces interzis."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Eroare necunoscută"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Iniţializează"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Alegeţi directorul de iniţializat"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Directorul curent"
 
@@ -538,100 +538,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Creează un director nou cu numele:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Numele directorului nu a fost completat"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Ar trebui să specificaţi un nume de director."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Merge"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Branch necompletat"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Vă rog specificaţi un branch sursă"
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Eroare comandă Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Locaţie:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Push"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -639,20 +599,20 @@
 "Nu puteţi executa push dacă branch-urile sunt desincronizate.\n"
 "Suprascriu?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Push încheiat cu succes"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d revizii copiate."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Directorul părinte nu există"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -662,11 +622,11 @@
 "nu există. Îl creez?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Selectează"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -674,32 +634,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Adăugat"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Şters"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Redenumit"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Modificat"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Necunoscut"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Neschimbat."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Tag-uri"
 
@@ -711,44 +671,612 @@
 msgid "Revision ID"
 msgstr "ID revizie"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr "Acest format de branch nu suportă tag-uri. Vă rog să-l actualizaţi."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Nu există revizi cu tag-uri în branch."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "Şte_rge tag"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Şterg tag?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Sigur doriţi să ştergeţi tag-ul <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "Adaugă tag"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Nume tag:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "ID revizie:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Nume tag necompletat"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Trebuie să specificaţi numele dorit pentru tag."
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Fişier(e) pentru commit"
+
+#~ msgid "Commit message:"
+#~ msgstr "Mesaj commit:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Merge-uri în aşteptare"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Nu s-a schimbat nimic în working tree."
+
+#~ msgid "Revno"
+#~ msgstr "Nr. revizie"
+
+#~ msgid "Set default push location"
+#~ msgstr "Locaţia implicită pentru push"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Nu e configurată o locaţie implicită pentru push.\n"
+#~ "Salvez %r ca locaţie implicită acum?"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Vă rog aşteptaţi, încarc reviziile..."
+
+#~ msgid "Time"
+#~ msgstr "Ora"
+
+#~ msgid "Pull successful"
+#~ msgstr "Pull executat cu succes"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Există revizii lipsă"
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Nu există revizii lipsă"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Locaţia părintelui necunoscută"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr "Nu pot calcula reviziile lipsă dacă locaţia părintelui e necunoscută"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Branch local la zi"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revizii lipsă."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Nu puteţi executa pull fără a avea locaţia branch-ului părinte"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d revizii copiate"
+
+#~ msgid "unchanged"
+#~ msgstr "nemodificat"
+
+#~ msgid "Bookmark"
+#~ msgstr "Favorit"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Favorite"
+
+#~ msgid "Revert successful"
+#~ msgstr "Revert executat cu succes"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Toate filele restaurate conform ultimei revizii."
+
+#~ msgid "ignored"
+#~ msgstr "ignorat"
+
+#~ msgid "unknown"
+#~ msgstr "necunoscut"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Vă rog verificaţi working tree-ul înainte de a continua."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Am detectat conflicte"
+
+#~ msgid "Last modified"
+#~ msgstr "Ultima modificare"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Fişier Glade lipsă."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Fişierul care descrie interfaţa su utilizatorul nu poate fi găsit."
+
+#~ msgid "Status"
+#~ msgstr "Stare"
+
+#~ msgid "Filename"
+#~ msgstr "Nume fișier"
+
+#~ msgid "Title:"
+#~ msgstr "Titlu:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Vă rog specificaţi un titlu pentru a continua."
+
+#~ msgid "No title given"
+#~ msgstr "Titlu necompletat"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Vă rog selectaţi un fişier din listă,\n"
+#~ "sau alegeţi cealaltă opţiune."
+
+#~ msgid "Size"
+#~ msgstr "Mărime"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Deschide fişierul selectat"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Adaugă fişierul selectat"
+
+#~ msgid "Add"
+#~ msgstr "Adaugă"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Redenumeşte fişierul selectat"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Elimină şi şterge"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Elimină fişierul/directorul selectat şi şterge-l de pe disc"
+
+#~ msgid "Rename"
+#~ msgstr "Redenumește"
+
+#~ msgid "Open"
+#~ msgstr "Deschide"
+
+#~ msgid "Remove"
+#~ msgstr "Elimină"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Şterge fişierul selectat"
+
+#~ msgid "Revert"
+#~ msgstr "Revert"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Anulează modificări"
+
+#~ msgid "Annotate"
+#~ msgstr "Adnotează"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Adnotează fişierul selectat"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Adaugă locaţia curentă la favorite"
+
+#~ msgid "Edit"
+#~ msgstr "Editează"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Editează locaţia favorită selectată"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Salvează modificări"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Afişează diff pentru fişier"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Afişează conţinutul fişierului în viewer-ul inclus"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Arată modificările pentru toate fişierele"
+
+#~ msgid "All..."
+#~ msgstr "Toate..."
+
+#~ msgid "Open Folder"
+#~ msgstr "Deschide folder"
+
+#~ msgid "Show differences"
+#~ msgstr "Afişează diferenţe"
+
+#~ msgid "Selected..."
+#~ msgstr "Selectat..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Afişează modificările fişierului selectat"
+
+#~ msgid "View contents"
+#~ msgstr "Afişează conţinut"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Şterge favoritul selectat"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Restaurează la această revizie"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Directorul curent a fost adăugat la favorite. Îl puteţi accesa\n"
+#~ "selectându-l de pe panoul din stânga"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Locaţie favorită adăugată cu succes"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Directorul curent este deja prezent în favorite.\n"
+#~ "Verificaţi panoul din stânga."
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Locaţie deja prezentă în favorite"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Vă rog specificaţi un nume pentru noul director"
+
+#~ msgid "No directory name given"
+#~ msgstr "Nume director necompletat"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Restaurează fişierul selectat conform reviziei selectate"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Şterg directorul şi toate directoarele din el?"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Afişează diferenţele dintre două revizii ale fişierului"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Toate fişierele cu starea 'adăugat'"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Nu am găsit fişiere proaspăt adăugate în working tree."
+
+#~ msgid "No matching files"
+#~ msgstr "Nu am găsit fişierele"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Nu e în acelaşi branch"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Vă rog selectaţi un fişier din listă pentru continuare."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Directorul există deja"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Vă rog specificaţi alt nume pentru continuare."
+
+#~ msgid "Selected only"
+#~ msgstr "Doar cele selectate"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Destinaţia nu este în acelaşi branch."
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Ce fişier(e) doriţi să ştergeţi?"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Redenumeşte..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Mută..."
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Vă rog specificaţi un nume nou pentru fişier."
+
+#~ msgid "Filename not given"
+#~ msgstr "Nume fişier necompletat"
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - GUI pentru Bazaar"
+
+#~ msgid "_Remove"
+#~ msgstr "Ște_rge"
+
+#~ msgid "Make _directory..."
+#~ msgstr "Creează _director..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Şterge fişier(e)..."
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Adaugă fişier(e)..."
+
+#~ msgid "_File"
+#~ msgstr "_Fişier"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Reîncarcă"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Afişează fişierele asc_unse"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_heckout..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Pu_ll"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Iniţializează..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Adnotează"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "Elimină toate modificările (revert)"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Pu_sh..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Diferenţe..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Merge..."
+
+#~ msgid "Missing _revisions"
+#~ msgstr "_Revizii lipsă"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "Ta_g-uri..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Con_flicte..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_Commit..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Log..."
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistici"
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tare..."
+
+#~ msgid "_Information..."
+#~ msgstr "_Informaţii..."
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Mod _istorie"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Ce fişier(e) doriţi să adăugaţi?"
+
+#~ msgid "_Help"
+#~ msgstr "Ajutor"
+
+#~ msgid "_Add"
+#~ msgstr "_Adaugă"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Adaugă fişier(e)"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Toate fişerele necunoscute, recursiv"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Creează director"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Director c_unoscut"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Mută"
+
+#~ msgid "Move to"
+#~ msgstr "Mută în"
+
+#~ msgid "Rename to"
+#~ msgstr "Redenumeşte în"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Redenumeşte"
+
+#~ msgid "_Move"
+#~ msgstr "_Mută"
+
+#~ msgid "Select a directory"
+#~ msgstr "Selectaţi un director"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Creează director"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Elimină fişier(e)"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Rădăcină checkout: "
+
+#~ msgid "(none)"
+#~ msgstr "(nimic)"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Checkout repository: "
+
+#~ msgid "Branch root: "
+#~ msgstr "Rădăcină branch: "
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Informaţii"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checkout al branch-ului: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Branch repository: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Rădăcină checkout lightweight: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Redenumește"
+
+#~ msgid "Shared repository: "
+#~ msgstr "Repository partajat: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publică în branch-ul: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Branch părinte: "
+
+#~ msgid "Control format: "
+#~ msgstr "Format control: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Format working tree: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Format:</b>"
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Branch-uri înrudite:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Locație:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Stare lock repository: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Format repository: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Format branch: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Fişiere redenumite: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Fişiere necunoscute: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Fişiere ignorate: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Revizii lipsă:</b>"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Stare lock:</b>"
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Stare lock branch: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Revizii lipsă în working tree: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Stare lock working tree: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Revizii lipsă în branch: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revizii în branch: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Fişiere nemodificate: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Fişiere modificate: "
+
+#~ msgid "Added files: "
+#~ msgstr "Fişiere adăugate: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Fişiere eliminate: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>În working tree:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Data ultimei revizii: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Data primei revizii: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Vârsta branch-ului în zile: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Număr autori: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>Istorie branch:</b>"
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Stocare revizii:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "Dimensiune repository: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revizii în repository: "
+
+#~ msgid "Merge from:"
+#~ msgstr "Sursa merge:"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Deschide director favorite în Nautilus"
+
+#~ msgid "_Get..."
+#~ msgstr "Creează _branch local"
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Subdosare versionate: "
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Adi Roiban https://launchpad.net/~adiroiban\n"
+#~ "  Sabin Iacob https://launchpad.net/~iacobs"

=== modified file 'po/ru.po'
--- po/ru.po	2011-12-02 05:55:20 +0000
+++ po/ru.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-02-18 06:41+0000\n"
 "Last-Translator: Sergey Basalaev <SBasalaev@gmail.com>\n"
 "Language-Team: Russian <ru@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "В_етка"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "Расположение ветки:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Назначение:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "Условное обозначение ветки:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Версия:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Выберите папку"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "Отсутствует расположение ветки"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "Вы должны указать расположение ветви"
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "Ветвь успешно создана"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "%d версия ветки"
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "Н/Д"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "_Проверка"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "_Облегченная проверка"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "У каталога нет рабочего дерева"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Операция прервана."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "Есть локальные изменения в ветви"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "Пожалуйста закрепите или откатите изменения перед обьединением."
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "добавлен"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "удален"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "переименован"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "переименован и изменен"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "изменён"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "_Публиковать только локально?"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "О_публиковать"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Публиковать"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Путь"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Тип"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Дата"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Опубликовал"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Сводка"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Публиковать с пустым сообщением?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "Вы можете описать вашу публикацию в сообщении"
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr "Публиковать с неизвестными?"
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr "Неизвестные файлы в рабочем дереве. Продолжить публикацию?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "Публиковать без внесения изменений?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Внешняя утилита:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Конфликты"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "В рабочем дереве конфликтов нет."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "конфликт путей"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "конфликт содержания"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "текстовый конфликт"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "совпадающий id"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "дубликат"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr "начальный контур"
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr "вне версионный предок"
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr "отсутствует предок"
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr "удален предок"
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "неизвестный тип конфликта"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Файл не был выбран"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Пожалуйста, выберите файл из списка."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Вызов внешнего приложения неудачен"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Невозможно разрешить конфликт"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -349,73 +349,73 @@
 msgid "_View"
 msgstr "_Просмотр"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Объединение прошло успешно"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Все изменения применены успешно ."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "Обнаружены конфликты"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "Пожалуйста, разрешите конфликты вручную перед публикацией."
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Каталог не является ветвью"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "Вы можете применить это действие только к ветви."
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Каталог не проверен"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr "Вы можете выполнить локальную публикацию только после проверки."
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Нет изменений для публикации"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr "Попытаться опубликовать если вы хотите опубликовать в любом случае."
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Конфликты в дереве"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "Вам необходимо устранить все конфликты перед публикацией."
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Ошибка точной публикации"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
@@ -423,29 +423,29 @@
 "В рабочем дереве содержаться неизвестные файлы.\n"
 "Пожалуйста добавьте или удалите их."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "Связанная ветвь устарела"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Файл без версии"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "Выбранный файл без версии"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr "Ветви не совпадают"
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
@@ -453,36 +453,36 @@
 "Вы не можете передать если ветви расходятся. Используйте\n"
 "опцию перезаписи если вы ходите передать в любом случае."
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "Нет результатов сравнения"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Выбранный файл не изменился."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr "Нет такой ревизии"
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Указанная вами ревизия не существует"
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Цель уже существует."
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 "Указанный каталог уже существует. Пожалуйста, укажите другое значение."
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Каталог уже является ветвью"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
@@ -491,11 +491,11 @@
 "Текущий каталог (%s) уже является ветвью.\n"
 "Используйте его  или инициализируйте другой каталог."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "Ветвь находится вне рабочего дерева"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -504,32 +504,32 @@
 "Текущий каталог (%s)\n"
 "является ветвью вне рабочего дерева."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Неизвестная ошибка bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "В доступе отказано"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "доступ запрещен."
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Неизвестная ошибка"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Инициализировать"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "Какой каталог вы хотите инициализировать?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Текущий каталог"
 
@@ -537,100 +537,60 @@
 msgid "Create a new directory with the name:"
 msgstr "Создайте новый каталог с именем:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Не указано имя каталога"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "вы должны указать имя нового каталога."
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Объединить"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr "Ветвь не выбрана"
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "Пожалуйста, укажите ветку для объединения"
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Ошибка комманды Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Местоположение:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Разместить"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
@@ -638,20 +598,20 @@
 "Вы не можете передать если ветви расходятся.\n"
 "Перезаписать?"
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "Успешное размещение"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "%d ревизия(и) передана(ы)."
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Отсутствует родительский каталог"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -661,11 +621,11 @@
 "не существует. Создать?"
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "В_ыделить"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -673,32 +633,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Добавлено"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Удалено"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Переименовано"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Изменено"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Неизвестный"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Без изменений."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Метки"
 
@@ -710,44 +670,621 @@
 msgid "Revision ID"
 msgstr "Идентификатор ревизии"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr "Метки не поддерживаются текущим форматом ветви. Пожалуйста обновите."
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr "Нет помеченной ревизии в ветви."
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_Удалить метку"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Удалить метку?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Вы уверены, что хотите удалить метку: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Добавить метку"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Название метки:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Идентификатор ревизии:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Не указано название метки"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr "Вы должны указать желаемое имя метки."
+
+#~ msgid "_Rename..."
+#~ msgstr "_Переименовать..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Переместить..."
+
+#~ msgid "_Refresh"
+#~ msgstr "Обновить"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Показывать скрытые файлы"
+
+#~ msgid "_Commit..."
+#~ msgstr "Зафиксировать"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Статус"
+
+#~ msgid "_Log..."
+#~ msgstr "Журнал..."
+
+#~ msgid "_Differences..."
+#~ msgstr "Различия..."
+
+#~ msgid "_Statistics"
+#~ msgstr "Статистика"
+
+#~ msgid "_Help"
+#~ msgstr "Справка"
+
+#~ msgid "Diff"
+#~ msgstr "Различия"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Какие файлы вы хотите добавить?"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Добавить файл(ы)"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Все файлы со статусом \"добавлен\""
+
+#~ msgid "_Remove"
+#~ msgstr "Удалить"
+
+#~ msgid "Selected only"
+#~ msgstr "Только отмеченные"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Удалить файл(ы)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Какие файлы вы хотите удалить?"
+
+#~ msgid "All unknowns recursively"
+#~ msgstr "Все неизвестные рекурсивно"
+
+#~ msgid "_Add"
+#~ msgstr "Добавить"
+
+#~ msgid "_Make directory"
+#~ msgstr "Создать каталог"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Переместить"
+
+#~ msgid "Move to"
+#~ msgstr "Переместить в"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Создать каталог"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Переименовать"
+
+#~ msgid "_Move"
+#~ msgstr "Переместить"
+
+#~ msgid "Select a directory"
+#~ msgstr "Выберите директорию"
+
+#~ msgid "Branch root: "
+#~ msgstr "Корень ветви: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Ветвь репозитория: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Родительская ветвь: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "Тип рабоего дерева: "
+
+#~ msgid "Repository format: "
+#~ msgstr "Тип репозитория: "
+
+#~ msgid "Branch format: "
+#~ msgstr "Тип ветви: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Неизмененные файлы: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Измененные файлы: "
+
+#~ msgid "Added files: "
+#~ msgstr "Добавленные файлы: "
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Состояние блокировки репозитория: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "Состояние блокировки ветви: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "Состояние блокировки рабочего дерева: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Переименованные файлы: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Неизвестные файлы: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Игнорируемые файлы: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Возраст ветви в днях: "
+
+#~ msgid "Title:"
+#~ msgstr "Заголовок:"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "Пожалуйста, выберите файл из этого списка,\n"
+#~ "или выберите другие опции."
+
+#~ msgid "Size of repository: "
+#~ msgstr "Размер репозитория: "
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Локальная ветьвь обновлена"
+
+#~ msgid "Bookmark"
+#~ msgstr "Закладка"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Закладки"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Добавить выбранный файл"
+
+#~ msgid "Add"
+#~ msgstr "Добавить"
+
+#~ msgid "Status"
+#~ msgstr "Состояние"
+
+#~ msgid "Filename"
+#~ msgstr "Имя файла"
+
+#~ msgid "unknown"
+#~ msgstr "неизвестный"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Показать изменения во всех файлах"
+
+#~ msgid "All..."
+#~ msgstr "Все..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Показать изменения в выбранном файле"
+
+#~ msgid "Edit"
+#~ msgstr "Редактировать"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Редактировать выбранную закладку"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "Текущий каталог добавлен в закладки. Вы можете\n"
+#~ "выбрать его на левой панели."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Закладка успешно добавлена"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "Текущий каталог уже добавлен в закладки.\n"
+#~ "Смотрите ссылку в левой панели."
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "Укажите имя нового каталога."
+
+#~ msgid "Directory already exists"
+#~ msgstr "Каталог уже существует"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Выберите другое имя."
+
+#~ msgid "Not the same branch"
+#~ msgstr "Это другая ветвь"
+
+#~ msgid "No matching files"
+#~ msgstr "Нет подходящих файлов"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Выберите новое имя для этого файла."
+
+#~ msgid "Time"
+#~ msgstr "Время"
+
+#~ msgid "ignored"
+#~ msgstr "игнорируется"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Переименовать выбранный файл"
+
+#~ msgid "Last modified"
+#~ msgstr "Последняя модификация"
+
+#~ msgid "Size"
+#~ msgstr "Размер"
+
+#~ msgid "Rename"
+#~ msgstr "Переименовать"
+
+#~ msgid "Open"
+#~ msgstr "Открыть"
+
+#~ msgid "Revert"
+#~ msgstr "Восстановить"
+
+#~ msgid "Open Folder"
+#~ msgstr "Открыть папку"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Открыть выбранный файл"
+
+#~ msgid "No directory name given"
+#~ msgstr "Не указано название папки"
+
+#~ msgid "Show differences"
+#~ msgstr "Показать изменения"
+
+#~ msgid "_Merge..."
+#~ msgstr "_Объединить..."
+
+#~ msgid "_File"
+#~ msgstr "_Файл"
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_Метки..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "_Конфликты..."
+
+#~ msgid "_Rename"
+#~ msgstr "_Переименовать"
+
+#~ msgid "Rename to"
+#~ msgstr "Переименовать в"
+
+#~ msgid "_Information..."
+#~ msgstr "_Информация..."
+
+#~ msgid "(none)"
+#~ msgstr "(нет)"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Местоположение:</b>"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Формат:</b>"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "Отсутствуют изменения в рабочем дереве."
+
+#~ msgid "Set default push location"
+#~ msgstr "Указать место размещения по-умолчанию"
+
+#~ msgid "Revno"
+#~ msgstr "Рев.№"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "Место размещения по-умолчанию не установлено.\n"
+#~ "Установить %r по-умолчанию?"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "Файл(ы) для публикации"
+
+#~ msgid "Commit message:"
+#~ msgstr "Сообщение публикации:"
+
+#~ msgid "Pending merges"
+#~ msgstr "Ожидающие слияния"
+
+#~ msgid "Please wait, revisions are being loaded..."
+#~ msgstr "Пожалуйста подождите, версии загружаются..."
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Обнаружены конфликты"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Откзаться от изменений"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Добавить текущее положение в закладки"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Опубликовать изменения"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Открыть папку с закладками в Наутилусе"
+
+#~ msgid "View contents"
+#~ msgstr "Просмотреть содержимое"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "Вернуться к этой версии"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Местоположение уже есть в закладках"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Вернуться к указанной версии выделенного файла"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Удалить каталог и все его подкаталоги?"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "Не найдены добавленные файлы в рабочем дереве"
+
+#~ msgid "Filename not given"
+#~ msgstr "Не указано имя файла"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Статус блокировки:</b>"
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>В рабочем дереве:</b>"
+
+#~ msgid "Parent location is unknown"
+#~ msgstr "Местонахождение предка неизвестно"
+
+#~ msgid "Cannot determine missing revisions if no parent location is known."
+#~ msgstr ""
+#~ "Нельзя определить отсутствующие ревизии если местоположение предка не "
+#~ "известно."
+
+#~ msgid "Pull successful"
+#~ msgstr "Получение выполненно"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "%d ревизия(й) получена(о)."
+
+#~ msgid "Revert successful"
+#~ msgstr "Откат выполнен"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "Все файлы возвращены к последней ревизии."
+
+#~ msgid "Pulling is not possible until there is a parent location."
+#~ msgstr "Получить не возможно пока здесь расположен предок."
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Открываемый файл не наден."
+
+#~ msgid "UI description file cannot be found."
+#~ msgstr "Файл описания идентификатора пользователя не найден."
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Пожалуйста укажите заголовок для продолжения."
+
+#~ msgid "No title given"
+#~ msgstr "Заголовок не указан"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "Убрать выбранный файл/каталог и удалить с диска."
+
+#~ msgid "Remove and delete"
+#~ msgstr "Убрать и удалить"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "Просмотреть содержимое файла во встроенном просмоторщике"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "Для продолжения выберите файл из списка."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Создать _каталог..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Добавить файл(ы)..."
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "Место назначения в другой ветви."
+
+#~ msgid "_Get..."
+#~ msgstr "_Забрать"
+
+#~ msgid "C_heckout..."
+#~ msgstr "_Проверить..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Пол_учить"
+
+#~ msgid "H_istory Mode"
+#~ msgstr "Режим и_стории"
+
+#~ msgid "_Initialize..."
+#~ msgstr "_Инициализация"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "О_ткатить все изменения"
+
+#~ msgid "Missing _revisions"
+#~ msgstr "Отсутствующие _ревизии"
+
+#~ msgid "Checkout root: "
+#~ msgstr "Проверяемый корень: "
+
+#~ msgid "_Versioned directory"
+#~ msgstr "Отслеживаемые _каталоги"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Проверка репозитория: "
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - Информация"
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Проверка ветви: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Доступный репозитоий: "
+
+#~ msgid "Light checkout root: "
+#~ msgstr "Облегченная проверка корня: "
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Пкбликуемая ветвь: "
+
+#~ msgid "Control format: "
+#~ msgstr "Формат контроля: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>Связанные ветви:</b>"
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Отслеживаемые подкаталолги: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Ревизий в ветви: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>История ветви:</b>"
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Колличество публикаций: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Ревизий в репозитории: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "Merge - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "Обьеденить из:"
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Есть отсутствующие ревизии"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d ревизия(-ий) отсутствует(-ют)."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Нет отсутсвующих ревизий."
+
+#~ msgid "unchanged"
+#~ msgstr "неизменённый"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "Пожалуйста укажите рабочее дерево перед продолжением."
+
+#~ msgid "Remove"
+#~ msgstr "Убрать"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Добавить аннотацию к выбранному файлу"
+
+#~ msgid "Annotate"
+#~ msgstr "Аннотация"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Убрать выбранный файл"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Показать изменения в файле"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "Показать изменения между двумя ревизиями файла"
+
+#~ msgid "Selected..."
+#~ msgstr "Выбранное..."
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Убрать выбранную закладку"
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Убрать файл(ы)..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "_Аннотация..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "П_ередать..."
+
+#~ msgid "Removed files: "
+#~ msgstr "Убранные файлы: "
+
+#~ msgid "<b>Missing revisions:</b>"
+#~ msgstr "<b>Отсутсвующие ревизии:</b>"
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Отсутсвующие ревизии в рабочем дереве: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Отсутсвующие ревизии в ветке: "
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Время последней ревизии: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Время первой ревизии: "
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Ревизий хранится:</b>"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Alexander Belchenko https://launchpad.net/~bialix\n"
+#~ "  Mikhail Pitertsev https://launchpad.net/~platiferro\n"
+#~ "  Oleg Koptev https://launchpad.net/~koptev-oleg\n"
+#~ "  Pavel A. Bragin https://launchpad.net/~balintrue\n"
+#~ "  Petr E. Antonov https://launchpad.net/~antpeter\n"
+#~ "  Rail Aliev https://launchpad.net/~rail\n"
+#~ "  Sergey Basalaev https://launchpad.net/~sbasalaev\n"
+#~ "  Sergey Sedov https://launchpad.net/~serg-sedov\n"
+#~ "  XPEH https://launchpad.net/~akidyarov"

=== modified file 'po/sr.po'
--- po/sr.po	2011-12-02 05:55:20 +0000
+++ po/sr.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
-"Last-Translator: Jelmer Vernooij <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-12-11 18:52+0000\n"
+"Last-Translator: Данило Шеган <Unknown>\n"
 "Language-Team: Serbian <sr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Грана"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr ""
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr ""
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr ""
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr ""
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr ""
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr ""
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr ""
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr ""
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,50 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  bilbija https://launchpad.net/~bilbija\n"
+#~ "  Данило Шеган https://launchpad.net/~danilo"

=== modified file 'po/sv.po'
--- po/sv.po	2012-02-22 06:51:43 +0000
+++ po/sv.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2012-02-21 16:04+0000\n"
-"Last-Translator: Rikard Edgren <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-08 08:27+0000\n"
+"Last-Translator: Daniel Nylander <yeager@ubuntu.com>\n"
 "Language-Team: Swedish <sv@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2012-02-22 06:51+0000\n"
-"X-Generator: Launchpad (build 14838)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_Gren"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
-msgstr "Grenens plats:"
+msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Mål:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
-msgstr "Grenens kortnamn:"
+msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
-msgstr "Version:"
+msgstr "Revision:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Välj en mapp"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
-msgstr "Grenens plats saknas"
+msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
-msgstr "Du måste ange en plats för grenen."
+msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
-msgstr "Förgrening lyckades"
+msgstr "Grening lyckades"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
-msgstr "%d version(er) förgrenade."
+msgstr "%d revision(er) grenade."
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
-msgstr "Inte tillgänglig"
+msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
-msgstr "Checka_ut"
+msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
-msgstr "_Lätt utcheckning"
+msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
-msgstr "Katalogen innehåller inte något arbetsträd"
+msgstr "Katalogen innehåller inte ett arbetsträd"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
-msgstr "Åtgärden avbröts."
+msgstr "Åtgärden avbruten."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "lades till"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "togs bort"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "bytte namn"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
-msgstr "omdöpt och ändrad"
+msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "ändrades"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Verkställ"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Sökväg"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Typ"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Datum"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "Verkställd av"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Sammanfattning"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
-msgstr "Externt verktyg:"
+msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
-msgstr "Konflikter"
+msgstr ""
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
-msgstr "Inga konflikter i arbetsträd."
+msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
-msgstr "sökvägskonflikt"
+msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
-msgstr "innehållskonflikt"
+msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
-msgstr "textkonflikt"
+msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
-msgstr "duplicera id"
+msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
-msgstr "duplicera"
+msgstr ""
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
-msgstr "överordnad loop"
+msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
-msgstr "okänd konflikttyp"
+msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Ingen fil valdes"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
-msgstr "Välj en fil från listan."
+msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
-msgstr "Anrop till externt verktyg misslyckades"
+msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
-msgstr "Kan inte lösa konflikt"
+msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,304 +346,258 @@
 msgid "_View"
 msgstr "_Visa"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
-msgstr "Sammanslagningen lyckades"
+msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
-msgstr "Alla ändringar har aktiverats utan problem."
+msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
-msgstr "Konflikter uppkom."
+msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "Katalogen är inte en gren"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
-msgstr "Du kan endast genomföra denna operation i en gren."
+msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Inga ändringar att verkställa"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Konflikter i träd"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr "Strikt verkställning misslyckades"
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
-"Det finns okända filer i arbetsträdet.\n"
-"Lägg till eller radera dem."
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "Filen inte versionskontrollerad"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
-msgstr "Ingen utdata från diff"
+msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Den valda filen har inte ändrats."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
-msgstr "Ingen sådan version"
+msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "Revisionen du angav finns inte."
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Mål finns redan"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
-msgstr "Målkatalogen existerar redan. Välj ett annat mål."
+msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "Katalogen är redan en gren"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
-"Den aktuella katalogen (%s) är redan en gren.\n"
-"Du kan börja använda den, eller initiera en ny katalog."
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
-msgstr "Gren utan arbetsträd"
+msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
-"Den nuvarande katalogen (%s)\n"
-"är en gren utan arbetsträd."
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
-msgstr "Okänt bzr-fel"
+msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Åtkomst nekas"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
-msgstr "åtkomst nekad."
+msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Okänt fel"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr "_Initiera"
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
-msgstr "Vilken mapp vill du initalisera?"
+msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
-msgstr "Nuvarande katalog"
+msgstr ""
 
 #: ../initialize.py:51
 msgid "Create a new directory with the name:"
-msgstr "Skapa en ny katalog med namnet:"
+msgstr ""
+
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
 
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr "Katalognamn ej specificerat"
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
-msgstr "Du bör specificera ett nytt katalognamn."
+msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
-msgstr "Ange en gren att slå samman med."
+msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
-msgstr "Bazaar kommando-fel"
-
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
 msgstr ""
 
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Plats:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_Skjut ut"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
-msgstr "Ingen existerande överordnad katalog"
+msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -651,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Markera"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -663,81 +617,369 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Lades till"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Togs bort"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Bytte namn"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Ändrades"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Okänd"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Inga ändringar."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
-msgstr "Etiketter"
+msgstr ""
 
 #: ../tags.py:110
 msgid "Tag Name"
-msgstr "Etikett-namn"
+msgstr ""
 
 #: ../tags.py:115
 msgid "Revision ID"
-msgstr "Versions-ID"
+msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
-msgstr "Etiketter stöds ej i detta gren-format. Vänligen uppgradera."
+msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
-msgstr "Inga versioner med etiketter i denna gren."
+msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "_Lägg till tagg"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Taggnamn:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
-msgstr "Versions-ID:"
+msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "_Rename..."
+#~ msgstr "_Byt namn..."
+
+#~ msgid "_Move..."
+#~ msgstr "_Flytta..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Skapa _katalog..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Ta bort fil(er)..."
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Användargränssnitt för Bazaar"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "_Lägg till fil(er)..."
+
+#~ msgid "_File"
+#~ msgstr "_Arkiv"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Uppdatera"
+
+#~ msgid "_Get..."
+#~ msgstr "_Hämta..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Visa _dolda filer"
+
+#~ msgid "C_heckout..."
+#~ msgstr "C_hecka ut..."
+
+#~ msgid "Pu_ll"
+#~ msgstr "Dra _in"
+
+#~ msgid "_Commit..."
+#~ msgstr "_Verkställ..."
+
+#~ msgid "Pu_sh..."
+#~ msgstr "Skjut _ut..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "S_tatus..."
+
+#~ msgid "_Log..."
+#~ msgstr "_Logg..."
+
+#~ msgid "_Differences..."
+#~ msgstr "_Skillnader"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Statistik"
+
+#~ msgid "_Help"
+#~ msgstr "_Hjälp"
+
+#~ msgid "Diff"
+#~ msgstr "Diff"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Vilka fil(er) vill du lägga till?"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - Lägg till fil(er)"
+
+#~ msgid "_Remove"
+#~ msgstr "_Ta bort"
+
+#~ msgid "Selected only"
+#~ msgstr "Endast markerade"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - Ta bort fil(er)"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "Vilka fil(er) vill du ta bort?"
+
+#~ msgid "_Add"
+#~ msgstr "_Lägg till"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - Skapa katalog"
+
+#~ msgid "_Versioned directory"
+#~ msgstr "_Versionshanterad katalog"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - Flytta"
+
+#~ msgid "Move to"
+#~ msgstr "Flytta till"
+
+#~ msgid "_Make directory"
+#~ msgstr "_Skapa katalog"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - Byt namn"
+
+#~ msgid "_Move"
+#~ msgstr "_Flytta"
+
+#~ msgid "Select a directory"
+#~ msgstr "Välj en katalog"
+
+#~ msgid "Repository checkout: "
+#~ msgstr "Förrådsutcheckning: "
+
+#~ msgid "Checkout of branch: "
+#~ msgstr "Checka ut gren: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "Förrådsgren: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "Delat förråd: "
+
+#~ msgid "_Rename"
+#~ msgstr "_Byt namn"
+
+#~ msgid "Rename to"
+#~ msgstr "Byt namn till"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "Publicera till gren: "
+
+#~ msgid "Parent branch: "
+#~ msgstr "Föräldergren: "
+
+#~ msgid "(none)"
+#~ msgstr "(ingen)"
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Oförändrade filer: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Ändrade filer: "
+
+#~ msgid "Added files: "
+#~ msgstr "Tillagda filer: "
+
+#~ msgid "Missing revisions in working tree: "
+#~ msgstr "Saknade revisioner i arbetsträd: "
+
+#~ msgid "Missing revisions in branch: "
+#~ msgstr "Saknade revisioner i gren: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "Revisioner i gren: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "Filer som bytt namn: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Okända filer: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ignorerade filer: "
+
+#~ msgid "Versioned subdirectories: "
+#~ msgstr "Versionshanterade underkataloger: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Tid för första revision: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "Ålder för gren (i dagar): "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "Antal insändare: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Borttagna filer: "
+
+#~ msgid "Title:"
+#~ msgstr "Titel:"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Tid för sista revision: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Storlek på förråd: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Revisioner i förråd: "
+
+#~ msgid "There are missing revisions"
+#~ msgstr "Det finns saknade revisioner"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "Lokal gren uppdaterad"
+
+#, python-format
+#~ msgid "%d revision(s) missing."
+#~ msgstr "%d revision(er) saknas."
+
+#~ msgid "There are no missing revisions."
+#~ msgstr "Det finns inga saknade revisioner."
+
+#~ msgid "Bookmark"
+#~ msgstr "Bokmärke"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Bokmärken"
+
+#~ msgid "Glade file cannot be found."
+#~ msgstr "Glade-filen kunde inte hittas."
+
+#~ msgid "Add the selected file"
+#~ msgstr "Lägg till den markerade filen"
+
+#~ msgid "Add"
+#~ msgstr "Lägg till"
+
+#~ msgid "unchanged"
+#~ msgstr "oförändrad"
+
+#~ msgid "Status"
+#~ msgstr "Status"
+
+#~ msgid "Filename"
+#~ msgstr "Filnamn"
+
+#~ msgid "unknown"
+#~ msgstr "okänd"
+
+#~ msgid "Remove"
+#~ msgstr "Ta bort"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Ta bort den markerade filen"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Verkställ ändringarna"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Visa skillnaderna för alla filer"
+
+#~ msgid "All..."
+#~ msgstr "Alla..."
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Bokmärk aktuell plats"
+
+#~ msgid "Edit"
+#~ msgstr "Redigera"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Redigera det markerade bokmärket"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Ta bort det markerade bokmärket"
+
+#~ msgid "No directory name given"
+#~ msgstr "Inget katalognamn angavs"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Katalogen finns redan"
+
+#~ msgid "Not the same branch"
+#~ msgstr "Inte i samma gren"
+
+#~ msgid "No matching files"
+#~ msgstr "Inga filer matchades"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "Ange ett nytt namn för filen."
+
+#~ msgid "Filename not given"
+#~ msgstr "Filnamn angavs inte"
+
+#~ msgid "Time"
+#~ msgstr "Tid"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Carl-Uno Olsson https://launchpad.net/~carl-uno\n"
+#~ "  Daniel Nylander https://launchpad.net/~yeager\n"
+#~ "  Fredrik Portström https://launchpad.net/~rheo\n"
+#~ "  Zirro https://launchpad.net/~magne-andersson"

=== modified file 'po/th.po'
--- po/th.po	2011-12-02 05:55:20 +0000
+++ po/th.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: olive\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-03-18 03:18+0000\n"
 "Last-Translator: SiraNokyoongtong <gumaraa@gmail.com>\n"
 "Language-Team: Thai <th@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "_สาขา"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "ตำแหน่งสาขา:"
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "ปลายทาง:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr "ชื่อเรียกสาขา:"
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "รุ่น:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "โปรดเลือกโฟลเดอร์"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "ไม่พบตำแหน่งสาขา"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "คุณต้องระบุตำแหน่งสาขา"
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "แตกสาขาสำเร็จ"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr "รุ่นที่ %d ของสาขา"
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "ไดเรกทอรีไม่มีสายงาน"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "ยกเลิกปฏิบัติการ"
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr "นั่นคือการเปลี่ยนแปลงในสาขา"
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr "โปรดยืนยันหรือย้อนกลับการเปลี่ยนแปลงก่อนจะรวม"
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "เพิ่มแล้ว"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "ลบแล้ว"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "เปลี่ยนชื่อแล้ว"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "เปลี่ยนชื่อและเปลี่ยนแปลงแล้ว"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "เปลี่ยนแปลงแล้ว"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr "<b>ข้อความยืนยัน</b>"
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr "ยืนยัน_อยู่ภายในเท่านั้น"
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "_ยืนยัน"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr "แฟ้ม"
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr "ยืนยันการเปลี่ยนแปลงทั้งหมด"
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr "ยืนยันการเปลี่ยนแปลงทั้งหมด*"
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr "ยืนยัน*"
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "ยืนยัน"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "พาธ"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "รูปแบบ"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr "<i>* ไม่สามารถเลือกแฟ้มขณะกำลังผสาน</i>"
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr "กำลังรอรุ่น"
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "วันที่"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "ผู้ยืนยัน"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "ภาพรวม"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr "เปรียบเทียบทั้งสายงาน"
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr "แฟ้มข้อความยืนยัน"
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr "ข้อความยืนยันโดยรวม"
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr "<b>ข้อความยืนยันโดยรวม</b>"
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr "เปรียบเทียบกับ "
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr "ข้อความยืนยันสำหรับ "
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "ยืนยันโดยไม่กำหนดข้อความ?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr "คุณสามารถระบุเหตุผลของการยืนยัน"
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr "มีแฟ้มที่ไม่รู้จักในสายงาน ยืนยันหรือไม่?"
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "ยืนยันแม้ไม่เปลี่ยนแปลง?"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr "ไม่มีการเปลี่ยนแปลงในสายงาน คุณต้องการยืนยันหรือไม่?"
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "เครื่องมืออำนวยความสะดวกภายนอก:"
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "ขัดแย้ง"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "ไม่มีความขัดแย้งในสายงานนนี้"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "ขัดแย้งที่พาธ"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "ขัดแย้งที่เนื้อหา"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "ขัดแย้งที่อักขระ"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "id ซ้ำซ้อน"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "ซ้ำซ้อน"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "ไม่ทราบรูปแบบของความผิดพลาด"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "ไม่มีแฟ้มถูกเลือก"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "โปรดเลือกแฟ้มจากรายการ"
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "การเรียกเครื่องมืออำนวยความสะดวกภายนอกล้มเหลว"
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "ไม่สามารถแก้ไขความขัดแย้ง"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,146 +346,146 @@
 msgid "_View"
 msgstr "มุม_มอง"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "รวมสำเร็จ"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "การเปลี่ยนแปลงทั้งหมดปรับใช้เรียบร้อย"
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr "พบความขัดแย้ง"
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr "โปรดแก้ไขความขัดแย้งด้วยตัวเองก่อนจะยืนยัน"
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr "ไดเรกทอรีไม่ใช่สาขา"
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr "การกระทำนี้คุณสามารถทำได้ในสาขาเท่านั้น"
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "ไม่มีการเปลี่ยนแปลงที่จะยืนยัน"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "ขัดแย้งในสายงาน"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr "คุณต้องแก้ไขความขัดแย้งก่อนการยืนยัน"
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr "ส่วนขอบของสาขาล้าสมัย"
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr "แฟ้มยังไม่ได้ระบุรุ่น"
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr "แฟ้มที่เลือกยังไม่ได้ระบุรุ่น"
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr "ไม่มีผลลัพธ์การเปรียบเทียบ"
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "แฟ้มที่เลือกไม่มีการเปลี่ยนแปลง"
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr "ไม่มีรุ่นที่คุณระบุ"
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr "ไดเรกทอรี่เป็นสาขาแล้ว"
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr "สาขาไม่มีสายงาน"
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
@@ -494,32 +494,32 @@
 "ไดเรกทอรีปัจจุบัน (%s)\n"
 "คือสาขาโดยไม่มีสายงาน"
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "bzr ผิดพลาดไม่ทราบสาเหตุ"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "ไม่ได้รับอนุญาต"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "ไม่ได้รับอนุญาต"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "ผิดพลาดไม่ทราบสาเหตุ"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr "ไดเรกทอรีใดที่คุณต้องการเริ่ม?"
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "ไดเรกทอรีปัจจุบัน"
 
@@ -527,119 +527,79 @@
 msgid "Create a new directory with the name:"
 msgstr "สร้างไดเรกทอรีใหม่ด้วยชื่อ:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "ไม่ได้ระบุชื่อไดเรกทอรี"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "คุณควรระบุชื่อไดเรกทอรี"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_ผสาน"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr "โปรดระบุสาขาที่จะรวมเข้ามา"
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "คำสั่ง Bazaar ผิดพลาด"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "ตำแหน่ง:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr "_ส่ง"
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
-#: ../push.py:109
+#: ../push.py:108
 msgid "Push successful"
 msgstr "ส่งเรียบร้อย"
 
-#: ../push.py:110
+#: ../push.py:109
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr "รุ่นที่ %d ได้ส่งแล้ว"
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -647,11 +607,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "เ_ลือก"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -659,32 +619,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "เพิ่มแล้ว"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "ลบแล้ว"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "เปลี่ยนชื่อแล้ว"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "แก้ไขแล้ว"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "ไม่ทราบ"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "ไม่มีการเปลี่ยนแปลง"
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "ป้าย"
 
@@ -696,44 +656,552 @@
 msgid "Revision ID"
 msgstr "หมายเลขประจำรุ่น"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "_ลบป้าย"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>ลบป้าย?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "คุณแน่ใจหรือไม่ที่ป้าย: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "เ_พิ่มป้าย"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "ชื่อป้าย:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "หมายเลขประจำรุ่น:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "ไม่มีชื่อป้ายถูกระบุ"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "File(s) to commit"
+#~ msgstr "แฟ้มที่จะยืนยัน"
+
+#~ msgid "Commit message:"
+#~ msgstr "ข้อความการยืนยัน:"
+
+#~ msgid "Pending merges"
+#~ msgstr "กำลังรอผสาน"
+
+#~ msgid "There are no changes in the working tree."
+#~ msgstr "ไม่มีการเปลี่ยนแปลงในสายงานนี้"
+
+#~ msgid "Set default push location"
+#~ msgstr "กำหนดตำแหน่งส่งปริยาย"
+
+#, python-format
+#~ msgid ""
+#~ "There is no default push location set.\n"
+#~ "Set %r as default now?"
+#~ msgstr ""
+#~ "นั่นไม่ใช่ตำแหน่งส่งปริยาย\n"
+#~ "ตั้ง %r เป็นปริยายเดี๋ยวนี้?"
+
+#~ msgid "Revno"
+#~ msgstr "ลำดับรุ่น"
+
+#~ msgid "Time"
+#~ msgstr "เวลา"
+
+#~ msgid "Local branch up to date"
+#~ msgstr "สาขาภายในเป็นปัจจุบันแล้ว"
+
+#~ msgid "Pull successful"
+#~ msgstr "ดึงสำเร็จ"
+
+#, python-format
+#~ msgid "%d revision(s) pulled."
+#~ msgstr "รุ่นที่ %d ได้ดึงลงมาแล้ว"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "ตรวจพบความขัดแย้ง"
+
+#~ msgid "Please have a look at the working tree before continuing."
+#~ msgstr "โปรดดูที่สายงานก่อนดำเนินการต่อ"
+
+#~ msgid "Revert successful"
+#~ msgstr "ย้อนกลับเรียบร้อย"
+
+#~ msgid "All files reverted to last revision."
+#~ msgstr "แฟ้มทั้งหมดย้อนกลับไปรุ่นก่อนหน้าเรียบร้อยแล้ว"
+
+#~ msgid "Bookmarks"
+#~ msgstr "ที่คั่นหน้า"
+
+#~ msgid "Bookmark"
+#~ msgstr "ที่คั่นหน้า"
+
+#~ msgid "unchanged"
+#~ msgstr "ไม่เปลี่ยนแปลง"
+
+#~ msgid "ignored"
+#~ msgstr "ละเลย"
+
+#~ msgid "unknown"
+#~ msgstr "ไม่ทราบ"
+
+#~ msgid "Filename"
+#~ msgstr "ชื่อแฟ้ม"
+
+#~ msgid "Status"
+#~ msgstr "สถานะ"
+
+#~ msgid "Size"
+#~ msgstr "ขนาด"
+
+#~ msgid "Last modified"
+#~ msgstr "แก้ไขล่าสุด"
+
+#~ msgid ""
+#~ "Please select a file from the list,\n"
+#~ "or choose the other option."
+#~ msgstr ""
+#~ "โปรดเลือกแฟ้มจากรายการ\n"
+#~ "หรือเลือกตัวเลือกอื่น"
+
+#~ msgid "Title:"
+#~ msgstr "หัวข้อ:"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "โปรดระบุหัวข้อที่จะดำเนินการต่อ"
+
+#~ msgid "Add"
+#~ msgstr "เพิ่ม"
+
+#~ msgid "Add the selected file"
+#~ msgstr "เพิ่มแฟ้มที่เลือก"
+
+#~ msgid "Remove"
+#~ msgstr "ลบ"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "ลบแฟ้มที่เลือก"
+
+#~ msgid "Remove and delete"
+#~ msgstr "เอาออกและลบ"
+
+#~ msgid "Remove the selected file/dir and delete from disk"
+#~ msgstr "เอาแฟ้ม/ไดเรกทอรีออกและลบจากดิสก์"
+
+#~ msgid "Rename"
+#~ msgstr "เปลี่ยนชื่อ"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "เปลี่ยนชื่อแฟ้มที่เลือก"
+
+#~ msgid "Open"
+#~ msgstr "เปิด"
+
+#~ msgid "Open the selected file"
+#~ msgstr "เปิดแฟ้มที่เลือก"
+
+#~ msgid "Revert"
+#~ msgstr "ย้อนกลับ"
+
+#~ msgid "Revert the changes"
+#~ msgstr "ย้อนกลับการเปลี่ยนแปลง"
+
+#~ msgid "Commit the changes"
+#~ msgstr "ยืนยันการเปลี่ยนแปลง"
+
+#~ msgid "Annotate"
+#~ msgstr "หมายเหตุ"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "ใส่หมายเหตุแฟ้มที่เลือก"
+
+#~ msgid "Diff"
+#~ msgstr "เปรียบเทียบ"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "แสดงการเปรียบเทียบของแฟ้ม"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "คั่นหน้าตำแหน่งปัจจุบัน"
+
+#~ msgid "Edit"
+#~ msgstr "แก้ไข"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "แก้ไขที่คั่นหน้าที่เลือก"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "ลบที่คั่นหน้าที่เลือก"
+
+#~ msgid "Open Folder"
+#~ msgstr "เปิดโฟลเดอร์"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "เปิดโฟลเดอร์ที่คั่นหน้าใน Nautilus"
+
+#~ msgid "Selected..."
+#~ msgstr "เลือกแล้ว..."
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "แสดงความแตกต่างของแฟ้มที่เลือก"
+
+#~ msgid "All..."
+#~ msgstr "ทั้งหมด..."
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "แสดงความแตกต่างของแฟ้มทั้งหมด"
+
+#~ msgid "View contents"
+#~ msgstr "แสดงเนื้อหา"
+
+#~ msgid "View the contents of the file in a builtin viewer"
+#~ msgstr "แสดงเนื้อหาของแฟ้มในตัวดูที่มีให้"
+
+#~ msgid "Show differences"
+#~ msgstr "แสดงความแตกต่าง"
+
+#~ msgid "Show the differences between two revisions of the file"
+#~ msgstr "แสดงความแตกต่างของแฟ้มระหว่างสองรุ่น"
+
+#~ msgid "Revert to this revision"
+#~ msgstr "ย้อนกลับมาเป็นรุ่นนี้"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "ย้อนกลับแฟ้มที่เลือกมาเป็นรุ่นที่เลือก"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "ลบไดเรกทอรีรวมทั้งไดเรกทอรีทั้งหมดข้างล่าง ?"
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "เพิ่มที่คั่นหน้าสำเร็จแล้ว"
+
+#~ msgid ""
+#~ "The current directory was bookmarked. You can reach\n"
+#~ "it by selecting it from the left panel."
+#~ msgstr ""
+#~ "ไดเรกทอรีปัจจุบันได้คั่นหน้าไว้แล้ว คุณสามารถเข้าถึง\n"
+#~ "มันโดยการเลือกจากพาเนลซ้าย"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "คั่นหน้าตำแหน่งนี้แล้ว"
+
+#~ msgid ""
+#~ "The current directory is already bookmarked.\n"
+#~ "See the left panel for reference."
+#~ msgstr ""
+#~ "ไดเรกทอรีนี้เป็นที่คั่นหน้าแล้ว\n"
+#~ "ดูพาเนลซ้ายเพื่ออ้างถึง"
+
+#~ msgid "Please specify a desired name for the new directory."
+#~ msgstr "โปรดระบุชื่อที่ต้องการสำหรับไดเรกทอรีใหม่"
+
+#~ msgid "Directory already exists"
+#~ msgstr "ไดเรกทอรีมีแล้ว"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "โปรดระบุชื่ออื่นเพื่อทำต่อ"
+
+#~ msgid "Please select a file from the list to proceed."
+#~ msgstr "โปรดเลือกแฟ้มจากรายการเพื่อดำเนินการ"
+
+#~ msgid "Not the same branch"
+#~ msgstr "ไม่ใช่สาขาเดียวกัน"
+
+#~ msgid "The destination is not in the same branch."
+#~ msgstr "ปลายทางไม่ใช่สาขาเดียวกัน"
+
+#~ msgid "No matching files"
+#~ msgstr "ไม่มีแฟ้มที่ตรงกัน"
+
+#~ msgid "No added files were found in the working tree."
+#~ msgstr "ไม่พบแฟ้มที่เพิ่มในสายงาน"
+
+#~ msgid "Which file(s) do you want to remove?"
+#~ msgstr "แฟ้มใดที่คุณต้องการลบ?"
+
+#~ msgid "Selected only"
+#~ msgstr "เฉพาะที่เลือกแล้ว"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "แฟ้มทั้งหมดเป็นสถานะ 'เพิ่มแล้ว'"
+
+#~ msgid "_Remove"
+#~ msgstr "_ถอดถอน"
+
+#~ msgid "Please specify a new name for the file."
+#~ msgstr "โปรดระบุชื่อใหม่สำหรับแฟ้ม"
+
+#~ msgid "Olive - Bazaar GUI"
+#~ msgstr "Olive - Bazaar GUI"
+
+#~ msgid "_File"
+#~ msgstr "แ_ฟ้ม"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "เ_พิ่มแฟ้ม..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "ลบแฟ้ม..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "สร้างไ_ดเรกทอรี..."
+
+#~ msgid "_Rename..."
+#~ msgstr "เ_ปลี่ยนชื่อ..."
+
+#~ msgid "_Move..."
+#~ msgstr "_ย้าย"
+
+#~ msgid "_Annotate..."
+#~ msgstr "_หมายเหตุ..."
+
+#~ msgid "Show _hidden files"
+#~ msgstr "แสดงแฟ้ม_ซ่อน"
+
+#~ msgid "_Refresh"
+#~ msgstr "เ_รียกใหม่"
+
+#~ msgid "Pu_ll"
+#~ msgstr "_ดึง"
+
+#~ msgid "Pu_sh..."
+#~ msgstr "_ส่ง..."
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_ย้อนกลับการเปลี่ยนแปลงทั้งหมด"
+
+#~ msgid "_Merge..."
+#~ msgstr "_รวม..."
+
+#~ msgid "_Commit..."
+#~ msgstr "_ยืนยัน..."
+
+#~ msgid "Ta_gs..."
+#~ msgstr "_ป้าย..."
+
+#~ msgid "S_tatus..."
+#~ msgstr "_สถานะ..."
+
+#~ msgid "Con_flicts..."
+#~ msgstr "_ขัดแย้ง..."
+
+#~ msgid "_Statistics"
+#~ msgstr "ส_ถิติ"
+
+#~ msgid "_Differences..."
+#~ msgstr "ความแ_ตกต่าง..."
+
+#~ msgid "_Log..."
+#~ msgstr "_ปูม..."
+
+#~ msgid "_Information..."
+#~ msgstr "_ข้อมูล..."
+
+#~ msgid "_Help"
+#~ msgstr "_วิธีใช้"
+
+#~ msgid "gtk-jump-to"
+#~ msgstr "gtk-jump-to"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "ลิขสิทธิ์ (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Sira Nokyoongtong (http://launchpad.net/~gumara)\n"
+#~ "\n"
+#~ "Launchpad Contributions:\n"
+#~ "  SiraNokyoongtong https://launchpad.net/~gumara"
+
+#~ msgid "Olive - Add file(s)"
+#~ msgstr "Olive - เพิ่มแฟ้ม"
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "แฟ้มใดที่คุณต้องการจะเพิ่ม?"
+
+#~ msgid "_Add"
+#~ msgstr "เ_พิ่ม"
+
+#~ msgid "Olive - Remove file(s)"
+#~ msgstr "Olive - ถอดถอนแฟ้ม"
+
+#~ msgid "Olive - Make directory"
+#~ msgstr "Olive - สร้างไดเรกทอรี"
+
+#~ msgid "_Make directory"
+#~ msgstr "สร้างไ_ดเรกทอรี"
+
+#~ msgid "Olive - Move"
+#~ msgstr "Olive - ย้าย"
+
+#~ msgid "Move to"
+#~ msgstr "ย้ายไปยัง"
+
+#~ msgid "Select a directory"
+#~ msgstr "เลือกไดเรกทอรี"
+
+#~ msgid "_Move"
+#~ msgstr "_ย้าย"
+
+#~ msgid "Olive - Rename"
+#~ msgstr "Olive - เปลี่ยนชื่อ"
+
+#~ msgid "Rename to"
+#~ msgstr "เปลี่ยนชื่อเป็น"
+
+#~ msgid "_Rename"
+#~ msgstr "เ_ปลี่ยนชื่อ"
+
+#~ msgid "Olive - Information"
+#~ msgstr "Olive - ข้อมูล"
+
+#~ msgid "(none)"
+#~ msgstr "(ไม่มี)"
+
+#~ msgid "Branch root: "
+#~ msgstr "รากสาขา: "
+
+#~ msgid "Repository branch: "
+#~ msgstr "สาขาคลัง: "
+
+#~ msgid "Shared repository: "
+#~ msgstr "คลังที่แบ่งปัน: "
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>ตำแหน่ง:</b>"
+
+#~ msgid "Publish to branch: "
+#~ msgstr "เผยแพร่สาขา: "
+
+#~ msgid "<b>Related branches:</b>"
+#~ msgstr "<b>สาขาที่เกี่ยวข้อง:</b>"
+
+#~ msgid "Repository format: "
+#~ msgstr "รูปแบบคลัง: "
+
+#~ msgid "Branch format: "
+#~ msgstr "รูปแบบสาขา: "
+
+#~ msgid "Working tree format: "
+#~ msgstr "รูปแบบสายงาน: "
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>รูปแบบ:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "สถานะการล็อคคลัง: "
+
+#~ msgid "Branch lock status: "
+#~ msgstr "สถานะการล็อคสาขา: "
+
+#~ msgid "Working tree lock status: "
+#~ msgstr "สถานะการล็อคสายงาน: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>สถานะการล็อค:</b>"
+
+#~ msgid "Ignored files: "
+#~ msgstr "แฟ้มที่เพิกเฉยแล้ว: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "แฟ้มที่ไม่รู้จัก: "
+
+#~ msgid "Renamed files: "
+#~ msgstr "แฟ้มที่เปลี่ยนชื่อแล้ว: "
+
+#~ msgid "Removed files: "
+#~ msgstr "แฟ้มที่ถอดถอนแล้ว: "
+
+#~ msgid "Added files: "
+#~ msgstr "แฟ้มที่เพิ่มแล้ว: "
+
+#~ msgid "Modified files: "
+#~ msgstr "แฟ้มที่แก้ไขแล้ว: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "แฟ้มที่ยังไม่เปลี่ยนแปลง: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>ในสายงาน:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "เวลาของรุ่นล่าสุด: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "เวลาของรุ่นแรก: "
+
+#~ msgid "Age of branch in days: "
+#~ msgstr "อายุของสาขา: "
+
+#~ msgid "Number of commiters: "
+#~ msgstr "จำนวนของผู้ยืนยัน: "
+
+#~ msgid "Revisions in branch: "
+#~ msgstr "รุ่นในสาขา: "
+
+#~ msgid "<b>Branch history:</b>"
+#~ msgstr "<b>ประวัติสาขา:</b>"
+
+#~ msgid "Size of repository: "
+#~ msgstr "ขนาดของคลัง: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "รุ่นในคลัง: "
+
+#~ msgid "Merge - Olive"
+#~ msgstr "ผสาน - Olive"
+
+#~ msgid "Merge from:"
+#~ msgstr "ผสานจาก:"
+
+#~ msgid "_Bookmark current directory"
+#~ msgstr "_คั่นหน้าไดเรกทอรีปัจจุบัน"
+
+#~ msgid "Show _ignored files"
+#~ msgstr "แสดงแฟ้มที่เ_พิกเฉยแล้ว"
+
+#~ msgid "Update"
+#~ msgstr "อัปเดท"
+
+#~ msgid "Please wait, loading ancestral graph..."
+#~ msgstr "โปรดรอ กำลังโหลดกราฟ"
+
+#~ msgid "Lead Developer:"
+#~ msgstr "หัวหน้านักพัฒนา:"
+
+#~ msgid "Contributors:"
+#~ msgstr "ผู้ร่วมสนับสนุน:"
+
+#~ msgid "Update successful but conflicts generated"
+#~ msgstr "อัปเดทเรียบร้อยแต่มีความขัดแย้ง"
+
+#~ msgid "Number of conflicts generated: %d."
+#~ msgstr "จำนวนของความขัดแย้ง: %d"
+
+#~ msgid "Update successful"
+#~ msgstr "อัปเดทเรียบร้อย"
+
+#~ msgid "No conflicts generated."
+#~ msgstr "ไม่มีความขัดแย้ง"

=== modified file 'po/tr.po'
--- po/tr.po	2011-12-02 05:55:20 +0000
+++ po/tr.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:57+0000\n"
-"Last-Translator: Rail Aliiev <rail@iqchoice.com>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:34+0000\n"
+"Last-Translator: Rail Aliev <rail@iqchoice.com>\n"
 "Language-Team: Turkish <tr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Hedef:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr ""
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Lütfen bir dizin seçin"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr ""
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr ""
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr ""
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "İşlem iptal edildi."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "eklendi"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "silindi"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr ""
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr ""
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "değiştirildi"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr ""
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr ""
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr ""
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr ""
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Tarih"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Özet"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Çelişenler"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr ""
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr ""
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr ""
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr ""
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "kopya"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr "_Görünüm"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr "Hedef zaten mevcut"
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "İzin verilmedi"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Bilinmeyen hata"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Birleştir"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Konum:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Seç"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,160 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Etiket İsmi"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "Time"
+#~ msgstr "Zaman"
+
+#~ msgid "unchanged"
+#~ msgstr "değiştirilmemiş"
+
+#~ msgid "Bookmark"
+#~ msgstr "Yer imi"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Yer İmleri"
+
+#~ msgid "ignored"
+#~ msgstr "yoksayıldı"
+
+#~ msgid "unknown"
+#~ msgstr "bilinmiyor"
+
+#~ msgid "Status"
+#~ msgstr "Durum"
+
+#~ msgid "Filename"
+#~ msgstr "Dosya ismi"
+
+#~ msgid "Size"
+#~ msgstr "Boyut"
+
+#~ msgid "Title:"
+#~ msgstr "Başlık:"
+
+#~ msgid "Last modified"
+#~ msgstr "Değiştirilme zamanı"
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Seçilen dosyanın adını değiştir"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Seçili dosyaları aç"
+
+#~ msgid "Add"
+#~ msgstr "Ekle"
+
+#~ msgid "Rename"
+#~ msgstr "Yeniden adlandır"
+
+#~ msgid "Open"
+#~ msgstr "Aç"
+
+#~ msgid "Remove"
+#~ msgstr "Kaldır"
+
+#~ msgid "Annotate"
+#~ msgstr "Notlar"
+
+#~ msgid "Edit"
+#~ msgstr "Düzenle"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Seçili yer imini sil"
+
+#~ msgid "Open Folder"
+#~ msgstr "Dizin aç"
+
+#~ msgid "_Move..."
+#~ msgstr "_Taşı..."
+
+#~ msgid "_Remove"
+#~ msgstr "_Sil"
+
+#~ msgid "_Rename..."
+#~ msgstr "_Yeniden Adlandır..."
+
+#~ msgid "_File"
+#~ msgstr "_Dosya"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "_Gizli dosyaları göster"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Tazele"
+
+#~ msgid "_Statistics"
+#~ msgstr "_İstatistikler"
+
+#~ msgid "_Help"
+#~ msgstr "_Yardım"
+
+#~ msgid "_Add"
+#~ msgstr "_Ekle"
+
+#~ msgid "Rename to"
+#~ msgstr "Yeniden adlandır"
+
+#~ msgid "_Move"
+#~ msgstr "_Taşı"
+
+#~ msgid "Select a directory"
+#~ msgstr "Bir dizin seçin"
+
+#~ msgid "(none)"
+#~ msgstr "(hiçbiri)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Yeniden Adlandır"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Biçim:</b>"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Konum:</b>"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Rail Aliev https://launchpad.net/~rail"

=== modified file 'po/uk.po'
--- po/uk.po	2011-12-02 05:55:20 +0000
+++ po/uk.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:59+0000\n"
-"Last-Translator: Jelmer Vernooij <Unknown>\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2009-11-18 06:36+0000\n"
+"Last-Translator: kosha <Unknown>\n"
 "Language-Team: Ukrainian <uk@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr ""
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr ""
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "Призначення:"
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "Модифікація:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "Будь ласка, виберіть теку"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr ""
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr ""
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr ""
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "ВІДСУТНЬО"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "Прийняти зміни"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "Легко прийняти зміни"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr "Директорія не має робочого дерева"
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "Дію перервано."
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "додано"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "видалено"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "змінена назва"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "змінена назва та внесені зміни"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "змінено"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "Підтвердити"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "Фіксація"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "Шлях"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "Тип"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "Дата"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr ""
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "Підсумок"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr "Підтвердити з пустим повідомленням?"
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr ""
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr "Зовнішні утиліти."
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "Конфлікти"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "Не має конфліктів у робочому дереві."
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "шлях конфлікту"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "зміст конфлікту"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "текст конфлікту"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr "повторення мітки"
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "повторення"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr "конфлікт невідомого типу"
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr "Не вибрано файлу"
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr "Виберіть файл з переліку."
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr "Помилка під час виклику зовнішньої утиліти."
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr "Не можливо розвязати конфлікт"
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -349,178 +349,178 @@
 msgid "_View"
 msgstr "_Погляд"
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr "Обєднано вдало"
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr "Всі зміни вдало прийняті."
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr "Директорія не звірена"
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr "Відсутні зміни для фіксації"
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr "Конфлікт у дереві"
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr "%s"
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr "Обраний файл не змінено."
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr "Невідома помилка bzr"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr "Доступ заборонено"
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr "доступ заборонено"
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr "Невідома помилка"
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr "Поточна директорія"
 
@@ -528,119 +528,79 @@
 msgid "Create a new directory with the name:"
 msgstr "Створити нову директорію під назвою:"
 
-#: ../initialize.py:87
+#: ../initialize.py:86
 msgid "Directory name not specified"
 msgstr "Назва директорії не унікальна"
 
-#: ../initialize.py:88
+#: ../initialize.py:87
 msgid "You should specify a new directory name."
 msgstr "Ви повинні вказати назву нової директорії"
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr "_Об'єднати"
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr "Помилка Bazaar"
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr "Розташування:"
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr "Не існує батьківської директорії"
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -648,11 +608,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr "_Вибрати"
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -660,32 +620,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr "Додано"
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr "Видалено"
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr "Назва змінена"
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr "Змінено"
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr "Невідомо"
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr "Без змін."
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr "Мітки"
 
@@ -697,44 +657,352 @@
 msgid "Revision ID"
 msgstr "Версія ID"
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr "Видалення мітки"
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr "<b><big>Видалити мітку?</big></b>"
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr "Ви впевнені, що хочете видалити мітку: <b>%s</b>?"
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr "Додати мітку"
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr "Назва мітки:"
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr "Версія ID:"
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr "Не вказана назва мітки"
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "Time"
+#~ msgstr "Час"
+
+#~ msgid "unchanged"
+#~ msgstr "без змін"
+
+#~ msgid "Bookmark"
+#~ msgstr "Закладка"
+
+#~ msgid "Bookmarks"
+#~ msgstr "Закладки"
+
+#~ msgid "ignored"
+#~ msgstr "ігнорується"
+
+#~ msgid "unknown"
+#~ msgstr "невідомо"
+
+#~ msgid "Last modified"
+#~ msgstr "Востаннє змінено"
+
+#~ msgid "Status"
+#~ msgstr "Стан"
+
+#~ msgid "Filename"
+#~ msgstr "Назва файлу"
+
+#~ msgid "Size"
+#~ msgstr "Розмір"
+
+#~ msgid "Title:"
+#~ msgstr "Назва:"
+
+#~ msgid "Add"
+#~ msgstr "Додати"
+
+#~ msgid "Open"
+#~ msgstr "Відкрити"
+
+#~ msgid "Open the selected file"
+#~ msgstr "Відкрити вибраний файл"
+
+#~ msgid "Remove"
+#~ msgstr "Видалити"
+
+#~ msgid "Revert"
+#~ msgstr "Повернути"
+
+#~ msgid "Open Folder"
+#~ msgstr "Відкрити теку"
+
+#~ msgid "_Move..."
+#~ msgstr "П_еремістити..."
+
+#~ msgid "_Remove"
+#~ msgstr "_Видалити"
+
+#~ msgid "_File"
+#~ msgstr "_Файл"
+
+#~ msgid "_Refresh"
+#~ msgstr "_Оновити"
+
+#~ msgid "Show _hidden files"
+#~ msgstr "Показувати при_ховані файли"
+
+#~ msgid "_Statistics"
+#~ msgstr "_Статистика"
+
+#~ msgid "_Help"
+#~ msgstr "_Допомога"
+
+#~ msgid "_Add"
+#~ msgstr "_Додати"
+
+#~ msgid "(none)"
+#~ msgstr "(жоден)"
+
+#~ msgid "_Rename"
+#~ msgstr "_Перейменувати"
+
+#~ msgid "<b>Format:</b>"
+#~ msgstr "<b>Формат:</b>"
+
+#~ msgid "Add the selected file"
+#~ msgstr "Додати обрані файли"
+
+#~ msgid "Remove and delete"
+#~ msgstr "Перемістити та видалити"
+
+#~ msgid "Diff"
+#~ msgstr "Відмінність"
+
+#~ msgid "Show the diff of the file"
+#~ msgstr "Показати відмінність файлу"
+
+#~ msgid "Remove the selected file"
+#~ msgstr "Перемістити обрані файли"
+
+#~ msgid "Commit the changes"
+#~ msgstr "Прийняти зміни"
+
+#~ msgid "Show differences"
+#~ msgstr "Показати відмінності"
+
+#~ msgid "All..."
+#~ msgstr "Все..."
+
+#~ msgid "View contents"
+#~ msgstr "Перегляд змісту"
+
+#~ msgid "Selected..."
+#~ msgstr "Обираємо..."
+
+#~ msgid "Bookmark successfully added"
+#~ msgstr "Закладка додана"
+
+#~ msgid "All files with status 'added'"
+#~ msgstr "Всі файли зі статусом 'додати'"
+
+#~ msgid "Directory already exists"
+#~ msgstr "Директорія існує"
+
+#~ msgid "Selected only"
+#~ msgstr "Тільки обрати"
+
+#~ msgid "_Initialize..."
+#~ msgstr "Запуск..."
+
+#~ msgid "Remove file(s)..."
+#~ msgstr "Перемістити файл(и)"
+
+#~ msgid "_Add file(s)..."
+#~ msgstr "Додати файл(и)"
+
+#~ msgid "S_tatus..."
+#~ msgstr "Стан"
+
+#~ msgid "https://launchpad.net/products/olive"
+#~ msgstr "https://launchpad.net/products/olive"
+
+#~ msgid "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+#~ msgstr "Copyright (C) 2006 Szilveszter Farkas (Phanatic)"
+
+#~ msgid "_Information..."
+#~ msgstr "Інформація"
+
+#~ msgid "Move to"
+#~ msgstr "Перемістити до"
+
+#~ msgid "Repository format: "
+#~ msgstr "Формат сховища: "
+
+#~ msgid "<b>Lock status:</b>"
+#~ msgstr "<b>Стан блокування:</b>"
+
+#~ msgid "Repository lock status: "
+#~ msgstr "Стан блокування сховища: "
+
+#~ msgid "Unknown files: "
+#~ msgstr "Невідомі файли: "
+
+#~ msgid "Unchanged files: "
+#~ msgstr "Незмінені файли: "
+
+#~ msgid "Modified files: "
+#~ msgstr "Змінені файли: "
+
+#~ msgid "Added files: "
+#~ msgstr "Додані файли: "
+
+#~ msgid "Size of repository: "
+#~ msgstr "Розмір сховища: "
+
+#~ msgid "Revisions in repository: "
+#~ msgstr "Версія у сховищі: "
+
+#~ msgid "Commit message:"
+#~ msgstr "Підтвердження:"
+
+#~ msgid "Pending merges"
+#~ msgstr "До обєднання"
+
+#~ msgid "Revno"
+#~ msgstr "Revno"
+
+#~ msgid "Conflicts detected"
+#~ msgstr "Визначено конфлікт"
+
+#~ msgid "Please specify a title to continue."
+#~ msgstr "Будь ласка, вкажіть назву для продовження."
+
+#~ msgid "Rename the selected file"
+#~ msgstr "Змінити назву обраним файлам"
+
+#~ msgid "Rename"
+#~ msgstr "Змінити назву"
+
+#~ msgid "Annotate the selected file"
+#~ msgstr "Аннотація обраного файлу"
+
+#~ msgid "Revert the changes"
+#~ msgstr "Повернути зміни"
+
+#~ msgid "Annotate"
+#~ msgstr "Аннотація"
+
+#~ msgid "Bookmark current location"
+#~ msgstr "Закладка поточної позиції"
+
+#~ msgid "Edit"
+#~ msgstr "Редагувати"
+
+#~ msgid "Edit the selected bookmark"
+#~ msgstr "Редагувати обрану закладку"
+
+#~ msgid "Open bookmark folder in Nautilus"
+#~ msgstr "Відкрити закладку теки у Наутілусі"
+
+#~ msgid "Show the differences of all files"
+#~ msgstr "Показати різницю у всіх файлах"
+
+#~ msgid "Show the differences of the selected file"
+#~ msgstr "Показати різницю у обраних файлах"
+
+#~ msgid "Remove the selected bookmark"
+#~ msgstr "Видалити обрану закладку"
+
+#~ msgid "Location already bookmarked"
+#~ msgstr "Позиція закладена"
+
+#~ msgid "Revert the selected file to the selected revision"
+#~ msgstr "Повернути попередню версію обраного файлу"
+
+#~ msgid "Delete directory with all directories below ?"
+#~ msgstr "Видалити директорію зі всіма підпорядкованими директоріями?"
+
+#~ msgid "Please specify another name to continue."
+#~ msgstr "Будь ласка, оберіть іншу назву для продовження."
+
+#~ msgid "_Rename..."
+#~ msgstr "Зміна назви..."
+
+#~ msgid "Make _directory..."
+#~ msgstr "Створення директорії..."
+
+#~ msgid "_Get..."
+#~ msgstr "Взяти..."
+
+#~ msgid "_Annotate..."
+#~ msgstr "Аннотація"
+
+#~ msgid "_Revert all changes"
+#~ msgstr "_Повернути зміни"
+
+#~ msgid "C_heckout..."
+#~ msgstr "Звірити..."
+
+#~ msgid "_Merge..."
+#~ msgstr "_Обєднати"
+
+#~ msgid "Con_flicts..."
+#~ msgstr "Конфлікти..."
+
+#~ msgid "Which file(s) do you want to add?"
+#~ msgstr "Які файл(и) Ви хочете додати?"
+
+#~ msgid "Rename to"
+#~ msgstr "Змінити назву на"
+
+#~ msgid "_Move"
+#~ msgstr "Перем_істити"
+
+#~ msgid "Select a directory"
+#~ msgstr "Вибрати директорію"
+
+#~ msgid "<b>Location:</b>"
+#~ msgstr "<b>Позиція:</b>"
+
+#~ msgid "Renamed files: "
+#~ msgstr "Змінити назву файлів: "
+
+#~ msgid "Ignored files: "
+#~ msgstr "Ігнорувати файли: "
+
+#~ msgid "Removed files: "
+#~ msgstr "Перемістити файли: "
+
+#~ msgid "<b>In the working tree:</b>"
+#~ msgstr "<b>В робоче дерево:</b>"
+
+#~ msgid "Time of last revision: "
+#~ msgstr "Час останньої версії: "
+
+#~ msgid "Time of first revision: "
+#~ msgstr "Час першої версії: "
+
+#~ msgid "<b>Revision store:</b>"
+#~ msgstr "<b>Історія версій:</b>"
+
+#~ msgid "Merge from:"
+#~ msgstr "Обєднати из:"
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  kosha https://launchpad.net/~o-kornyeyev"

=== modified file 'po/zh_CN.po'
--- po/zh_CN.po	2011-12-02 05:55:20 +0000
+++ po/zh_CN.po	2011-03-08 04:41:48 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: bzr-gtk\n"
 "Report-Msgid-Bugs-To: FULL NAME <EMAIL@ADDRESS>\n"
-"POT-Creation-Date: 2011-12-01 11:46+0100\n"
-"PO-Revision-Date: 2011-11-30 22:58+0000\n"
+"POT-Creation-Date: 2011-03-06 02:19+0100\n"
+"PO-Revision-Date: 2010-03-17 09:03+0000\n"
 "Last-Translator: Eleanor Chen <chenyueg@gmail.com>\n"
 "Language-Team: Simplified Chinese <zh_CN@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
-"X-Launchpad-Export-Date: 2011-12-02 05:55+0000\n"
-"X-Generator: Launchpad (build 14414)\n"
+"X-Launchpad-Export-Date: 2011-03-08 04:41+0000\n"
+"X-Generator: Launchpad (build 12351)\n"
 
 #: ../bazaar-properties.desktop.in.h:1
 msgid "Bazaar Preferences"
@@ -42,165 +42,165 @@
 msgstr ""
 
 #. Create the widgets
-#: ../branch.py:46
+#: ../branch.py:52
 msgid "_Branch"
 msgstr "分支(_B)"
 
-#: ../branch.py:49 ../checkout.py:49
+#: ../branch.py:55 ../checkout.py:55
 msgid "Branch location:"
 msgstr "分支位置："
 
-#: ../branch.py:51 ../checkout.py:50
+#: ../branch.py:57 ../checkout.py:56
 msgid "Destination:"
 msgstr "目标："
 
-#: ../branch.py:52
+#: ../branch.py:58
 msgid "Branck nick:"
 msgstr ""
 
-#: ../branch.py:53 ../checkout.py:52
+#: ../branch.py:59 ../checkout.py:58
 msgid "Revision:"
 msgstr "修订版本:"
 
-#: ../branch.py:54 ../checkout.py:47
+#: ../branch.py:60 ../checkout.py:53
 msgid "Please select a folder"
 msgstr "请选择一个文件夹"
 
-#: ../branch.py:134 ../checkout.py:153
+#: ../branch.py:140 ../checkout.py:159
 msgid "Missing branch location"
 msgstr "缺少分支地址"
 
-#: ../branch.py:135 ../checkout.py:154
+#: ../branch.py:141 ../checkout.py:160
 msgid "You must specify a branch location."
 msgstr "你必须指定一个分支地址"
 
-#: ../branch.py:174
+#: ../branch.py:182
 msgid "Branching successful"
 msgstr "创建分支成功"
 
-#: ../branch.py:175
+#: ../branch.py:183
 #, python-format
 msgid "%d revision(s) branched."
 msgstr ""
 
-#: ../branch.py:183 ../checkout.py:185
+#: ../branch.py:191 ../checkout.py:191
 msgid "N/A"
 msgstr "N/A"
 
 #. Create the widgets
-#: ../checkout.py:44
+#: ../checkout.py:50
 msgid "Check_out"
 msgstr "签出(_O)"
 
-#: ../checkout.py:51
+#: ../checkout.py:57
 msgid "Branch nick:"
 msgstr ""
 
-#: ../checkout.py:56
+#: ../checkout.py:62
 msgid "_Lightweight checkout"
 msgstr "轻量级签出(_L)"
 
-#: ../commands.py:305
+#: ../commands.py:307
 msgid "Directory does not have a working tree"
 msgstr ""
 
-#: ../commands.py:306
+#: ../commands.py:308
 msgid "Operation aborted."
 msgstr "操作中止。"
 
-#: ../commands.py:410
+#: ../commands.py:412
 msgid "There are local changes in the branch"
 msgstr ""
 
-#: ../commands.py:411
+#: ../commands.py:413
 msgid "Please commit or revert the changes before merging."
 msgstr ""
 
-#: ../commit.py:178
+#: ../commit.py:182
 msgid "added"
 msgstr "已添加"
 
-#: ../commit.py:179
+#: ../commit.py:183
 msgid "removed"
 msgstr "已移除"
 
-#: ../commit.py:180
+#: ../commit.py:184
 msgid "renamed"
 msgstr "已重命名"
 
-#: ../commit.py:181
+#: ../commit.py:185
 msgid "renamed and modified"
 msgstr "已重命名并且已修改"
 
-#: ../commit.py:182
+#: ../commit.py:186
 msgid "modified"
 msgstr "已修改"
 
-#: ../commit.py:183
+#: ../commit.py:187
 msgid "kind changed"
 msgstr ""
 
-#: ../commit.py:276
+#: ../commit.py:280
 msgid "<b>Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:329
+#: ../commit.py:333
 msgid "_Only commit locally"
 msgstr ""
 
-#: ../commit.py:361
+#: ../commit.py:364
 msgid "Comm_it"
 msgstr "提交(_I)"
 
-#: ../commit.py:388
+#: ../commit.py:390
 msgid "Files"
 msgstr ""
 
-#: ../commit.py:393
+#: ../commit.py:395
 msgid "Commit all changes"
 msgstr ""
 
-#: ../commit.py:399
+#: ../commit.py:401
 msgid "Only commit selected changes"
 msgstr ""
 
-#: ../commit.py:405
+#: ../commit.py:407
 msgid "Commit all changes*"
 msgstr ""
 
-#: ../commit.py:437
+#: ../commit.py:440
 msgid "Commit*"
 msgstr ""
 
-#: ../commit.py:439
+#: ../commit.py:442
 msgid "Commit"
 msgstr "提交"
 
-#: ../commit.py:443 ../conflicts.py:107
+#: ../commit.py:446 ../conflicts.py:111
 msgid "Path"
 msgstr "路径"
 
-#: ../commit.py:445 ../conflicts.py:109
+#: ../commit.py:448 ../conflicts.py:113
 msgid "Type"
 msgstr "类型"
 
-#: ../commit.py:478
+#: ../commit.py:481
 msgid "<i>* Cannot select specific files when merging</i>"
 msgstr ""
 
-#: ../commit.py:482
+#: ../commit.py:485
 msgid "Pending Revisions"
 msgstr ""
 
-#: ../commit.py:503
+#: ../commit.py:507
 msgid "Date"
 msgstr "日期"
 
-#: ../commit.py:505
+#: ../commit.py:509
 msgid "Committer"
 msgstr "提交者"
 
-#: ../commit.py:507 ../search.py:60
+#: ../commit.py:511 ../search.py:59
 msgid "Summary"
 msgstr "概要"
 
@@ -208,133 +208,133 @@
 #. decide that we really don't ever want to display it, we should
 #. actually remove it, and other references to it, along with the
 #. tests that it is set properly.
-#: ../commit.py:517
+#: ../commit.py:521
 msgid "Diff for whole tree"
 msgstr ""
 
 #. Whole tree
-#: ../commit.py:542 ../commit.py:626
+#: ../commit.py:545 ../commit.py:628
 msgid "File commit message"
 msgstr ""
 
-#: ../commit.py:549
+#: ../commit.py:552
 msgid "Global Commit Message"
 msgstr ""
 
-#: ../commit.py:551
+#: ../commit.py:554
 msgid "<b>Global Commit Message</b>"
 msgstr ""
 
-#: ../commit.py:578
+#: ../commit.py:581
 msgid "Diff for "
 msgstr ""
 
-#: ../commit.py:632
+#: ../commit.py:634
 msgid "Commit message for "
 msgstr ""
 
-#: ../commit.py:687
+#: ../commit.py:689
 msgid "Commit cancelled"
 msgstr ""
 
-#: ../commit.py:688
+#: ../commit.py:690
 msgid "Do you want to save your commit messages ?"
 msgstr ""
 
-#: ../commit.py:706
+#: ../commit.py:708
 msgid "Commit with an empty message?"
 msgstr ""
 
-#: ../commit.py:707
+#: ../commit.py:709
 msgid "You can describe your commit intent in the message."
 msgstr ""
 
-#: ../commit.py:727
+#: ../commit.py:729
 msgid "Commit with unknowns?"
 msgstr ""
 
-#: ../commit.py:728
+#: ../commit.py:730
 msgid "Unknown files exist in the working tree. Commit anyway?"
 msgstr ""
 
-#: ../commit.py:748
+#: ../commit.py:750
 msgid "Commit with no changes?"
 msgstr "没有更改仍然要提交吗？"
 
-#: ../commit.py:749
+#: ../commit.py:751
 msgid ""
 "There are no changes in the working tree. Do you want to commit anyway?"
 msgstr ""
 
-#: ../conflicts.py:45
+#: ../conflicts.py:50
 msgid "External utility:"
 msgstr ""
 
-#: ../conflicts.py:97
+#: ../conflicts.py:101
 msgid "Conflicts"
 msgstr "冲突"
 
-#: ../conflicts.py:100
+#: ../conflicts.py:104
 msgid "No conflicts in working tree."
 msgstr "工作树中没有冲突。"
 
-#: ../conflicts.py:114
+#: ../conflicts.py:118
 msgid "path conflict"
 msgstr "路径冲突"
 
-#: ../conflicts.py:116
+#: ../conflicts.py:120
 msgid "contents conflict"
 msgstr "内容冲突"
 
-#: ../conflicts.py:118
+#: ../conflicts.py:122
 msgid "text conflict"
 msgstr "文本冲突"
 
-#: ../conflicts.py:120
+#: ../conflicts.py:124
 msgid "duplicate id"
 msgstr ""
 
-#: ../conflicts.py:122
+#: ../conflicts.py:126
 msgid "duplicate"
 msgstr "复制"
 
-#: ../conflicts.py:124
+#: ../conflicts.py:128
 msgid "parent loop"
 msgstr ""
 
-#: ../conflicts.py:126
+#: ../conflicts.py:130
 msgid "unversioned parent"
 msgstr ""
 
-#: ../conflicts.py:128
+#: ../conflicts.py:132
 msgid "missing parent"
 msgstr ""
 
-#: ../conflicts.py:130
+#: ../conflicts.py:134
 msgid "deleting parent"
 msgstr ""
 
-#: ../conflicts.py:132
+#: ../conflicts.py:136
 msgid "unknown type of conflict"
 msgstr ""
 
-#: ../conflicts.py:161
+#: ../conflicts.py:165
 msgid "No file was selected"
 msgstr ""
 
-#: ../conflicts.py:162
+#: ../conflicts.py:166
 msgid "Please select a file from the list."
 msgstr ""
 
-#: ../conflicts.py:172
+#: ../conflicts.py:176
 msgid "Call to external utility failed"
 msgstr ""
 
-#: ../conflicts.py:174
+#: ../conflicts.py:178
 msgid "Cannot resolve conflict"
 msgstr ""
 
-#: ../conflicts.py:175
+#: ../conflicts.py:179
 msgid ""
 "Only conflicts on the text of files can be resolved with Olive at the "
 "moment. Content conflicts, on the structure of the tree, need to be resolved "
@@ -346,178 +346,178 @@
 msgid "_View"
 msgstr ""
 
-#: ../diff.py:448
+#: ../diff.py:447
 msgid "Wrap _Long Lines"
 msgstr ""
 
 #. No conflicts found.
-#: ../diff.py:493 ../merge.py:144
+#: ../diff.py:492 ../merge.py:146
 msgid "Merge successful"
 msgstr ""
 
-#: ../diff.py:494 ../merge.py:145
+#: ../diff.py:493 ../merge.py:147
 msgid "All changes applied successfully."
 msgstr ""
 
 #. There are conflicts to be resolved.
-#: ../diff.py:497 ../merge.py:148
+#: ../diff.py:496 ../merge.py:150
 msgid "Conflicts encountered"
 msgstr ""
 
-#: ../diff.py:498 ../merge.py:149
+#: ../diff.py:497 ../merge.py:151
 msgid "Please resolve the conflicts manually before committing."
 msgstr ""
 
-#: ../errors.py:31
+#: ../errors.py:28
 msgid "Directory is not a branch"
 msgstr ""
 
-#: ../errors.py:32
+#: ../errors.py:29
 msgid "You can perform this action only in a branch."
 msgstr ""
 
-#: ../errors.py:34
+#: ../errors.py:31
 msgid "Directory is not a checkout"
 msgstr ""
 
-#: ../errors.py:35
+#: ../errors.py:32
 msgid "You can perform local commit only on checkouts."
 msgstr ""
 
-#: ../errors.py:37
+#: ../errors.py:34
 msgid "No changes to commit"
 msgstr ""
 
-#: ../errors.py:38
+#: ../errors.py:35
 msgid "Try force commit if you want to commit anyway."
 msgstr ""
 
-#: ../errors.py:40
+#: ../errors.py:37
 msgid "No changes to merge"
 msgstr ""
 
-#: ../errors.py:41
+#: ../errors.py:38
 msgid "Merge location is already fully merged in working tree."
 msgstr ""
 
-#: ../errors.py:43
+#: ../errors.py:40
 msgid "Conflicts in tree"
 msgstr ""
 
-#: ../errors.py:44
+#: ../errors.py:41
 msgid "You need to resolve the conflicts before committing."
 msgstr ""
 
-#: ../errors.py:46
+#: ../errors.py:43
 msgid "Strict commit failed"
 msgstr ""
 
-#: ../errors.py:47
+#: ../errors.py:44
 msgid ""
 "There are unknown files in the working tree.\n"
 "Please add or delete them."
 msgstr ""
 
-#: ../errors.py:49
+#: ../errors.py:46
 msgid "Bound branch is out of date"
 msgstr ""
 
 #. FIXME: Really ? Internationalizing %s ?? --vila080505
-#: ../errors.py:51
+#: ../errors.py:48
 #, python-format
 msgid "%s"
 msgstr ""
 
-#: ../errors.py:53
+#: ../errors.py:50
 msgid "File not versioned"
 msgstr ""
 
-#: ../errors.py:54
+#: ../errors.py:51
 msgid "The selected file is not versioned."
 msgstr ""
 
-#: ../errors.py:56 ../push.py:100
+#: ../errors.py:53 ../push.py:99
 msgid "Branches have been diverged"
 msgstr ""
 
-#: ../errors.py:57
+#: ../errors.py:54
 msgid ""
 "You cannot push if branches have diverged. Use the\n"
 "overwrite option if you want to push anyway."
 msgstr ""
 
-#: ../errors.py:59
+#: ../errors.py:56
 msgid "No diff output"
 msgstr ""
 
-#: ../errors.py:60
+#: ../errors.py:57
 msgid "The selected file hasn't changed."
 msgstr ""
 
-#: ../errors.py:62
+#: ../errors.py:59
 msgid "No such revision"
 msgstr ""
 
-#: ../errors.py:63
+#: ../errors.py:60
 msgid "The revision you specified doesn't exist."
 msgstr ""
 
-#: ../errors.py:65
+#: ../errors.py:62
 msgid "Target already exists"
 msgstr ""
 
-#: ../errors.py:66
+#: ../errors.py:63
 msgid "Target directory already exists. Please select another target."
 msgstr ""
 
-#: ../errors.py:68
+#: ../errors.py:65
 msgid "Directory is already a branch"
 msgstr ""
 
-#: ../errors.py:69
+#: ../errors.py:66
 #, python-format
 msgid ""
 "The current directory (%s) is already a branch.\n"
 "You can start using it, or initialize another directory."
 msgstr ""
 
-#: ../errors.py:71
+#: ../errors.py:68
 msgid "Branch without a working tree"
 msgstr ""
 
-#: ../errors.py:72
+#: ../errors.py:69
 #, python-format
 msgid ""
 "The current directory (%s)\n"
 "is a branch without a working tree."
 msgstr ""
 
-#: ../errors.py:74
+#: ../errors.py:71
 msgid "Unknown bzr error"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "Permission denied"
 msgstr ""
 
-#: ../errors.py:76
+#: ../errors.py:73
 msgid "permission denied."
 msgstr ""
 
-#: ../errors.py:78
+#: ../errors.py:75
 msgid "Unknown error"
 msgstr ""
 
 #. Create the widgets
-#: ../initialize.py:46
+#: ../initialize.py:48
 msgid "_Initialize"
 msgstr ""
 
-#: ../initialize.py:47
+#: ../initialize.py:49
 msgid "Which directory do you want to initialize?"
 msgstr ""
 
-#: ../initialize.py:49
+#: ../initialize.py:50
 msgid "Current directory"
 msgstr ""
 
@@ -525,119 +525,79 @@
 msgid "Create a new directory with the name:"
 msgstr ""
 
+#: ../initialize.py:86
+msgid "Directory name not specified"
+msgstr ""
+
 #: ../initialize.py:87
-msgid "Directory name not specified"
-msgstr ""
-
-#: ../initialize.py:88
 msgid "You should specify a new directory name."
 msgstr ""
 
-#: ../loom.py:49
+#: ../loom.py:53
 msgid "Upgrade to Loom branch?"
 msgstr ""
 
-#: ../loom.py:50
+#: ../loom.py:54
 msgid "Branch is not a loom branch. Upgrade to Loom format?"
 msgstr ""
 
-#: ../merge.py:52
+#: ../merge.py:54
 msgid "Merge from"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Folder"
 msgstr ""
 
-#: ../merge.py:54
+#: ../merge.py:56
 msgid "Custom Location"
 msgstr ""
 
-#: ../merge.py:57
+#: ../merge.py:59
 msgid "_Merge"
 msgstr ""
 
-#: ../merge.py:130
+#: ../merge.py:132
 msgid "Branch not given"
 msgstr ""
 
-#: ../merge.py:131
+#: ../merge.py:133
 msgid "Please specify a branch to merge from."
 msgstr ""
 
-#: ../merge.py:139
+#: ../merge.py:141
 msgid "Bazaar command error"
 msgstr ""
 
-#: ../nautilus-bzr.py:460
-msgid "File id:"
-msgstr ""
-
-#: ../nautilus-bzr.py:463
-msgid "SHA1Sum:"
-msgstr ""
-
-#: ../nautilus-bzr.py:469
-msgid "Last Change Revision:"
-msgstr ""
-
-#: ../nautilus-bzr.py:474
-msgid "Last Change Author:"
-msgstr ""
-
-#: ../nautilus-bzr.py:515
-msgid "Push location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:518
-msgid "Parent location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:521
-msgid "Bound location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:524
-msgid "Public location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:527
-msgid "Submit location:"
-msgstr ""
-
-#: ../nautilus-bzr.py:530
-msgid "Append revisions only"
-msgstr ""
-
 #. Create the widgets
-#: ../push.py:50
+#: ../push.py:51
 msgid "Location:"
 msgstr ""
 
-#: ../push.py:52
+#: ../push.py:53
 msgid "_Push"
 msgstr ""
 
-#: ../push.py:101
+#: ../push.py:100
 msgid ""
 "You cannot push if branches have diverged.\n"
 "Overwrite?"
 msgstr ""
 
+#: ../push.py:108
+msgid "Push successful"
+msgstr ""
+
 #: ../push.py:109
-msgid "Push successful"
-msgstr ""
-
-#: ../push.py:110
 #, python-format
 msgid "%d revision(s) pushed."
 msgstr ""
 
-#: ../push.py:141
+#: ../push.py:142
 msgid "Non existing parent directory"
 msgstr ""
 
-#: ../push.py:142
+#: ../push.py:143
 #, python-format
 msgid ""
 "The parent directory (%s)\n"
@@ -645,11 +605,11 @@
 msgstr ""
 
 #. Create the widgets
-#: ../revbrowser.py:35
+#: ../revbrowser.py:45
 msgid "_Select"
 msgstr ""
 
-#: ../search.py:41
+#: ../search.py:44
 msgid "Search for:"
 msgstr ""
 
@@ -657,32 +617,32 @@
 msgid "Document"
 msgstr ""
 
-#: ../status.py:87
+#: ../status.py:94
 msgid "Added"
 msgstr ""
 
-#: ../status.py:93
+#: ../status.py:100
 msgid "Removed"
 msgstr ""
 
-#: ../status.py:99
+#: ../status.py:106
 msgid "Renamed"
 msgstr ""
 
-#: ../status.py:106
+#: ../status.py:113
 msgid "Modified"
 msgstr ""
 
-#: ../status.py:114
+#: ../status.py:121
 msgid "Unknown"
 msgstr ""
 
-#: ../status.py:119
+#: ../status.py:126
 msgid "No changes."
 msgstr ""
 
 #. Set properties
-#: ../tags.py:60
+#: ../tags.py:66
 msgid "Tags"
 msgstr ""
 
@@ -694,44 +654,56 @@
 msgid "Revision ID"
 msgstr ""
 
-#: ../tags.py:148
+#: ../tags.py:150
 msgid "Tags are not supported by this branch format. Please upgrade."
 msgstr ""
 
-#: ../tags.py:154
+#: ../tags.py:156
 msgid "No tagged revisions in the branch."
 msgstr ""
 
-#: ../tags.py:222
+#: ../tags.py:231
 msgid "_Remove tag"
 msgstr ""
 
-#: ../tags.py:232
+#: ../tags.py:241
 msgid "<b><big>Remove tag?</big></b>"
 msgstr ""
 
-#: ../tags.py:234
+#: ../tags.py:243
 #, python-format
 msgid "Are you sure you want to remove the tag: <b>%s</b>?"
 msgstr ""
 
 #. Create the widgets
-#: ../tags.py:278
+#: ../tags.py:288
 msgid "_Add tag"
 msgstr ""
 
-#: ../tags.py:280
+#: ../tags.py:290
 msgid "Tag Name:"
 msgstr ""
 
-#: ../tags.py:281
+#: ../tags.py:291
 msgid "Revision ID:"
 msgstr ""
 
-#: ../tags.py:312
+#: ../tags.py:322
 msgid "No tag name specified"
 msgstr ""
 
-#: ../tags.py:313
+#: ../tags.py:323
 msgid "You have to specify the tag's desired name."
 msgstr ""
+
+#~ msgid "translator-credits"
+#~ msgstr ""
+#~ "Launchpad Contributions:\n"
+#~ "  Aron Xu https://launchpad.net/~happyaron\n"
+#~ "  Chen Tao https://launchpad.net/~pro711"
+
+#~ msgid "File(s) to commit"
+#~ msgstr "准备提交的文件"
+
+#~ msgid "Commit message:"
+#~ msgstr "提交说明："

=== modified file 'preferences/__init__.py'
--- preferences/__init__.py	2011-09-07 16:01:14 +0000
+++ preferences/__init__.py	2011-08-13 02:44:14 +0000
@@ -64,7 +64,6 @@
     def close(self, widget=None):
         self.window.destroy()
 
-
 class BranchPreferencesWindow(Gtk.Dialog):
     """Displays global preferences windows."""
     def __init__(self, config=None):

=== modified file 'preferences/identity.py'
--- preferences/identity.py	2011-09-07 16:01:14 +0000
+++ preferences/identity.py	2011-08-27 13:02:59 +0000
@@ -21,7 +21,7 @@
 
     def __init__(self, config):
         self.config = config
-        super(IdentityPage, self).__init__(rows=4, columns=2)
+        Gtk.Table.__init__(self, rows=4, columns=2)
         self.set_border_width(12)
         self.set_row_spacings(6)
         self.set_col_spacings(6)
@@ -30,36 +30,27 @@
         label = Gtk.Label()
         label.set_markup("E-Mail:")
         align.add(label)
-        self.attach(
-            align, 0, 1, 0, 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.attach(align, 0, 1, 0, 1, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         self.username = Gtk.Entry()
         self.username.set_text(self.config.username())
-        self.attach(
-            self.username, 1, 2, 0, 1,
-            Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-            Gtk.AttachOptions.FILL)
+        self.attach(self.username, 1, 2, 0, 1, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         align = Gtk.Alignment.new(0.0, 0.5, 0.0, 0.0)
         label = Gtk.Label()
         label.set_markup("GPG signing command:")
         align.add(label)
-        self.attach(
-            align, 0, 1, 1, 2, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.attach(align, 0, 1, 1, 2, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         self.email = Gtk.Entry()
         self.email.set_text(self.config.gpg_signing_command())
-        self.attach(
-            self.email, 1, 2, 1, 2,
-            Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-            Gtk.AttachOptions.FILL)
+        self.attach(self.email, 1, 2, 1, 2, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         align = Gtk.Alignment.new(0.0, 0.1, 0.0, 0.0)
         label = Gtk.Label()
         label.set_markup("Check GPG Signatures:")
         align.add(label)
-        self.attach(
-            align, 0, 1, 2, 3, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.attach(align, 0, 1, 2, 3, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         sigvals = Gtk.VBox()
         self.check_sigs_if_possible = Gtk.RadioButton.new_with_label(
@@ -72,17 +63,13 @@
             self.check_sigs_if_possible, "Check _never")
         sigvals.pack_start(self.check_sigs_never, True, True, 0)
         # FIXME: Set default
-        self.attach(
-            sigvals, 1, 2, 2, 3,
-            Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-            Gtk.AttachOptions.FILL)
+        self.attach(sigvals, 1, 2, 2, 3, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         align = Gtk.Alignment.new(0.0, 0.1, 0.0, 0.0)
         label = Gtk.Label()
         label.set_markup("Create GPG Signatures:")
         align.add(label)
-        self.attach(
-            align, 0, 1, 3, 4, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
+        self.attach(align, 0, 1, 3, 4, Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)
 
         create_sigs = Gtk.VBox()
         self.create_sigs_when_required = Gtk.RadioButton.new_with_label(
@@ -95,7 +82,4 @@
             self.create_sigs_when_required, "Sign _Never")
         create_sigs.pack_start(self.create_sigs_never, True, True, 0)
         # FIXME: Set default
-        self.attach(
-            create_sigs, 1, 2, 3, 4,
-            Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL,
-            Gtk.AttachOptions.FILL)
+        self.attach(create_sigs, 1, 2, 3, 4, Gtk.AttachOptions.EXPAND | Gtk.AttachOptions.FILL, Gtk.AttachOptions.FILL)

=== modified file 'preferences/notifications.py'
--- preferences/notifications.py	2011-09-05 03:44:26 +0000
+++ preferences/notifications.py	2011-08-13 02:44:14 +0000
@@ -34,8 +34,7 @@
 
     def __init__(self, config, homogeneous=False, spacing=6):
         self.config = config
-        super(NotificationsPage, self).__init__(
-            homogeneous=homogeneous, spacing=spacing)
+        Gtk.VBox.__init__(self, homogeneous=homogeneous, spacing=spacing)
         self.set_spacing(spacing) # The vertical one
 
         lan_frame = Gtk.Frame(label="LAN Notifications")

=== modified file 'preferences/plugins.py'
--- preferences/plugins.py	2012-02-09 03:43:01 +0000
+++ preferences/plugins.py	2011-08-27 21:08:38 +0000
@@ -17,11 +17,10 @@
 from gi.repository import Gtk
 
 
-class PluginsPage(Gtk.Paned):
+class PluginsPage(Gtk.VPaned):
 
     def __init__(self):
-        super(PluginsPage, self).__init__()
-        self.set_orientation(Gtk.Orientation.VERTICAL)
+        Gtk.VPaned.__init__(self)
         self.set_border_width(12)
         self.set_position(216)
 
@@ -73,9 +72,6 @@
     def row_selected(self, tv, path=None, tvc=None):
         if path is None:
             (path, focus) = tv.get_cursor()
-        if path is None:
-            # The event was fired as the widget was destroyed.
-            return
         import bzrlib
         p = bzrlib.plugin.plugins()[self.model[path][0]].module
         from inspect import getdoc

=== modified file 'push.py'
--- push.py	2012-03-11 21:41:49 +0000
+++ push.py	2011-08-13 01:12:20 +0000
@@ -1,5 +1,4 @@
-# Copyright (C) 2006 by Szilveszter Farkas (Phanatic)
-#                       <szilveszter.farkas@gmail.com>
+# Copyright (C) 2006 by Szilveszter Farkas (Phanatic) <szilveszter.farkas@gmail.com>
 # Copyright (C) 2007 by Jelmer Vernooij <jelmer@samba.org>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -16,73 +15,62 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from errors import show_bzr_error
 
-from bzrlib import (
-    errors,
-    ui,
-    )
-from bzrlib.controldir import ControlDir
-from bzrlib.push import PushResult
-from bzrlib.transport import get_transport
+import bzrlib.errors as errors
 
 from bzrlib.plugins.gtk.dialog import (
+    info_dialog,
     question_dialog,
     )
+
 from bzrlib.plugins.gtk.history import UrlHistory
 from bzrlib.plugins.gtk.i18n import _i18n
-from bzrlib.plugins.gtk.ui import ProgressPanel
 
 
 class PushDialog(Gtk.Dialog):
     """New implementation of the Push dialog."""
 
-    def __init__(self, repository=None, revid=None, branch=None, parent=None):
+    def __init__(self, repository, revid, branch=None, parent=None):
         """Initialize the Push dialog. """
-        super(PushDialog, self).__init__(
-            title="Push", parent=parent, flags=0, border_width=6,
-            buttons=(Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE))
-        if repository is None:
-            repository = branch.repository
-        self.branch = branch
-
-        # Unused arguments
+        Gtk.Dialog.__init__(self, title="Push",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+
+
+        # Get arguments
         self.repository = repository
-        if revid is None:
-            revid = branch.last_revision()
         self.revid = revid
+        self.branch = branch
 
         # Create the widgets
         self._label_location = Gtk.Label(label=_i18n("Location:"))
         self._combo = Gtk.ComboBox.new_with_entry()
         self._button_push = Gtk.Button(_i18n("_Push"), use_underline=True)
-        self._hbox_location = Gtk.Box(Gtk.Orientation.HORIZONTAL, 6)
-        self._push_message = Gtk.Label(xalign=0)
-        self._progress_widget = ProgressPanel()
+        self._hbox_location = Gtk.HBox()
 
         # Set callbacks
-        ui.ui_factory.set_progress_bar_widget(self._progress_widget)
-        self.connect('close', self._on_close_clicked)
         self._button_push.connect('clicked', self._on_push_clicked)
 
         # Set properties
-        content_area = self.get_content_area()
-        content_area.set_spacing(6)
+        self._label_location.set_alignment(0, 0.5)
+        self._hbox_location.set_spacing(3)
+        self.get_content_area().set_spacing(3)
 
         # Pack widgets
-        self._hbox_location.pack_start(self._label_location, False, False, 0)
-        self._hbox_location.pack_start(self._combo, False, False, 0)
-        content_area.pack_start(self._hbox_location, True, True, 0)
-        content_area.pack_start(self._progress_widget, True, True, 0)
-        content_area.pack_start(self._push_message, True, True, 0)
+        self._hbox_location.pack_start(
+            self._label_location, False, False, 0)
+        self._hbox_location.pack_start(self._combo, True, True, 0)
+        self.get_content_area().pack_start(self._hbox_location, True, True, 0)
+        # XXX sinzui 2011-08-12: maybe False, False, 0
         self.get_action_area().pack_end(self._button_push, True, True, 0)
 
         # Show the dialog
-        content_area.show_all()
-        self._progress_widget.hide()
-        self._push_message.hide()
+        self.get_content_area().show_all()
 
         # Build location history
         self._history = UrlHistory(self.branch.get_config(), 'push_history')
@@ -92,7 +80,7 @@
         """Build up the location history. """
         self._combo_model = Gtk.ListStore(str)
         for item in self._history.get_entries():
-            self._combo_model.append([item])
+            self._combo_model.append([ item ])
         self._combo.set_model(self._combo_model)
         self._combo.set_entry_text_column(0)
 
@@ -101,36 +89,28 @@
             if location is not None:
                 self._combo.get_child().set_text(location)
 
-    def _on_close_clicked(self, widget):
-        """Close dialog handler."""
-        ui.ui_factory.set_progress_bar_widget(None)
-
     @show_bzr_error
     def _on_push_clicked(self, widget):
         """Push button clicked handler. """
-        self._push_message.hide()
-        self._progress_widget.tick()
         location = self._combo.get_child().get_text()
+        revs = 0
 
         try:
-            message = do_push(self.branch, location, overwrite=False)
+            revs = do_push(self.branch, location=location, overwrite=False)
         except errors.DivergedBranches:
-            response = question_dialog(
-                _i18n('Branches have been diverged'),
-                _i18n('You cannot push if branches have diverged.\n'
-                      'Overwrite?'))
+            response = question_dialog(_i18n('Branches have been diverged'),
+                                       _i18n('You cannot push if branches have diverged.\nOverwrite?'))
             if response == Gtk.ResponseType.YES:
-                message = do_push(self.branch, location, overwrite=True)
-            else:
-                return
+                revs = do_push(self.branch, location=location, overwrite=True)
+
+        if self.branch is not None and self.branch.get_push_location() is None:
+            self.branch.set_push_location(location)
+
         self._history.add_entry(location)
-        if (self.branch is not None
-            and self.branch.get_push_location() is None):
-            self.branch.set_push_location(location)
-        if message:
-            self._progress_widget.finished()
-            self._push_message.props.label = message
-            self._push_message.show()
+        info_dialog(_i18n('Push successful'),
+                    _i18n("%d revision(s) pushed.") % revs)
+
+        self.response(Gtk.ResponseType.OK)
 
 
 def do_push(br_from, location, overwrite):
@@ -141,62 +121,44 @@
     :param overwrite: overwrite target location if it diverged
     :return: number of revisions pushed
     """
-    revision_id = None
-    to_transport = get_transport(location)
+    from bzrlib.bzrdir import BzrDir
+    from bzrlib.transport import get_transport
+
+    transport = get_transport(location)
+    location_url = transport.base
+
+    old_rh = []
+
     try:
-        dir_to = ControlDir.open_from_transport(to_transport)
+        dir_to = BzrDir.open(location_url)
+        br_to = dir_to.open_branch()
     except errors.NotBranchError:
-        dir_to = None
-
-    if dir_to is None:
+        # create a branch.
+        transport = transport.clone('..')
         try:
-            br_to = br_from.create_clone_on_transport(
-                to_transport, revision_id=revision_id)
+            relurl = transport.relpath(location_url)
+            transport.mkdir(relurl)
         except errors.NoSuchFile:
-            response = question_dialog(
-                _i18n('Non existing parent directory'),
-                _i18n("The parent directory (%s)\ndoesn't exist. Create?") %
-                    location)
+            response = question_dialog(_i18n('Non existing parent directory'),
+                         _i18n("The parent directory (%s)\ndoesn't exist. Create?") % location)
             if response == Gtk.ResponseType.OK:
-                br_to = br_from.create_clone_on_transport(
-                    to_transport, revision_id=revision_id, create_prefix=True)
+                transport.create_prefix()
             else:
-                return _i18n("Push aborted.")
-        push_result = create_push_result(br_from, br_to)
+                return
+        dir_to = br_from.bzrdir.clone(location_url,
+            revision_id=br_from.last_revision())
+        br_to = dir_to.open_branch()
+        count = len(br_to.revision_history())
     else:
-        push_result = dir_to.push_branch(br_from, revision_id, overwrite)
-    message = create_push_message(br_from, push_result)
-    return message
-
-
-def create_push_message(br_from, push_result):
-    """Return a mesage explaining what happened during the push."""
-    messages = []
-    rev_count = br_from.revno() - push_result.old_revno
-    messages.append(_i18n("%d revision(s) pushed.") % rev_count)
-    if push_result.stacked_on is not None:
-        messages.append(_i18n("Stacked on %s.") % push_result.stacked_on)
-    if push_result.workingtree_updated is False:
-        messages.append(_i18n(
-            "\nThe working tree was not updated:"
-            "\nSee 'bzr help working-trees' for more information."))
-    return '\n'.join(messages)
-
-
-def create_push_result(br_from, br_to):
-    """Return a PushResult like one created by ControlDir.push_branch()."""
-    push_result = PushResult()
-    push_result.source_branch = br_from
-    push_result.target_branch = br_to
-    push_result.branch_push_result = None
-    push_result.master_branch = None
-    push_result.old_revno = 0
-    push_result.old_revid = br_to.last_revision()
-    push_result.workingtree_updated = None  # Not applicable to this case.
-    try:
-        push_result.stacked_on = br_to.get_stacked_on_url()
-    except (errors.UnstackableBranchFormat,
-            errors.UnstackableRepositoryFormat,
-            errors.NotStacked):
-        push_result.stacked_on = None
-    return push_result
+        old_rh = br_to.revision_history()
+        try:
+            tree_to = dir_to.open_workingtree()
+        except errors.NotLocalUrl:
+            # FIXME - what to do here? how should we warn the user?
+            count = br_to.pull(br_from, overwrite)
+        except errors.NoWorkingTree:
+            count = br_to.pull(br_from, overwrite)
+        else:
+            count = tree_to.pull(br_from, overwrite)
+
+    return count

=== modified file 'revbrowser.py'
--- revbrowser.py	2011-09-08 03:11:06 +0000
+++ revbrowser.py	2011-07-31 16:50:29 +0000
@@ -14,6 +14,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from bzrlib.plugins.gtk.branchview.treeview import TreeView
@@ -23,10 +24,10 @@
 class RevisionBrowser(Gtk.Dialog):
     """ Revision Browser main window. """
     def __init__(self, branch, parent=None):
-        super(RevisionBrowser, self).__init__(
-            title="Revision Browser - Olive", parent=parent,
-            flags=Gtk.DialogFlags.MODAL,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Revision Browser - Olive",
+                                  parent=parent,
+                                  flags=Gtk.DialogFlags.MODAL,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
 
         # Get arguments
         self.branch = branch
@@ -43,15 +44,15 @@
 
         # Set properties
         self.set_default_size(600, 400)
-        self.get_content_area().set_spacing(3)
+        self.vbox.set_spacing(3)
         self.treeview.set_property('graph-column-visible', False)
         self.treeview.set_property('date-column-visible', True)
         self.treeview.set_property('mainline-only', True)
 
         # Construct the dialog
-        self.action_area.pack_end(self._button_select, False, False, 0)
+        self.action_area.pack_end(self._button_select)
 
-        self.get_content_area().pack_start(self.treeview, True, True, 0)
+        self.vbox.pack_start(self.treeview, True, True)
 
         # Show the dialog
         self.show_all()

=== modified file 'revisionmenu.py'
--- revisionmenu.py	2011-09-03 01:25:04 +0000
+++ revisionmenu.py	2011-07-31 16:50:29 +0000
@@ -47,29 +47,28 @@
 
     def create_items(self):
         if len(self.revids) == 1:
-            item = Gtk.MenuItem.new_with_mnemonic("View _Changes")
+            item = Gtk.MenuItem("View _Changes")
             item.connect('activate', self.show_diff)
             self.append(item)
 
-            item = Gtk.MenuItem.new_with_mnemonic("_Push")
+            item = Gtk.MenuItem("_Push")
             item.connect('activate', self.show_push)
             self.append(item)
 
-            item = Gtk.MenuItem.new_with_mnemonic("_Tag Revision")
+            item = Gtk.MenuItem("_Tag Revision")
             item.connect('activate', self.show_tag)
             self.append(item)
 
-            item = Gtk.MenuItem.new_with_mnemonic("_Merge Directive")
+            item = Gtk.MenuItem("_Merge Directive")
             item.connect('activate', self.store_merge_directive)
             # FIXME: self.append(item)
 
-            item = Gtk.MenuItem.new_with_mnemonic("_Send Merge Directive")
+            item = Gtk.MenuItem("_Send Merge Directive")
             item.connect('activate', self.send_merge_directive)
             self.append(item)
 
             if self.wt:
-                item = Gtk.MenuItem.new_with_mnemonic(
-                    "_Revert to this revision")
+                item = Gtk.MenuItem("_Revert to this revision")
                 item.connect('activate', self.revert)
                 self.append(item)
 

=== modified file 'revisionview.py'
--- revisionview.py	2011-12-20 16:16:57 +0000
+++ revisionview.py	2011-08-13 03:06:56 +0000
@@ -22,7 +22,10 @@
 
 from bzrlib import trace
 from bzrlib.osutils import format_date
-from bzrlib.bencode import bdecode
+try:
+    from bzrlib.bencode import bdecode
+except ImportError:
+    from bzrlib.util.bencode import bdecode
 from bzrlib.testament import Testament
 
 from bzrlib.plugins.gtk import icon_path
@@ -48,6 +51,8 @@
             webbrowser._tryorder.insert(0, '%s "%%s"' % cmd)
     webbrowser.open(uri)
 
+if getattr(Gtk, 'link_button_set_uri_hook', None) is not None:
+    Gtk.link_button_set_uri_hook(_open_link)
 
 class BugsTab(Gtk.VBox):
 
@@ -322,7 +327,7 @@
     }
 
     def __init__(self, branch=None, repository=None):
-        super(RevisionView, self).__init__()
+        Gtk.Notebook.__init__(self)
 
         self._revision = None
         self._branch = branch
@@ -547,7 +552,7 @@
                 button.add(image)
                 button.connect("clicked", self._show_clicked_cb,
                                self._revision.revision_id, revid)
-                hbox.pack_start(button, False, True, 0)
+                hbox.pack_start(button, False, True, True, 0)
                 button.show()
 
             button = Gtk.Button()
@@ -684,6 +689,7 @@
 
         self.connect('notify::revision', self._add_tags)
 
+        self.avatarsbox.show()
         return self.avatarsbox
     
     def _create_parents(self):

=== modified file 'search.py'
--- search.py	2011-09-05 03:44:26 +0000
+++ search.py	2011-08-27 18:03:04 +0000
@@ -21,16 +21,14 @@
 
 from bzrlib.plugins.gtk.i18n import _i18n
 
-
 class SearchDialog(Gtk.Dialog):
     """Search dialog."""
-
     def __init__(self, index, parent=None):
-        super(SearchDialog, self).__init__(
-            title="Search Revisions", parent=parent,
-            flags=Gtk.DialogFlags.MODAL,
-            buttons=(Gtk.STOCK_OK, Gtk.ResponseType.OK,
-                Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Search Revisions",
+                                  parent=parent,
+                                  flags=Gtk.DialogFlags.MODAL,
+                                  buttons=(Gtk.STOCK_OK, Gtk.ResponseType.OK,
+                                           Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
         pixbuf = self.render_icon_pixbuf(Gtk.STOCK_FIND, Gtk.IconSize.MENU)
         self.set_icon(pixbuf)
         
@@ -44,29 +42,23 @@
         self.searchentry.connect('activate', self._searchentry_activate)
         # TODO: Completion using the bzr-search suggests functionality
         self.searchbar.add(self.searchentry)
-        self.get_content_area().pack_start(self.searchbar, False, False, 0)
+        self.vbox.pack_start(self.searchbar, expand=False, fill=False)
 
-        self.results_model = Gtk.ListStore(
-            GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_PYOBJECT)
+        self.results_model = Gtk.ListStore(GObject.TYPE_STRING, GObject.TYPE_STRING, GObject.TYPE_PYOBJECT)
         self.results_treeview = Gtk.TreeView(self.results_model)
-        self.results_treeview.connect(
-            "row-activated", self._searchresult_row_activated)
+        self.results_treeview.connect("row-activated", self._searchresult_row_activated)
 
-        documentname_column = Gtk.TreeViewColumn(
-            _i18n("Document"), Gtk.CellRendererText(), text=0)
+        documentname_column = Gtk.TreeViewColumn(_i18n("Document"), Gtk.CellRendererText(), text=0)
         self.results_treeview.append_column(documentname_column)
 
-        summary_column = Gtk.TreeViewColumn(
-            _i18n("Summary"), Gtk.CellRendererText(), text=1)
+        summary_column = Gtk.TreeViewColumn(_i18n("Summary"), Gtk.CellRendererText(), text=1)
         self.results_treeview.append_column(summary_column)
 
         results_scrolledwindow = Gtk.ScrolledWindow()
-        results_scrolledwindow.set_policy(
-            Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
+        results_scrolledwindow.set_policy(Gtk.PolicyType.NEVER, Gtk.PolicyType.AUTOMATIC)
         results_scrolledwindow.add(self.results_treeview)
 
-        self.get_content_area().pack_start(
-            results_scrolledwindow, True, True, 0)
+        self.vbox.pack_start(results_scrolledwindow, expand=True, fill=True)
 
         self.set_default_size(600, 400)
         # Show the dialog
@@ -83,9 +75,7 @@
         self.results_model.clear()
         self.index._branch.lock_read()
         try:
-            query = [
-                (query_item,)
-                for query_item in self.searchentry.get_text().split(" ")]
+            query = [(query_item,) for query_item in self.searchentry.get_text().split(" ")]
             for result in self.index.search(query):
                 if isinstance(result, _mod_index.FileTextHit):
                     revid = result.text_key[-1]
@@ -93,8 +83,7 @@
                     revid = result.revision_key[0]
                 else:
                     raise AssertionError()
-                self.results_model.append(
-                    [result.document_name(), result.summary(), revid])
+                self.results_model.append([result.document_name(), result.summary(), revid])
         finally:
             self.index._branch.unlock()
     

=== modified file 'setup.py'
--- setup.py	2012-07-09 15:23:26 +0000
+++ setup.py	2011-07-31 15:52:43 +0000
@@ -1,47 +1,33 @@
 #!/usr/bin/python
 """GTK+ Frontends for various Bazaar commands."""
 
-import os
-import sys
-
-from info import bzr_plugin_version
+from info import *
 
 from distutils.core import setup, Command
 from distutils.command.install_data import install_data
 from distutils.command.build import build
 from distutils.command.sdist import sdist
 try:
-    from DistUtilsExtra.command import build_i18n
+    from DistUtilsExtra.command import *
 except ImportError:
-    # Python distutils extra is not available.
-    class cmd_build_i18n(build):
-        user_options = []
-
-        def initialize_options(self):
-            self.domain = None
-            self.desktop_files = None
-
-        def finalize_options(self):
-            pass
-
+   # Python distutils extra is not available.
+    class cmd_build_i18n(Command):
         def run(self):
-            print >> sys.stderr, (
-                "For internationalization support you'll need to install "
-                "https://launchpad.net/python-distutils-extra")
+            print >> sys.stderr, "For internationalization support you'll need to install https://launchpad.net/python-distutils-extra"
 else:
     # Use build_i18n from DistUtilsExtra
     cmd_build_i18n = build_i18n.build_i18n
 
+import os
+import sys
 
 class Check(Command):
     description = "Run unit tests"
 
-    user_options = [
-        ('module=', 'm', 'The test module to run'),
-        ]
+    user_options = []
 
     def initialize_options(self):
-        self.module = None
+        pass
 
     def finalize_options(self):
         pass
@@ -52,12 +38,11 @@
     def run(self):
         from bzrlib.tests import TestLoader, TestSuite, TextTestRunner
         from bzrlib.plugin import PluginImporter
-        PluginImporter.specific_paths["bzrlib.plugins.gtk"] = os.path.dirname(
-            __file__)
+        PluginImporter.specific_paths["bzrlib.plugins.gtk"] = os.path.dirname(__file__)
         from bzrlib.plugins.gtk.tests import load_tests
         suite = TestSuite()
         loader = TestLoader()
-        load_tests(suite, self.module, loader)
+        load_tests(suite, None, loader)
         runner = TextTestRunner()
         result = runner.run(suite)
         return result.wasSuccessful()
@@ -78,8 +63,7 @@
         return 'build_credits'
 
     def run(self):
-        from bzrlib.plugin import load_plugins
-        load_plugins()
+        from bzrlib.plugin import load_plugins; load_plugins()
         from bzrlib.branch import Branch
         from bzrlib.plugins.stats.cmds import find_credits
 
@@ -142,15 +126,15 @@
     version = bzr_plugin_version[:3]
     version_string = ".".join([str(x) for x in version])
     setup(
-        name="bzr-gtk",
-        version=version_string,
-        maintainer="Jelmer Vernooij",
-        maintainer_email="jelmer@samba.org",
-        description="GTK+ Frontends for various Bazaar commands",
-        license="GNU GPL v2 or later",
-        scripts=['bzr-handle-patch'],
-        url="http://bazaar-vcs.org/BzrGtk",
-        package_dir={
+        name = "bzr-gtk",
+        version = version_string,
+        maintainer = "Jelmer Vernooij",
+        maintainer_email = "jelmer@samba.org",
+        description = "GTK+ Frontends for various Bazaar commands",
+        license = "GNU GPL v2 or later",
+        scripts = ['bzr-handle-patch', 'bzr-notify'],
+        url = "http://bazaar-vcs.org/BzrGtk",
+        package_dir = {
             "bzrlib.plugins.gtk": ".",
             "bzrlib.plugins.gtk.viz": "viz",
             "bzrlib.plugins.gtk.annotate": "annotate",
@@ -158,7 +142,7 @@
             "bzrlib.plugins.gtk.branchview": "branchview",
             "bzrlib.plugins.gtk.preferences": "preferences",
             },
-        packages=[
+        packages = [
             "bzrlib.plugins.gtk",
             "bzrlib.plugins.gtk.viz",
             "bzrlib.plugins.gtk.annotate",
@@ -166,7 +150,7 @@
             "bzrlib.plugins.gtk.branchview",
             "bzrlib.plugins.gtk.preferences",
         ],
-        data_files=[('share/bzr-gtk', ['credits.pickle']),
+        data_files=[ ('share/bzr-gtk', ['credits.pickle']),
                     ('share/bzr-gtk/icons', ['icons/commit.png',
                                              'icons/commit16.png',
                                              'icons/diff.png',
@@ -188,11 +172,11 @@
                     # In case Python distutils extra is not available,
                     # install the .desktop files
                     ('share/applications', ['bazaar-properties.desktop',
-                                            'bzr-handle-patch.desktop']),
-                    ('share/application-registry', ['bzr-gtk.applications']),
+                                            'bzr-handle-patch.desktop',
+                                            'bzr-notify.desktop']),
+                    ('share/application-registry', ['bzr-Gtk.applications']),
                     ('share/pixmaps', ['icons/bzr-icon-64.png']),
-                    ('share/icons/hicolor/scalable/apps',
-                        ['icons/bzr-panel.svg']),
+                    ('share/icons/hicolor/scalable/apps', ['icons/bzr-panel.svg']),
                     ('share/icons/hicolor/scalable/emblems',
                      ['icons/emblem-bzr-added.svg',
                       'icons/emblem-bzr-conflict.svg',

=== modified file 'tags.py'
--- tags.py	2012-02-09 03:43:01 +0000
+++ tags.py	2011-08-12 20:29:49 +0000
@@ -15,6 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from gi.repository import GObject
 from gi.repository import Gtk
 
 from bzrlib.plugins.gtk.dialog import error_dialog
@@ -28,7 +29,7 @@
     """ Tags window. Allows the user to view/add/remove tags. """
     def __init__(self, branch, parent=None):
         """ Initialize the Tags window. """
-        super(TagsWindow, self).__init__(parent=parent)
+        Window.__init__(self, parent)
 
         # Get arguments
         self.branch = branch
@@ -46,7 +47,7 @@
         self._vbox_buttons = Gtk.VBox()
         self._vbox_buttons_top = Gtk.VBox()
         self._vbox_buttons_bottom = Gtk.VBox()
-        self._vpaned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+        self._vpaned = Gtk.VPaned()
 
         # Set callbacks
         self._button_add.connect('clicked', self._on_add_clicked)
@@ -73,19 +74,13 @@
         # Construct the dialog
         self._scrolledwindow_tags.add(self._treeview_tags)
 
-        self._vbox_buttons_top.pack_start(
-            self._button_add, False, False, 0)
-        self._vbox_buttons_top.pack_start(
-            self._button_remove, False, False, 0)
-        self._vbox_buttons_top.pack_start(
-            self._button_refresh, False, False, 0)
-        self._vbox_buttons_bottom.pack_start(
-            self._button_close, False, False, 0)
+        self._vbox_buttons_top.pack_start(self._button_add, False, False, 0)
+        self._vbox_buttons_top.pack_start(self._button_remove, False, False, 0)
+        self._vbox_buttons_top.pack_start(self._button_refresh, False, False, 0)
+        self._vbox_buttons_bottom.pack_start(self._button_close, False, False, 0)
 
-        self._vbox_buttons.pack_start(
-            self._vbox_buttons_top, True, True, 0)
-        self._vbox_buttons.pack_start(
-            self._vbox_buttons_bottom, False, False, 0)
+        self._vbox_buttons.pack_start(self._vbox_buttons_top, True, True, 0)
+        self._vbox_buttons.pack_start(self._vbox_buttons_bottom, False, False, 0)
 
         self._vpaned.add1(self._scrolledwindow_tags)
         self._vpaned.add2(self._revisionview)
@@ -197,8 +192,6 @@
         # Refresh RevisionView only if there are tags available
         if not self._no_tags:
             (path, col) = self._treeview_tags.get_cursor()
-            if path is None:
-                return  # The widget is being destroyed.
             revision = self._model[path][1]
             self._revisionview.set_revision(self.branch.repository.get_revision(revision))
 
@@ -206,9 +199,10 @@
 class RemoveTagDialog(Gtk.Dialog):
     """ Confirm removal of tag. """
     def __init__(self, tagname, parent):
-        super(RemoveTagDialog, self).__init__(
-            title="Remove tag", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Remove tag",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
 
         # Get the arguments
         self.tag = tagname
@@ -246,12 +240,12 @@
         self._hbox.pack_start(self._image_question, True, True, 0)
         self._hbox.pack_start(self._vbox_question, True, True, 0)
 
-        self.get_content_area().add(self._hbox)
+        self.vbox.add(self._hbox)
 
-        self.action_area.pack_end(self._button_remove, False, False, 0)
+        self.action_area.pack_end(self._button_remove)
 
         # Display dialog
-        self.get_content_area().show_all()
+        self.vbox.show_all()
 
         # Default to Commit button
         self._button_remove.grab_default()
@@ -266,9 +260,11 @@
 
     def __init__(self, repository, revid=None, branch=None, parent=None):
         """ Initialize Add tag dialog. """
-        super(AddTagDialog, self).__init__(
-            title="Add tag", parent=parent, flags=0,
-            buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL))
+        GObject.GObject.__init__(self, title="Add tag",
+                                  parent=parent,
+                                  flags=0,
+                                  buttons=(Gtk.STOCK_CANCEL, 
+                                           Gtk.ResponseType.CANCEL))
 
         # Get arguments
         self._repository = repository
@@ -301,11 +297,11 @@
         self._table.attach(self._label_revid, 0, 1, 1, 2)
         self._table.attach(self._entry_name, 1, 2, 0, 1)
         self._table.attach(self._hbox_revid, 1, 2, 1, 2)
-        self.get_content_area().add(self._table)
-        self.action_area.pack_end(self._button_add, False, False, 0)
+        self.vbox.add(self._table)
+        self.action_area.pack_end(self._button_add)
 
         # Show the dialog
-        self.get_content_area().show_all()
+        self.vbox.show_all()
 
     def _on_add_clicked(self, widget):
         """ Add button clicked handler. """

=== modified file 'tests/__init__.py'
--- tests/__init__.py	2012-03-04 00:09:11 +0000
+++ tests/__init__.py	2011-02-18 13:01:03 +0000
@@ -14,77 +14,17 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-__all__ = [
-    'load_tests',
-    'MockMethod',
-    'MockProperty',
-    ]
-
-import os
-
-
-def discover_test_names(module_or_name):
-    if isinstance(module_or_name, basestring):
-        match = module_or_name
-    else:
-        match = ''
-    file_names = os.listdir(os.path.dirname(__file__))
-    test_names = set()
-    for file_name in file_names:
-        name, ext = os.path.splitext(file_name)
-        if name.startswith('test_') and ext == '.py' and match in name:
-            test_names.add("%s.%s" % (__name__, name))
-    return test_names
-
 
 def load_tests(basic_tests, module, loader):
-    test_names = discover_test_names(module)
-    basic_tests.addTest(loader.loadTestsFromModuleNames(test_names))
+    testmod_names = [
+        'test_annotate_config',
+        'test_commit',
+        'test_diff',
+        'test_history',
+        'test_linegraph',
+        'test_revisionview',
+        ]
+
+    basic_tests.addTest(loader.loadTestsFromModuleNames(
+            ["%s.%s" % (__name__, tmn) for tmn in testmod_names]))
     return basic_tests
-
-
-class MockMethod(object):
-
-    @classmethod
-    def bind(klass, test_instance, obj, method_name,
-             return_value=None, raise_error=None, raise_on=1):
-        original_method = getattr(obj, method_name)
-        test_instance.addCleanup(setattr, obj, method_name, original_method)
-        setattr(obj, method_name, klass(return_value, raise_error, raise_on))
-
-    def __init__(self, return_value=None, raise_error=None, raise_on=1):
-        self.called = False
-        self.call_count = 0
-        self.args = None
-        self.kwargs = None
-        self.return_value = return_value
-        self.raise_error = raise_error
-        self.raise_on = raise_on
-
-    def __call__(self, *args, **kwargs):
-        self.called = True
-        self.call_count += 1
-        self.args = args
-        self.kwargs = kwargs
-        if self.raise_error is not None and self.call_count == self.raise_on:
-            raise self.raise_error
-        return self.return_value
-
-
-class MockProperty(MockMethod):
-
-    @classmethod
-    def bind(klass, test_instance, obj, method_name, return_value=None):
-        original_method = getattr(obj, method_name)
-        test_instance.addCleanup(setattr, obj, method_name, original_method)
-        mock = klass(return_value)
-        setattr(obj, method_name, property(mock.get_value, mock.set_value))
-        return mock
-
-    def get_value(self, other):
-        self.called = True
-        return self.return_value
-
-    def set_value(self, other, value):
-        self.called = True
-        self.return_value = value

=== modified file 'tests/test_annotate_config.py'
--- tests/test_annotate_config.py	2012-02-09 03:01:20 +0000
+++ tests/test_annotate_config.py	2009-05-07 11:48:03 +0000
@@ -16,8 +16,6 @@
 
 """Test the annotate configuration functionality."""
 
-import os
-
 from bzrlib import (
     tests,
     )
@@ -26,20 +24,12 @@
     config,
     gannotate,
     )
-from bzrlib.plugins.gtk.annotate.config import gannotate_config_filename
-
 
 class TestConfig(tests.TestCaseInTempDir):
 
     def setUp(self):
-        # Create an instance before the env is changed so that
-        # icon lookups work.
+        super(TestConfig, self).setUp()
         self.window = gannotate.GAnnotateWindow()
-        super(TestConfig, self).setUp()
-
-    def tearDown(self):
-        self.window.destroy()
-        super(TestConfig, self).tearDown()
 
     def test_create_initial_config(self):
         """We can create a config even without a prior conf file"""
@@ -48,15 +38,3 @@
         width = conf['window']['width']
         # configobj presents attributes as strings only
         self.assertIsInstance(width, str)
-
-    def test_write(self):
-        """The window state and pane position is saved."""
-        conf = config.GAnnotateConfig(self.window)
-        self.window.pane.set_position(200)
-        self.assertIs(False, conf._write())
-        self.assertEqual(200, conf['window']['pane_position'])
-        config_path = gannotate_config_filename()
-        self.assertIs(True, os.path.isfile(config_path))
-        with open(config_path) as config_file:
-            config_data = config_file.read()
-        self.assertIn('pane_position = 200', config_data)

=== removed file 'tests/test_avatarsbox.py'
--- tests/test_avatarsbox.py	2011-09-03 22:00:09 +0000
+++ tests/test_avatarsbox.py	1970-01-01 00:00:00 +0000
@@ -1,47 +0,0 @@
-# Copyright (C) 2011 Curtis Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the AvatarsBox functionality."""
-
-from bzrlib import (
-    tests,
-    )
-
-from bzrlib.plugins.gtk.avatarsbox import Avatar
-
-
-class TestAvatar(tests.TestCase):
-
-    def test__init(self):
-        apparent_username = 'Random J User <randomjuser@eg.dom>'
-        avatar = Avatar(apparent_username)
-        self.assertEqual(apparent_username, avatar.apparent_username)
-        self.assertEqual('Random J User', avatar.username)
-        self.assertEqual('randomjuser@eg.dom', avatar.email)
-        self.assertEqual(None, avatar.image)
-
-    def test_eq_true(self):
-        apparent_username = 'Random J User <randomjuser@eg.dom>'
-        avatar_1 = Avatar(apparent_username)
-        avatar_2 = Avatar(apparent_username)
-        self.assertTrue(avatar_1 == avatar_2)
-
-    def test_eq_false(self):
-        apparent_username = 'Random J User <randomjuser@eg.dom>'
-        avatar_1 = Avatar(apparent_username)
-        avatar_2 = Avatar(apparent_username)
-        avatar_2.username = 'changed'
-        self.assertFalse(avatar_1 == avatar_2)

=== modified file 'tests/test_commit.py'
--- tests/test_commit.py	2012-03-22 17:14:22 +0000
+++ tests/test_commit.py	2011-08-27 15:31:00 +0000
@@ -17,8 +17,6 @@
 """Test the Commit functionality."""
 
 import os
-import subprocess
-from tempfile import NamedTemporaryFile
 
 from gi.repository import Gtk
 
@@ -28,17 +26,11 @@
     uncommit,
     )
 try:
-    from bzrlib.tests.features import UnicodeFilenameFeature
-except ImportError: # bzr < 2.5
-    from bzrlib.tests import UnicodeFilenameFeature
-from bzrlib import bencode
+    from bzrlib import bencode
+except ImportError:
+    from bzrlib.util import bencode
 
-from bzrlib.plugins.gtk import (
-    commit,
-    commitmsgs,
-    )
-from bzrlib.plugins.gtk.commitmsgs import SavedCommitMessagesManager
-from bzrlib.plugins.gtk.tests import MockMethod
+from bzrlib.plugins.gtk import commit
 
 
 # TODO: All we need is basic ancestry code to test this, we shouldn't need a
@@ -50,8 +42,7 @@
         tree = self.make_branch_and_tree('.')
         tree.commit('one')
 
-        self.addCleanup(tree.lock_read().unlock)
-        self.assertEquals([], list(commit.pending_revisions(tree)))
+        self.assertIs(None, commit.pending_revisions(tree))
 
     def test_pending_revisions_simple(self):
         tree = self.make_branch_and_tree('tree')
@@ -61,8 +52,7 @@
         tree.merge_from_branch(tree2.branch)
         self.assertEqual([rev_id1, rev_id2], tree.get_parent_ids())
 
-        self.addCleanup(tree.lock_read().unlock)
-        pending_revisions = list(commit.pending_revisions(tree))
+        pending_revisions = commit.pending_revisions(tree)
         # One primary merge
         self.assertEqual(1, len(pending_revisions))
         # Revision == rev_id2
@@ -80,8 +70,7 @@
         tree.merge_from_branch(tree2.branch)
         self.assertEqual([rev_id1, rev_id4], tree.get_parent_ids())
 
-        self.addCleanup(tree.lock_read().unlock)
-        pending_revisions = list(commit.pending_revisions(tree))
+        pending_revisions = commit.pending_revisions(tree)
         # One primary merge
         self.assertEqual(1, len(pending_revisions))
         # Revision == rev_id2
@@ -104,8 +93,7 @@
         tree.merge_from_branch(tree3.branch, force=True)
         self.assertEqual([rev_id1, rev_id3, rev_id5], tree.get_parent_ids())
 
-        self.addCleanup(tree.lock_read().unlock)
-        pending_revisions = list(commit.pending_revisions(tree))
+        pending_revisions = commit.pending_revisions(tree)
         # Two primary merges
         self.assertEqual(2, len(pending_revisions))
         # Revision == rev_id2
@@ -148,33 +136,13 @@
 
 class TestCommitDialogSimple(tests.TestCaseWithTransport):
 
-    def test_init(self):
-        MockMethod.bind(self, CommitDialogNoWidgets, 'setup_params')
-        MockMethod.bind(self, CommitDialogNoWidgets, 'construct')
-        MockMethod.bind(self, CommitDialogNoWidgets, 'fill_in_data')
-
-        tree = self.make_branch_and_tree('tree')
-        rev_id = tree.commit('first')
-        dlg = CommitDialogNoWidgets(tree)
-        self.assertIs(tree, dlg._wt)
-        self.assertIs(None, dlg._selected)
-        self.assertTrue(dlg._enable_per_file_commits)
-        self.assertTrue(dlg._commit_all_changes)
-        self.assertIs(None, dlg.committed_revision_id)
-        self.assertIs(None, dlg._last_selected_file)
-        self.assertIsInstance(
-            dlg._saved_commit_messages_manager, SavedCommitMessagesManager)
-        self.assertTrue(CommitDialogNoWidgets.setup_params.called)
-        self.assertTrue(CommitDialogNoWidgets.construct.called)
-        self.assertTrue(CommitDialogNoWidgets.fill_in_data.called)
-
     def test_setup_parameters_no_pending(self):
         tree = self.make_branch_and_tree('tree')
         rev_id = tree.commit('first')
 
         dlg = CommitDialogNoWidgets(tree)
         self.assertEqual(rev_id, dlg._basis_tree.get_revision_id())
-        self.assertEquals([], dlg._pending)
+        self.assertIs(None, dlg._pending)
         self.assertFalse(dlg._is_checkout)
 
     def test_setup_parameters_checkout(self):
@@ -185,7 +153,7 @@
 
         dlg = CommitDialogNoWidgets(tree2)
         self.assertEqual(rev_id, dlg._basis_tree.get_revision_id())
-        self.assertEquals([], dlg._pending)
+        self.assertIs(None, dlg._pending)
         self.assertTrue(dlg._is_checkout)
 
     def test_setup_parameters_pending(self):
@@ -216,32 +184,6 @@
         self.assertEqual([], delta.removed)
         self.assertEqual([(u'a', 'a-id', 'file')], delta.added)
 
-    def test_on_treeview_files_cursor_changed_no_selection(self):
-        MockMethod.bind(self, CommitDialogNoWidgets, '_update_per_file_info')
-        tree = self.make_branch_and_tree('tree')
-        rev_id = tree.commit('first')
-        dlg = CommitDialogNoWidgets(tree)
-        treeview = Gtk.TreeView()
-        dlg._on_treeview_files_cursor_changed(treeview)
-        self.assertFalse(CommitDialogNoWidgets._update_per_file_info.called)
-
-    def test_on_treeview_files_cursor_changed_with_destroyed_treeview(self):
-        MockMethod.bind(self, CommitDialogNoWidgets, '_update_per_file_info')
-        tree = self.make_branch_and_tree('tree')
-        rev_id = tree.commit('first')
-        dlg = CommitDialogNoWidgets(tree)
-        treeview = Gtk.TreeView()
-        treeview.destroy()
-        dlg._on_treeview_files_cursor_changed(treeview)
-        self.assertFalse(CommitDialogNoWidgets._update_per_file_info.called)
-
-    def test_get_line_height(self):
-        tree = self.make_branch_and_tree('tree')
-        dlg = CommitDialogNoWidgets(tree)
-        textview = Gtk.TextView()
-        line_height = dlg.get_line_height(textview)
-        self.assertIsInstance(line_height, int)
-
 
 class TestCommitDialog(tests.TestCaseWithTransport):
 
@@ -346,7 +288,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'added'),
                           ('b-id', 'b', True, 'b/', 'added'),
                           ('c-id', 'b/c', True, 'b/c', 'added'),
@@ -363,7 +305,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('b-id', 'd', True, 'b/ => d/', 'renamed'),
                           ('a-id', 'd/a', True, 'a => d/a', 'renamed'),
                          ], values)
@@ -378,7 +320,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'modified'),
                          ], values)
 
@@ -398,7 +340,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('b-id', 'd', True, 'b/ => d/', 'renamed'),
                           ('a-id', 'd/a', True, 'a => d/a', 'renamed and modified'),
                           ('c-id', 'd/c', True, 'd/c', 'modified'),
@@ -421,7 +363,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('a-id', 'a', True, 'a => a/', 'kind changed'),
                           # ('b-id', 'c', True, 'b => c/', 'renamed and modified'),
                          ], values)
@@ -437,7 +379,7 @@
 
         dlg = commit.CommitDialog(tree)
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", True, 'All Files', ''),
+        self.assertEqual([(None, None, True, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'removed'),
                           ('b-id', 'b', True, 'b/', 'removed'),
                          ], values)
@@ -452,7 +394,7 @@
 
         dlg = commit.CommitDialog(tree, selected='a')
         values = [(r[0], r[1], r[2], r[3], r[4]) for r in dlg._files_store]
-        self.assertEqual([("", "", False, 'All Files', ''),
+        self.assertEqual([(None, None, False, 'All Files', ''),
                           ('a-id', 'a', True, 'a', 'added'),
                           ('b-id', 'b', False, 'b/', 'added'),
                          ], values)
@@ -636,7 +578,7 @@
         tree.add(['a', 'b'], ['a-id', 'b-id'])
 
         dlg = commit.CommitDialog(tree)
-        self.assertEqual([("", "", True),
+        self.assertEqual([(None, None, True),
                           ('a-id', 'a', True),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
@@ -651,26 +593,26 @@
 
         # Toggle a single entry should set just that entry to False
         dlg._toggle_commit(None, 1, dlg._files_store)
-        self.assertEqual([("", "", True),
+        self.assertEqual([(None, None, True),
                           ('a-id', 'a', False),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         # Toggling the main entry should set all entries
         dlg._toggle_commit(None, 0, dlg._files_store)
-        self.assertEqual([("", "", False),
+        self.assertEqual([(None, None, False),
                           ('a-id', 'a', False),
                           ('b-id', 'b', False),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         dlg._toggle_commit(None, 2, dlg._files_store)
-        self.assertEqual([("", "", False),
+        self.assertEqual([(None, None, False),
                           ('a-id', 'a', False),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
 
         dlg._toggle_commit(None, 0, dlg._files_store)
-        self.assertEqual([("", "", True),
+        self.assertEqual([(None, None, True),
                           ('a-id', 'a', True),
                           ('b-id', 'b', True),
                          ], [(r[0], r[1], r[2]) for r in dlg._files_store])
@@ -1108,7 +1050,7 @@
                          bencode.bdecode(file_info.encode('UTF-8')))
 
     def test_commit_unicode_messages(self):
-        self.requireFeature(UnicodeFilenameFeature)
+        self.requireFeature(tests.UnicodeFilenameFeature)
 
         tree = self.make_branch_and_tree('tree')
         tree.branch.get_config().set_user_option('per_file_commits', 'true')
@@ -1182,7 +1124,7 @@
         super(TestSavedCommitMessages, self).setUp()
         # Install our hook
         branch.Branch.hooks.install_named_hook(
-            'post_uncommit', commitmsgs.save_commit_messages, None)
+            'post_uncommit', commit.save_commit_messages, None)
 
     def _get_file_info_dict(self, rank):
         file_info = [dict(path='a', file_id='a-id', message='a msg %d' % rank),
@@ -1305,32 +1247,3 @@
         self.assertEquals(u'', self._get_commit_message())
         self.assertEquals(u'de',
                           self._get_file_commit_messages())
-
-
-class BzrHandlePatchTestCase(tests.TestCase):
-
-    def setUp(self):
-        top = os.path.abspath(os.path.join(
-            os.path.dirname(__file__), os.pardir))
-        self.script = os.path.join(top, 'bzr-handle-patch')
-        self.env = dict(os.environ)
-        self.env['BZR_PLUGINS_AT'] = 'gtk@%s' % top
-        self.patch = NamedTemporaryFile()
-        self.patch.write('\n'.join([
-            "=== added file '_test.txt'",
-            "--- _test.txt	1970-01-01 00:00:00 +0000",
-            "+++ _test.txt	2012-02-03 20:00:34 +0000",
-            "@@ -0,0 +1,1 @@",
-            "+hello",
-            ]))
-        self.patch.flush()
-        super(BzrHandlePatchTestCase, self).setUp()
-
-    def test_smoketest(self):
-        # This is a smoke test to verify the process starts.
-        bzr_notify = subprocess.Popen(
-            [self.script, self.patch.name, 'test'],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=self.env)
-        stdout, stderr = bzr_notify.communicate()
-        self.assertEqual('', stdout)
-        self.assertEqual('', stderr)

=== modified file 'tests/test_diff.py'
--- tests/test_diff.py	2012-02-05 05:14:11 +0000
+++ tests/test_diff.py	2011-08-12 19:50:45 +0000
@@ -15,34 +15,22 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+from cStringIO import StringIO
 import os
 
-from gi.repository import Gtk
-
 from bzrlib import (
     conflicts,
     errors,
     tests,
     )
-try:
-    from bzrlib.tests.features import UnicodeFilenameFeature
-except ImportError: # bzr < 2.5
-    from bzrlib.tests import UnicodeFilenameFeature
 from bzrlib.merge_directive import MergeDirective2
 
 from bzrlib.plugins.gtk.diff import (
     DiffController,
-    DiffFileView,
     DiffView,
-    DiffWidget,
-    DiffWindow,
-    have_gtksourceview,
     iter_changes_to_status,
     MergeDirectiveController,
     )
-from bzrlib.plugins.gtk.tests import MockMethod
-
-
 eg_diff = """\
 === modified file 'tests/test_diff.py'
 --- tests/test_diff.py	2008-03-11 13:18:28 +0000
@@ -62,35 +50,30 @@
  class TestDiffViewSimple(tests.TestCase):
 """
 
-
-class FakeDiffFileView(DiffFileView):
-
-    SHOW_WIDGETS = False
-
-
-class DiffFileViewTestCase(tests.TestCase):
-
-    def test_init_construct(self):
-        view = FakeDiffFileView()
-        self.assertIsNot(None, view.buffer)
-        self.assertIsNot(None, view.sourceview)
-        self.assertIs(False, view.sourceview.props.editable)
-        font_desc = view.sourceview.get_style_context().get_font(
-            Gtk.StateFlags.NORMAL)
-        self.assertIn('Monospace', font_desc.get_family())
-
-    def test_init_construct_have_gtksourceview(self):
-        if not have_gtksourceview:
-            return
-        view = FakeDiffFileView()
-        self.assertEqual('Diff', view.buffer.get_language().get_name())
-        self.assertIs(True, view.buffer.get_highlight_syntax())
+class TestDiffViewSimple(tests.TestCase):
+
+    def test_parse_colordiffrc(self):
+        colordiffrc = '''\
+newtext=blue
+oldtext = Red
+# now a comment and a blank line
+
+diffstuff = #ffff00  
+  # another comment preceded by whitespace
+'''
+        colors = {
+                'newtext': 'blue',
+                'oldtext': 'Red',
+                'diffstuff': '#ffff00',
+        }
+        parsed_colors = DiffView.parse_colordiffrc(StringIO(colordiffrc))
+        self.assertEqual(colors, parsed_colors)
 
 
 class TestDiffView(tests.TestCaseWithTransport):
 
     def test_unicode(self):
-        self.requireFeature(UnicodeFilenameFeature)
+        self.requireFeature(tests.UnicodeFilenameFeature)
 
         tree = self.make_branch_and_tree('tree')
         self.build_tree([u'tree/\u03a9'])
@@ -112,91 +95,6 @@
             )
 
 
-
-class FakeDiffWidget(DiffWidget):
-
-    SHOW_WIDGETS = False
-
-
-class TestDiffWidget(tests.TestCaseWithTransport):
-
-    def test_treeview_cursor_cb(self):
-        widget = FakeDiffWidget()
-        widget.set_diff_text_sections(
-            [('', None, 'patch1'), ('a', 'a', 'patch2')])
-        widget.treeview.set_cursor(Gtk.TreePath(path=1), None, False)
-        widget._treeview_cursor_cb(None)
-        self.assertTrue('patch2', widget.diff_view.buffer.props.text)
-
-    def test_treeview_cursor_cb_with_destroyed_treeview(self):
-        widget = FakeDiffWidget()
-        widget.set_diff_text_sections(
-            [('', None, 'patch1'), ('a', 'a', 'patch2')])
-        MockMethod.bind(self, widget.diff_view, 'show_diff')
-        widget.treeview.destroy()
-        widget._treeview_cursor_cb(None)
-        self.assertFalse(widget.diff_view.show_diff.called)
-
-
-class FakeDiffWindow(DiffWindow):
-
-    SHOW_WIDGETS = False
-
-
-class DiffWindowTestCase(tests.TestCaseWithTransport):
-
-    def test_init(self):
-        window = DiffWindow()
-        self.assertEqual('bzr diff', window.props.title)
-        self.assertEqual(0, window.props.border_width)
-
-    def test_init_construct_without_operations(self):
-        window = DiffWindow()
-        widgets = window.vbox.get_children()
-        self.assertEqual(2, len(widgets))
-        self.assertIsInstance(widgets[0], Gtk.MenuBar)
-        self.assertIsInstance(widgets[1], DiffWidget)
-
-    def test_init_construct_with_operations(self):
-        method = MockMethod()
-        window = DiffWindow(operations=[('title', method)])
-        widgets = window.vbox.get_children()
-        self.assertEqual(3, len(widgets))
-        self.assertIsInstance(widgets[0], Gtk.MenuBar)
-        self.assertIsInstance(widgets[1], Gtk.HButtonBox)
-        self.assertIsInstance(widgets[2], DiffWidget)
-
-    def test_get_menu_bar(self):
-        window = DiffWindow()
-        menu_bar = window._get_menu_bar()
-        self.assertIsNot(None, menu_bar)
-        menus = menu_bar.get_children()
-        self.assertEqual(1, len(menus))
-        self.assertEqual('_View', menus[0].props.label)
-        sub_menu = menus[0].get_submenu()
-        self.assertIsNot(None, sub_menu)
-        items = sub_menu.get_children()
-        self.assertEqual(1, len(items))
-        menus[0].get_submenu().get_children()[0].props.label
-        self.assertEqual('Wrap _Long Lines', items[0].props.label)
-
-    def test_get_button_bar_with_none(self):
-        window = DiffWindow()
-        self.assertIs(None, window._get_button_bar(None))
-
-    def test_get_button_bar_with_operations(self):
-        window = DiffWindow()
-        method = MockMethod()
-        button_bar = window._get_button_bar([('title', method)])
-        self.assertIsNot(None, button_bar)
-        buttons = button_bar.get_children()
-        self.assertEqual(1, len(buttons))
-        self.assertEqual('title', buttons[0].props.label)
-        buttons[0].emit('clicked')
-        self.assertIs(True, method.called)
-
-
-
 class MockDiffWidget(object):
 
     def set_diff_text_sections(self, sections):

=== removed file 'tests/test_graphcell.py'
--- tests/test_graphcell.py	2011-09-04 20:04:03 +0000
+++ tests/test_graphcell.py	1970-01-01 00:00:00 +0000
@@ -1,81 +0,0 @@
-# Copyright (C) 2011 Curtis Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the CellRendererGraph functionality."""
-
-from gi.repository import Gtk
-
-from bzrlib import (
-    tests,
-    )
-
-from bzrlib.plugins.gtk.branchview.graphcell import CellRendererGraph
-
-
-class CellRendererGraphTestCase(tests.TestCase):
-
-    def test_columns_len(self):
-        cell = CellRendererGraph()
-        self.assertEqual(0, cell.columns_len)
-        cell.columns_len = 1
-        self.assertEqual(1, cell.columns_len)
-
-    def test_props_writeonly(self):
-        # Props can be set, but not read, though they can be accessed
-        # as attributes
-        cell = CellRendererGraph()
-        cell.props.node = (1, 0)
-        cell.props.tags = ['2.0']
-        cell.props.in_lines = ((1, 2, 1.0))
-        cell.props.out_lines = ((1, 3, 1.0))
-        self.assertEqual((1, 0), cell.node)
-        self.assertRaises(TypeError, cell.props, 'node')
-        self.assertEqual(['2.0'], cell.tags)
-        self.assertRaises(TypeError, cell.props, 'tags')
-        self.assertEqual(((1, 2, 1.0)), cell.in_lines)
-        self.assertRaises(TypeError, cell.props, 'in_lines')
-        self.assertEqual(((1, 3, 1.0)), cell.out_lines)
-        self.assertRaises(TypeError, cell.props, 'out_lines')
-
-    def test_do_activate(self):
-        # The cell cannot be activated. It returns True to indicate the
-        # event is handled.
-        cell = CellRendererGraph()
-        self.assertEqual(
-            True, cell.do_activate(None, None, None, None, None))
-
-    def test_do_editing_started(self):
-        # The cell cannot be edited. It returns None.
-        cell = CellRendererGraph()
-        self.assertEqual(
-            None, cell.do_editing_started(None, None, None, None, None))
-
-    def test_do_get_size(self):
-        # The layout offset and size is based by cell.box_size(widget)
-        # box_size is cached, and this can be set ensure a predictable result.
-        cell = CellRendererGraph()
-        cell.columns_len = 1
-        cell._box_size = 21
-        treeview = Gtk.TreeView()
-        self.assertEqual(
-            (0, 0, 44, 22), cell.do_get_size(treeview, None))
-
-    def test_do_render(self):
-        # A simple test to verify the method is defined. Cairo is broken
-        # in gi--contexts cannot get created.
-        cell = CellRendererGraph()
-        self.assertEqual(
-            "<type 'instancemethod'>", str(type(cell.do_render)))

=== removed file 'tests/test_notify.py'
--- tests/test_notify.py	2012-02-19 15:00:34 +0000
+++ tests/test_notify.py	1970-01-01 00:00:00 +0000
@@ -1,64 +0,0 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2012 Curtis C. Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-import os
-import subprocess
-
-from bzrlib import tests
-from bzrlib.plugins.gtk.notify import NotifyPopupMenu
-
-
-class FakeNotifyPopupMenu(NotifyPopupMenu):
-
-    SHOW_WIDGETS = False
-
-
-class NotifyPopupMenuTestCase(tests.TestCase):
-
-    def test_init(self):
-        menu = FakeNotifyPopupMenu()
-        items = menu.get_children()
-        self.assertEqual(8, len(items))
-        self.assertEqual('_Gateway to LAN', items[0].props.label)
-        self.assertEqual('Announce _branches on LAN', items[2].props.label)
-        self.assertEqual('gtk-preferences', items[4].props.label)
-        self.assertEqual('gtk-about', items[5].props.label)
-        self.assertEqual('gtk-quit', items[7].props.label)
-
-
-class BzrNotifyTestCase(tests.TestCase):
-
-    def setUp(self):
-        top = os.path.abspath(os.path.join(
-            os.path.dirname(__file__), os.pardir))
-        self.script = os.path.join(top, 'bzr-notify')
-        self.env = dict(os.environ)
-        self.env['BZR_PLUGINS_AT'] = 'gtk@%s' % top
-        super(BzrNotifyTestCase, self).setUp()
-
-    def test_smoketest(self):
-        # This is a smoke test to verify the process starts.
-        # The logic of the module must be moved into notify.py
-        # where it can be properly tested.
-        bzr_notify = subprocess.Popen(
-            [self.script, 'test'],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=self.env)
-        stdout, stderr = bzr_notify.communicate()
-        self.assertEqual('', stdout)
-        self.assertTrue(
-            stderr in (
-            '', 'ERROR:root:Could not find any typelib for AppIndicator3\n'))

=== removed file 'tests/test_push.py'
--- tests/test_push.py	2012-03-20 12:39:08 +0000
+++ tests/test_push.py	1970-01-01 00:00:00 +0000
@@ -1,230 +0,0 @@
-# Copyright (C) 2012 Curtis Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the ui functionality."""
-
-from gi.repository import Gtk
-
-from bzrlib import (
-    errors,
-    tests,
-    ui,
-    )
-
-from bzrlib.plugins.gtk import (
-    push,
-    set_ui_factory,
-    )
-from bzrlib.plugins.gtk.tests import MockMethod
-from bzrlib.plugins.gtk.history import UrlHistory
-from bzrlib.plugins.gtk.ui import ProgressPanel
-
-
-class PushTestCase(tests.TestCaseWithMemoryTransport):
-
-    def make_push_branch(self):
-        tree = self.make_branch_and_memory_tree('test')
-        return tree.branch
-
-    def test_init(self):
-        set_ui_factory()
-        branch = self.make_push_branch()
-        dialog = push.PushDialog(
-            repository=None, revid=None, branch=branch, parent=None)
-        self.assertIs(None, dialog.props.parent)
-        self.assertIs(branch.repository, dialog.repository)
-        self.assertIs(branch.last_revision(), dialog.revid)
-        self.assertIs(branch, dialog.branch)
-        # Layout rules to match HIG.
-        self.assertIsInstance(dialog._label_location, Gtk.Label)
-        self.assertIsInstance(dialog._combo, Gtk.ComboBox)
-        self.assertIsInstance(dialog._button_push, Gtk.Button)
-        self.assertIsInstance(dialog._hbox_location, Gtk.Box)
-        self.assertIsInstance(dialog._progress_widget, ProgressPanel)
-        self.assertIsInstance(dialog._push_message, Gtk.Label)
-        self.assertIsInstance(dialog._history, UrlHistory)
-        self.assertIs(
-            ui.ui_factory._progress_bar_widget, dialog._progress_widget)
-        self.assertEqual(
-            Gtk.Orientation.HORIZONTAL,
-            dialog._hbox_location.props.orientation)
-        self.assertEqual(0.0, dialog._push_message.props.xalign)
-        self.assertEqual(6, dialog.props.border_width)
-        self.assertEqual(6, dialog._hbox_location.props.spacing)
-        self.assertEqual(6, dialog.get_content_area().props.spacing)
-        # Show rules.
-        self.assertIs(True, dialog._combo.props.visible)
-        self.assertIs(False, dialog._progress_widget.props.visible)
-        self.assertIs(False, dialog._push_message.props.visible)
-
-    def test_build_history(self):
-        set_ui_factory()
-        branch = self.make_push_branch()
-        branch.set_push_location('lp:~user/fnord/trunk')
-        dialog = push.PushDialog(None, None, branch)
-        dialog._history.add_entry('lp:~user/fnord/test1')
-        dialog._history.add_entry('lp:~user/fnord/test2')
-        dialog._build_history()
-        self.assertEqual(
-            'lp:~user/fnord/trunk', dialog._combo.get_child().props.text)
-        self.assertIsInstance(dialog._combo_model, Gtk.ListStore)
-        self.assertIs(dialog._combo.get_model(), dialog._combo_model)
-        locations = [row[0] for row in dialog._combo_model]
-        self.assertEqual(
-            ['lp:~user/fnord/test1', 'lp:~user/fnord/test2'], locations)
-
-    def test_on_close_clicked(self):
-        # The ui_factory's progress bar widget is set to None.
-        set_ui_factory()
-        branch = self.make_push_branch()
-        dialog = push.PushDialog(None, None, branch)
-        dialog._on_close_clicked(None)
-        self.assertIs(None, ui.ui_factory._progress_bar_widget)
-
-    def test_on_push_clicked_without_errors(self):
-        # Verify the dialog's and branch's final states after a push.
-        MockMethod.bind(self, push, 'do_push', "test success")
-        set_ui_factory()
-        branch = self.make_push_branch()
-        dialog = push.PushDialog(None, None, branch)
-        MockMethod.bind(self, dialog._progress_widget, 'tick')
-        dialog._combo.get_child().props.text = 'lp:~user/fnord/test'
-        dialog._on_push_clicked(None)
-        self.assertIs(True, dialog._progress_widget.tick.called)
-        self.assertIs(False, dialog._progress_widget.props.visible)
-        self.assertIs(True, push.do_push.called)
-        self.assertEqual(
-            (branch, 'lp:~user/fnord/test'), push.do_push.args)
-        self.assertEqual(
-            {'overwrite': False}, push.do_push.kwargs)
-        self.assertIs(True, dialog._push_message.props.visible)
-        self.assertEqual('test success', dialog._push_message.props.label)
-        self.assertEqual(
-            'lp:~user/fnord/test', dialog._history.get_entries()[-1])
-        self.assertEqual('lp:~user/fnord/test', branch.get_push_location())
-
-    def test_on_push_clicked_with_divered_branches(self):
-        # Verify that when DivergedBranches is raise, the user can choose
-        # to overwrite the branch.
-        error = errors.DivergedBranches(None, None)
-        MockMethod.bind(self, push, 'do_push', raise_error=error)
-        MockMethod.bind(self, push, 'question_dialog', Gtk.ResponseType.YES)
-        set_ui_factory()
-        branch = self.make_push_branch()
-        dialog = push.PushDialog(None, None, branch)
-        dialog._combo.get_child().props.text = 'lp:~user/fnord/test'
-        dialog._on_push_clicked(None)
-        self.assertIs(True, push.do_push.called)
-        self.assertEqual(2, push.do_push.call_count)
-        self.assertEqual(
-            (branch, 'lp:~user/fnord/test'), push.do_push.args)
-        self.assertEqual(
-            {'overwrite': True}, push.do_push.kwargs)
-
-
-class DoPushTestCase(tests.TestCaseWithTransport):
-
-    def setup_ui(self):
-        set_ui_factory()
-        progress_panel = ProgressPanel()
-        ui.ui_factory.set_progress_bar_widget(progress_panel)
-        MockMethod.bind(self, progress_panel.pb, 'tick')
-        MockMethod.bind(self, progress_panel.pb, 'update')
-        MockMethod.bind(self, progress_panel.pb, 'finished')
-        return progress_panel
-
-    def make_from_branch(self):
-        from_tree = self.make_branch_and_tree('this')
-        self.build_tree(['this/a', 'this/b'])
-        from_tree.add(['a', 'b'])
-        from_tree.commit("msg")
-        return from_tree.branch
-
-    def test_do_push_without_dir(self):
-        progress_panel = self.setup_ui()
-        from_branch = self.make_from_branch()
-        message = push.do_push(from_branch, 'that', False)
-        self.assertEqual('1 revision(s) pushed.', message)
-        self.assertEqual(True, progress_panel.pb.update.called)
-        self.assertEqual(True, progress_panel.pb.finished.called)
-
-    def test_do_push_without_parent_dir(self):
-        progress_panel = self.setup_ui()
-        from_branch = self.make_from_branch()
-        MockMethod.bind(self, push, 'question_dialog', Gtk.ResponseType.OK)
-        message = push.do_push(from_branch, 'that/there', False)
-        self.assertEqual('1 revision(s) pushed.', message)
-        self.assertEqual(True, push.question_dialog.called)
-        self.assertEqual(True, progress_panel.pb.update.called)
-        self.assertEqual(True, progress_panel.pb.finished.called)
-
-    def test_do_push_without_parent_dir_aborted(self):
-        self.setup_ui()
-        from_branch = self.make_from_branch()
-        MockMethod.bind(self, push, 'question_dialog', Gtk.ResponseType.CANCEL)
-        message = push.do_push(from_branch, 'that/there', False)
-        self.assertEqual('Push aborted.', message)
-
-    def test_do_push_with_dir(self):
-        progress_panel = self.setup_ui()
-        self.make_branch_and_tree('that')
-        from_branch = self.make_from_branch()
-        message = push.do_push(from_branch, 'that', False)
-        self.assertEqual('1 revision(s) pushed.', message)
-        self.assertEqual(True, progress_panel.pb.update.called)
-        self.assertEqual(True, progress_panel.pb.finished.called)
-
-    def test_create_push_result_unstacked(self):
-        from_branch = object()
-        to_branch = self.make_branch_and_tree('that').branch
-        push_result = push.create_push_result(from_branch, to_branch)
-        self.assertIs(from_branch, push_result.source_branch)
-        self.assertIs(to_branch, push_result.target_branch)
-        self.assertIs(None, push_result.branch_push_result)
-        self.assertIs(None, push_result.master_branch)
-        self.assertEqual(0, push_result.old_revno)
-        self.assertEqual(to_branch.last_revision(), push_result.old_revid)
-        self.assertIs(None, push_result.workingtree_updated)
-        self.assertIs(None, push_result.stacked_on)
-
-    def test_create_push_result_stacked(self):
-        from_branch = object()
-        to_branch = self.make_branch_and_tree('that').branch
-        MockMethod.bind(self, to_branch, 'get_stacked_on_url', 'lp:project')
-        push_result = push.create_push_result(from_branch, to_branch)
-        self.assertEqual('lp:project', push_result.stacked_on)
-
-    def test_create_push_message_stacked_on(self):
-        from_branch = object()
-        to_branch = self.make_branch_and_tree('that').branch
-        MockMethod.bind(self, to_branch, 'get_stacked_on_url', 'lp:project')
-        push_result = push.create_push_result(from_branch, to_branch)
-        from_branch = self.make_from_branch()
-        message = push.create_push_message(from_branch, push_result)
-        self.assertEqual(
-            '1 revision(s) pushed.\nStacked on lp:project.', message)
-
-    def test_create_push_message_workingtree_updated_false(self):
-        from_branch = object()
-        to_branch = self.make_branch_and_tree('that').branch
-        push_result = push.create_push_result(from_branch, to_branch)
-        push_result.workingtree_updated = False
-        from_branch = self.make_from_branch()
-        message = push.create_push_message(from_branch, push_result)
-        self.assertEqual(
-            "1 revision(s) pushed.\n\nThe working tree was not updated:\n"
-            "See 'bzr help working-trees' for more information.",
-            message)

=== modified file 'tests/test_revisionview.py'
--- tests/test_revisionview.py	2011-12-20 16:16:57 +0000
+++ tests/test_revisionview.py	2011-08-12 19:50:45 +0000
@@ -16,27 +16,19 @@
 
 """Test the RevisionView functionality."""
 
-import os
-
 from bzrlib import (
     tests,
     )
-from bzrlib import bencode
+try:
+    from bzrlib import bencode
+except ImportError:
+    from bzrlib.util import bencode
 
 from bzrlib.plugins.gtk import revisionview
 
 
-def fake_icon_path(*args):
-    return os.path.join(
-        os.path.dirname(__file__),  '..', 'icons', *args)
-
-
 class TestPendingRevisions(tests.TestCaseWithMemoryTransport):
 
-    def setUp(self):
-        super(TestPendingRevisions, self).setUp()
-        self.overrideAttr(revisionview, 'icon_path', new=fake_icon_path)
-
     def assertBufferText(self, text, buffer):
         """Check the text stored in the buffer."""
         self.assertEqual(text, buffer.get_text(buffer.get_start_iter(),
@@ -50,7 +42,6 @@
         b = builder.get_branch()
 
         rv = revisionview.RevisionView(b)
-        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
         self.assertEqual(rev.committer, rv.committer.get_text())
@@ -71,7 +62,6 @@
         b = tree.branch
 
         rv = revisionview.RevisionView(b)
-        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
 
@@ -92,7 +82,6 @@
         b = tree.branch
 
         rv = revisionview.RevisionView(b)
-        self.addCleanup(rv.destroy)
         rev = b.repository.get_revision('A')
         rv.set_revision(rev)
 

=== removed file 'tests/test_treemodel.py'
--- tests/test_treemodel.py	2011-09-04 20:04:03 +0000
+++ tests/test_treemodel.py	1970-01-01 00:00:00 +0000
@@ -1,101 +0,0 @@
-# Copyright (C) 2011 Curtis Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the BranchTreeModel functionality."""
-
-from time import (
-    strftime,
-    localtime,
-    )
-
-from bzrlib import (
-    tests,
-    )
-
-from bzrlib.plugins.gtk.branchview.treemodel import BranchTreeModel
-
-
-class BranchTreeModelTestCase(tests.TestCaseWithMemoryTransport):
-
-    def make_test_branch(self, revid, message=None, committer=None):
-        builder = self.make_branch_builder('test')
-        builder.build_snapshot(
-            revid, None, [('add', ('', 'root-id', 'directory', None))],
-            message=message, committer=committer)
-        return builder.get_branch()
-
-    def test_init(self):
-        branch = self.make_test_branch('A')
-        revision = branch.repository.get_revision('A')
-        branch.tags.set_tag('2.0', revision.revision_id)
-        model = BranchTreeModel(branch, [])
-        self.assertEqual(branch, model.branch)
-        self.assertEqual(branch.repository, model.repository)
-        self.assertEqual({'A': [u'2.0']}, model.tags)
-        self.assertEqual({}, model.revisions)
-        self.assertEqual([], model.line_graph_data)
-
-    def test_add_tag_create(self):
-        branch = self.make_test_branch('A')
-        revision = branch.repository.get_revision('A')
-        model = BranchTreeModel(branch, [])
-        model.add_tag('2.0', revision.revision_id)
-        self.assertEqual({'A': [u'2.0']}, model.tags)
-
-    def test_add_tag_append(self):
-        branch = self.make_test_branch('A')
-        revision = branch.repository.get_revision('A')
-        branch.tags.set_tag('2.0', revision.revision_id)
-        model = BranchTreeModel(branch, [])
-        model.add_tag('2.1', revision.revision_id)
-        self.assertEqual({'A': ['2.0', '2.1']}, model.tags)
-
-    def test_line_graph_item_to_model_row(self):
-        branch = self.make_test_branch(
-            'A', message='badger', committer='fnord')
-        revision = branch.repository.get_revision('A')
-        branch.tags.set_tag('2.0', revision.revision_id)
-        model = BranchTreeModel(branch, [])
-        data_item = (
-            revision.revision_id, (1, 0), (5, 6, 0.5), ('B'), ('C'), [12, 34])
-        row = model._line_graph_item_to_model_row(0, data_item)
-        self.assertEqual(revision.revision_id, row[0], 'Wrong revid.')
-        self.assertEqual((1, 0), row[1], 'Wrong node.')
-        self.assertEqual((5, 6, 0.5), row[2], 'Wrong lines.')
-        self.assertEqual([], row[3], 'Wrong last_lines.')
-        self.assertEqual('12.34', row[4], 'Wrong revno.')
-        self.assertEqual('badger', row[5], 'Wrong summary.')
-        self.assertEqual('badger', row[6], 'Wrong message.')
-        self.assertEqual('fnord', row[7], 'wrong committer.')
-        self.assertEqual(
-            strftime("%Y-%m-%d %H:%M", localtime(revision.timestamp)),
-            row[8], 'Wrong timestamp.')
-        self.assertEqual(revision, row[9], 'Wrong revision.')
-        self.assertEqual(('B'), row[10], 'Wrong parents.')
-        self.assertEqual(('C'), row[11], 'Wrong children.')
-        self.assertEqual(['2.0'], row[12], 'Wrong tags.')
-        self.assertEqual('fnord', row[13], 'Wrong authors.')
-
-    def test_set_line_graph_data(self):
-        branch = self.make_test_branch(
-            'A', message='badger', committer='fnord')
-        rev_id = branch.repository.get_revision('A').revision_id
-        model = BranchTreeModel(branch, [])
-        data = [(rev_id, (2, 0), (3, 4, 0.5), None, None, [1, 2])]
-        model.set_line_graph_data(data)
-        self.assertEqual(data, model.line_graph_data)
-        tree_iter = model.get_iter_first()
-        self.assertEqual(rev_id, model.get_value(tree_iter, 0))

=== removed file 'tests/test_ui.py'
--- tests/test_ui.py	2012-02-28 04:53:55 +0000
+++ tests/test_ui.py	1970-01-01 00:00:00 +0000
@@ -1,375 +0,0 @@
-# Copyright (C) 2012 Curtis Hovey <sinzui.is@verizon.net>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
-"""Test the ui functionality."""
-
-from gi.repository import Gtk
-
-from bzrlib import (
-    tests,
-    )
-
-from bzrlib.plugins.gtk import ui
-from bzrlib.plugins.gtk.tests import (
-    MockMethod,
-    MockProperty,
-    )
-from bzrlib.progress import ProgressTask
-
-
-class MainIterationTestCase(tests.TestCase):
-
-    def test_main_iteration(self):
-        # The main_iteration decorator iterates over the pending Gtk events
-        # after calling its function so that the UI is updated too.
-        button = Gtk.ToggleButton(label='before')
-
-        def event_listener(button):
-            button.props.label = 'after'
-
-        button.connect('clicked', event_listener)
-
-        def test_func(self):
-            button.emit('clicked')
-            return True
-
-        decorated_func = ui.main_iteration(test_func)
-        result = decorated_func(object())
-        self.assertIs(True, result)
-        self.assertIs(False, Gtk.events_pending())
-        self.assertEqual('after', button.props.label)
-
-
-class PromptDialogTestCase(tests.TestCase):
-
-    def test_init(self):
-        # The text and buttons are created.
-        dialog = ui.PromptDialog('test 123')
-        self.assertEqual('test 123', dialog.props.text)
-        self.assertEqual(Gtk.MessageType.QUESTION, dialog.props.message_type)
-        buttons = dialog.get_action_area().get_children()
-        self.assertEqual('gtk-yes', buttons[0].props.label)
-        self.assertEqual('gtk-no', buttons[1].props.label)
-
-
-class InfoDialogTestCase(tests.TestCase):
-
-    def test_init(self):
-        # The text and buttons are created.
-        dialog = ui.InfoDialog('test 123')
-        self.assertEqual('test 123', dialog.props.text)
-        self.assertEqual(Gtk.MessageType.INFO, dialog.props.message_type)
-        buttons = dialog.get_action_area().get_children()
-        self.assertEqual('gtk-close', buttons[0].props.label)
-
-
-class WarningDialogTestCase(tests.TestCase):
-
-    def test_init(self):
-        # The text and buttons are created.
-        dialog = ui.WarningDialog('test 123')
-        self.assertEqual('test 123', dialog.props.text)
-        self.assertEqual(Gtk.MessageType.WARNING, dialog.props.message_type)
-        buttons = dialog.get_action_area().get_children()
-        self.assertEqual('gtk-close', buttons[0].props.label)
-
-
-class ErrorDialogTestCase(tests.TestCase):
-
-    def test_init(self):
-        # The text and buttons are created, then shown.
-        dialog = ui.ErrorDialog('test 123')
-        self.assertEqual('test 123', dialog.props.text)
-        self.assertEqual(Gtk.MessageType.ERROR, dialog.props.message_type)
-        buttons = dialog.get_action_area().get_children()
-        self.assertEqual('gtk-close', buttons[0].props.label)
-
-
-class PasswordDialogTestCase(tests.TestCase):
-
-    def test_init(self):
-        # The label, password entry, and buttons are created, then shown.
-        MockMethod.bind(self, Gtk.Box, 'show_all')
-        dialog = ui.PasswordDialog('test password')
-        content_area = dialog.get_content_area()
-        self.assertIs(True, dialog.get_content_area().show_all.called)
-        widgets = content_area.get_children()
-        self.assertEqual('test password', widgets[0].props.label)
-        self.assertEqual(False, widgets[1].props.visibility)
-        buttons = dialog.get_action_area().get_children()
-        self.assertEqual('gtk-cancel', buttons[0].props.label)
-        self.assertEqual(
-            Gtk.ResponseType.CANCEL,
-            dialog.get_response_for_widget(buttons[0]))
-        self.assertEqual('gtk-ok', buttons[1].props.label)
-        self.assertEqual(
-            Gtk.ResponseType.OK,
-            dialog.get_response_for_widget(buttons[1]))
-
-
-class GtkProgressBarTestCase(tests.TestCase):
-
-    def test_init(self):
-        progress_bar = ui.GtkProgressBar()
-        self.assertEqual(0.0, progress_bar.props.fraction)
-        self.assertIs(None, progress_bar.total)
-        self.assertIs(None, progress_bar.current)
-
-    def test_tick(self):
-        # tick() shows the widget, does one pulse, then handles the pending
-        # events in the main loop.
-        MockMethod.bind(self, ui.GtkProgressBar, 'show')
-        MockMethod.bind(self, ui.GtkProgressBar, 'pulse')
-        progress_bar = ui.GtkProgressBar()
-        progress_bar.tick()
-        self.assertIs(True, progress_bar.show.called)
-        self.assertEqual('with_main_iteration', progress_bar.tick.__name__)
-
-    def test_update_with_data(self):
-        # update() shows the widget, sets the fraction, then handles the
-        # pending events in the main loop.
-        MockMethod.bind(self, ui.GtkProgressBar, 'show')
-        progress_bar = ui.GtkProgressBar()
-        progress_bar.update(msg='test', current_cnt=5, total_cnt=10)
-        self.assertIs(True, progress_bar.show.called)
-        self.assertEqual(0.5, progress_bar.props.fraction)
-        self.assertEqual(10, progress_bar.total)
-        self.assertEqual(5, progress_bar.current)
-        self.assertEqual('with_main_iteration', progress_bar.update.__name__)
-
-    def test_update_without_data(self):
-        progress_bar = ui.GtkProgressBar()
-        progress_bar.update(current_cnt=5, total_cnt=None)
-        self.assertEqual(0.0, progress_bar.props.fraction)
-        self.assertIs(None, progress_bar.total)
-        self.assertEqual(5, progress_bar.current)
-
-    def test_update_with_insane_data(self):
-        # The fraction must be between 0.0 and 1.0.
-        progress_bar = ui.GtkProgressBar()
-        self.assertRaises(
-            ValueError, progress_bar.update, None, 20, 2)
-
-    def test_finished(self):
-        # finished() hides the widget, resets the state, then handles the
-        # pending events in the main loop.
-        MockMethod.bind(self, ui.GtkProgressBar, 'hide')
-        progress_bar = ui.GtkProgressBar()
-        progress_bar.finished()
-        self.assertIs(True, progress_bar.hide.called)
-        self.assertEqual(0.0, progress_bar.props.fraction)
-        self.assertIs(None, progress_bar.total)
-        self.assertIs(None, progress_bar.current)
-        self.assertEqual('with_main_iteration', progress_bar.finished.__name__)
-
-    def test_clear(self):
-        # clear() is synonymous with finished.
-        MockMethod.bind(self, ui.GtkProgressBar, 'finished')
-        progress_bar = ui.GtkProgressBar()
-        progress_bar.finished()
-        self.assertIs(True, progress_bar.finished.called)
-
-
-class ProgressContainerMixin:
-
-    def test_tick(self):
-        progress_widget = self.progress_container()
-        MockMethod.bind(self, progress_widget, 'show_all')
-        MockMethod.bind(self, progress_widget.pb, 'tick')
-        progress_widget.tick()
-        self.assertIs(True, progress_widget.show_all.called)
-        self.assertIs(True, progress_widget.pb.tick.called)
-
-    def test_update(self):
-        progress_widget = self.progress_container()
-        MockMethod.bind(self, progress_widget, 'show_all')
-        MockMethod.bind(self, progress_widget.pb, 'update')
-        progress_widget.update('test', 5, 10)
-        self.assertIs(True, progress_widget.show_all.called)
-        self.assertIs(True, progress_widget.pb.update.called)
-        self.assertEqual(
-            ('test', 5, 10), progress_widget.pb.update.args)
-
-    def test_finished(self):
-        progress_widget = self.progress_container()
-        MockMethod.bind(self, progress_widget, 'hide')
-        MockMethod.bind(self, progress_widget.pb, 'finished')
-        progress_widget.finished()
-        self.assertIs(True, progress_widget.hide.called)
-        self.assertIs(True, progress_widget.pb.finished.called)
-
-    def test_clear(self):
-        progress_widget = self.progress_container()
-        MockMethod.bind(self, progress_widget, 'hide')
-        MockMethod.bind(self, progress_widget.pb, 'clear')
-        progress_widget.clear()
-        self.assertIs(True, progress_widget.hide.called)
-        self.assertIs(True, progress_widget.pb.clear.called)
-
-
-class ProgressBarWindowTestCase(ProgressContainerMixin, tests.TestCase):
-
-    progress_container = ui.ProgressBarWindow
-
-    def test_init(self):
-        pb_window = ui.ProgressBarWindow()
-        self.assertEqual('Progress', pb_window.props.title)
-        self.assertEqual(
-            Gtk.WindowPosition.CENTER_ALWAYS, pb_window.props.window_position)
-        self.assertIsInstance(pb_window.pb, ui.GtkProgressBar)
-
-
-class ProgressPanelTestCase(ProgressContainerMixin, tests.TestCase):
-
-    progress_container = ui.ProgressPanel
-
-    def test_init(self):
-        pb_window = ui.ProgressPanel()
-        self.assertEqual(
-            Gtk.Orientation.HORIZONTAL, pb_window.props.orientation)
-        self.assertEqual(5, pb_window.props.spacing)
-        self.assertIsInstance(pb_window.pb, ui.GtkProgressBar)
-        widgets = pb_window.get_children()
-        # The image's stock and icon_name properties are always None?
-        self.assertIsInstance(widgets[0], Gtk.Image)
-
-
-class GtkUIFactoryTestCase(tests.TestCase):
-
-    def test__init(self):
-        ui_factory = ui.GtkUIFactory()
-        self.assertIs(None, ui_factory._progress_bar_widget)
-
-    def test_set_progress_bar_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        progress_widget = ui.ProgressPanel()
-        ui_factory.set_progress_bar_widget(progress_widget)
-        self.assertIs(progress_widget, ui_factory._progress_bar_widget)
-
-    def test_get_boolean_true(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.PromptDialog, 'run', Gtk.ResponseType.YES)
-        boolean_value = ui_factory.get_boolean('test')
-        self.assertIs(True, ui.PromptDialog.run.called)
-        self.assertIs(True, boolean_value)
-
-    def test_get_boolean_false(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.PromptDialog, 'run', Gtk.ResponseType.NO)
-        boolean_value = ui_factory.get_boolean('test')
-        self.assertIs(True, ui.PromptDialog.run.called)
-        self.assertIs(False, boolean_value)
-
-    def test_show_message(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.InfoDialog, 'run', Gtk.ResponseType.CLOSE)
-        ui_factory.show_message('test')
-        self.assertIs(True, ui.InfoDialog.run.called)
-
-    def test_show_warning(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.WarningDialog, 'run', Gtk.ResponseType.CLOSE)
-        ui_factory.show_warning('test')
-        self.assertIs(True, ui.WarningDialog.run.called)
-
-    def test_show_Error(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.ErrorDialog, 'run', Gtk.ResponseType.CLOSE)
-        ui_factory.show_error('test')
-        self.assertIs(True, ui.ErrorDialog.run.called)
-
-    def test_show_user_warning(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.WarningDialog, 'run', Gtk.ResponseType.CLOSE)
-        ui_factory.show_user_warning(
-            'recommend_upgrade', current_format_name='1.0', basedir='./test')
-        self.assertIs(True, ui.WarningDialog.run.called)
-
-    def test_show_user_warning_supressed(self):
-        ui_factory = ui.GtkUIFactory()
-        ui_factory.suppressed_warnings.add('recommend_upgrade')
-        MockMethod.bind(self, ui.WarningDialog, 'run', Gtk.ResponseType.CLOSE)
-        ui_factory.show_user_warning(
-            'recommend_upgrade', current_format_name='1.0', basedir='./test')
-        self.assertIs(False, ui.WarningDialog.run.called)
-
-    def test_get_password(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.PasswordDialog, 'run', Gtk.ResponseType.OK)
-        mock_property = MockProperty.bind(
-            self, ui.PasswordDialog, 'passwd', 'secret')
-        password = ui_factory.get_password('test')
-        self.assertIs(True, ui.PasswordDialog.run.called)
-        self.assertIs(True, mock_property.called)
-        self.assertEqual('secret', password)
-
-    def test_progress_all_finished_with_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        progress_widget = ui.ProgressPanel()
-        MockMethod.bind(self, progress_widget, 'finished')
-        ui_factory.set_progress_bar_widget(progress_widget)
-        self.assertIs(None, ui_factory._progress_all_finished())
-        self.assertIs(True, progress_widget.finished.called)
-
-    def test_progress_all_finished_without_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        self.assertIs(None, ui_factory._progress_all_finished())
-
-    def test_progress_updated_with_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        progress_widget = ui.ProgressPanel()
-        MockMethod.bind(self, progress_widget, 'update')
-        ui_factory.set_progress_bar_widget(progress_widget)
-        task = ProgressTask()
-        task.msg = 'test'
-        task.current_cnt = 1
-        task.total_cnt = 2
-        self.assertIs(None, ui_factory._progress_updated(task))
-        self.assertIs(True, progress_widget.update.called)
-        self.assertEqual(
-            ('test', 1, 2), progress_widget.update.args)
-
-    def test_progress_updated_without_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.ProgressBarWindow, 'update')
-        task = ProgressTask()
-        task.msg = 'test'
-        task.current_cnt = 1
-        task.total_cnt = 2
-        self.assertIs(None, ui_factory._progress_updated(task))
-        self.assertIsInstance(
-            ui_factory._progress_bar_widget, ui.ProgressBarWindow)
-        self.assertIs(True, ui_factory._progress_bar_widget.update.called)
-        self.assertEqual(
-            ('test', 1, 2), ui_factory._progress_bar_widget.update.args)
-
-    def test_report_transport_activity_with_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        progress_widget = ui.ProgressPanel()
-        MockMethod.bind(self, progress_widget, 'tick')
-        ui_factory.set_progress_bar_widget(progress_widget)
-        self.assertIs(
-            None, ui_factory.report_transport_activity(None, None, None))
-        self.assertIs(True, progress_widget.tick.called)
-
-    def test_report_transport_activity_without_widget(self):
-        ui_factory = ui.GtkUIFactory()
-        MockMethod.bind(self, ui.ProgressBarWindow, 'tick')
-        self.assertIs(
-            None, ui_factory.report_transport_activity(None, None, None))
-        self.assertIsInstance(
-            ui_factory._progress_bar_widget, ui.ProgressBarWindow)
-        self.assertIs(True, ui.ProgressBarWindow.tick.called)

=== modified file 'ui.py'
--- ui.py	2012-02-27 21:07:38 +0000
+++ ui.py	2011-08-27 18:03:04 +0000
@@ -24,61 +24,32 @@
 from bzrlib.ui import UIFactory
 
 
-def main_iteration(function):
-    def with_main_iteration(self, *args, **kwargs):
-        result = function(self, *args, **kwargs)
-        while Gtk.events_pending():
-            Gtk.main_iteration_do(False)
-        return result
-    return with_main_iteration
-
-
-class PromptDialog(Gtk.MessageDialog):
+class PromptDialog(Gtk.Dialog):
     """Prompt the user for a yes/no answer."""
 
-    def __init__(self, prompt, parent=None):
-        super(PromptDialog, self).__init__(
-            parent, Gtk.DialogFlags.DESTROY_WITH_PARENT,
-            Gtk.MessageType.QUESTION, Gtk.ButtonsType.YES_NO, prompt)
-
-
-class InfoDialog(Gtk.MessageDialog):
-    """Show the user an informational message."""
-
-    MESSAGE_TYPE = Gtk.MessageType.INFO
-
-    def __init__(self, prompt, parent=None):
-        super(InfoDialog, self).__init__(
-            parent, Gtk.DialogFlags.DESTROY_WITH_PARENT,
-            self.MESSAGE_TYPE, Gtk.ButtonsType.CLOSE, prompt)
-
-
-class WarningDialog(InfoDialog):
-    """Show the user a warning message."""
-
-    MESSAGE_TYPE = Gtk.MessageType.WARNING
-
-
-class ErrorDialog(InfoDialog):
-    """Show the user a warning message."""
-
-    MESSAGE_TYPE = Gtk.MessageType.ERROR
+    def __init__(self, prompt):
+        Gtk.Dialog.__init__(self)
+
+        label = Gtk.Label(label=prompt)
+        self.vbox.pack_start(label, True, True, 10)
+        self.vbox.show_all()
+
+        self.add_buttons(Gtk.STOCK_YES, Gtk.ResponseType.YES, Gtk.STOCK_NO,
+                         Gtk.ResponseType.NO)
 
 
 class GtkProgressBar(Gtk.ProgressBar):
 
     def __init__(self):
-        super(GtkProgressBar, self).__init__()
+        Gtk.ProgressBar.__init__(self)
         self.set_fraction(0.0)
         self.current = None
         self.total = None
 
-    @main_iteration
     def tick(self):
         self.show()
         self.pulse()
 
-    @main_iteration
     def update(self, msg=None, current_cnt=None, total_cnt=None):
         self.show()
         if current_cnt is not None:
@@ -88,43 +59,21 @@
         if msg is not None:
             self.set_text(msg)
         if None not in (self.current, self.total):
-            fraction = float(self.current) / self.total
-            if fraction < 0.0 or fraction > 1.0:
-                raise ValueError
-            self.set_fraction(fraction)
-
-    @main_iteration
-    def finished(self):
-        self.set_fraction(0.0)
-        self.current = None
-        self.total = None
-        self.hide()
-
-    def clear(self):
-        self.finished()
-
-
-class ProgressContainerMixin:
-    """Expose GtkProgressBar methods to a container class."""
-
-    def tick(self, *args, **kwargs):
-        self.show_all()
-        self.pb.tick(*args, **kwargs)
-
-    def update(self, *args, **kwargs):
-        self.show_all()
-        self.pb.update(*args, **kwargs)
-
-    def finished(self):
-        self.hide()
-        self.pb.finished()
-
-    def clear(self):
-        self.hide()
-        self.pb.clear()
-
-
-class ProgressBarWindow(ProgressContainerMixin, Gtk.Window):
+            self.fraction = float(self.current) / self.total
+            if self.fraction < 0.0 or self.fraction > 1.0:
+                raise AssertionError
+            self.set_fraction(self.fraction)
+        while Gtk.events_pending():
+            Gtk.main_iteration()
+
+    def finished(self):
+        self.hide()
+
+    def clear(self):
+        self.hide()
+
+
+class ProgressBarWindow(Gtk.Window):
 
     def __init__(self):
         super(ProgressBarWindow, self).__init__(type=Gtk.WindowType.TOPLEVEL)
@@ -136,35 +85,69 @@
         self.resize(250, 15)
         self.set_resizable(False)
 
-
-class ProgressPanel(ProgressContainerMixin, Gtk.Box):
+    def tick(self, *args, **kwargs):
+        self.show_all()
+        self.pb.tick(*args, **kwargs)
+
+    def update(self, *args, **kwargs):
+        self.show_all()
+        self.pb.update(*args, **kwargs)
+
+    def finished(self):
+        self.pb.finished()
+        self.hide()
+        self.destroy()
+
+    def clear(self):
+        self.pb.clear()
+        self.hide()
+
+
+class ProgressPanel(Gtk.HBox):
 
     def __init__(self):
-        super(ProgressPanel, self).__init__(Gtk.Orientation.HORIZONTAL, 5)
+        super(ProgressPanel, self).__init__()
         image_loading = Gtk.Image.new_from_stock(Gtk.STOCK_REFRESH,
                                                  Gtk.IconSize.BUTTON)
         image_loading.show()
 
         self.pb = GtkProgressBar()
+        self.set_spacing(5)
         self.set_border_width(5)
         self.pack_start(image_loading, False, False, 0)
         self.pack_start(self.pb, True, True, 0)
 
+    def tick(self, *args, **kwargs):
+        self.show_all()
+        self.pb.tick(*args, **kwargs)
+
+    def update(self, *args, **kwargs):
+        self.show_all()
+        self.pb.update(*args, **kwargs)
+
+    def finished(self):
+        self.pb.finished()
+        self.hide()
+
+    def clear(self):
+        self.pb.clear()
+        self.hide()
+
 
 class PasswordDialog(Gtk.Dialog):
     """ Prompt the user for a password. """
 
     def __init__(self, prompt):
-        super(PasswordDialog, self).__init__()
+        Gtk.Dialog.__init__(self)
 
         label = Gtk.Label(label=prompt)
-        self.get_content_area().pack_start(label, True, True, 10)
+        self.vbox.pack_start(label, True, True, 10)
 
         self.entry = Gtk.Entry()
         self.entry.set_visibility(False)
-        self.get_content_area().pack_end(self.entry, False, False, 10)
+        self.vbox.pack_end(self.entry, padding=10)
 
-        self.get_content_area().show_all()
+        self.vbox.show_all()
 
         self.add_buttons(Gtk.STOCK_OK, Gtk.ResponseType.OK,
                          Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL)
@@ -193,30 +176,6 @@
         dialog.destroy()
         return (response == Gtk.ResponseType.YES)
 
-    def show_message(self, msg):
-        """See UIFactory.show_message."""
-        dialog = InfoDialog(msg)
-        dialog.run()
-        dialog.destroy()
-
-    def show_warning(self, msg):
-        """See UIFactory.show_warning."""
-        dialog = WarningDialog(msg)
-        dialog.run()
-        dialog.destroy()
-
-    def show_error(self, msg):
-        """See UIFactory.show_error."""
-        dialog = ErrorDialog(msg)
-        dialog.run()
-        dialog.destroy()
-
-    def show_user_warning(self, warning_id, **message_args):
-        """See UIFactory.show_user_warning."""
-        if warning_id not in self.suppressed_warnings:
-            message = self.format_user_warning(warning_id, message_args)
-            self.show_warning(message)
-
     def get_password(self, prompt='', **kwargs):
         """Prompt the user for a password.
 
@@ -224,7 +183,7 @@
         :param kwargs: Arguments which will be expanded into the prompt.
                        This lets front ends display different things if
                        they so choose.
-        :return: The password string, return None if the user
+        :return: The password string, return None if the user 
                  canceled the request.
         """
         dialog = PasswordDialog(prompt % kwargs)
@@ -237,24 +196,17 @@
             return None
 
     def _progress_all_finished(self):
-        """See UIFactory._progress_all_finished."""
+        """See UIFactory._progress_all_finished"""
         pbw = self._progress_bar_widget
         if pbw:
             pbw.finished()
 
-    def _ensure_progress_widget(self):
+    def _progress_updated(self, task):
+        """See UIFactory._progress_updated"""
         if self._progress_bar_widget is None:
-            # Default to a window since nobody gave us a better means to report
+            # Default to a window since nobody gave us a better mean to report
             # progress.
             self.set_progress_bar_widget(ProgressBarWindow())
-
-    def _progress_updated(self, task):
-        """See UIFactory._progress_updated."""
-        self._ensure_progress_widget()
         self._progress_bar_widget.update(task.msg,
                                          task.current_cnt, task.total_cnt)
 
-    def report_transport_activity(self, transport, byte_count, direction):
-        """See UIFactory.report_transport_activity."""
-        self._ensure_progress_widget()
-        self._progress_bar_widget.tick()

=== modified file 'viz/branchwin.py'
--- viz/branchwin.py	2012-03-01 21:29:00 +0000
+++ viz/branchwin.py	2011-08-27 20:18:43 +0000
@@ -38,7 +38,7 @@
                        None for no limit.
         """
 
-        super(BranchWindow, self).__init__(parent=parent)
+        Window.__init__(self, parent=parent)
         self.set_border_width(0)
 
         self.branch      = branch
@@ -78,6 +78,9 @@
         self.accel_group = Gtk.AccelGroup()
         self.add_accel_group(self.accel_group)
 
+        if getattr(Gtk.Action, 'set_tool_item_type', None) is not None:
+            Gtk.Action.set_tool_item_type(Gtk.MenuToolButton)
+
         self.prev_rev_action = Gtk.Action("prev-rev", "_Previous Revision", "Go to the previous revision", Gtk.STOCK_GO_DOWN)
         self.prev_rev_action.set_accel_path("<viz>/Go/Previous Revision")
         self.prev_rev_action.set_accel_group(self.accel_group)
@@ -134,9 +137,9 @@
     def construct_paned(self):
         """Construct the main HPaned/VPaned contents."""
         if self.config.get_user_option('viz-vertical') == 'True':
-            self.paned = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
+            self.paned = Gtk.HPaned()
         else:
-            self.paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+            self.paned = Gtk.VPaned()
 
         self.paned.pack1(self.construct_top(), resize=False, shrink=True)
         self.paned.pack2(self.construct_bottom(), resize=True, shrink=False)
@@ -371,9 +374,9 @@
     def construct_bottom(self):
         """Construct the bottom half of the window."""
         if self.config.get_user_option('viz-wide-diffs') == 'True':
-            self.diff_paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
+            self.diff_paned = Gtk.VPaned()
         else:
-            self.diff_paned = Gtk.Paned.new(Gtk.Orientation.HORIZONTAL)
+            self.diff_paned = Gtk.HPaned()
         (width, height) = self.get_size()
         self.diff_paned.set_size_request(20, 20) # shrinkable
 
@@ -429,8 +432,7 @@
                         except KeyError:
                             str = ""
 
-                        item = Gtk.MenuItem(
-                            label=parent.message.split("\n")[0] + str)
+                        item = Gtk.MenuItem(parent.message.split("\n")[0] + str)
                         item.connect('activate', self._set_revision_cb, parent_id)
                         prev_menu.add(item)
                 prev_menu.show_all()
@@ -451,8 +453,7 @@
                     except KeyError:
                         str = ""
 
-                    item = Gtk.MenuItem(
-                        label=child.message.split("\n")[0] + str)
+                    item = Gtk.MenuItem(child.message.split("\n")[0] + str)
                     item.connect('activate', self._set_revision_cb, child_id)
                     next_menu.add(item)
                 next_menu.show_all()
@@ -478,10 +479,7 @@
         else:
             parent_id = parents[0]
 
-        if revision is not None:
-            self.show_diff(revision.revision_id, parent_id)
-        else:
-            self.show_diff(NULL_REVISION)
+        self.show_diff(revision.revision_id, parent_id)
         self.treeview.grab_focus()
 
     def _back_clicked_cb(self, *args):
@@ -545,9 +543,7 @@
         dialog = SearchDialog(index)
 
         if dialog.run() == Gtk.ResponseType.OK:
-            revid = dialog.get_revision()
-            if revid is not None:
-                self.set_revision(revid)
+            self.set_revision(dialog.get_revision())
 
         dialog.destroy()
 
@@ -573,7 +569,7 @@
         old = self.paned
         self.vbox.remove(old)
         self.vbox.pack_start(
-            self.construct_paned(), True, True, 0)
+            self.construct_paned(), True, True, True, 0)
         self._make_diff_paned_nonzero_size()
         self._make_diff_nonzero_size()
 
@@ -657,7 +653,7 @@
             return width, height
         return None
 
-    def show_diff(self, revid, parentid=NULL_REVISION):
+    def show_diff(self, revid=None, parentid=NULL_REVISION):
         """Open a new window to show a diff between the given revisions."""
         from bzrlib.plugins.gtk.diff import DiffWindow
         window = DiffWindow(parent=self)

=== modified file 'window.py'
--- window.py	2011-09-05 03:44:26 +0000
+++ window.py	2011-08-12 19:50:45 +0000
@@ -6,7 +6,7 @@
 class Window(Gtk.Window):
 
     def __init__(self, parent=None):
-        super(Window, self).__init__(type=Gtk.WindowType.TOPLEVEL)
+        Gtk.Window.__init__(self, type=Gtk.WindowType.TOPLEVEL)
         self._parent = parent
 
         self.connect('key-press-event', self._on_key_press)

